/* Generated by Cython 0.23.5 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03020000)
    #error Cython requires Python 2.6+ or Python 3.2+.
#else
#define CYTHON_ABI "0_23_5"
#include <stddef.h>
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if !defined(CYTHON_USE_PYLONG_INTERNALS) && CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x02070000
#define CYTHON_USE_PYLONG_INTERNALS 1
#endif
#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
#define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None)) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if PY_VERSION_HEX >= 0x030500B1
#define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
#define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
#elif CYTHON_COMPILING_IN_CPYTHON && PY_MAJOR_VERSION >= 3
typedef struct {
    unaryfunc am_await;
    unaryfunc am_aiter;
    unaryfunc am_anext;
} __Pyx_PyAsyncMethodsStruct;
#define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
#else
#define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)

#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__pyart__io___rsl_interface
#define __PYX_HAVE_API__pyart__io___rsl_interface
#include "rsl.h"
#include "string.h"
#include "stdio.h"
#include "stdlib.h"
#include "numpy/arrayobject.h"
#include "numpy/ufuncobject.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif

#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
typedef struct {PyObject **p; char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT 0
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER) && defined (_M_X64)
    #define __Pyx_sst_abs(value) _abs64(value)
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyObject_AsSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
#if PY_MAJOR_VERSION < 3
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u)
{
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#else
#define __Pyx_Py_UNICODE_strlen Py_UNICODE_strlen
#endif
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c));
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */

static PyObject *__pyx_m;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "pyart/io/_rsl_interface.pyx",
  "__init__.pxd",
  "pyart/io/stringsource",
  "type.pxd",
};
#define IS_UNSIGNED(type) (((type) -1) > 0)
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name;
  struct __Pyx_StructField_* fields;
  size_t size;
  size_t arraysize[8];
  int ndim;
  char typegroup;
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;


/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":725
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":726
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":727
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":728
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":732
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":733
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":734
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":735
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":739
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":740
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":749
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":750
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":751
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":753
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":754
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":755
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":757
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":758
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":760
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":761
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":762
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;

/* "pyart/io/_rsl_interface.pyx":29
 * # the next line is required so that RSL_F_LIST and RSL_INVF_LIST can be
 * # properly wrapped as Cython does not export the typedef from _rsl_h
 * ctypedef unsigned short Range             # <<<<<<<<<<<<<<
 * import numpy as np
 * cimport numpy as np
 */
typedef unsigned short __pyx_t_5pyart_2io_14_rsl_interface_Range;
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif


/*--- Type declarations ---*/
struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume;
struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay;
struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep;
struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile;
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py;
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":764
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":765
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":766
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":768
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
struct __pyx_opt_args_5pyart_2io_14_rsl_interface_create_volume;

/* "pyart/io/_rsl_interface.pyx":63
 * 
 * cpdef create_volume(
 *         np.ndarray[np.float32_t, ndim=2] arr,             # <<<<<<<<<<<<<<
 *         np.ndarray[np.int32_t, ndim=1] rays_per_sweep,
 *         int vol_num=1):
 */
struct __pyx_opt_args_5pyart_2io_14_rsl_interface_create_volume {
  int __pyx_n;
  int vol_num;
};

/* "pyart/io/_rsl_interface.pxd":6
 * cimport _rsl_h
 * 
 * cdef class _RslVolume:             # <<<<<<<<<<<<<<
 *     cdef _rsl_h.Volume * _Volume
 *     cdef int _dealloc
 */
struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume *__pyx_vtab;
  Volume *_Volume;
  int _dealloc;
};


/* "pyart/io/_rsl_interface.pyx":209
 * 
 * 
 * cdef class _RslRay:             # <<<<<<<<<<<<<<
 *     """
 *     A object for accessing RSL Ray data and header information
 */
struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslRay *__pyx_vtab;
  Ray *_Ray;
  int _dealloc;
};


/* "pyart/io/_rsl_interface.pyx":629
 * 
 * 
 * cdef class _RslSweep:             # <<<<<<<<<<<<<<
 *     """
 *     A object for accessing RSL Sweep data and header information.
 */
struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslSweep *__pyx_vtab;
  Sweep *_Sweep;
  int _dealloc;
};


/* "pyart/io/_rsl_interface.pyx":1077
 * 
 * 
 * cdef class RslFile:             # <<<<<<<<<<<<<<
 *     """
 *     RslFile(filename)
 */
struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile {
  PyObject_HEAD
  Radar *_Radar;
  Volume *_Volume;
  Sweep *_Sweep;
  Ray *_Ray;
};


/* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_float____Range___to_py")
 * cdef object __Pyx_CFunc_float____Range___to_py(float (*f)(Range) except *):             # <<<<<<<<<<<<<<
 *     def wrap(Range x):
 *         """wrap(x: 'Range') -> 'float'"""
 */
struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py {
  PyObject_HEAD
  float (*__pyx_v_f)(__pyx_t_5pyart_2io_14_rsl_interface_Range);
};

struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py {
  PyObject_HEAD
  __pyx_t_5pyart_2io_14_rsl_interface_Range (*__pyx_v_f)(float);
};



/* "pyart/io/_rsl_interface.pyx":771
 * 
 * 
 * cdef class _RslVolume:             # <<<<<<<<<<<<<<
 *     """
 *     A object for accessing RSL Volume data and header information.
 */

struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume {
  PyObject *(*load)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *, Volume *);
  PyObject *(*_prtmode)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *, Ray_header);
};
static struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume *__pyx_vtabptr_5pyart_2io_14_rsl_interface__RslVolume;


/* "pyart/io/_rsl_interface.pyx":209
 * 
 * 
 * cdef class _RslRay:             # <<<<<<<<<<<<<<
 *     """
 *     A object for accessing RSL Ray data and header information
 */

struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslRay {
  PyObject *(*load)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *, Ray *);
};
static struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslRay *__pyx_vtabptr_5pyart_2io_14_rsl_interface__RslRay;


/* "pyart/io/_rsl_interface.pyx":629
 * 
 * 
 * cdef class _RslSweep:             # <<<<<<<<<<<<<<
 *     """
 *     A object for accessing RSL Sweep data and header information.
 */

struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslSweep {
  PyObject *(*load)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *, Sweep *);
};
static struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslSweep *__pyx_vtabptr_5pyart_2io_14_rsl_interface__RslSweep;

/* --- Runtime support code (head) --- */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name);

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

static CYTHON_INLINE int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact);

static CYTHON_INLINE int  __Pyx_GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);

static void __Pyx_RaiseBufferIndexError(int axis);

#define __Pyx_BufPtrStrided1d(type, buf, i0, s0) (type)((char*)buf + i0 * s0)
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb);

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

static double __Pyx__PyObject_AsDouble(PyObject* obj);
#if CYTHON_COMPILING_IN_PYPY
#define __Pyx_PyObject_AsDouble(obj)\
(likely(PyFloat_CheckExact(obj)) ? PyFloat_AS_DOUBLE(obj) :\
 likely(PyInt_CheckExact(obj)) ?\
 PyFloat_AsDouble(obj) : __Pyx__PyObject_AsDouble(obj))
#else
#define __Pyx_PyObject_AsDouble(obj)\
((likely(PyFloat_CheckExact(obj))) ?\
 PyFloat_AS_DOUBLE(obj) : __Pyx__PyObject_AsDouble(obj))
#endif

#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void);

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected);

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, long intval, int inplace);
#else
#define __Pyx_PyInt_EqObjC(op1, op2, intval, inplace)\
    PyObject_RichCompare(op1, op2, Py_EQ)
    #endif

#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyObject_DelAttrStr(o,n) __Pyx_PyObject_SetAttrStr(o,n,NULL)
static CYTHON_INLINE int __Pyx_PyObject_SetAttrStr(PyObject* obj, PyObject* attr_name, PyObject* value) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_setattro))
        return tp->tp_setattro(obj, attr_name, value);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_setattr))
        return tp->tp_setattr(obj, PyString_AS_STRING(attr_name), value);
#endif
    return PyObject_SetAttr(obj, attr_name, value);
}
#else
#define __Pyx_PyObject_DelAttrStr(o,n)   PyObject_DelAttr(o,n)
#define __Pyx_PyObject_SetAttrStr(o,n,v) PyObject_SetAttr(o,n,v)
#endif

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name);

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx_PyFloat_AddObjC(PyObject *op1, PyObject *op2, double floatval, int inplace);
#else
#define __Pyx_PyFloat_AddObjC(op1, op2, floatval, inplace)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

static void __Pyx_RaiseBufferFallbackError(void);

#define __Pyx_BufPtrStrided2d(type, buf, i0, s0, i1, s1) (type)((char*)buf + i0 * s0 + i1 * s1)
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

#include <string.h>

static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyString_Equals __Pyx_PyUnicode_Equals
#else
#define __Pyx_PyString_Equals __Pyx_PyBytes_Equals
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

#if PY_MAJOR_VERSION >= 3 && !CYTHON_COMPILING_IN_PYPY
static PyObject *__Pyx_PyDict_GetItem(PyObject *d, PyObject* key) {
    PyObject *value;
    value = PyDict_GetItemWithError(d, key);
    if (unlikely(!value)) {
        if (!PyErr_Occurred()) {
            PyObject* args = PyTuple_Pack(1, key);
            if (likely(args))
                PyErr_SetObject(PyExc_KeyError, args);
            Py_XDECREF(args);
        }
        return NULL;
    }
    Py_INCREF(value);
    return value;
}
#else
    #define __Pyx_PyDict_GetItem(d, key) PyObject_GetItem(d, key)
#endif

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type);

#define __Pyx_CyFunction_USED 1
#include <structmember.h>
#define __Pyx_CYFUNCTION_STATICMETHOD  0x01
#define __Pyx_CYFUNCTION_CLASSMETHOD   0x02
#define __Pyx_CYFUNCTION_CCLASS        0x04
#define __Pyx_CyFunction_GetClosure(f)\
    (((__pyx_CyFunctionObject *) (f))->func_closure)
#define __Pyx_CyFunction_GetClassObj(f)\
    (((__pyx_CyFunctionObject *) (f))->func_classobj)
#define __Pyx_CyFunction_Defaults(type, f)\
    ((type *)(((__pyx_CyFunctionObject *) (f))->defaults))
#define __Pyx_CyFunction_SetDefaultsGetter(f, g)\
    ((__pyx_CyFunctionObject *) (f))->defaults_getter = (g)
typedef struct {
    PyCFunctionObject func;
#if PY_VERSION_HEX < 0x030500A0
    PyObject *func_weakreflist;
#endif
    PyObject *func_dict;
    PyObject *func_name;
    PyObject *func_qualname;
    PyObject *func_doc;
    PyObject *func_globals;
    PyObject *func_code;
    PyObject *func_closure;
    PyObject *func_classobj;
    void *defaults;
    int defaults_pyobjects;
    int flags;
    PyObject *defaults_tuple;
    PyObject *defaults_kwdict;
    PyObject *(*defaults_getter)(PyObject *);
    PyObject *func_annotations;
} __pyx_CyFunctionObject;
static PyTypeObject *__pyx_CyFunctionType = 0;
#define __Pyx_CyFunction_NewEx(ml, flags, qualname, self, module, globals, code)\
    __Pyx_CyFunction_New(__pyx_CyFunctionType, ml, flags, qualname, self, module, globals, code)
static PyObject *__Pyx_CyFunction_New(PyTypeObject *, PyMethodDef *ml,
                                      int flags, PyObject* qualname,
                                      PyObject *self,
                                      PyObject *module, PyObject *globals,
                                      PyObject* code);
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *m,
                                                         size_t size,
                                                         int pyobjects);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *m,
                                                            PyObject *tuple);
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *m,
                                                             PyObject *dict);
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *m,
                                                              PyObject *dict);
static int __pyx_CyFunction_init(void);

static int __Pyx_SetVtable(PyObject *dict, void *vtable);

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


static Py_ssize_t __Pyx_zeros[] = {0, 0, 0, 0, 0, 0, 0, 0};
static Py_ssize_t __Pyx_minusones[] = {-1, -1, -1, -1, -1, -1, -1, -1};

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

static CYTHON_INLINE Range __Pyx_PyInt_As_Range(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_Range(Range value);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_Py_intptr_t(Py_intptr_t value);

static CYTHON_INLINE Py_intptr_t __Pyx_PyInt_As_Py_intptr_t(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

static PyObject* __pyx_convert__to_py_Radar_header(Radar_header s);
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if (defined(_WIN32) || defined(__clang__)) && defined(__cplusplus) && CYTHON_CCOMPLEX
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eqf(a, b)   ((a)==(b))
    #define __Pyx_c_sumf(a, b)  ((a)+(b))
    #define __Pyx_c_difff(a, b) ((a)-(b))
    #define __Pyx_c_prodf(a, b) ((a)*(b))
    #define __Pyx_c_quotf(a, b) ((a)/(b))
    #define __Pyx_c_negf(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zerof(z) ((z)==(float)0)
    #define __Pyx_c_conjf(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_absf(z)     (::std::abs(z))
        #define __Pyx_c_powf(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zerof(z) ((z)==0)
    #define __Pyx_c_conjf(z)    (conjf(z))
    #if 1
        #define __Pyx_c_absf(z)     (cabsf(z))
        #define __Pyx_c_powf(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq(a, b)   ((a)==(b))
    #define __Pyx_c_sum(a, b)  ((a)+(b))
    #define __Pyx_c_diff(a, b) ((a)-(b))
    #define __Pyx_c_prod(a, b) ((a)*(b))
    #define __Pyx_c_quot(a, b) ((a)/(b))
    #define __Pyx_c_neg(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero(z) ((z)==(double)0)
    #define __Pyx_c_conj(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (::std::abs(z))
        #define __Pyx_c_pow(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero(z) ((z)==0)
    #define __Pyx_c_conj(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (cabs(z))
        #define __Pyx_c_pow(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value);

static CYTHON_INLINE unsigned short __Pyx_PyInt_As_unsigned_short(PyObject *);

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_short(unsigned short value);

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

static int __Pyx_check_binary_version(void);

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name);

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_7_RslRay_load(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, Ray *__pyx_v_Ray); /* proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_9_RslSweep_load(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, Sweep *__pyx_v_Sweep); /* proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_10_RslVolume_load(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, Volume *__pyx_v_Volume); /* proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_10_RslVolume__prtmode(CYTHON_UNUSED struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, Ray_header __pyx_v_h); /* proto*/

/* Module declarations from 'pyart.io._rsl_h' */

/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'libc.string' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'cpython' */

/* Module declarations from 'cpython.object' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;
static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *, char *, char *, int *); /*proto*/

/* Module declarations from 'pyart.io._rsl_interface' */
static PyTypeObject *__pyx_ptype_5pyart_2io_14_rsl_interface__RslVolume = 0;
static PyTypeObject *__pyx_ptype_5pyart_2io_14_rsl_interface__RslRay = 0;
static PyTypeObject *__pyx_ptype_5pyart_2io_14_rsl_interface__RslSweep = 0;
static PyTypeObject *__pyx_ptype_5pyart_2io_14_rsl_interface_RslFile = 0;
static PyTypeObject *__pyx_ptype___pyx_scope_struct____Pyx_CFunc_float____Range___to_py = 0;
static PyTypeObject *__pyx_ptype___pyx_scope_struct____Pyx_CFunc_Range____float___to_py = 0;
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_copy_volume(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_create_volume(PyArrayObject *, PyArrayObject *, int __pyx_skip_dispatch, struct __pyx_opt_args_5pyart_2io_14_rsl_interface_create_volume *__pyx_optional_args); /*proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface__label_volume(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *, PyObject *, int __pyx_skip_dispatch); /*proto*/
static PyObject *__Pyx_CFunc_float____Range___to_py(float (*)(__pyx_t_5pyart_2io_14_rsl_interface_Range)); /*proto*/
static PyObject *__Pyx_CFunc_Range____float___to_py(__pyx_t_5pyart_2io_14_rsl_interface_Range (*)(float)); /*proto*/
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t = { "float32_t", NULL, sizeof(__pyx_t_5numpy_float32_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t = { "int32_t", NULL, sizeof(__pyx_t_5numpy_int32_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_int32_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_int32_t), 0 };
#define __Pyx_MODULE_NAME "pyart.io._rsl_interface"
int __pyx_module_is_main_pyart__io___rsl_interface = 0;

/* Implementation of 'pyart.io._rsl_interface' */
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_IOError;
static PyObject *__pyx_builtin_RuntimeError;
static char __pyx_k_B[] = "B";
static char __pyx_k_H[] = "H";
static char __pyx_k_I[] = "I";
static char __pyx_k_L[] = "L";
static char __pyx_k_O[] = "O";
static char __pyx_k_Q[] = "Q";
static char __pyx_k_b[] = "b";
static char __pyx_k_d[] = "d";
static char __pyx_k_f[] = "f";
static char __pyx_k_g[] = "g";
static char __pyx_k_h[] = "h";
static char __pyx_k_i[] = "i";
static char __pyx_k_l[] = "l";
static char __pyx_k_q[] = "q";
static char __pyx_k_x[] = "x";
static char __pyx_k_Zd[] = "Zd";
static char __pyx_k_Zf[] = "Zf";
static char __pyx_k_Zg[] = "Zg";
static char __pyx_k_np[] = "np";
static char __pyx_k_S24[] = "|S24";
static char __pyx_k_arr[] = "arr";
static char __pyx_k_day[] = "day";
static char __pyx_k_sec[] = "sec";
static char __pyx_k_sum[] = "sum";
static char __pyx_k_vcp[] = "vcp";
static char __pyx_k_city[] = "city";
static char __pyx_k_data[] = "data";
static char __pyx_k_dual[] = "dual                    ";
static char __pyx_k_hour[] = "hour";
static char __pyx_k_latd[] = "latd";
static char __pyx_k_latm[] = "latm";
static char __pyx_k_lats[] = "lats";
static char __pyx_k_lond[] = "lond";
static char __pyx_k_lonm[] = "lonm";
static char __pyx_k_lons[] = "lons";
static char __pyx_k_main[] = "__main__";
static char __pyx_k_name[] = "name";
static char __pyx_k_test[] = "__test__";
static char __pyx_k_wrap[] = "wrap";
static char __pyx_k_year[] = "year";
static char __pyx_k_dtype[] = "dtype";
static char __pyx_k_empty[] = "empty";
static char __pyx_k_fixed[] = "fixed                   ";
static char __pyx_k_int32[] = "int32";
static char __pyx_k_month[] = "month";
static char __pyx_k_numpy[] = "numpy";
static char __pyx_k_radar[] = "radar";
static char __pyx_k_range[] = "range";
static char __pyx_k_shape[] = "shape";
static char __pyx_k_state[] = "state";
static char __pyx_k_zeros[] = "zeros";
static char __pyx_k_callid[] = "callid";
static char __pyx_k_height[] = "height";
static char __pyx_k_import[] = "__import__";
static char __pyx_k_lpulse[] = "lpulse";
static char __pyx_k_minute[] = "minute";
static char __pyx_k_number[] = "number";
static char __pyx_k_spulse[] = "spulse";
static char __pyx_k_volume[] = "volume";
static char __pyx_k_wsr88d[] = "wsr88d";
static char __pyx_k_IOError[] = "IOError";
static char __pyx_k_azimuth[] = "azimuth";
static char __pyx_k_country[] = "country";
static char __pyx_k_float32[] = "float32";
static char __pyx_k_nsweeps[] = "nsweeps";
static char __pyx_k_project[] = "project";
static char __pyx_k_seconds[] = "seconds";
static char __pyx_k_vol_num[] = "vol_num";
static char __pyx_k_altitude[] = "altitude";
static char __pyx_k_datetime[] = "datetime";
static char __pyx_k_filename[] = "filename";
static char __pyx_k_get_data[] = "get_data";
static char __pyx_k_nvolumes[] = "nvolumes";
static char __pyx_k_elevation[] = "elevation";
static char __pyx_k_scan_mode[] = "scan_mode";
static char __pyx_k_timedelta[] = "timedelta";
static char __pyx_k_ValueError[] = "ValueError";
static char __pyx_k_get_volume[] = "get_volume";
static char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static char __pyx_k_radar_name[] = "radar_name";
static char __pyx_k_radar_type[] = "radar_type";
static char __pyx_k_total_rays[] = "total_rays";
static char __pyx_k_cfunc_to_py[] = "cfunc.to_py";
static char __pyx_k_RuntimeError[] = "RuntimeError";
static char __pyx_k_radar_format[] = "radar_format";
static char __pyx_k_stringsource[] = "stringsource";
static char __pyx_k_get_nray_array[] = "get_nray_array";
static char __pyx_k_rays_per_sweep[] = "rays_per_sweep";
static char __pyx_k_RSL_VERSION_STR[] = "_RSL_VERSION_STR";
static char __pyx_k_nyquist_velocity[] = "nyquist_velocity";
static char __pyx_k_invalid_ray_number[] = "invalid ray_number";
static char __pyx_k_file_cannot_be_read[] = "file cannot be read.";
static char __pyx_k_invalid_radar_format[] = "invalid radar_format:";
static char __pyx_k_invalid_sweep_number[] = "invalid sweep_number";
static char __pyx_k_meters_between_gates[] = "meters_between_gates";
static char __pyx_k_instrument_parameters[] = "instrument_parameters";
static char __pyx_k_invalid_volume_number[] = "invalid volume_number";
static char __pyx_k_callid_must_be_provided[] = "callid must be provided.";
static char __pyx_k_ndarray_is_not_C_contiguous[] = "ndarray is not C contiguous";
static char __pyx_k_Pyx_CFunc_Range____float___to[] = "__Pyx_CFunc_Range____float___to_py.<locals>.wrap";
static char __pyx_k_Pyx_CFunc_float____Range___to[] = "__Pyx_CFunc_float____Range___to_py.<locals>.wrap";
static char __pyx_k_cannot_load__RslRay_with_NULL[] = "cannot load _RslRay with NULL";
static char __pyx_k_meters_to_center_of_first_gate[] = "meters_to_center_of_first_gate";
static char __pyx_k_pyart_io__rsl_interface_Cython[] = "\npyart.io._rsl_interface\n=======================\n\nCython wrapper around the NASA TRMM RSL library.\n\n.. autosummary::\n    :toctree: generated/\n\n    copy_volume\n    create_volume\n    _label_volume\n\n.. autosummary::\n    :toctree: generated/\n    :template: dev_template.rst\n\n    RslFile\n    _RslVolume\n    _RslSweep\n    _RslRay\n\n\n";
static char __pyx_k_cannot_load__RslSweep_with_NULL[] = "cannot load _RslSweep with NULL";
static char __pyx_k_unknown_dtype_code_in_numpy_pxd[] = "unknown dtype code in numpy.pxd (%d)";
static char __pyx_k_Format_string_allocated_too_shor[] = "Format string allocated too short, see comment in numpy.pxd";
static char __pyx_k_Non_native_byte_order_not_suppor[] = "Non-native byte order not supported";
static char __pyx_k_cannot_load__RslVolume_with_NULL[] = "cannot load _RslVolume with NULL";
static char __pyx_k_ndarray_is_not_Fortran_contiguou[] = "ndarray is not Fortran contiguous";
static char __pyx_k_Format_string_allocated_too_shor_2[] = "Format string allocated too short.";
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor;
static PyObject *__pyx_kp_u_Format_string_allocated_too_shor_2;
static PyObject *__pyx_n_s_IOError;
static PyObject *__pyx_kp_u_Non_native_byte_order_not_suppor;
static PyObject *__pyx_n_s_Pyx_CFunc_Range____float___to;
static PyObject *__pyx_n_s_Pyx_CFunc_float____Range___to;
static PyObject *__pyx_n_s_RSL_VERSION_STR;
static PyObject *__pyx_n_s_RuntimeError;
static PyObject *__pyx_kp_s_S24;
static PyObject *__pyx_n_s_ValueError;
static PyObject *__pyx_n_s_altitude;
static PyObject *__pyx_n_s_arr;
static PyObject *__pyx_n_s_azimuth;
static PyObject *__pyx_n_s_callid;
static PyObject *__pyx_kp_s_callid_must_be_provided;
static PyObject *__pyx_kp_s_cannot_load__RslRay_with_NULL;
static PyObject *__pyx_kp_s_cannot_load__RslSweep_with_NULL;
static PyObject *__pyx_kp_s_cannot_load__RslVolume_with_NULL;
static PyObject *__pyx_n_s_cfunc_to_py;
static PyObject *__pyx_n_s_city;
static PyObject *__pyx_n_s_country;
static PyObject *__pyx_n_s_data;
static PyObject *__pyx_n_s_datetime;
static PyObject *__pyx_n_s_day;
static PyObject *__pyx_n_s_dtype;
static PyObject *__pyx_kp_s_dual;
static PyObject *__pyx_n_s_elevation;
static PyObject *__pyx_n_s_empty;
static PyObject *__pyx_kp_s_file_cannot_be_read;
static PyObject *__pyx_n_s_filename;
static PyObject *__pyx_kp_s_fixed;
static PyObject *__pyx_n_s_float32;
static PyObject *__pyx_n_s_get_data;
static PyObject *__pyx_n_s_get_nray_array;
static PyObject *__pyx_n_s_get_volume;
static PyObject *__pyx_n_s_height;
static PyObject *__pyx_n_s_hour;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_n_s_instrument_parameters;
static PyObject *__pyx_n_s_int32;
static PyObject *__pyx_kp_s_invalid_radar_format;
static PyObject *__pyx_kp_s_invalid_ray_number;
static PyObject *__pyx_kp_s_invalid_sweep_number;
static PyObject *__pyx_kp_s_invalid_volume_number;
static PyObject *__pyx_n_s_latd;
static PyObject *__pyx_n_s_latm;
static PyObject *__pyx_n_s_lats;
static PyObject *__pyx_n_s_lond;
static PyObject *__pyx_n_s_lonm;
static PyObject *__pyx_n_s_lons;
static PyObject *__pyx_n_s_lpulse;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_n_s_meters_between_gates;
static PyObject *__pyx_n_s_meters_to_center_of_first_gate;
static PyObject *__pyx_n_s_minute;
static PyObject *__pyx_n_s_month;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_kp_u_ndarray_is_not_C_contiguous;
static PyObject *__pyx_kp_u_ndarray_is_not_Fortran_contiguou;
static PyObject *__pyx_n_s_np;
static PyObject *__pyx_n_s_nsweeps;
static PyObject *__pyx_n_s_number;
static PyObject *__pyx_n_s_numpy;
static PyObject *__pyx_n_s_nvolumes;
static PyObject *__pyx_n_s_nyquist_velocity;
static PyObject *__pyx_n_s_project;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_radar;
static PyObject *__pyx_n_s_radar_format;
static PyObject *__pyx_n_s_radar_name;
static PyObject *__pyx_n_s_radar_type;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_n_s_rays_per_sweep;
static PyObject *__pyx_n_s_scan_mode;
static PyObject *__pyx_n_s_sec;
static PyObject *__pyx_n_s_seconds;
static PyObject *__pyx_n_s_shape;
static PyObject *__pyx_n_s_spulse;
static PyObject *__pyx_n_s_state;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_sum;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_timedelta;
static PyObject *__pyx_n_s_total_rays;
static PyObject *__pyx_kp_u_unknown_dtype_code_in_numpy_pxd;
static PyObject *__pyx_n_s_vcp;
static PyObject *__pyx_n_s_vol_num;
static PyObject *__pyx_n_s_volume;
static PyObject *__pyx_n_s_wrap;
static PyObject *__pyx_n_s_wsr88d;
static PyObject *__pyx_n_s_x;
static PyObject *__pyx_n_s_year;
static PyObject *__pyx_n_s_zeros;
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_copy_volume(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_volume); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_2create_volume(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_rays_per_sweep, int __pyx_v_vol_num); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_4_label_volume(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_volume, PyObject *__pyx_v_radar); /* proto */
static void __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay___dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_2get_datetime(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4get_data(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5month___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5month_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_month); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3day___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3day_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_day); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4year___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4year_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_year); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4hour___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4hour_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_hour); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6minute___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6minute_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_minute); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3sec___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3sec_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_sec); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_unam_rng); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_azimuth); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_ray_num); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4elev___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4elev_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_elev); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_elev_num); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_range_bin1); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_gate_size); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_res); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_sweep_rate); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3prf___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3prf_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_prf); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4prf2___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_prf2); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_azim_rate); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_fix_angle); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5pitch___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_pitch); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4roll___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4roll_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_roll); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7heading___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7heading_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_heading); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_pitch_rate); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_roll_rate); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_heading_rate); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lat___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lat_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_lat); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lon___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lon_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_lon); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3alt___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3alt_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_alt); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3rvc___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_rvc); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_east); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_north); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_up); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_pulse_count); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_pulse_width); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_beam_width); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9frequency___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_frequency); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_wavelength); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_nyq_vel); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5nbins___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_nbins); /* proto */
static void __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep___dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_2get_ray(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, int __pyx_v_ray_number); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4get_data(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, int __pyx_v_sweep_num); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4elev___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_elev); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_azimuth); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_beam_width); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_vert_half_bw); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_horz_half_bw); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, int __pyx_v_nrays); /* proto */
static void __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume___dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_2total_rays(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_4get_nray_array(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_6get_sweep(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, int __pyx_v_sweep_number); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_8get_azimuth_and_elev_array(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_10get_sweep_fix_angles(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12get_sweep_azimuths(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_14get_sweep_elevs(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_16get_instr_params(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_18get_data(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_20is_range_bins_uniform(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, int __pyx_v_nsweeps); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, float __pyx_v_calibr_const); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile___cinit__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, PyObject *__pyx_v_filename, PyObject *__pyx_v_radar_format, PyObject *__pyx_v_callid); /* proto */
static void __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_2__dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4get_volume(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_volume_number); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6available_moments(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8get_radar_header(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_10get_volume_array(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_volume_num); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_5month___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_5month_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_month); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3day___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3day_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_day); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4year___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4year_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_year); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4hour___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4hour_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_hour); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6minute___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6minute_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_minute); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3sec___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3sec_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, float __pyx_v_sec); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_nvolumes); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6number___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6number_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_number); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latd___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latd_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_latd); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latm___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latm_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_latm); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lats___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lats_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lats); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lond___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lond_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lond); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lonm___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lonm_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lonm); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lons___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lons_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lons); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6height___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6height_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_height); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6spulse___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6spulse_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_spulse); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6lpulse___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lpulse); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_scan_mode); /* proto */
static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3vcp___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3vcp_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_vcp); /* proto */
static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static PyObject *__pyx_pf_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_wrap(PyObject *__pyx_self, __pyx_t_5pyart_2io_14_rsl_interface_Range __pyx_v_x); /* proto */
static PyObject *__pyx_pf_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_wrap(PyObject *__pyx_self, float __pyx_v_x); /* proto */
static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface__RslVolume(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface__RslRay(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface__RslSweep(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface_RslFile(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_float____Range___to_py(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_Range____float___to_py(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_float_0_1;
static PyObject *__pyx_float_1e6;
static PyObject *__pyx_float_1_31072000e_05;
static PyObject *__pyx_float_neg_999_;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_23;
static PyObject *__pyx_int_24;
static PyObject *__pyx_tuple_;
static PyObject *__pyx_tuple__2;
static PyObject *__pyx_tuple__3;
static PyObject *__pyx_tuple__4;
static PyObject *__pyx_tuple__5;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_tuple__7;
static PyObject *__pyx_tuple__8;
static PyObject *__pyx_tuple__9;
static PyObject *__pyx_tuple__10;
static PyObject *__pyx_tuple__11;
static PyObject *__pyx_tuple__12;
static PyObject *__pyx_tuple__13;
static PyObject *__pyx_tuple__14;
static PyObject *__pyx_tuple__15;
static PyObject *__pyx_tuple__17;
static PyObject *__pyx_codeobj__16;
static PyObject *__pyx_codeobj__18;

/* "pyart/io/_rsl_interface.pyx":38
 * 
 * 
 * cpdef copy_volume(_RslVolume volume):             # <<<<<<<<<<<<<<
 *     """
 *     copy_volume(volume)
 */

static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_1copy_volume(PyObject *__pyx_self, PyObject *__pyx_v_volume); /*proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_copy_volume(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_volume, CYTHON_UNUSED int __pyx_skip_dispatch) {
  Volume *__pyx_v_volume_copy;
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_rslvolume = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_volume", 0);

  /* "pyart/io/_rsl_interface.pyx":55
 * 
 *     """
 *     volume_copy = _rsl_h.RSL_copy_volume(volume._Volume)             # <<<<<<<<<<<<<<
 *     rslvolume = _RslVolume()
 *     rslvolume.load(volume_copy)
 */
  __pyx_v_volume_copy = RSL_copy_volume(__pyx_v_volume->_Volume);

  /* "pyart/io/_rsl_interface.pyx":56
 *     """
 *     volume_copy = _rsl_h.RSL_copy_volume(volume._Volume)
 *     rslvolume = _RslVolume()             # <<<<<<<<<<<<<<
 *     rslvolume.load(volume_copy)
 *     rslvolume._dealloc = 1
 */
  __pyx_t_1 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_5pyart_2io_14_rsl_interface__RslVolume), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 56; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_rslvolume = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":57
 *     volume_copy = _rsl_h.RSL_copy_volume(volume._Volume)
 *     rslvolume = _RslVolume()
 *     rslvolume.load(volume_copy)             # <<<<<<<<<<<<<<
 *     rslvolume._dealloc = 1
 *     return rslvolume
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_rslvolume->__pyx_vtab)->load(__pyx_v_rslvolume, __pyx_v_volume_copy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 57; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":58
 *     rslvolume = _RslVolume()
 *     rslvolume.load(volume_copy)
 *     rslvolume._dealloc = 1             # <<<<<<<<<<<<<<
 *     return rslvolume
 * 
 */
  __pyx_v_rslvolume->_dealloc = 1;

  /* "pyart/io/_rsl_interface.pyx":59
 *     rslvolume.load(volume_copy)
 *     rslvolume._dealloc = 1
 *     return rslvolume             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_rslvolume));
  __pyx_r = ((PyObject *)__pyx_v_rslvolume);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":38
 * 
 * 
 * cpdef copy_volume(_RslVolume volume):             # <<<<<<<<<<<<<<
 *     """
 *     copy_volume(volume)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.copy_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_rslvolume);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_1copy_volume(PyObject *__pyx_self, PyObject *__pyx_v_volume); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_copy_volume[] = "\n    copy_volume(volume)\n\n    Return a copy of a _RslVolume object.\n\n    Parameters\n    ----------\n    volume : _RslVolume\n        _RslVolume object to create a copy of.\n\n    Returns\n    -------\n    nvolume : _RslVolume\n        Copy of volume.\n\n    ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_1copy_volume(PyObject *__pyx_self, PyObject *__pyx_v_volume) {
  CYTHON_UNUSED int __pyx_lineno = 0;
  CYTHON_UNUSED const char *__pyx_filename = NULL;
  CYTHON_UNUSED int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("copy_volume (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_volume), __pyx_ptype_5pyart_2io_14_rsl_interface__RslVolume, 1, "volume", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_copy_volume(__pyx_self, ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_volume));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_copy_volume(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_volume) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("copy_volume", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_5pyart_2io_14_rsl_interface_copy_volume(__pyx_v_volume, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 38; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.copy_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":62
 * 
 * 
 * cpdef create_volume(             # <<<<<<<<<<<<<<
 *         np.ndarray[np.float32_t, ndim=2] arr,
 *         np.ndarray[np.int32_t, ndim=1] rays_per_sweep,
 */

static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_3create_volume(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_create_volume(PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_rays_per_sweep, CYTHON_UNUSED int __pyx_skip_dispatch, struct __pyx_opt_args_5pyart_2io_14_rsl_interface_create_volume *__pyx_optional_args) {
  int __pyx_v_vol_num = ((int)1);
  float (**__pyx_v_RSL_F_LIST)(Range);
  Range (**__pyx_v_RSL_INVF_LIST)(float);
  Volume *__pyx_v_volume;
  Sweep *__pyx_v_sweep;
  Ray *__pyx_v_ray;
  npy_intp __pyx_v_nsweeps;
  npy_intp __pyx_v_nbins;
  PyObject *__pyx_v_ray_index = NULL;
  npy_intp __pyx_v_nsweep;
  PyObject *__pyx_v_nrays = NULL;
  PyObject *__pyx_v_nray = NULL;
  npy_intp __pyx_v_nbin;
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_rslvolume = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_rays_per_sweep;
  __Pyx_Buffer __pyx_pybuffer_rays_per_sweep;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  float (*__pyx_t_1[42])(Range);
  Range (*__pyx_t_2[42])(float);
  npy_intp __pyx_t_3;
  npy_intp __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  Py_ssize_t __pyx_t_9;
  PyObject *(*__pyx_t_10)(PyObject *);
  Py_ssize_t __pyx_t_11;
  npy_intp __pyx_t_12;
  npy_intp __pyx_t_13;
  PyObject *__pyx_t_14 = NULL;
  float __pyx_t_15;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_volume", 0);
  if (__pyx_optional_args) {
    if (__pyx_optional_args->__pyx_n > 0) {
      __pyx_v_vol_num = __pyx_optional_args->vol_num;
    }
  }
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_rays_per_sweep.pybuffer.buf = NULL;
  __pyx_pybuffer_rays_per_sweep.refcount = 0;
  __pyx_pybuffernd_rays_per_sweep.data = NULL;
  __pyx_pybuffernd_rays_per_sweep.rcbuffer = &__pyx_pybuffer_rays_per_sweep;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_arr.diminfo[1].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_arr.diminfo[1].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[1];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer, (PyObject*)__pyx_v_rays_per_sweep, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_rays_per_sweep.diminfo[0].strides = __pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_rays_per_sweep.diminfo[0].shape = __pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer.shape[0];

  /* "pyart/io/_rsl_interface.pyx":92
 *     """
 *     # these variables can be moved to the module level if used elsewhere
 *     cdef (float (*)(_rsl_h.Range)) * RSL_F_LIST = [             # <<<<<<<<<<<<<<
 *         _rsl_h.DZ_F, _rsl_h.VR_F, _rsl_h.SW_F, _rsl_h.CZ_F, _rsl_h.ZT_F,
 *         _rsl_h.DR_F, _rsl_h.LR_F, _rsl_h.ZD_F, _rsl_h.DM_F, _rsl_h.RH_F,
 */
  __pyx_t_1[0] = DZ_F;
  __pyx_t_1[1] = VR_F;
  __pyx_t_1[2] = SW_F;
  __pyx_t_1[3] = CZ_F;
  __pyx_t_1[4] = ZT_F;
  __pyx_t_1[5] = DR_F;
  __pyx_t_1[6] = LR_F;
  __pyx_t_1[7] = ZD_F;
  __pyx_t_1[8] = DM_F;
  __pyx_t_1[9] = RH_F;
  __pyx_t_1[10] = PH_F;
  __pyx_t_1[11] = XZ_F;
  __pyx_t_1[12] = CD_F;
  __pyx_t_1[13] = MZ_F;
  __pyx_t_1[14] = MD_F;
  __pyx_t_1[15] = ZE_F;
  __pyx_t_1[16] = VE_F;
  __pyx_t_1[17] = KD_F;
  __pyx_t_1[18] = TI_F;
  __pyx_t_1[19] = DX_F;
  __pyx_t_1[20] = CH_F;
  __pyx_t_1[21] = AH_F;
  __pyx_t_1[22] = CV_F;
  __pyx_t_1[23] = AV_F;
  __pyx_t_1[24] = SQ_F;
  __pyx_t_1[25] = VS_F;
  __pyx_t_1[26] = VL_F;
  __pyx_t_1[27] = VG_F;
  __pyx_t_1[28] = VT_F;
  __pyx_t_1[29] = NP_F;
  __pyx_t_1[30] = HC_F;
  __pyx_t_1[31] = VC_F;
  __pyx_t_1[32] = VR_F;
  __pyx_t_1[33] = SW_F;
  __pyx_t_1[34] = VR_F;
  __pyx_t_1[35] = SW_F;
  __pyx_t_1[36] = DZ_F;
  __pyx_t_1[37] = CZ_F;
  __pyx_t_1[38] = PH_F;
  __pyx_t_1[39] = SD_F;
  __pyx_t_1[40] = DZ_F;
  __pyx_t_1[41] = DZ_F;
  __pyx_v_RSL_F_LIST = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":103
 *         _rsl_h.DZ_F, _rsl_h.DZ_F]
 * 
 *     cdef (_rsl_h.Range (*)(float)) * RSL_INVF_LIST = [             # <<<<<<<<<<<<<<
 *         _rsl_h.DZ_INVF, _rsl_h.VR_INVF, _rsl_h.SW_INVF, _rsl_h.CZ_INVF,
 *         _rsl_h.ZT_INVF, _rsl_h.DR_INVF, _rsl_h.LR_INVF, _rsl_h.ZD_INVF,
 */
  __pyx_t_2[0] = DZ_INVF;
  __pyx_t_2[1] = VR_INVF;
  __pyx_t_2[2] = SW_INVF;
  __pyx_t_2[3] = CZ_INVF;
  __pyx_t_2[4] = ZT_INVF;
  __pyx_t_2[5] = DR_INVF;
  __pyx_t_2[6] = LR_INVF;
  __pyx_t_2[7] = ZD_INVF;
  __pyx_t_2[8] = DM_INVF;
  __pyx_t_2[9] = RH_INVF;
  __pyx_t_2[10] = PH_INVF;
  __pyx_t_2[11] = XZ_INVF;
  __pyx_t_2[12] = CD_INVF;
  __pyx_t_2[13] = MZ_INVF;
  __pyx_t_2[14] = MD_INVF;
  __pyx_t_2[15] = ZE_INVF;
  __pyx_t_2[16] = VE_INVF;
  __pyx_t_2[17] = KD_INVF;
  __pyx_t_2[18] = TI_INVF;
  __pyx_t_2[19] = DX_INVF;
  __pyx_t_2[20] = CH_INVF;
  __pyx_t_2[21] = AH_INVF;
  __pyx_t_2[22] = CV_INVF;
  __pyx_t_2[23] = AV_INVF;
  __pyx_t_2[24] = SQ_INVF;
  __pyx_t_2[25] = VS_INVF;
  __pyx_t_2[26] = VL_INVF;
  __pyx_t_2[27] = VG_INVF;
  __pyx_t_2[28] = VT_INVF;
  __pyx_t_2[29] = NP_INVF;
  __pyx_t_2[30] = HC_INVF;
  __pyx_t_2[31] = VC_INVF;
  __pyx_t_2[32] = VR_INVF;
  __pyx_t_2[33] = SW_INVF;
  __pyx_t_2[34] = VR_INVF;
  __pyx_t_2[35] = SW_INVF;
  __pyx_t_2[36] = DZ_INVF;
  __pyx_t_2[37] = CZ_INVF;
  __pyx_t_2[38] = PH_INVF;
  __pyx_t_2[39] = SD_INVF;
  __pyx_t_2[40] = DZ_INVF;
  __pyx_t_2[41] = DZ_INVF;
  __pyx_v_RSL_INVF_LIST = __pyx_t_2;

  /* "pyart/io/_rsl_interface.pyx":121
 *     cdef int ray_i
 * 
 *     nsweeps = rays_per_sweep.shape[0]             # <<<<<<<<<<<<<<
 *     nbins = arr.shape[1]
 * 
 */
  __pyx_v_nsweeps = (__pyx_v_rays_per_sweep->dimensions[0]);

  /* "pyart/io/_rsl_interface.pyx":122
 * 
 *     nsweeps = rays_per_sweep.shape[0]
 *     nbins = arr.shape[1]             # <<<<<<<<<<<<<<
 * 
 *     volume = _rsl_h.RSL_new_volume(nsweeps)
 */
  __pyx_v_nbins = (__pyx_v_arr->dimensions[1]);

  /* "pyart/io/_rsl_interface.pyx":124
 *     nbins = arr.shape[1]
 * 
 *     volume = _rsl_h.RSL_new_volume(nsweeps)             # <<<<<<<<<<<<<<
 *     volume.h.nsweeps = nsweeps
 * 
 */
  __pyx_v_volume = RSL_new_volume(__pyx_v_nsweeps);

  /* "pyart/io/_rsl_interface.pyx":125
 * 
 *     volume = _rsl_h.RSL_new_volume(nsweeps)
 *     volume.h.nsweeps = nsweeps             # <<<<<<<<<<<<<<
 * 
 *     ray_index = 0
 */
  __pyx_v_volume->h.nsweeps = __pyx_v_nsweeps;

  /* "pyart/io/_rsl_interface.pyx":127
 *     volume.h.nsweeps = nsweeps
 * 
 *     ray_index = 0             # <<<<<<<<<<<<<<
 *     for nsweep in range(nsweeps):
 *         nrays = rays_per_sweep[nsweep]
 */
  __Pyx_INCREF(__pyx_int_0);
  __pyx_v_ray_index = __pyx_int_0;

  /* "pyart/io/_rsl_interface.pyx":128
 * 
 *     ray_index = 0
 *     for nsweep in range(nsweeps):             # <<<<<<<<<<<<<<
 *         nrays = rays_per_sweep[nsweep]
 *         sweep = _rsl_h.RSL_new_sweep(nrays)
 */
  __pyx_t_3 = __pyx_v_nsweeps;
  for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
    __pyx_v_nsweep = __pyx_t_4;

    /* "pyart/io/_rsl_interface.pyx":129
 *     ray_index = 0
 *     for nsweep in range(nsweeps):
 *         nrays = rays_per_sweep[nsweep]             # <<<<<<<<<<<<<<
 *         sweep = _rsl_h.RSL_new_sweep(nrays)
 *         volume.sweep[nsweep] = sweep
 */
    __pyx_t_5 = __pyx_v_nsweep;
    __pyx_t_6 = -1;
    if (__pyx_t_5 < 0) {
      __pyx_t_5 += __pyx_pybuffernd_rays_per_sweep.diminfo[0].shape;
      if (unlikely(__pyx_t_5 < 0)) __pyx_t_6 = 0;
    } else if (unlikely(__pyx_t_5 >= __pyx_pybuffernd_rays_per_sweep.diminfo[0].shape)) __pyx_t_6 = 0;
    if (unlikely(__pyx_t_6 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_6);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_7 = __Pyx_PyInt_From_npy_int32((*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_int32_t *, __pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer.buf, __pyx_t_5, __pyx_pybuffernd_rays_per_sweep.diminfo[0].strides))); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_XDECREF_SET(__pyx_v_nrays, __pyx_t_7);
    __pyx_t_7 = 0;

    /* "pyart/io/_rsl_interface.pyx":130
 *     for nsweep in range(nsweeps):
 *         nrays = rays_per_sweep[nsweep]
 *         sweep = _rsl_h.RSL_new_sweep(nrays)             # <<<<<<<<<<<<<<
 *         volume.sweep[nsweep] = sweep
 *         sweep.h.nrays = nrays
 */
    __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_nrays); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 130; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = RSL_new_sweep(__pyx_t_6);

    /* "pyart/io/_rsl_interface.pyx":131
 *         nrays = rays_per_sweep[nsweep]
 *         sweep = _rsl_h.RSL_new_sweep(nrays)
 *         volume.sweep[nsweep] = sweep             # <<<<<<<<<<<<<<
 *         sweep.h.nrays = nrays
 *         for nray in range(nrays):
 */
    (__pyx_v_volume->sweep[__pyx_v_nsweep]) = __pyx_v_sweep;

    /* "pyart/io/_rsl_interface.pyx":132
 *         sweep = _rsl_h.RSL_new_sweep(nrays)
 *         volume.sweep[nsweep] = sweep
 *         sweep.h.nrays = nrays             # <<<<<<<<<<<<<<
 *         for nray in range(nrays):
 *             ray = _rsl_h.RSL_new_ray(nbins)
 */
    __pyx_t_6 = __Pyx_PyInt_As_int(__pyx_v_nrays); if (unlikely((__pyx_t_6 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep->h.nrays = __pyx_t_6;

    /* "pyart/io/_rsl_interface.pyx":133
 *         volume.sweep[nsweep] = sweep
 *         sweep.h.nrays = nrays
 *         for nray in range(nrays):             # <<<<<<<<<<<<<<
 *             ray = _rsl_h.RSL_new_ray(nbins)
 *             sweep.ray[nray] = ray
 */
    __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_INCREF(__pyx_v_nrays);
    __Pyx_GIVEREF(__pyx_v_nrays);
    PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_v_nrays);
    __pyx_t_8 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_7, NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (likely(PyList_CheckExact(__pyx_t_8)) || PyTuple_CheckExact(__pyx_t_8)) {
      __pyx_t_7 = __pyx_t_8; __Pyx_INCREF(__pyx_t_7); __pyx_t_9 = 0;
      __pyx_t_10 = NULL;
    } else {
      __pyx_t_9 = -1; __pyx_t_7 = PyObject_GetIter(__pyx_t_8); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_10 = Py_TYPE(__pyx_t_7)->tp_iternext; if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    for (;;) {
      if (likely(!__pyx_t_10)) {
        if (likely(PyList_CheckExact(__pyx_t_7))) {
          if (__pyx_t_9 >= PyList_GET_SIZE(__pyx_t_7)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_8 = PyList_GET_ITEM(__pyx_t_7, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_8 = PySequence_ITEM(__pyx_t_7, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          #endif
        } else {
          if (__pyx_t_9 >= PyTuple_GET_SIZE(__pyx_t_7)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_8 = PyTuple_GET_ITEM(__pyx_t_7, __pyx_t_9); __Pyx_INCREF(__pyx_t_8); __pyx_t_9++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_8 = PySequence_ITEM(__pyx_t_7, __pyx_t_9); __pyx_t_9++; if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_8);
          #endif
        }
      } else {
        __pyx_t_8 = __pyx_t_10(__pyx_t_7);
        if (unlikely(!__pyx_t_8)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 133; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_8);
      }
      __Pyx_XDECREF_SET(__pyx_v_nray, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "pyart/io/_rsl_interface.pyx":134
 *         sweep.h.nrays = nrays
 *         for nray in range(nrays):
 *             ray = _rsl_h.RSL_new_ray(nbins)             # <<<<<<<<<<<<<<
 *             sweep.ray[nray] = ray
 *             ray.h.nbins = nbins
 */
      __pyx_v_ray = RSL_new_ray(__pyx_v_nbins);

      /* "pyart/io/_rsl_interface.pyx":135
 *         for nray in range(nrays):
 *             ray = _rsl_h.RSL_new_ray(nbins)
 *             sweep.ray[nray] = ray             # <<<<<<<<<<<<<<
 *             ray.h.nbins = nbins
 *             ray.h.f = RSL_F_LIST[vol_num]
 */
      __pyx_t_11 = __Pyx_PyIndex_AsSsize_t(__pyx_v_nray); if (unlikely((__pyx_t_11 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 135; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      (__pyx_v_sweep->ray[__pyx_t_11]) = __pyx_v_ray;

      /* "pyart/io/_rsl_interface.pyx":136
 *             ray = _rsl_h.RSL_new_ray(nbins)
 *             sweep.ray[nray] = ray
 *             ray.h.nbins = nbins             # <<<<<<<<<<<<<<
 *             ray.h.f = RSL_F_LIST[vol_num]
 *             ray.h.invf = RSL_INVF_LIST[vol_num]
 */
      __pyx_v_ray->h.nbins = __pyx_v_nbins;

      /* "pyart/io/_rsl_interface.pyx":137
 *             sweep.ray[nray] = ray
 *             ray.h.nbins = nbins
 *             ray.h.f = RSL_F_LIST[vol_num]             # <<<<<<<<<<<<<<
 *             ray.h.invf = RSL_INVF_LIST[vol_num]
 *             for nbin in range(nbins):
 */
      __pyx_v_ray->h.f = (__pyx_v_RSL_F_LIST[__pyx_v_vol_num]);

      /* "pyart/io/_rsl_interface.pyx":138
 *             ray.h.nbins = nbins
 *             ray.h.f = RSL_F_LIST[vol_num]
 *             ray.h.invf = RSL_INVF_LIST[vol_num]             # <<<<<<<<<<<<<<
 *             for nbin in range(nbins):
 *                 ray.range[nbin] = ray.h.invf(arr[ray_index, nbin])
 */
      __pyx_v_ray->h.invf = (__pyx_v_RSL_INVF_LIST[__pyx_v_vol_num]);

      /* "pyart/io/_rsl_interface.pyx":139
 *             ray.h.f = RSL_F_LIST[vol_num]
 *             ray.h.invf = RSL_INVF_LIST[vol_num]
 *             for nbin in range(nbins):             # <<<<<<<<<<<<<<
 *                 ray.range[nbin] = ray.h.invf(arr[ray_index, nbin])
 *             ray_index += 1
 */
      __pyx_t_12 = __pyx_v_nbins;
      for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
        __pyx_v_nbin = __pyx_t_13;

        /* "pyart/io/_rsl_interface.pyx":140
 *             ray.h.invf = RSL_INVF_LIST[vol_num]
 *             for nbin in range(nbins):
 *                 ray.range[nbin] = ray.h.invf(arr[ray_index, nbin])             # <<<<<<<<<<<<<<
 *             ray_index += 1
 * 
 */
        __pyx_t_8 = __Pyx_PyInt_From_Py_intptr_t(__pyx_v_nbin); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_8);
        __pyx_t_14 = PyTuple_New(2); if (unlikely(!__pyx_t_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_14);
        __Pyx_INCREF(__pyx_v_ray_index);
        __Pyx_GIVEREF(__pyx_v_ray_index);
        PyTuple_SET_ITEM(__pyx_t_14, 0, __pyx_v_ray_index);
        __Pyx_GIVEREF(__pyx_t_8);
        PyTuple_SET_ITEM(__pyx_t_14, 1, __pyx_t_8);
        __pyx_t_8 = 0;
        __pyx_t_8 = PyObject_GetItem(((PyObject *)__pyx_v_arr), __pyx_t_14); if (unlikely(__pyx_t_8 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
        __Pyx_GOTREF(__pyx_t_8);
        __Pyx_DECREF(__pyx_t_14); __pyx_t_14 = 0;
        __pyx_t_15 = __pyx_PyFloat_AsFloat(__pyx_t_8); if (unlikely((__pyx_t_15 == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 140; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
        (__pyx_v_ray->range[__pyx_v_nbin]) = __pyx_v_ray->h.invf(__pyx_t_15);
      }

      /* "pyart/io/_rsl_interface.pyx":141
 *             for nbin in range(nbins):
 *                 ray.range[nbin] = ray.h.invf(arr[ray_index, nbin])
 *             ray_index += 1             # <<<<<<<<<<<<<<
 * 
 *     rslvolume = _RslVolume()
 */
      __pyx_t_8 = __Pyx_PyInt_AddObjC(__pyx_v_ray_index, __pyx_int_1, 1, 1); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 141; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF_SET(__pyx_v_ray_index, __pyx_t_8);
      __pyx_t_8 = 0;

      /* "pyart/io/_rsl_interface.pyx":133
 *         volume.sweep[nsweep] = sweep
 *         sweep.h.nrays = nrays
 *         for nray in range(nrays):             # <<<<<<<<<<<<<<
 *             ray = _rsl_h.RSL_new_ray(nbins)
 *             sweep.ray[nray] = ray
 */
    }
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  }

  /* "pyart/io/_rsl_interface.pyx":143
 *             ray_index += 1
 * 
 *     rslvolume = _RslVolume()             # <<<<<<<<<<<<<<
 *     rslvolume.load(volume)
 *     rslvolume._dealloc = 1
 */
  __pyx_t_7 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_5pyart_2io_14_rsl_interface__RslVolume), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_v_rslvolume = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "pyart/io/_rsl_interface.pyx":144
 * 
 *     rslvolume = _RslVolume()
 *     rslvolume.load(volume)             # <<<<<<<<<<<<<<
 *     rslvolume._dealloc = 1
 *     return rslvolume
 */
  __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_rslvolume->__pyx_vtab)->load(__pyx_v_rslvolume, __pyx_v_volume); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 144; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;

  /* "pyart/io/_rsl_interface.pyx":145
 *     rslvolume = _RslVolume()
 *     rslvolume.load(volume)
 *     rslvolume._dealloc = 1             # <<<<<<<<<<<<<<
 *     return rslvolume
 * 
 */
  __pyx_v_rslvolume->_dealloc = 1;

  /* "pyart/io/_rsl_interface.pyx":146
 *     rslvolume.load(volume)
 *     rslvolume._dealloc = 1
 *     return rslvolume             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_rslvolume));
  __pyx_r = ((PyObject *)__pyx_v_rslvolume);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":62
 * 
 * 
 * cpdef create_volume(             # <<<<<<<<<<<<<<
 *         np.ndarray[np.float32_t, ndim=2] arr,
 *         np.ndarray[np.int32_t, ndim=1] rays_per_sweep,
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_14);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.io._rsl_interface.create_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF(__pyx_v_ray_index);
  __Pyx_XDECREF(__pyx_v_nrays);
  __Pyx_XDECREF(__pyx_v_nray);
  __Pyx_XDECREF((PyObject *)__pyx_v_rslvolume);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_3create_volume(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_2create_volume[] = "\n    create_volume(arr, rays_per_sweep, vol_num=1)\n\n    Create a _RslVolume object from a 2D float32 array.\n\n    No headers parameters except nsweeps, nrays and nbins are not set in the\n    resulting _RslVolume object.\n\n    Parameters\n    ----------\n    arr : array, 2D, float32\n        Two dimensional float32 array.\n    rays_per_sweep: array, 1D, int32\n        Array listing number of rays in each sweep.\n    vol_num : int\n        Volume number used to set f and invf in the header.  The default is\n        for velocity fields.  Useful values are 0 for reflectivity and\n        1 for velocity.\n\n    Returns\n    -------\n    volumes : _RslVolume\n        _RslVolume containing array data.\n\n    ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_3create_volume(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyArrayObject *__pyx_v_arr = 0;
  PyArrayObject *__pyx_v_rays_per_sweep = 0;
  int __pyx_v_vol_num;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("create_volume (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_arr,&__pyx_n_s_rays_per_sweep,&__pyx_n_s_vol_num,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_arr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_rays_per_sweep)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("create_volume", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_vol_num);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "create_volume") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_arr = ((PyArrayObject *)values[0]);
    __pyx_v_rays_per_sweep = ((PyArrayObject *)values[1]);
    if (values[2]) {
      __pyx_v_vol_num = __Pyx_PyInt_As_int(values[2]); if (unlikely((__pyx_v_vol_num == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_vol_num = ((int)1);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("create_volume", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.create_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_arr), __pyx_ptype_5numpy_ndarray, 1, "arr", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 63; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_rays_per_sweep), __pyx_ptype_5numpy_ndarray, 1, "rays_per_sweep", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_2create_volume(__pyx_self, __pyx_v_arr, __pyx_v_rays_per_sweep, __pyx_v_vol_num);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_2create_volume(CYTHON_UNUSED PyObject *__pyx_self, PyArrayObject *__pyx_v_arr, PyArrayObject *__pyx_v_rays_per_sweep, int __pyx_v_vol_num) {
  __Pyx_LocalBuf_ND __pyx_pybuffernd_arr;
  __Pyx_Buffer __pyx_pybuffer_arr;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_rays_per_sweep;
  __Pyx_Buffer __pyx_pybuffer_rays_per_sweep;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  struct __pyx_opt_args_5pyart_2io_14_rsl_interface_create_volume __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("create_volume", 0);
  __pyx_pybuffer_arr.pybuffer.buf = NULL;
  __pyx_pybuffer_arr.refcount = 0;
  __pyx_pybuffernd_arr.data = NULL;
  __pyx_pybuffernd_arr.rcbuffer = &__pyx_pybuffer_arr;
  __pyx_pybuffer_rays_per_sweep.pybuffer.buf = NULL;
  __pyx_pybuffer_rays_per_sweep.refcount = 0;
  __pyx_pybuffernd_rays_per_sweep.data = NULL;
  __pyx_pybuffernd_rays_per_sweep.rcbuffer = &__pyx_pybuffer_rays_per_sweep;
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_arr.rcbuffer->pybuffer, (PyObject*)__pyx_v_arr, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_arr.diminfo[0].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_arr.diminfo[0].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_arr.diminfo[1].strides = __pyx_pybuffernd_arr.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_arr.diminfo[1].shape = __pyx_pybuffernd_arr.rcbuffer->pybuffer.shape[1];
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer, (PyObject*)__pyx_v_rays_per_sweep, &__Pyx_TypeInfo_nn___pyx_t_5numpy_int32_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_pybuffernd_rays_per_sweep.diminfo[0].strides = __pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_rays_per_sweep.diminfo[0].shape = __pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer.shape[0];
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2.__pyx_n = 1;
  __pyx_t_2.vol_num = __pyx_v_vol_num;
  __pyx_t_1 = __pyx_f_5pyart_2io_14_rsl_interface_create_volume(__pyx_v_arr, __pyx_v_rays_per_sweep, 0, &__pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 62; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.io._rsl_interface.create_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_arr.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_rays_per_sweep.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":149
 * 
 * 
 * cpdef _label_volume(_RslVolume volume, radar):             # <<<<<<<<<<<<<<
 *     """
 *     _label_volume(volume, radar)
 */

static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_5_label_volume(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_f_5pyart_2io_14_rsl_interface__label_volume(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_volume, PyObject *__pyx_v_radar, CYTHON_UNUSED int __pyx_skip_dispatch) {
  Sweep *__pyx_v_sweep;
  Ray *__pyx_v_ray;
  int __pyx_v_ray_index;
  Volume *__pyx_v_vol;
  int __pyx_v_nsweeps;
  CYTHON_UNUSED int __pyx_v_nbins;
  PyObject *__pyx_v_gate_size = NULL;
  PyObject *__pyx_v_range_bin1 = NULL;
  PyObject *__pyx_v_alt = NULL;
  PyObject *__pyx_v_nyq_vels = NULL;
  PyObject *__pyx_v_azimuths = NULL;
  PyObject *__pyx_v_elevs = NULL;
  int __pyx_v_nsweep;
  int __pyx_v_nrays;
  int __pyx_v_nray;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Volume *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  double __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  float __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_label_volume", 0);

  /* "pyart/io/_rsl_interface.pyx":173
 *     cdef int ray_index
 * 
 *     vol = volume._Volume             # <<<<<<<<<<<<<<
 *     nsweeps = vol.h.nsweeps
 *     nbins = vol.sweep[0].ray[0].h.nbins
 */
  __pyx_t_1 = __pyx_v_volume->_Volume;
  __pyx_v_vol = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":174
 * 
 *     vol = volume._Volume
 *     nsweeps = vol.h.nsweeps             # <<<<<<<<<<<<<<
 *     nbins = vol.sweep[0].ray[0].h.nbins
 * 
 */
  __pyx_t_2 = __pyx_v_vol->h.nsweeps;
  __pyx_v_nsweeps = __pyx_t_2;

  /* "pyart/io/_rsl_interface.pyx":175
 *     vol = volume._Volume
 *     nsweeps = vol.h.nsweeps
 *     nbins = vol.sweep[0].ray[0].h.nbins             # <<<<<<<<<<<<<<
 * 
 *     gate_size = int(radar.range['meters_between_gates'])
 */
  __pyx_t_2 = ((__pyx_v_vol->sweep[0])->ray[0])->h.nbins;
  __pyx_v_nbins = __pyx_t_2;

  /* "pyart/io/_rsl_interface.pyx":177
 *     nbins = vol.sweep[0].ray[0].h.nbins
 * 
 *     gate_size = int(radar.range['meters_between_gates'])             # <<<<<<<<<<<<<<
 *     range_bin1 = int(radar.range['meters_to_center_of_first_gate'])
 *     if 'shape' in dir(radar.altitude['data']):
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_range); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_meters_between_gates); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_gate_size = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":178
 * 
 *     gate_size = int(radar.range['meters_between_gates'])
 *     range_bin1 = int(radar.range['meters_to_center_of_first_gate'])             # <<<<<<<<<<<<<<
 *     if 'shape' in dir(radar.altitude['data']):
 *         if radar.altitude['data'].shape == ():
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_range); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_meters_to_center_of_first_gate); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyNumber_Int(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_range_bin1 = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":179
 *     gate_size = int(radar.range['meters_between_gates'])
 *     range_bin1 = int(radar.range['meters_to_center_of_first_gate'])
 *     if 'shape' in dir(radar.altitude['data']):             # <<<<<<<<<<<<<<
 *         if radar.altitude['data'].shape == ():
 *             alt = float(radar.altitude['data'])
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_altitude); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Dir(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_5 = (__Pyx_PySequence_ContainsTF(__pyx_n_s_shape, __pyx_t_3, Py_EQ)); if (unlikely(__pyx_t_5 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 179; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = (__pyx_t_5 != 0);
  if (__pyx_t_6) {

    /* "pyart/io/_rsl_interface.pyx":180
 *     range_bin1 = int(radar.range['meters_to_center_of_first_gate'])
 *     if 'shape' in dir(radar.altitude['data']):
 *         if radar.altitude['data'].shape == ():             # <<<<<<<<<<<<<<
 *             alt = float(radar.altitude['data'])
 *         else:
 */
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_altitude); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 180; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_shape); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_empty_tuple, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 180; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_6) {

      /* "pyart/io/_rsl_interface.pyx":181
 *     if 'shape' in dir(radar.altitude['data']):
 *         if radar.altitude['data'].shape == ():
 *             alt = float(radar.altitude['data'])             # <<<<<<<<<<<<<<
 *         else:
 *             alt = radar.altitude['data'][0]
 */
      __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_altitude); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_data); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_7 = __Pyx_PyObject_AsDouble(__pyx_t_3); if (unlikely(__pyx_t_7 == ((double)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyFloat_FromDouble(__pyx_t_7); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_v_alt = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "pyart/io/_rsl_interface.pyx":180
 *     range_bin1 = int(radar.range['meters_to_center_of_first_gate'])
 *     if 'shape' in dir(radar.altitude['data']):
 *         if radar.altitude['data'].shape == ():             # <<<<<<<<<<<<<<
 *             alt = float(radar.altitude['data'])
 *         else:
 */
      goto __pyx_L4;
    }

    /* "pyart/io/_rsl_interface.pyx":183
 *             alt = float(radar.altitude['data'])
 *         else:
 *             alt = radar.altitude['data'][0]             # <<<<<<<<<<<<<<
 *     else:
 *         alt = radar.altitude['data']
 */
    /*else*/ {
      __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_altitude); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_4, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 183; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_alt = __pyx_t_3;
      __pyx_t_3 = 0;
    }
    __pyx_L4:;

    /* "pyart/io/_rsl_interface.pyx":179
 *     gate_size = int(radar.range['meters_between_gates'])
 *     range_bin1 = int(radar.range['meters_to_center_of_first_gate'])
 *     if 'shape' in dir(radar.altitude['data']):             # <<<<<<<<<<<<<<
 *         if radar.altitude['data'].shape == ():
 *             alt = float(radar.altitude['data'])
 */
    goto __pyx_L3;
  }

  /* "pyart/io/_rsl_interface.pyx":185
 *             alt = radar.altitude['data'][0]
 *     else:
 *         alt = radar.altitude['data']             # <<<<<<<<<<<<<<
 * 
 *     nyq_vels = radar.instrument_parameters['nyquist_velocity']['data']
 */
  /*else*/ {
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_altitude); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 185; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_alt = __pyx_t_4;
    __pyx_t_4 = 0;
  }
  __pyx_L3:;

  /* "pyart/io/_rsl_interface.pyx":187
 *         alt = radar.altitude['data']
 * 
 *     nyq_vels = radar.instrument_parameters['nyquist_velocity']['data']             # <<<<<<<<<<<<<<
 *     azimuths = radar.azimuth['data']
 *     elevs = radar.elevation['data']
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_instrument_parameters); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_nyquist_velocity); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 187; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_nyq_vels = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":188
 * 
 *     nyq_vels = radar.instrument_parameters['nyquist_velocity']['data']
 *     azimuths = radar.azimuth['data']             # <<<<<<<<<<<<<<
 *     elevs = radar.elevation['data']
 * 
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_azimuth); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyObject_GetItem(__pyx_t_4, __pyx_n_s_data); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 188; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_azimuths = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":189
 *     nyq_vels = radar.instrument_parameters['nyquist_velocity']['data']
 *     azimuths = radar.azimuth['data']
 *     elevs = radar.elevation['data']             # <<<<<<<<<<<<<<
 * 
 *     # label the volume
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_v_radar, __pyx_n_s_elevation); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyObject_GetItem(__pyx_t_3, __pyx_n_s_data); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 189; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_elevs = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":192
 * 
 *     # label the volume
 *     ray_index = 0             # <<<<<<<<<<<<<<
 *     vol.h.nsweeps = nsweeps
 *     for nsweep in range(nsweeps):
 */
  __pyx_v_ray_index = 0;

  /* "pyart/io/_rsl_interface.pyx":193
 *     # label the volume
 *     ray_index = 0
 *     vol.h.nsweeps = nsweeps             # <<<<<<<<<<<<<<
 *     for nsweep in range(nsweeps):
 *         sweep = vol.sweep[nsweep]
 */
  __pyx_v_vol->h.nsweeps = __pyx_v_nsweeps;

  /* "pyart/io/_rsl_interface.pyx":194
 *     ray_index = 0
 *     vol.h.nsweeps = nsweeps
 *     for nsweep in range(nsweeps):             # <<<<<<<<<<<<<<
 *         sweep = vol.sweep[nsweep]
 *         nrays = sweep.h.nrays
 */
  __pyx_t_2 = __pyx_v_nsweeps;
  for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_2; __pyx_t_8+=1) {
    __pyx_v_nsweep = __pyx_t_8;

    /* "pyart/io/_rsl_interface.pyx":195
 *     vol.h.nsweeps = nsweeps
 *     for nsweep in range(nsweeps):
 *         sweep = vol.sweep[nsweep]             # <<<<<<<<<<<<<<
 *         nrays = sweep.h.nrays
 *         for nray in range(nrays):
 */
    __pyx_v_sweep = (__pyx_v_vol->sweep[__pyx_v_nsweep]);

    /* "pyart/io/_rsl_interface.pyx":196
 *     for nsweep in range(nsweeps):
 *         sweep = vol.sweep[nsweep]
 *         nrays = sweep.h.nrays             # <<<<<<<<<<<<<<
 *         for nray in range(nrays):
 *             ray = sweep.ray[nray]
 */
    __pyx_t_9 = __pyx_v_sweep->h.nrays;
    __pyx_v_nrays = __pyx_t_9;

    /* "pyart/io/_rsl_interface.pyx":197
 *         sweep = vol.sweep[nsweep]
 *         nrays = sweep.h.nrays
 *         for nray in range(nrays):             # <<<<<<<<<<<<<<
 *             ray = sweep.ray[nray]
 *             ray.h.azimuth = azimuths[ray_index]
 */
    __pyx_t_9 = __pyx_v_nrays;
    for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_9; __pyx_t_10+=1) {
      __pyx_v_nray = __pyx_t_10;

      /* "pyart/io/_rsl_interface.pyx":198
 *         nrays = sweep.h.nrays
 *         for nray in range(nrays):
 *             ray = sweep.ray[nray]             # <<<<<<<<<<<<<<
 *             ray.h.azimuth = azimuths[ray_index]
 *             ray.h.elev = elevs[ray_index]
 */
      __pyx_v_ray = (__pyx_v_sweep->ray[__pyx_v_nray]);

      /* "pyart/io/_rsl_interface.pyx":199
 *         for nray in range(nrays):
 *             ray = sweep.ray[nray]
 *             ray.h.azimuth = azimuths[ray_index]             # <<<<<<<<<<<<<<
 *             ray.h.elev = elevs[ray_index]
 *             ray.h.nyq_vel = nyq_vels[ray_index]
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_azimuths, __pyx_v_ray_index, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = __pyx_PyFloat_AsFloat(__pyx_t_4); if (unlikely((__pyx_t_11 == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 199; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_ray->h.azimuth = __pyx_t_11;

      /* "pyart/io/_rsl_interface.pyx":200
 *             ray = sweep.ray[nray]
 *             ray.h.azimuth = azimuths[ray_index]
 *             ray.h.elev = elevs[ray_index]             # <<<<<<<<<<<<<<
 *             ray.h.nyq_vel = nyq_vels[ray_index]
 *             ray.h.range_bin1 = range_bin1
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_elevs, __pyx_v_ray_index, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = __pyx_PyFloat_AsFloat(__pyx_t_4); if (unlikely((__pyx_t_11 == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 200; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_ray->h.elev = __pyx_t_11;

      /* "pyart/io/_rsl_interface.pyx":201
 *             ray.h.azimuth = azimuths[ray_index]
 *             ray.h.elev = elevs[ray_index]
 *             ray.h.nyq_vel = nyq_vels[ray_index]             # <<<<<<<<<<<<<<
 *             ray.h.range_bin1 = range_bin1
 *             ray.h.gate_size = gate_size
 */
      __pyx_t_4 = __Pyx_GetItemInt(__pyx_v_nyq_vels, __pyx_v_ray_index, int, 1, __Pyx_PyInt_From_int, 0, 1, 1); if (unlikely(__pyx_t_4 == NULL)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 201; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = __pyx_PyFloat_AsFloat(__pyx_t_4); if (unlikely((__pyx_t_11 == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 201; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_v_ray->h.nyq_vel = __pyx_t_11;

      /* "pyart/io/_rsl_interface.pyx":202
 *             ray.h.elev = elevs[ray_index]
 *             ray.h.nyq_vel = nyq_vels[ray_index]
 *             ray.h.range_bin1 = range_bin1             # <<<<<<<<<<<<<<
 *             ray.h.gate_size = gate_size
 *             ray.h.alt = alt
 */
      __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_v_range_bin1); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 202; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ray->h.range_bin1 = __pyx_t_12;

      /* "pyart/io/_rsl_interface.pyx":203
 *             ray.h.nyq_vel = nyq_vels[ray_index]
 *             ray.h.range_bin1 = range_bin1
 *             ray.h.gate_size = gate_size             # <<<<<<<<<<<<<<
 *             ray.h.alt = alt
 *             ray_index += 1
 */
      __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_v_gate_size); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 203; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ray->h.gate_size = __pyx_t_12;

      /* "pyart/io/_rsl_interface.pyx":204
 *             ray.h.range_bin1 = range_bin1
 *             ray.h.gate_size = gate_size
 *             ray.h.alt = alt             # <<<<<<<<<<<<<<
 *             ray_index += 1
 *     return
 */
      __pyx_t_12 = __Pyx_PyInt_As_int(__pyx_v_alt); if (unlikely((__pyx_t_12 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ray->h.alt = __pyx_t_12;

      /* "pyart/io/_rsl_interface.pyx":205
 *             ray.h.gate_size = gate_size
 *             ray.h.alt = alt
 *             ray_index += 1             # <<<<<<<<<<<<<<
 *     return
 * 
 */
      __pyx_v_ray_index = (__pyx_v_ray_index + 1);
    }
  }

  /* "pyart/io/_rsl_interface.pyx":206
 *             ray.h.alt = alt
 *             ray_index += 1
 *     return             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":149
 * 
 * 
 * cpdef _label_volume(_RslVolume volume, radar):             # <<<<<<<<<<<<<<
 *     """
 *     _label_volume(volume, radar)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.io._rsl_interface._label_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_gate_size);
  __Pyx_XDECREF(__pyx_v_range_bin1);
  __Pyx_XDECREF(__pyx_v_alt);
  __Pyx_XDECREF(__pyx_v_nyq_vels);
  __Pyx_XDECREF(__pyx_v_azimuths);
  __Pyx_XDECREF(__pyx_v_elevs);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_5_label_volume(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_4_label_volume[] = "\n    _label_volume(volume, radar)\n\n    Add labels for dealiasing to a _RslVolume object from a radar object.\n\n    This function does not set all parameter in the _RslVolume suitable for\n    writing out the volume, rather it set those parameters which must be set\n    prior to using :py:func:`pyart.correct._fourdd_interface.fourdd_dealias`.\n\n    Parameters\n    ----------\n    volume : _RslVolume\n        Volume object to which parameters will be set as needed prior to\n        dealiasing.  Object is manipulated in-place.\n    radar : Radar\n        Radar object from which parameters are taken.\n\n    ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_5_label_volume(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_volume = 0;
  PyObject *__pyx_v_radar = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("_label_volume (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_volume,&__pyx_n_s_radar,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_volume)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_radar)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("_label_volume", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "_label_volume") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_volume = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)values[0]);
    __pyx_v_radar = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("_label_volume", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._label_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_volume), __pyx_ptype_5pyart_2io_14_rsl_interface__RslVolume, 1, "volume", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_4_label_volume(__pyx_self, __pyx_v_volume, __pyx_v_radar);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_4_label_volume(CYTHON_UNUSED PyObject *__pyx_self, struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_volume, PyObject *__pyx_v_radar) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_label_volume", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_5pyart_2io_14_rsl_interface__label_volume(__pyx_v_volume, __pyx_v_radar, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 149; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._label_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":306
 *     cdef int _dealloc
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_ray(self._Ray)
 */

/* Python wrapper */
static void __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_1__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_1__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay___dealloc__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay___dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/io/_rsl_interface.pyx":307
 * 
 *     def __dealloc__(self):
 *         if self._dealloc == 1:             # <<<<<<<<<<<<<<
 *             _rsl_h.RSL_free_ray(self._Ray)
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_dealloc == 1) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":308
 *     def __dealloc__(self):
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_ray(self._Ray)             # <<<<<<<<<<<<<<
 * 
 *     cdef load(self, _rsl_h.Ray * Ray):
 */
    RSL_free_ray(__pyx_v_self->_Ray);

    /* "pyart/io/_rsl_interface.pyx":307
 * 
 *     def __dealloc__(self):
 *         if self._dealloc == 1:             # <<<<<<<<<<<<<<
 *             _rsl_h.RSL_free_ray(self._Ray)
 * 
 */
  }

  /* "pyart/io/_rsl_interface.pyx":306
 *     cdef int _dealloc
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_ray(self._Ray)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "pyart/io/_rsl_interface.pyx":310
 *             _rsl_h.RSL_free_ray(self._Ray)
 * 
 *     cdef load(self, _rsl_h.Ray * Ray):             # <<<<<<<<<<<<<<
 *         """ Load the _RslRay object, must be called after creation. """
 *         if Ray is NULL:
 */

static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_7_RslRay_load(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, Ray *__pyx_v_Ray) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "pyart/io/_rsl_interface.pyx":312
 *     cdef load(self, _rsl_h.Ray * Ray):
 *         """ Load the _RslRay object, must be called after creation. """
 *         if Ray is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError('cannot load _RslRay with NULL')
 *         self._Ray = Ray
 */
  __pyx_t_1 = ((__pyx_v_Ray == NULL) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":313
 *         """ Load the _RslRay object, must be called after creation. """
 *         if Ray is NULL:
 *             raise ValueError('cannot load _RslRay with NULL')             # <<<<<<<<<<<<<<
 *         self._Ray = Ray
 *         self._dealloc = 0
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple_, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":312
 *     cdef load(self, _rsl_h.Ray * Ray):
 *         """ Load the _RslRay object, must be called after creation. """
 *         if Ray is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError('cannot load _RslRay with NULL')
 *         self._Ray = Ray
 */
  }

  /* "pyart/io/_rsl_interface.pyx":314
 *         if Ray is NULL:
 *             raise ValueError('cannot load _RslRay with NULL')
 *         self._Ray = Ray             # <<<<<<<<<<<<<<
 *         self._dealloc = 0
 * 
 */
  __pyx_v_self->_Ray = __pyx_v_Ray;

  /* "pyart/io/_rsl_interface.pyx":315
 *             raise ValueError('cannot load _RslRay with NULL')
 *         self._Ray = Ray
 *         self._dealloc = 0             # <<<<<<<<<<<<<<
 * 
 *     def get_datetime(self):
 */
  __pyx_v_self->_dealloc = 0;

  /* "pyart/io/_rsl_interface.pyx":310
 *             _rsl_h.RSL_free_ray(self._Ray)
 * 
 *     cdef load(self, _rsl_h.Ray * Ray):             # <<<<<<<<<<<<<<
 *         """ Load the _RslRay object, must be called after creation. """
 *         if Ray is NULL:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":317
 *         self._dealloc = 0
 * 
 *     def get_datetime(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_datetime()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3get_datetime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_7_RslRay_2get_datetime[] = "\n        get_datetime()\n\n        Return a datetime describing the date and time of the ray.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3get_datetime(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_datetime (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_2get_datetime(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_2get_datetime(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_s = NULL;
  PyObject *__pyx_v_full_seconds = NULL;
  PyObject *__pyx_v_fractional_seconds = NULL;
  PyObject *__pyx_v_microseconds = NULL;
  PyObject *__pyx_v_dt = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *(*__pyx_t_5)(PyObject *);
  int __pyx_t_6;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  Py_ssize_t __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_datetime", 0);

  /* "pyart/io/_rsl_interface.pyx":323
 *         Return a datetime describing the date and time of the ray.
 *         """
 *         s = self             # <<<<<<<<<<<<<<
 *         full_seconds, fractional_seconds = divmod(s.sec, 1)
 *         microseconds = int(fractional_seconds * 1e6)
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_self));
  __pyx_v_s = __pyx_v_self;

  /* "pyart/io/_rsl_interface.pyx":324
 *         """
 *         s = self
 *         full_seconds, fractional_seconds = divmod(s.sec, 1)             # <<<<<<<<<<<<<<
 *         microseconds = int(fractional_seconds * 1e6)
 *         # Some UF writers incorrectly specify midnight as 24:00:00 rather
 */
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_sec); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyNumber_Divmod(__pyx_t_1, __pyx_int_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_2))) || (PyList_CheckExact(__pyx_t_2))) {
    PyObject* sequence = __pyx_t_2;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_1 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_1 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_1 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    Py_ssize_t index = -1;
    __pyx_t_4 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_5 = Py_TYPE(__pyx_t_4)->tp_iternext;
    index = 0; __pyx_t_1 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_1)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_1);
    index = 1; __pyx_t_3 = __pyx_t_5(__pyx_t_4); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_5(__pyx_t_4), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = NULL;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 324; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L4_unpacking_done:;
  }
  __pyx_v_full_seconds = __pyx_t_1;
  __pyx_t_1 = 0;
  __pyx_v_fractional_seconds = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":325
 *         s = self
 *         full_seconds, fractional_seconds = divmod(s.sec, 1)
 *         microseconds = int(fractional_seconds * 1e6)             # <<<<<<<<<<<<<<
 *         # Some UF writers incorrectly specify midnight as 24:00:00 rather
 *         # than 00:00:00.  Handle this case explicitly
 */
  __pyx_t_2 = PyNumber_Multiply(__pyx_v_fractional_seconds, __pyx_float_1e6); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 325; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyNumber_Int(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 325; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_microseconds = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":328
 *         # Some UF writers incorrectly specify midnight as 24:00:00 rather
 *         # than 00:00:00.  Handle this case explicitly
 *         if s.hour == 24:             # <<<<<<<<<<<<<<
 *             s.hour = 23
 *             s.minute = 0
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_hour); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyInt_EqObjC(__pyx_t_3, __pyx_int_24, 24, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_6) {

    /* "pyart/io/_rsl_interface.pyx":329
 *         # than 00:00:00.  Handle this case explicitly
 *         if s.hour == 24:
 *             s.hour = 23             # <<<<<<<<<<<<<<
 *             s.minute = 0
 *             full_seconds = 0
 */
    if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_hour, __pyx_int_23) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 329; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":330
 *         if s.hour == 24:
 *             s.hour = 23
 *             s.minute = 0             # <<<<<<<<<<<<<<
 *             full_seconds = 0
 *             dt = datetime(s.year, s.month, s.day, s.hour, s.minute,
 */
    if (__Pyx_PyObject_SetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_minute, __pyx_int_0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 330; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":331
 *             s.hour = 23
 *             s.minute = 0
 *             full_seconds = 0             # <<<<<<<<<<<<<<
 *             dt = datetime(s.year, s.month, s.day, s.hour, s.minute,
 *                           full_seconds, microseconds)
 */
    __Pyx_INCREF(__pyx_int_0);
    __Pyx_DECREF_SET(__pyx_v_full_seconds, __pyx_int_0);

    /* "pyart/io/_rsl_interface.pyx":332
 *             s.minute = 0
 *             full_seconds = 0
 *             dt = datetime(s.year, s.month, s.day, s.hour, s.minute,             # <<<<<<<<<<<<<<
 *                           full_seconds, microseconds)
 *             return dt + timedelta(seconds=1)
 */
    __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_year); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_month); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_day); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_hour); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_8);
    __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_minute); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_9);

    /* "pyart/io/_rsl_interface.pyx":333
 *             full_seconds = 0
 *             dt = datetime(s.year, s.month, s.day, s.hour, s.minute,
 *                           full_seconds, microseconds)             # <<<<<<<<<<<<<<
 *             return dt + timedelta(seconds=1)
 *         return datetime(s.year, s.month, s.day, s.hour, s.minute,
 */
    __pyx_t_10 = NULL;
    __pyx_t_11 = 0;
    if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_10)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_10);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
        __pyx_t_11 = 1;
      }
    }
    __pyx_t_12 = PyTuple_New(7+__pyx_t_11); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_12);
    if (__pyx_t_10) {
      __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_12, 0, __pyx_t_10); __pyx_t_10 = NULL;
    }
    __Pyx_GIVEREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_12, 0+__pyx_t_11, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_12, 1+__pyx_t_11, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_7);
    PyTuple_SET_ITEM(__pyx_t_12, 2+__pyx_t_11, __pyx_t_7);
    __Pyx_GIVEREF(__pyx_t_8);
    PyTuple_SET_ITEM(__pyx_t_12, 3+__pyx_t_11, __pyx_t_8);
    __Pyx_GIVEREF(__pyx_t_9);
    PyTuple_SET_ITEM(__pyx_t_12, 4+__pyx_t_11, __pyx_t_9);
    __Pyx_INCREF(__pyx_v_full_seconds);
    __Pyx_GIVEREF(__pyx_v_full_seconds);
    PyTuple_SET_ITEM(__pyx_t_12, 5+__pyx_t_11, __pyx_v_full_seconds);
    __Pyx_INCREF(__pyx_v_microseconds);
    __Pyx_GIVEREF(__pyx_v_microseconds);
    PyTuple_SET_ITEM(__pyx_t_12, 6+__pyx_t_11, __pyx_v_microseconds);
    __pyx_t_1 = 0;
    __pyx_t_4 = 0;
    __pyx_t_7 = 0;
    __pyx_t_8 = 0;
    __pyx_t_9 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_12, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 332; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_v_dt = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pyart/io/_rsl_interface.pyx":334
 *             dt = datetime(s.year, s.month, s.day, s.hour, s.minute,
 *                           full_seconds, microseconds)
 *             return dt + timedelta(seconds=1)             # <<<<<<<<<<<<<<
 *         return datetime(s.year, s.month, s.day, s.hour, s.minute,
 *                         int(full_seconds), microseconds)
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_timedelta); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_seconds, __pyx_int_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_12 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_empty_tuple, __pyx_t_3); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_12);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Add(__pyx_v_dt, __pyx_t_12); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
    __pyx_r = __pyx_t_3;
    __pyx_t_3 = 0;
    goto __pyx_L0;

    /* "pyart/io/_rsl_interface.pyx":328
 *         # Some UF writers incorrectly specify midnight as 24:00:00 rather
 *         # than 00:00:00.  Handle this case explicitly
 *         if s.hour == 24:             # <<<<<<<<<<<<<<
 *             s.hour = 23
 *             s.minute = 0
 */
  }

  /* "pyart/io/_rsl_interface.pyx":335
 *                           full_seconds, microseconds)
 *             return dt + timedelta(seconds=1)
 *         return datetime(s.year, s.month, s.day, s.hour, s.minute,             # <<<<<<<<<<<<<<
 *                         int(full_seconds), microseconds)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_12 = __Pyx_GetModuleGlobalName(__pyx_n_s_datetime); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_12);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_year); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_9 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_month); if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_9);
  __pyx_t_8 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_day); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_8);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_hour); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_s), __pyx_n_s_minute); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);

  /* "pyart/io/_rsl_interface.pyx":336
 *             return dt + timedelta(seconds=1)
 *         return datetime(s.year, s.month, s.day, s.hour, s.minute,
 *                         int(full_seconds), microseconds)             # <<<<<<<<<<<<<<
 * 
 *     def get_data(self):
 */
  __pyx_t_1 = PyNumber_Int(__pyx_v_full_seconds); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 336; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_10 = NULL;
  __pyx_t_11 = 0;
  if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_12))) {
    __pyx_t_10 = PyMethod_GET_SELF(__pyx_t_12);
    if (likely(__pyx_t_10)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_12);
      __Pyx_INCREF(__pyx_t_10);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_12, function);
      __pyx_t_11 = 1;
    }
  }
  __pyx_t_13 = PyTuple_New(7+__pyx_t_11); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  if (__pyx_t_10) {
    __Pyx_GIVEREF(__pyx_t_10); PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_10); __pyx_t_10 = NULL;
  }
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_13, 0+__pyx_t_11, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_9);
  PyTuple_SET_ITEM(__pyx_t_13, 1+__pyx_t_11, __pyx_t_9);
  __Pyx_GIVEREF(__pyx_t_8);
  PyTuple_SET_ITEM(__pyx_t_13, 2+__pyx_t_11, __pyx_t_8);
  __Pyx_GIVEREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_13, 3+__pyx_t_11, __pyx_t_7);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_13, 4+__pyx_t_11, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_13, 5+__pyx_t_11, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_microseconds);
  __Pyx_GIVEREF(__pyx_v_microseconds);
  PyTuple_SET_ITEM(__pyx_t_13, 6+__pyx_t_11, __pyx_v_microseconds);
  __pyx_t_2 = 0;
  __pyx_t_9 = 0;
  __pyx_t_8 = 0;
  __pyx_t_7 = 0;
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_12, __pyx_t_13, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":317
 *         self._dealloc = 0
 * 
 *     def get_datetime(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_datetime()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_XDECREF(__pyx_t_13);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.get_datetime", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_s);
  __Pyx_XDECREF(__pyx_v_full_seconds);
  __Pyx_XDECREF(__pyx_v_fractional_seconds);
  __Pyx_XDECREF(__pyx_v_microseconds);
  __Pyx_XDECREF(__pyx_v_dt);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":338
 *                         int(full_seconds), microseconds)
 * 
 *     def get_data(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_data()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5get_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_7_RslRay_4get_data[] = "\n        get_data()\n\n        Return the one-dimensional data contained in the ray.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5get_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_data (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4get_data(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4get_data(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  Range __pyx_v_raw;
  PyArrayObject *__pyx_v_data = 0;
  int __pyx_v_shape;
  int __pyx_v_nbin;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_data;
  __Pyx_Buffer __pyx_pybuffer_data;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  int __pyx_t_10;
  Py_ssize_t __pyx_t_11;
  int __pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_data", 0);
  __pyx_pybuffer_data.pybuffer.buf = NULL;
  __pyx_pybuffer_data.refcount = 0;
  __pyx_pybuffernd_data.data = NULL;
  __pyx_pybuffernd_data.rcbuffer = &__pyx_pybuffer_data;

  /* "pyart/io/_rsl_interface.pyx":347
 *         cdef np.ndarray[np.float32_t, ndim = 1] data
 * 
 *         shape = (self._Ray.h.nbins)             # <<<<<<<<<<<<<<
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 *         for nbin in range(self._Ray.h.nbins):
 */
  __pyx_t_1 = __pyx_v_self->_Ray->h.nbins;
  __pyx_v_shape = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":348
 * 
 *         shape = (self._Ray.h.nbins)
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05             # <<<<<<<<<<<<<<
 *         for nbin in range(self._Ray.h.nbins):
 *             raw = self._Ray.range[nbin]
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_shape); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyFloat_AddObjC(__pyx_t_5, __pyx_float_1_31072000e_05, 1.31072000e+05, 0); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_2);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
    __pyx_t_1 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_data.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_1 < 0)) {
      PyErr_Fetch(&__pyx_t_7, &__pyx_t_8, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_data.rcbuffer->pybuffer, (PyObject*)__pyx_v_data, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_7); Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_7, __pyx_t_8, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_data.diminfo[0].strides = __pyx_pybuffernd_data.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_data.diminfo[0].shape = __pyx_pybuffernd_data.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 348; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_6 = 0;
  __pyx_v_data = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":349
 *         shape = (self._Ray.h.nbins)
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 *         for nbin in range(self._Ray.h.nbins):             # <<<<<<<<<<<<<<
 *             raw = self._Ray.range[nbin]
 *             data[nbin] = self._Ray.h.f(raw)
 */
  __pyx_t_1 = __pyx_v_self->_Ray->h.nbins;
  for (__pyx_t_10 = 0; __pyx_t_10 < __pyx_t_1; __pyx_t_10+=1) {
    __pyx_v_nbin = __pyx_t_10;

    /* "pyart/io/_rsl_interface.pyx":350
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 *         for nbin in range(self._Ray.h.nbins):
 *             raw = self._Ray.range[nbin]             # <<<<<<<<<<<<<<
 *             data[nbin] = self._Ray.h.f(raw)
 *         return data
 */
    __pyx_v_raw = (__pyx_v_self->_Ray->range[__pyx_v_nbin]);

    /* "pyart/io/_rsl_interface.pyx":351
 *         for nbin in range(self._Ray.h.nbins):
 *             raw = self._Ray.range[nbin]
 *             data[nbin] = self._Ray.h.f(raw)             # <<<<<<<<<<<<<<
 *         return data
 * 
 */
    __pyx_t_11 = __pyx_v_nbin;
    __pyx_t_12 = -1;
    if (__pyx_t_11 < 0) {
      __pyx_t_11 += __pyx_pybuffernd_data.diminfo[0].shape;
      if (unlikely(__pyx_t_11 < 0)) __pyx_t_12 = 0;
    } else if (unlikely(__pyx_t_11 >= __pyx_pybuffernd_data.diminfo[0].shape)) __pyx_t_12 = 0;
    if (unlikely(__pyx_t_12 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_12);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    *__Pyx_BufPtrStrided1d(__pyx_t_5numpy_float32_t *, __pyx_pybuffernd_data.rcbuffer->pybuffer.buf, __pyx_t_11, __pyx_pybuffernd_data.diminfo[0].strides) = __pyx_v_self->_Ray->h.f(__pyx_v_raw);
  }

  /* "pyart/io/_rsl_interface.pyx":352
 *             raw = self._Ray.range[nbin]
 *             data[nbin] = self._Ray.h.f(raw)
 *         return data             # <<<<<<<<<<<<<<
 * 
 *     # header properties mapped to class attributes.
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_data));
  __pyx_r = ((PyObject *)__pyx_v_data);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":338
 *                         int(full_seconds), microseconds)
 * 
 *     def get_data(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_data()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.get_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_data);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":356
 *     # header properties mapped to class attributes.
 *     property month:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.month
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5month_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5month_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5month___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5month___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":357
 *     property month:
 *         def __get__(self):
 *             return self._Ray.h.month             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int month):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.month); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 357; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":356
 *     # header properties mapped to class attributes.
 *     property month:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.month
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.month.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":359
 *             return self._Ray.h.month
 * 
 *         def __set__(self, int month):             # <<<<<<<<<<<<<<
 *             self._Ray.h.month = month
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5month_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_month); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5month_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_month) {
  int __pyx_v_month;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_month); {
    __pyx_v_month = __Pyx_PyInt_As_int(__pyx_arg_month); if (unlikely((__pyx_v_month == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 359; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.month.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5month_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_month));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5month_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_month) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":360
 * 
 *         def __set__(self, int month):
 *             self._Ray.h.month = month             # <<<<<<<<<<<<<<
 * 
 *     property day:
 */
  __pyx_v_self->_Ray->h.month = __pyx_v_month;

  /* "pyart/io/_rsl_interface.pyx":359
 *             return self._Ray.h.month
 * 
 *         def __set__(self, int month):             # <<<<<<<<<<<<<<
 *             self._Ray.h.month = month
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":363
 * 
 *     property day:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.day
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3day_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3day_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3day___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3day___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":364
 *     property day:
 *         def __get__(self):
 *             return self._Ray.h.day             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int day):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.day); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 364; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":363
 * 
 *     property day:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.day
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.day.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":366
 *             return self._Ray.h.day
 * 
 *         def __set__(self, int day):             # <<<<<<<<<<<<<<
 *             self._Ray.h.day = day
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3day_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_day); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3day_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_day) {
  int __pyx_v_day;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_day); {
    __pyx_v_day = __Pyx_PyInt_As_int(__pyx_arg_day); if (unlikely((__pyx_v_day == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 366; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.day.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3day_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_day));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3day_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_day) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":367
 * 
 *         def __set__(self, int day):
 *             self._Ray.h.day = day             # <<<<<<<<<<<<<<
 * 
 *     property year:
 */
  __pyx_v_self->_Ray->h.day = __pyx_v_day;

  /* "pyart/io/_rsl_interface.pyx":366
 *             return self._Ray.h.day
 * 
 *         def __set__(self, int day):             # <<<<<<<<<<<<<<
 *             self._Ray.h.day = day
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":370
 * 
 *     property year:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.year
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4year_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4year_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4year___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4year___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":371
 *     property year:
 *         def __get__(self):
 *             return self._Ray.h.year             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int year):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.year); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 371; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":370
 * 
 *     property year:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.year
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.year.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":373
 *             return self._Ray.h.year
 * 
 *         def __set__(self, int year):             # <<<<<<<<<<<<<<
 *             self._Ray.h.year = year
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4year_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_year); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4year_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_year) {
  int __pyx_v_year;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_year); {
    __pyx_v_year = __Pyx_PyInt_As_int(__pyx_arg_year); if (unlikely((__pyx_v_year == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 373; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.year.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4year_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_year));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4year_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_year) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":374
 * 
 *         def __set__(self, int year):
 *             self._Ray.h.year = year             # <<<<<<<<<<<<<<
 * 
 *     property hour:
 */
  __pyx_v_self->_Ray->h.year = __pyx_v_year;

  /* "pyart/io/_rsl_interface.pyx":373
 *             return self._Ray.h.year
 * 
 *         def __set__(self, int year):             # <<<<<<<<<<<<<<
 *             self._Ray.h.year = year
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":377
 * 
 *     property hour:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.hour
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4hour_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4hour_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4hour___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4hour___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":378
 *     property hour:
 *         def __get__(self):
 *             return self._Ray.h.hour             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int hour):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.hour); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 378; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":377
 * 
 *     property hour:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.hour
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.hour.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":380
 *             return self._Ray.h.hour
 * 
 *         def __set__(self, int hour):             # <<<<<<<<<<<<<<
 *             self._Ray.h.hour = hour
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4hour_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_hour); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4hour_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_hour) {
  int __pyx_v_hour;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_hour); {
    __pyx_v_hour = __Pyx_PyInt_As_int(__pyx_arg_hour); if (unlikely((__pyx_v_hour == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 380; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.hour.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4hour_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_hour));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4hour_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_hour) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":381
 * 
 *         def __set__(self, int hour):
 *             self._Ray.h.hour = hour             # <<<<<<<<<<<<<<
 * 
 *     property minute:
 */
  __pyx_v_self->_Ray->h.hour = __pyx_v_hour;

  /* "pyart/io/_rsl_interface.pyx":380
 *             return self._Ray.h.hour
 * 
 *         def __set__(self, int hour):             # <<<<<<<<<<<<<<
 *             self._Ray.h.hour = hour
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":384
 * 
 *     property minute:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.minute
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6minute_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6minute_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6minute___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6minute___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":385
 *     property minute:
 *         def __get__(self):
 *             return self._Ray.h.minute             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int minute):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.minute); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 385; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":384
 * 
 *     property minute:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.minute
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.minute.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":387
 *             return self._Ray.h.minute
 * 
 *         def __set__(self, int minute):             # <<<<<<<<<<<<<<
 *             self._Ray.h.minute = minute
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6minute_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_minute); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6minute_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_minute) {
  int __pyx_v_minute;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_minute); {
    __pyx_v_minute = __Pyx_PyInt_As_int(__pyx_arg_minute); if (unlikely((__pyx_v_minute == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 387; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.minute.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6minute_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_minute));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6minute_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_minute) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":388
 * 
 *         def __set__(self, int minute):
 *             self._Ray.h.minute = minute             # <<<<<<<<<<<<<<
 * 
 *     property sec:
 */
  __pyx_v_self->_Ray->h.minute = __pyx_v_minute;

  /* "pyart/io/_rsl_interface.pyx":387
 *             return self._Ray.h.minute
 * 
 *         def __set__(self, int minute):             # <<<<<<<<<<<<<<
 *             self._Ray.h.minute = minute
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":391
 * 
 *     property sec:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.sec
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3sec_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3sec_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3sec___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3sec___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":392
 *     property sec:
 *         def __get__(self):
 *             return self._Ray.h.sec             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float sec):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.sec); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 392; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":391
 * 
 *     property sec:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.sec
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.sec.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":394
 *             return self._Ray.h.sec
 * 
 *         def __set__(self, float sec):             # <<<<<<<<<<<<<<
 *             self._Ray.h.sec = sec
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3sec_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sec); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3sec_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sec) {
  float __pyx_v_sec;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_sec); {
    __pyx_v_sec = __pyx_PyFloat_AsFloat(__pyx_arg_sec); if (unlikely((__pyx_v_sec == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 394; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.sec.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3sec_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_sec));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3sec_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_sec) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":395
 * 
 *         def __set__(self, float sec):
 *             self._Ray.h.sec = sec             # <<<<<<<<<<<<<<
 * 
 *     property unam_rng:
 */
  __pyx_v_self->_Ray->h.sec = __pyx_v_sec;

  /* "pyart/io/_rsl_interface.pyx":394
 *             return self._Ray.h.sec
 * 
 *         def __set__(self, float sec):             # <<<<<<<<<<<<<<
 *             self._Ray.h.sec = sec
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":398
 * 
 *     property unam_rng:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.unam_rng
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":399
 *     property unam_rng:
 *         def __get__(self):
 *             return self._Ray.h.unam_rng             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float unam_rng):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.unam_rng); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 399; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":398
 * 
 *     property unam_rng:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.unam_rng
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.unam_rng.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":401
 *             return self._Ray.h.unam_rng
 * 
 *         def __set__(self, float unam_rng):             # <<<<<<<<<<<<<<
 *             self._Ray.h.unam_rng = unam_rng
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_unam_rng); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_unam_rng) {
  float __pyx_v_unam_rng;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_unam_rng); {
    __pyx_v_unam_rng = __pyx_PyFloat_AsFloat(__pyx_arg_unam_rng); if (unlikely((__pyx_v_unam_rng == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 401; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.unam_rng.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_unam_rng));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_unam_rng) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":402
 * 
 *         def __set__(self, float unam_rng):
 *             self._Ray.h.unam_rng = unam_rng             # <<<<<<<<<<<<<<
 * 
 *     property azimuth:
 */
  __pyx_v_self->_Ray->h.unam_rng = __pyx_v_unam_rng;

  /* "pyart/io/_rsl_interface.pyx":401
 *             return self._Ray.h.unam_rng
 * 
 *         def __set__(self, float unam_rng):             # <<<<<<<<<<<<<<
 *             self._Ray.h.unam_rng = unam_rng
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":405
 * 
 *     property azimuth:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.azimuth
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":406
 *     property azimuth:
 *         def __get__(self):
 *             return self._Ray.h.azimuth             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float azimuth):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.azimuth); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 406; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":405
 * 
 *     property azimuth:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.azimuth
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.azimuth.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":408
 *             return self._Ray.h.azimuth
 * 
 *         def __set__(self, float azimuth):             # <<<<<<<<<<<<<<
 *             self._Ray.h.azimuth = azimuth
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_azimuth); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_azimuth) {
  float __pyx_v_azimuth;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_azimuth); {
    __pyx_v_azimuth = __pyx_PyFloat_AsFloat(__pyx_arg_azimuth); if (unlikely((__pyx_v_azimuth == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 408; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.azimuth.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_azimuth));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_azimuth) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":409
 * 
 *         def __set__(self, float azimuth):
 *             self._Ray.h.azimuth = azimuth             # <<<<<<<<<<<<<<
 * 
 *     property ray_num:
 */
  __pyx_v_self->_Ray->h.azimuth = __pyx_v_azimuth;

  /* "pyart/io/_rsl_interface.pyx":408
 *             return self._Ray.h.azimuth
 * 
 *         def __set__(self, float azimuth):             # <<<<<<<<<<<<<<
 *             self._Ray.h.azimuth = azimuth
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":412
 * 
 *     property ray_num:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.ray_num
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":413
 *     property ray_num:
 *         def __get__(self):
 *             return self._Ray.h.ray_num             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int ray_num):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.ray_num); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 413; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":412
 * 
 *     property ray_num:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.ray_num
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.ray_num.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":415
 *             return self._Ray.h.ray_num
 * 
 *         def __set__(self, int ray_num):             # <<<<<<<<<<<<<<
 *             self._Ray.h.ray_num = ray_num
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_ray_num); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_ray_num) {
  int __pyx_v_ray_num;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_ray_num); {
    __pyx_v_ray_num = __Pyx_PyInt_As_int(__pyx_arg_ray_num); if (unlikely((__pyx_v_ray_num == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 415; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.ray_num.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_ray_num));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_ray_num) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":416
 * 
 *         def __set__(self, int ray_num):
 *             self._Ray.h.ray_num = ray_num             # <<<<<<<<<<<<<<
 * 
 *     property elev:
 */
  __pyx_v_self->_Ray->h.ray_num = __pyx_v_ray_num;

  /* "pyart/io/_rsl_interface.pyx":415
 *             return self._Ray.h.ray_num
 * 
 *         def __set__(self, int ray_num):             # <<<<<<<<<<<<<<
 *             self._Ray.h.ray_num = ray_num
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":419
 * 
 *     property elev:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.elev
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4elev_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4elev_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4elev___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4elev___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":420
 *     property elev:
 *         def __get__(self):
 *             return self._Ray.h.elev             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float elev):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.elev); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 420; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":419
 * 
 *     property elev:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.elev
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.elev.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":422
 *             return self._Ray.h.elev
 * 
 *         def __set__(self, float elev):             # <<<<<<<<<<<<<<
 *             self._Ray.h.elev = elev
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4elev_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_elev); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4elev_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_elev) {
  float __pyx_v_elev;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_elev); {
    __pyx_v_elev = __pyx_PyFloat_AsFloat(__pyx_arg_elev); if (unlikely((__pyx_v_elev == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 422; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.elev.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4elev_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_elev));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4elev_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_elev) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":423
 * 
 *         def __set__(self, float elev):
 *             self._Ray.h.elev = elev             # <<<<<<<<<<<<<<
 * 
 *     property elev_num:
 */
  __pyx_v_self->_Ray->h.elev = __pyx_v_elev;

  /* "pyart/io/_rsl_interface.pyx":422
 *             return self._Ray.h.elev
 * 
 *         def __set__(self, float elev):             # <<<<<<<<<<<<<<
 *             self._Ray.h.elev = elev
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":426
 * 
 *     property elev_num:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.elev_num
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":427
 *     property elev_num:
 *         def __get__(self):
 *             return self._Ray.h.elev_num             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int elev_num):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.elev_num); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":426
 * 
 *     property elev_num:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.elev_num
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.elev_num.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":429
 *             return self._Ray.h.elev_num
 * 
 *         def __set__(self, int elev_num):             # <<<<<<<<<<<<<<
 *             self._Ray.h.elev_num = elev_num
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_elev_num); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_elev_num) {
  int __pyx_v_elev_num;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_elev_num); {
    __pyx_v_elev_num = __Pyx_PyInt_As_int(__pyx_arg_elev_num); if (unlikely((__pyx_v_elev_num == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 429; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.elev_num.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_elev_num));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_elev_num) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":430
 * 
 *         def __set__(self, int elev_num):
 *             self._Ray.h.elev_num = elev_num             # <<<<<<<<<<<<<<
 * 
 *     property range_bin1:
 */
  __pyx_v_self->_Ray->h.elev_num = __pyx_v_elev_num;

  /* "pyart/io/_rsl_interface.pyx":429
 *             return self._Ray.h.elev_num
 * 
 *         def __set__(self, int elev_num):             # <<<<<<<<<<<<<<
 *             self._Ray.h.elev_num = elev_num
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":433
 * 
 *     property range_bin1:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.range_bin1
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":434
 *     property range_bin1:
 *         def __get__(self):
 *             return self._Ray.h.range_bin1             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int range_bin1):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.range_bin1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":433
 * 
 *     property range_bin1:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.range_bin1
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.range_bin1.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":436
 *             return self._Ray.h.range_bin1
 * 
 *         def __set__(self, int range_bin1):             # <<<<<<<<<<<<<<
 *             self._Ray.h.range_bin1 = range_bin1
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_range_bin1); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_range_bin1) {
  int __pyx_v_range_bin1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_range_bin1); {
    __pyx_v_range_bin1 = __Pyx_PyInt_As_int(__pyx_arg_range_bin1); if (unlikely((__pyx_v_range_bin1 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 436; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.range_bin1.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_range_bin1));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_range_bin1) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":437
 * 
 *         def __set__(self, int range_bin1):
 *             self._Ray.h.range_bin1 = range_bin1             # <<<<<<<<<<<<<<
 * 
 *     property gate_size:
 */
  __pyx_v_self->_Ray->h.range_bin1 = __pyx_v_range_bin1;

  /* "pyart/io/_rsl_interface.pyx":436
 *             return self._Ray.h.range_bin1
 * 
 *         def __set__(self, int range_bin1):             # <<<<<<<<<<<<<<
 *             self._Ray.h.range_bin1 = range_bin1
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":440
 * 
 *     property gate_size:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.gate_size
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":441
 *     property gate_size:
 *         def __get__(self):
 *             return self._Ray.h.gate_size             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int gate_size):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.gate_size); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 441; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":440
 * 
 *     property gate_size:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.gate_size
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.gate_size.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":443
 *             return self._Ray.h.gate_size
 * 
 *         def __set__(self, int gate_size):             # <<<<<<<<<<<<<<
 *             self._Ray.h.gate_size = gate_size
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_gate_size); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_gate_size) {
  int __pyx_v_gate_size;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_gate_size); {
    __pyx_v_gate_size = __Pyx_PyInt_As_int(__pyx_arg_gate_size); if (unlikely((__pyx_v_gate_size == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 443; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.gate_size.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_gate_size));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_gate_size) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":444
 * 
 *         def __set__(self, int gate_size):
 *             self._Ray.h.gate_size = gate_size             # <<<<<<<<<<<<<<
 * 
 *     property vel_res:
 */
  __pyx_v_self->_Ray->h.gate_size = __pyx_v_gate_size;

  /* "pyart/io/_rsl_interface.pyx":443
 *             return self._Ray.h.gate_size
 * 
 *         def __set__(self, int gate_size):             # <<<<<<<<<<<<<<
 *             self._Ray.h.gate_size = gate_size
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":447
 * 
 *     property vel_res:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_res
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":448
 *     property vel_res:
 *         def __get__(self):
 *             return self._Ray.h.vel_res             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float vel_res):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.vel_res); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 448; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":447
 * 
 *     property vel_res:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_res
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_res.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":450
 *             return self._Ray.h.vel_res
 * 
 *         def __set__(self, float vel_res):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_res = vel_res
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_res); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_res) {
  float __pyx_v_vel_res;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_vel_res); {
    __pyx_v_vel_res = __pyx_PyFloat_AsFloat(__pyx_arg_vel_res); if (unlikely((__pyx_v_vel_res == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 450; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_res.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_vel_res));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_res) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":451
 * 
 *         def __set__(self, float vel_res):
 *             self._Ray.h.vel_res = vel_res             # <<<<<<<<<<<<<<
 * 
 *     property sweep_rate:
 */
  __pyx_v_self->_Ray->h.vel_res = __pyx_v_vel_res;

  /* "pyart/io/_rsl_interface.pyx":450
 *             return self._Ray.h.vel_res
 * 
 *         def __set__(self, float vel_res):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_res = vel_res
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":454
 * 
 *     property sweep_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.sweep_rate
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":455
 *     property sweep_rate:
 *         def __get__(self):
 *             return self._Ray.h.sweep_rate             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float sweep_rate):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.sweep_rate); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 455; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":454
 * 
 *     property sweep_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.sweep_rate
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.sweep_rate.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":457
 *             return self._Ray.h.sweep_rate
 * 
 *         def __set__(self, float sweep_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.sweep_rate = sweep_rate
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sweep_rate); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sweep_rate) {
  float __pyx_v_sweep_rate;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_sweep_rate); {
    __pyx_v_sweep_rate = __pyx_PyFloat_AsFloat(__pyx_arg_sweep_rate); if (unlikely((__pyx_v_sweep_rate == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 457; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.sweep_rate.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_sweep_rate));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_sweep_rate) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":458
 * 
 *         def __set__(self, float sweep_rate):
 *             self._Ray.h.sweep_rate = sweep_rate             # <<<<<<<<<<<<<<
 * 
 *     property prf:
 */
  __pyx_v_self->_Ray->h.sweep_rate = __pyx_v_sweep_rate;

  /* "pyart/io/_rsl_interface.pyx":457
 *             return self._Ray.h.sweep_rate
 * 
 *         def __set__(self, float sweep_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.sweep_rate = sweep_rate
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":461
 * 
 *     property prf:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.prf
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3prf_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3prf_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3prf___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3prf___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":462
 *     property prf:
 *         def __get__(self):
 *             return self._Ray.h.prf             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int prf):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.prf); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 462; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":461
 * 
 *     property prf:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.prf
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.prf.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":464
 *             return self._Ray.h.prf
 * 
 *         def __set__(self, int prf):             # <<<<<<<<<<<<<<
 *             self._Ray.h.prf = prf
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3prf_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_prf); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3prf_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_prf) {
  int __pyx_v_prf;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_prf); {
    __pyx_v_prf = __Pyx_PyInt_As_int(__pyx_arg_prf); if (unlikely((__pyx_v_prf == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 464; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.prf.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3prf_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_prf));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3prf_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_prf) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":465
 * 
 *         def __set__(self, int prf):
 *             self._Ray.h.prf = prf             # <<<<<<<<<<<<<<
 * 
 *     property prf2:
 */
  __pyx_v_self->_Ray->h.prf = __pyx_v_prf;

  /* "pyart/io/_rsl_interface.pyx":464
 *             return self._Ray.h.prf
 * 
 *         def __set__(self, int prf):             # <<<<<<<<<<<<<<
 *             self._Ray.h.prf = prf
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":468
 * 
 *     property prf2:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.prf2
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4prf2___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4prf2___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":469
 *     property prf2:
 *         def __get__(self):
 *             return self._Ray.h.prf2             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int prf2):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.prf2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 469; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":468
 * 
 *     property prf2:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.prf2
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.prf2.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":471
 *             return self._Ray.h.prf2
 * 
 *         def __set__(self, int prf2):             # <<<<<<<<<<<<<<
 *             self._Ray.h.prf2 = prf2
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_prf2); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_prf2) {
  int __pyx_v_prf2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_prf2); {
    __pyx_v_prf2 = __Pyx_PyInt_As_int(__pyx_arg_prf2); if (unlikely((__pyx_v_prf2 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.prf2.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_prf2));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_prf2) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":472
 * 
 *         def __set__(self, int prf2):
 *             self._Ray.h.prf2 = prf2             # <<<<<<<<<<<<<<
 * 
 *     property azim_rate:
 */
  __pyx_v_self->_Ray->h.prf2 = __pyx_v_prf2;

  /* "pyart/io/_rsl_interface.pyx":471
 *             return self._Ray.h.prf2
 * 
 *         def __set__(self, int prf2):             # <<<<<<<<<<<<<<
 *             self._Ray.h.prf2 = prf2
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":475
 * 
 *     property azim_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.azim_rate
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":476
 *     property azim_rate:
 *         def __get__(self):
 *             return self._Ray.h.azim_rate             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float azim_rate):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.azim_rate); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 476; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":475
 * 
 *     property azim_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.azim_rate
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.azim_rate.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":478
 *             return self._Ray.h.azim_rate
 * 
 *         def __set__(self, float azim_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.azim_rate = azim_rate
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_azim_rate); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_azim_rate) {
  float __pyx_v_azim_rate;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_azim_rate); {
    __pyx_v_azim_rate = __pyx_PyFloat_AsFloat(__pyx_arg_azim_rate); if (unlikely((__pyx_v_azim_rate == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 478; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.azim_rate.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_azim_rate));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_azim_rate) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":479
 * 
 *         def __set__(self, float azim_rate):
 *             self._Ray.h.azim_rate = azim_rate             # <<<<<<<<<<<<<<
 * 
 *     property fix_angle:
 */
  __pyx_v_self->_Ray->h.azim_rate = __pyx_v_azim_rate;

  /* "pyart/io/_rsl_interface.pyx":478
 *             return self._Ray.h.azim_rate
 * 
 *         def __set__(self, float azim_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.azim_rate = azim_rate
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":482
 * 
 *     property fix_angle:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.fix_angle
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":483
 *     property fix_angle:
 *         def __get__(self):
 *             return self._Ray.h.fix_angle             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float fix_angle):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.fix_angle); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 483; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":482
 * 
 *     property fix_angle:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.fix_angle
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.fix_angle.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":485
 *             return self._Ray.h.fix_angle
 * 
 *         def __set__(self, float fix_angle):             # <<<<<<<<<<<<<<
 *             self._Ray.h.fix_angle = fix_angle
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_fix_angle); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_fix_angle) {
  float __pyx_v_fix_angle;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_fix_angle); {
    __pyx_v_fix_angle = __pyx_PyFloat_AsFloat(__pyx_arg_fix_angle); if (unlikely((__pyx_v_fix_angle == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 485; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.fix_angle.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_fix_angle));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_fix_angle) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":486
 * 
 *         def __set__(self, float fix_angle):
 *             self._Ray.h.fix_angle = fix_angle             # <<<<<<<<<<<<<<
 * 
 *     property pitch:
 */
  __pyx_v_self->_Ray->h.fix_angle = __pyx_v_fix_angle;

  /* "pyart/io/_rsl_interface.pyx":485
 *             return self._Ray.h.fix_angle
 * 
 *         def __set__(self, float fix_angle):             # <<<<<<<<<<<<<<
 *             self._Ray.h.fix_angle = fix_angle
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":489
 * 
 *     property pitch:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pitch
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5pitch___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5pitch___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":490
 *     property pitch:
 *         def __get__(self):
 *             return self._Ray.h.pitch             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float pitch):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.pitch); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 490; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":489
 * 
 *     property pitch:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pitch
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pitch.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":492
 *             return self._Ray.h.pitch
 * 
 *         def __set__(self, float pitch):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pitch = pitch
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pitch); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pitch) {
  float __pyx_v_pitch;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_pitch); {
    __pyx_v_pitch = __pyx_PyFloat_AsFloat(__pyx_arg_pitch); if (unlikely((__pyx_v_pitch == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pitch.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_pitch));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_pitch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":493
 * 
 *         def __set__(self, float pitch):
 *             self._Ray.h.pitch = pitch             # <<<<<<<<<<<<<<
 * 
 *     property roll:
 */
  __pyx_v_self->_Ray->h.pitch = __pyx_v_pitch;

  /* "pyart/io/_rsl_interface.pyx":492
 *             return self._Ray.h.pitch
 * 
 *         def __set__(self, float pitch):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pitch = pitch
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":496
 * 
 *     property roll:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.roll
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4roll_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4roll_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4roll___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4roll___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":497
 *     property roll:
 *         def __get__(self):
 *             return self._Ray.h.roll             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float roll):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.roll); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 497; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":496
 * 
 *     property roll:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.roll
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.roll.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":499
 *             return self._Ray.h.roll
 * 
 *         def __set__(self, float roll):             # <<<<<<<<<<<<<<
 *             self._Ray.h.roll = roll
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4roll_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_roll); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4roll_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_roll) {
  float __pyx_v_roll;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_roll); {
    __pyx_v_roll = __pyx_PyFloat_AsFloat(__pyx_arg_roll); if (unlikely((__pyx_v_roll == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 499; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.roll.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4roll_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_roll));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_4roll_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_roll) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":500
 * 
 *         def __set__(self, float roll):
 *             self._Ray.h.roll = roll             # <<<<<<<<<<<<<<
 * 
 *     property heading:
 */
  __pyx_v_self->_Ray->h.roll = __pyx_v_roll;

  /* "pyart/io/_rsl_interface.pyx":499
 *             return self._Ray.h.roll
 * 
 *         def __set__(self, float roll):             # <<<<<<<<<<<<<<
 *             self._Ray.h.roll = roll
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":503
 * 
 *     property heading:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.heading
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7heading_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7heading_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7heading___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7heading___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":504
 *     property heading:
 *         def __get__(self):
 *             return self._Ray.h.heading             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float heading):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.heading); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 504; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":503
 * 
 *     property heading:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.heading
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.heading.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":506
 *             return self._Ray.h.heading
 * 
 *         def __set__(self, float heading):             # <<<<<<<<<<<<<<
 *             self._Ray.h.heading = heading
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7heading_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_heading); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7heading_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_heading) {
  float __pyx_v_heading;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_heading); {
    __pyx_v_heading = __pyx_PyFloat_AsFloat(__pyx_arg_heading); if (unlikely((__pyx_v_heading == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 506; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.heading.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7heading_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_heading));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7heading_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_heading) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":507
 * 
 *         def __set__(self, float heading):
 *             self._Ray.h.heading = heading             # <<<<<<<<<<<<<<
 * 
 *     property pitch_rate:
 */
  __pyx_v_self->_Ray->h.heading = __pyx_v_heading;

  /* "pyart/io/_rsl_interface.pyx":506
 *             return self._Ray.h.heading
 * 
 *         def __set__(self, float heading):             # <<<<<<<<<<<<<<
 *             self._Ray.h.heading = heading
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":510
 * 
 *     property pitch_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pitch_rate
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":511
 *     property pitch_rate:
 *         def __get__(self):
 *             return self._Ray.h.pitch_rate             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float pitch_rate):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.pitch_rate); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 511; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":510
 * 
 *     property pitch_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pitch_rate
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pitch_rate.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":513
 *             return self._Ray.h.pitch_rate
 * 
 *         def __set__(self, float pitch_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pitch_rate = pitch_rate
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pitch_rate); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pitch_rate) {
  float __pyx_v_pitch_rate;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_pitch_rate); {
    __pyx_v_pitch_rate = __pyx_PyFloat_AsFloat(__pyx_arg_pitch_rate); if (unlikely((__pyx_v_pitch_rate == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 513; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pitch_rate.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_pitch_rate));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_pitch_rate) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":514
 * 
 *         def __set__(self, float pitch_rate):
 *             self._Ray.h.pitch_rate = pitch_rate             # <<<<<<<<<<<<<<
 * 
 *     property roll_rate:
 */
  __pyx_v_self->_Ray->h.pitch_rate = __pyx_v_pitch_rate;

  /* "pyart/io/_rsl_interface.pyx":513
 *             return self._Ray.h.pitch_rate
 * 
 *         def __set__(self, float pitch_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pitch_rate = pitch_rate
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":517
 * 
 *     property roll_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.roll_rate
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":518
 *     property roll_rate:
 *         def __get__(self):
 *             return self._Ray.h.roll_rate             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float roll_rate):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.roll_rate); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 518; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":517
 * 
 *     property roll_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.roll_rate
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.roll_rate.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":520
 *             return self._Ray.h.roll_rate
 * 
 *         def __set__(self, float roll_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.roll_rate = roll_rate
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_roll_rate); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_roll_rate) {
  float __pyx_v_roll_rate;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_roll_rate); {
    __pyx_v_roll_rate = __pyx_PyFloat_AsFloat(__pyx_arg_roll_rate); if (unlikely((__pyx_v_roll_rate == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 520; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.roll_rate.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_roll_rate));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_roll_rate) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":521
 * 
 *         def __set__(self, float roll_rate):
 *             self._Ray.h.roll_rate = roll_rate             # <<<<<<<<<<<<<<
 * 
 *     property heading_rate:
 */
  __pyx_v_self->_Ray->h.roll_rate = __pyx_v_roll_rate;

  /* "pyart/io/_rsl_interface.pyx":520
 *             return self._Ray.h.roll_rate
 * 
 *         def __set__(self, float roll_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.roll_rate = roll_rate
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":524
 * 
 *     property heading_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.heading_rate
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":525
 *     property heading_rate:
 *         def __get__(self):
 *             return self._Ray.h.heading_rate             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float heading_rate):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.heading_rate); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 525; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":524
 * 
 *     property heading_rate:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.heading_rate
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.heading_rate.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":527
 *             return self._Ray.h.heading_rate
 * 
 *         def __set__(self, float heading_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.heading_rate = heading_rate
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_heading_rate); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_heading_rate) {
  float __pyx_v_heading_rate;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_heading_rate); {
    __pyx_v_heading_rate = __pyx_PyFloat_AsFloat(__pyx_arg_heading_rate); if (unlikely((__pyx_v_heading_rate == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 527; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.heading_rate.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_heading_rate));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_heading_rate) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":528
 * 
 *         def __set__(self, float heading_rate):
 *             self._Ray.h.heading_rate = heading_rate             # <<<<<<<<<<<<<<
 * 
 *     property lat:
 */
  __pyx_v_self->_Ray->h.heading_rate = __pyx_v_heading_rate;

  /* "pyart/io/_rsl_interface.pyx":527
 *             return self._Ray.h.heading_rate
 * 
 *         def __set__(self, float heading_rate):             # <<<<<<<<<<<<<<
 *             self._Ray.h.heading_rate = heading_rate
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":531
 * 
 *     property lat:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.lat
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lat_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lat_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lat___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lat___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":532
 *     property lat:
 *         def __get__(self):
 *             return self._Ray.h.lat             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float lat):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.lat); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 532; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":531
 * 
 *     property lat:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.lat
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.lat.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":534
 *             return self._Ray.h.lat
 * 
 *         def __set__(self, float lat):             # <<<<<<<<<<<<<<
 *             self._Ray.h.lat = lat
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lat_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lat); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lat_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lat) {
  float __pyx_v_lat;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_lat); {
    __pyx_v_lat = __pyx_PyFloat_AsFloat(__pyx_arg_lat); if (unlikely((__pyx_v_lat == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 534; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.lat.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lat_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_lat));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lat_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_lat) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":535
 * 
 *         def __set__(self, float lat):
 *             self._Ray.h.lat = lat             # <<<<<<<<<<<<<<
 * 
 *     property lon:
 */
  __pyx_v_self->_Ray->h.lat = __pyx_v_lat;

  /* "pyart/io/_rsl_interface.pyx":534
 *             return self._Ray.h.lat
 * 
 *         def __set__(self, float lat):             # <<<<<<<<<<<<<<
 *             self._Ray.h.lat = lat
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":538
 * 
 *     property lon:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.lon
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lon_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lon_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lon___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lon___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":539
 *     property lon:
 *         def __get__(self):
 *             return self._Ray.h.lon             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float lon):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.lon); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 539; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":538
 * 
 *     property lon:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.lon
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.lon.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":541
 *             return self._Ray.h.lon
 * 
 *         def __set__(self, float lon):             # <<<<<<<<<<<<<<
 *             self._Ray.h.lon = lon
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lon_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lon); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lon_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lon) {
  float __pyx_v_lon;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_lon); {
    __pyx_v_lon = __pyx_PyFloat_AsFloat(__pyx_arg_lon); if (unlikely((__pyx_v_lon == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 541; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.lon.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lon_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_lon));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3lon_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_lon) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":542
 * 
 *         def __set__(self, float lon):
 *             self._Ray.h.lon = lon             # <<<<<<<<<<<<<<
 * 
 *     property alt:
 */
  __pyx_v_self->_Ray->h.lon = __pyx_v_lon;

  /* "pyart/io/_rsl_interface.pyx":541
 *             return self._Ray.h.lon
 * 
 *         def __set__(self, float lon):             # <<<<<<<<<<<<<<
 *             self._Ray.h.lon = lon
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":545
 * 
 *     property alt:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.alt
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3alt_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3alt_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3alt___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3alt___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":546
 *     property alt:
 *         def __get__(self):
 *             return self._Ray.h.alt             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int alt):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.alt); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 546; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":545
 * 
 *     property alt:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.alt
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.alt.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":548
 *             return self._Ray.h.alt
 * 
 *         def __set__(self, int alt):             # <<<<<<<<<<<<<<
 *             self._Ray.h.alt = alt
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3alt_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_alt); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3alt_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_alt) {
  int __pyx_v_alt;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_alt); {
    __pyx_v_alt = __Pyx_PyInt_As_int(__pyx_arg_alt); if (unlikely((__pyx_v_alt == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 548; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.alt.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3alt_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_alt));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3alt_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_alt) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":549
 * 
 *         def __set__(self, int alt):
 *             self._Ray.h.alt = alt             # <<<<<<<<<<<<<<
 * 
 *     property rvc:
 */
  __pyx_v_self->_Ray->h.alt = __pyx_v_alt;

  /* "pyart/io/_rsl_interface.pyx":548
 *             return self._Ray.h.alt
 * 
 *         def __set__(self, int alt):             # <<<<<<<<<<<<<<
 *             self._Ray.h.alt = alt
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":552
 * 
 *     property rvc:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.rvc
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3rvc___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3rvc___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":553
 *     property rvc:
 *         def __get__(self):
 *             return self._Ray.h.rvc             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float rvc):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.rvc); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":552
 * 
 *     property rvc:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.rvc
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.rvc.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":555
 *             return self._Ray.h.rvc
 * 
 *         def __set__(self, float rvc):             # <<<<<<<<<<<<<<
 *             self._Ray.h.rvc = rvc
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_rvc); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_rvc) {
  float __pyx_v_rvc;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_rvc); {
    __pyx_v_rvc = __pyx_PyFloat_AsFloat(__pyx_arg_rvc); if (unlikely((__pyx_v_rvc == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 555; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.rvc.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_rvc));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_rvc) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":556
 * 
 *         def __set__(self, float rvc):
 *             self._Ray.h.rvc = rvc             # <<<<<<<<<<<<<<
 * 
 *     property vel_east:
 */
  __pyx_v_self->_Ray->h.rvc = __pyx_v_rvc;

  /* "pyart/io/_rsl_interface.pyx":555
 *             return self._Ray.h.rvc
 * 
 *         def __set__(self, float rvc):             # <<<<<<<<<<<<<<
 *             self._Ray.h.rvc = rvc
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":559
 * 
 *     property vel_east:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_east
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":560
 *     property vel_east:
 *         def __get__(self):
 *             return self._Ray.h.vel_east             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float vel_east):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.vel_east); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 560; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":559
 * 
 *     property vel_east:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_east
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_east.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":562
 *             return self._Ray.h.vel_east
 * 
 *         def __set__(self, float vel_east):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_east = vel_east
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_east); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_east) {
  float __pyx_v_vel_east;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_vel_east); {
    __pyx_v_vel_east = __pyx_PyFloat_AsFloat(__pyx_arg_vel_east); if (unlikely((__pyx_v_vel_east == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 562; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_east.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_vel_east));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_east) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":563
 * 
 *         def __set__(self, float vel_east):
 *             self._Ray.h.vel_east = vel_east             # <<<<<<<<<<<<<<
 * 
 *     property vel_north:
 */
  __pyx_v_self->_Ray->h.vel_east = __pyx_v_vel_east;

  /* "pyart/io/_rsl_interface.pyx":562
 *             return self._Ray.h.vel_east
 * 
 *         def __set__(self, float vel_east):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_east = vel_east
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":566
 * 
 *     property vel_north:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_north
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":567
 *     property vel_north:
 *         def __get__(self):
 *             return self._Ray.h.vel_north             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float vel_north):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.vel_north); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 567; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":566
 * 
 *     property vel_north:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_north
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_north.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":569
 *             return self._Ray.h.vel_north
 * 
 *         def __set__(self, float vel_north):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_north = vel_north
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_north); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_north) {
  float __pyx_v_vel_north;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_vel_north); {
    __pyx_v_vel_north = __pyx_PyFloat_AsFloat(__pyx_arg_vel_north); if (unlikely((__pyx_v_vel_north == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 569; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_north.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_vel_north));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_north) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":570
 * 
 *         def __set__(self, float vel_north):
 *             self._Ray.h.vel_north = vel_north             # <<<<<<<<<<<<<<
 * 
 *     property vel_up:
 */
  __pyx_v_self->_Ray->h.vel_north = __pyx_v_vel_north;

  /* "pyart/io/_rsl_interface.pyx":569
 *             return self._Ray.h.vel_north
 * 
 *         def __set__(self, float vel_north):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_north = vel_north
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":573
 * 
 *     property vel_up:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_up
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":574
 *     property vel_up:
 *         def __get__(self):
 *             return self._Ray.h.vel_up             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float vel_up):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.vel_up); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 574; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":573
 * 
 *     property vel_up:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.vel_up
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_up.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":576
 *             return self._Ray.h.vel_up
 * 
 *         def __set__(self, float vel_up):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_up = vel_up
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_up); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vel_up) {
  float __pyx_v_vel_up;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_vel_up); {
    __pyx_v_vel_up = __pyx_PyFloat_AsFloat(__pyx_arg_vel_up); if (unlikely((__pyx_v_vel_up == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 576; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.vel_up.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_vel_up));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_vel_up) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":577
 * 
 *         def __set__(self, float vel_up):
 *             self._Ray.h.vel_up = vel_up             # <<<<<<<<<<<<<<
 * 
 *     property pulse_count:
 */
  __pyx_v_self->_Ray->h.vel_up = __pyx_v_vel_up;

  /* "pyart/io/_rsl_interface.pyx":576
 *             return self._Ray.h.vel_up
 * 
 *         def __set__(self, float vel_up):             # <<<<<<<<<<<<<<
 *             self._Ray.h.vel_up = vel_up
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":580
 * 
 *     property pulse_count:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pulse_count
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":581
 *     property pulse_count:
 *         def __get__(self):
 *             return self._Ray.h.pulse_count             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int pulse_count):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.pulse_count); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 581; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":580
 * 
 *     property pulse_count:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pulse_count
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pulse_count.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":583
 *             return self._Ray.h.pulse_count
 * 
 *         def __set__(self, int pulse_count):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pulse_count = pulse_count
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pulse_count); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pulse_count) {
  int __pyx_v_pulse_count;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_pulse_count); {
    __pyx_v_pulse_count = __Pyx_PyInt_As_int(__pyx_arg_pulse_count); if (unlikely((__pyx_v_pulse_count == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 583; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pulse_count.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_pulse_count));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_pulse_count) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":584
 * 
 *         def __set__(self, int pulse_count):
 *             self._Ray.h.pulse_count = pulse_count             # <<<<<<<<<<<<<<
 * 
 *     property pulse_width:
 */
  __pyx_v_self->_Ray->h.pulse_count = __pyx_v_pulse_count;

  /* "pyart/io/_rsl_interface.pyx":583
 *             return self._Ray.h.pulse_count
 * 
 *         def __set__(self, int pulse_count):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pulse_count = pulse_count
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":587
 * 
 *     property pulse_width:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pulse_width
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":588
 *     property pulse_width:
 *         def __get__(self):
 *             return self._Ray.h.pulse_width             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float pulse_width):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.pulse_width); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 588; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":587
 * 
 *     property pulse_width:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.pulse_width
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pulse_width.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":590
 *             return self._Ray.h.pulse_width
 * 
 *         def __set__(self, float pulse_width):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pulse_width = pulse_width
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pulse_width); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_pulse_width) {
  float __pyx_v_pulse_width;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_pulse_width); {
    __pyx_v_pulse_width = __pyx_PyFloat_AsFloat(__pyx_arg_pulse_width); if (unlikely((__pyx_v_pulse_width == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 590; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.pulse_width.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_pulse_width));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_pulse_width) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":591
 * 
 *         def __set__(self, float pulse_width):
 *             self._Ray.h.pulse_width = pulse_width             # <<<<<<<<<<<<<<
 * 
 *     property beam_width:
 */
  __pyx_v_self->_Ray->h.pulse_width = __pyx_v_pulse_width;

  /* "pyart/io/_rsl_interface.pyx":590
 *             return self._Ray.h.pulse_width
 * 
 *         def __set__(self, float pulse_width):             # <<<<<<<<<<<<<<
 *             self._Ray.h.pulse_width = pulse_width
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":594
 * 
 *     property beam_width:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.beam_width
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":595
 *     property beam_width:
 *         def __get__(self):
 *             return self._Ray.h.beam_width             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float beam_width):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.beam_width); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 595; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":594
 * 
 *     property beam_width:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.beam_width
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.beam_width.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":597
 *             return self._Ray.h.beam_width
 * 
 *         def __set__(self, float beam_width):             # <<<<<<<<<<<<<<
 *             self._Ray.h.beam_width = beam_width
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_beam_width); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_beam_width) {
  float __pyx_v_beam_width;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_beam_width); {
    __pyx_v_beam_width = __pyx_PyFloat_AsFloat(__pyx_arg_beam_width); if (unlikely((__pyx_v_beam_width == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 597; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.beam_width.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_beam_width));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_beam_width) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":598
 * 
 *         def __set__(self, float beam_width):
 *             self._Ray.h.beam_width = beam_width             # <<<<<<<<<<<<<<
 * 
 *     property frequency:
 */
  __pyx_v_self->_Ray->h.beam_width = __pyx_v_beam_width;

  /* "pyart/io/_rsl_interface.pyx":597
 *             return self._Ray.h.beam_width
 * 
 *         def __set__(self, float beam_width):             # <<<<<<<<<<<<<<
 *             self._Ray.h.beam_width = beam_width
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":601
 * 
 *     property frequency:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.frequency
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9frequency___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9frequency___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":602
 *     property frequency:
 *         def __get__(self):
 *             return self._Ray.h.frequency             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float frequency):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.frequency); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 602; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":601
 * 
 *     property frequency:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.frequency
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.frequency.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":604
 *             return self._Ray.h.frequency
 * 
 *         def __set__(self, float frequency):             # <<<<<<<<<<<<<<
 *             self._Ray.h.frequency = frequency
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_frequency); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_frequency) {
  float __pyx_v_frequency;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_frequency); {
    __pyx_v_frequency = __pyx_PyFloat_AsFloat(__pyx_arg_frequency); if (unlikely((__pyx_v_frequency == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 604; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.frequency.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_frequency));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_frequency) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":605
 * 
 *         def __set__(self, float frequency):
 *             self._Ray.h.frequency = frequency             # <<<<<<<<<<<<<<
 * 
 *     property wavelength:
 */
  __pyx_v_self->_Ray->h.frequency = __pyx_v_frequency;

  /* "pyart/io/_rsl_interface.pyx":604
 *             return self._Ray.h.frequency
 * 
 *         def __set__(self, float frequency):             # <<<<<<<<<<<<<<
 *             self._Ray.h.frequency = frequency
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":608
 * 
 *     property wavelength:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.wavelength
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":609
 *     property wavelength:
 *         def __get__(self):
 *             return self._Ray.h.wavelength             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float wavelength):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.wavelength); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 609; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":608
 * 
 *     property wavelength:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.wavelength
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.wavelength.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":611
 *             return self._Ray.h.wavelength
 * 
 *         def __set__(self, float wavelength):             # <<<<<<<<<<<<<<
 *             self._Ray.h.wavelength = wavelength
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_wavelength); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_wavelength) {
  float __pyx_v_wavelength;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_wavelength); {
    __pyx_v_wavelength = __pyx_PyFloat_AsFloat(__pyx_arg_wavelength); if (unlikely((__pyx_v_wavelength == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 611; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.wavelength.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_wavelength));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_wavelength) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":612
 * 
 *         def __set__(self, float wavelength):
 *             self._Ray.h.wavelength = wavelength             # <<<<<<<<<<<<<<
 * 
 *     property nyq_vel:
 */
  __pyx_v_self->_Ray->h.wavelength = __pyx_v_wavelength;

  /* "pyart/io/_rsl_interface.pyx":611
 *             return self._Ray.h.wavelength
 * 
 *         def __set__(self, float wavelength):             # <<<<<<<<<<<<<<
 *             self._Ray.h.wavelength = wavelength
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":615
 * 
 *     property nyq_vel:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.nyq_vel
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":616
 *     property nyq_vel:
 *         def __get__(self):
 *             return self._Ray.h.nyq_vel             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float nyq_vel):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Ray->h.nyq_vel); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 616; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":615
 * 
 *     property nyq_vel:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.nyq_vel
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.nyq_vel.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":618
 *             return self._Ray.h.nyq_vel
 * 
 *         def __set__(self, float nyq_vel):             # <<<<<<<<<<<<<<
 *             self._Ray.h.nyq_vel = nyq_vel
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nyq_vel); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nyq_vel) {
  float __pyx_v_nyq_vel;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_nyq_vel); {
    __pyx_v_nyq_vel = __pyx_PyFloat_AsFloat(__pyx_arg_nyq_vel); if (unlikely((__pyx_v_nyq_vel == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 618; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.nyq_vel.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((float)__pyx_v_nyq_vel));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, float __pyx_v_nyq_vel) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":619
 * 
 *         def __set__(self, float nyq_vel):
 *             self._Ray.h.nyq_vel = nyq_vel             # <<<<<<<<<<<<<<
 * 
 *     property nbins:
 */
  __pyx_v_self->_Ray->h.nyq_vel = __pyx_v_nyq_vel;

  /* "pyart/io/_rsl_interface.pyx":618
 *             return self._Ray.h.nyq_vel
 * 
 *         def __set__(self, float nyq_vel):             # <<<<<<<<<<<<<<
 *             self._Ray.h.nyq_vel = nyq_vel
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":622
 * 
 *     property nbins:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.nbins
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5nbins___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5nbins___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":623
 *     property nbins:
 *         def __get__(self):
 *             return self._Ray.h.nbins             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int nbins):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Ray->h.nbins); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 623; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":622
 * 
 *     property nbins:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Ray.h.nbins
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.nbins.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":625
 *             return self._Ray.h.nbins
 * 
 *         def __set__(self, int nbins):             # <<<<<<<<<<<<<<
 *             self._Ray.h.nbins = nbins
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nbins); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nbins) {
  int __pyx_v_nbins;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_nbins); {
    __pyx_v_nbins = __Pyx_PyInt_As_int(__pyx_arg_nbins); if (unlikely((__pyx_v_nbins == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 625; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslRay.nbins.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_self), ((int)__pyx_v_nbins));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_self, int __pyx_v_nbins) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":626
 * 
 *         def __set__(self, int nbins):
 *             self._Ray.h.nbins = nbins             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->_Ray->h.nbins = __pyx_v_nbins;

  /* "pyart/io/_rsl_interface.pyx":625
 *             return self._Ray.h.nbins
 * 
 *         def __set__(self, int nbins):             # <<<<<<<<<<<<<<
 *             self._Ray.h.nbins = nbins
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":658
 *     cdef int _dealloc
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_sweep(self._Sweep)
 */

/* Python wrapper */
static void __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_1__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_1__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep___dealloc__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep___dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/io/_rsl_interface.pyx":659
 * 
 *     def __dealloc__(self):
 *         if self._dealloc == 1:             # <<<<<<<<<<<<<<
 *             _rsl_h.RSL_free_sweep(self._Sweep)
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_dealloc == 1) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":660
 *     def __dealloc__(self):
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_sweep(self._Sweep)             # <<<<<<<<<<<<<<
 * 
 *     cdef load(self, _rsl_h.Sweep * Sweep):
 */
    RSL_free_sweep(__pyx_v_self->_Sweep);

    /* "pyart/io/_rsl_interface.pyx":659
 * 
 *     def __dealloc__(self):
 *         if self._dealloc == 1:             # <<<<<<<<<<<<<<
 *             _rsl_h.RSL_free_sweep(self._Sweep)
 * 
 */
  }

  /* "pyart/io/_rsl_interface.pyx":658
 *     cdef int _dealloc
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_sweep(self._Sweep)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "pyart/io/_rsl_interface.pyx":662
 *             _rsl_h.RSL_free_sweep(self._Sweep)
 * 
 *     cdef load(self, _rsl_h.Sweep * Sweep):             # <<<<<<<<<<<<<<
 *         """ Load the _RslSweep object, must be called after creation. """
 *         if Sweep is NULL:
 */

static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_9_RslSweep_load(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, Sweep *__pyx_v_Sweep) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "pyart/io/_rsl_interface.pyx":664
 *     cdef load(self, _rsl_h.Sweep * Sweep):
 *         """ Load the _RslSweep object, must be called after creation. """
 *         if Sweep is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot load _RslSweep with NULL")
 *         self._Sweep = Sweep
 */
  __pyx_t_1 = ((__pyx_v_Sweep == NULL) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":665
 *         """ Load the _RslSweep object, must be called after creation. """
 *         if Sweep is NULL:
 *             raise ValueError("cannot load _RslSweep with NULL")             # <<<<<<<<<<<<<<
 *         self._Sweep = Sweep
 *         self._dealloc = 0
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__2, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 665; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 665; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":664
 *     cdef load(self, _rsl_h.Sweep * Sweep):
 *         """ Load the _RslSweep object, must be called after creation. """
 *         if Sweep is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError("cannot load _RslSweep with NULL")
 *         self._Sweep = Sweep
 */
  }

  /* "pyart/io/_rsl_interface.pyx":666
 *         if Sweep is NULL:
 *             raise ValueError("cannot load _RslSweep with NULL")
 *         self._Sweep = Sweep             # <<<<<<<<<<<<<<
 *         self._dealloc = 0
 * 
 */
  __pyx_v_self->_Sweep = __pyx_v_Sweep;

  /* "pyart/io/_rsl_interface.pyx":667
 *             raise ValueError("cannot load _RslSweep with NULL")
 *         self._Sweep = Sweep
 *         self._dealloc = 0             # <<<<<<<<<<<<<<
 * 
 *     def get_ray(self, int ray_number):
 */
  __pyx_v_self->_dealloc = 0;

  /* "pyart/io/_rsl_interface.pyx":662
 *             _rsl_h.RSL_free_sweep(self._Sweep)
 * 
 *     cdef load(self, _rsl_h.Sweep * Sweep):             # <<<<<<<<<<<<<<
 *         """ Load the _RslSweep object, must be called after creation. """
 *         if Sweep is NULL:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":669
 *         self._dealloc = 0
 * 
 *     def get_ray(self, int ray_number):             # <<<<<<<<<<<<<<
 *         """
 *         get_ray(ray_number)
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_3get_ray(PyObject *__pyx_v_self, PyObject *__pyx_arg_ray_number); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_9_RslSweep_2get_ray[] = "\n        get_ray(ray_number)\n\n        Return a _RslRay for a given ray.\n\n        Parameters\n        ----------\n        ray_number : int\n            Ray number to retrieve\n\n        Returns\n        -------\n        ray : _RslRay\n            _RslRay object containing the requested ray.\n\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_3get_ray(PyObject *__pyx_v_self, PyObject *__pyx_arg_ray_number) {
  int __pyx_v_ray_number;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_ray (wrapper)", 0);
  assert(__pyx_arg_ray_number); {
    __pyx_v_ray_number = __Pyx_PyInt_As_int(__pyx_arg_ray_number); if (unlikely((__pyx_v_ray_number == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 669; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.get_ray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_2get_ray(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((int)__pyx_v_ray_number));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_2get_ray(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, int __pyx_v_ray_number) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *__pyx_v_rslray = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_ray", 0);

  /* "pyart/io/_rsl_interface.pyx":686
 * 
 *         """
 *         if ray_number < 0 or ray_number >= self._Sweep.h.nrays:             # <<<<<<<<<<<<<<
 *             raise ValueError('invalid ray_number')
 *         rslray = _RslRay()
 */
  __pyx_t_2 = ((__pyx_v_ray_number < 0) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_ray_number >= __pyx_v_self->_Sweep->h.nrays) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":687
 *         """
 *         if ray_number < 0 or ray_number >= self._Sweep.h.nrays:
 *             raise ValueError('invalid ray_number')             # <<<<<<<<<<<<<<
 *         rslray = _RslRay()
 *         rslray.load(self._Sweep.ray[ray_number])
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__3, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":686
 * 
 *         """
 *         if ray_number < 0 or ray_number >= self._Sweep.h.nrays:             # <<<<<<<<<<<<<<
 *             raise ValueError('invalid ray_number')
 *         rslray = _RslRay()
 */
  }

  /* "pyart/io/_rsl_interface.pyx":688
 *         if ray_number < 0 or ray_number >= self._Sweep.h.nrays:
 *             raise ValueError('invalid ray_number')
 *         rslray = _RslRay()             # <<<<<<<<<<<<<<
 *         rslray.load(self._Sweep.ray[ray_number])
 *         return rslray
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_5pyart_2io_14_rsl_interface__RslRay), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 688; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_rslray = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":689
 *             raise ValueError('invalid ray_number')
 *         rslray = _RslRay()
 *         rslray.load(self._Sweep.ray[ray_number])             # <<<<<<<<<<<<<<
 *         return rslray
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslRay *)__pyx_v_rslray->__pyx_vtab)->load(__pyx_v_rslray, (__pyx_v_self->_Sweep->ray[__pyx_v_ray_number])); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 689; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":690
 *         rslray = _RslRay()
 *         rslray.load(self._Sweep.ray[ray_number])
 *         return rslray             # <<<<<<<<<<<<<<
 * 
 *     def get_data(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_rslray));
  __pyx_r = ((PyObject *)__pyx_v_rslray);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":669
 *         self._dealloc = 0
 * 
 *     def get_ray(self, int ray_number):             # <<<<<<<<<<<<<<
 *         """
 *         get_ray(ray_number)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.get_ray", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_rslray);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":692
 *         return rslray
 * 
 *     def get_data(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_data()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5get_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_9_RslSweep_4get_data[] = "\n        get_data()\n\n        Return the two-dimensional data contained in the sweep.\n\n        If a given ray has few bins than the first ray, the missing bins\n        will be filled with 131072.0\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5get_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_data (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4get_data(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4get_data(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  Range __pyx_v_raw;
  Ray *__pyx_v_ray;
  PyArrayObject *__pyx_v_data = 0;
  Sweep *__pyx_v_sweep;
  int __pyx_v_nrays;
  int __pyx_v_nbins;
  PyObject *__pyx_v_shape = NULL;
  int __pyx_v_nray;
  int __pyx_v_nbin;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_data;
  __Pyx_Buffer __pyx_pybuffer_data;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Sweep *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  Py_ssize_t __pyx_t_14;
  Py_ssize_t __pyx_t_15;
  int __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_data", 0);
  __pyx_pybuffer_data.pybuffer.buf = NULL;
  __pyx_pybuffer_data.refcount = 0;
  __pyx_pybuffernd_data.data = NULL;
  __pyx_pybuffernd_data.rcbuffer = &__pyx_pybuffer_data;

  /* "pyart/io/_rsl_interface.pyx":705
 *         cdef np.ndarray[np.float32_t, ndim = 2] data
 * 
 *         sweep = self._Sweep             # <<<<<<<<<<<<<<
 *         nrays = sweep.h.nrays
 *         nbins = sweep.ray[0].h.nbins
 */
  __pyx_t_1 = __pyx_v_self->_Sweep;
  __pyx_v_sweep = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":706
 * 
 *         sweep = self._Sweep
 *         nrays = sweep.h.nrays             # <<<<<<<<<<<<<<
 *         nbins = sweep.ray[0].h.nbins
 * 
 */
  __pyx_t_2 = __pyx_v_sweep->h.nrays;
  __pyx_v_nrays = __pyx_t_2;

  /* "pyart/io/_rsl_interface.pyx":707
 *         sweep = self._Sweep
 *         nrays = sweep.h.nrays
 *         nbins = sweep.ray[0].h.nbins             # <<<<<<<<<<<<<<
 * 
 *         shape = (nrays, nbins)
 */
  __pyx_t_2 = (__pyx_v_sweep->ray[0])->h.nbins;
  __pyx_v_nbins = __pyx_t_2;

  /* "pyart/io/_rsl_interface.pyx":709
 *         nbins = sweep.ray[0].h.nbins
 * 
 *         shape = (nrays, nbins)             # <<<<<<<<<<<<<<
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 *         for nray in range(nrays):
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_nrays); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 709; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_nbins); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 709; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 709; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_4);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_v_shape = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pyart/io/_rsl_interface.pyx":710
 * 
 *         shape = (nrays, nbins)
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05             # <<<<<<<<<<<<<<
 *         for nray in range(nrays):
 *             ray = sweep.ray[nray]
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_zeros); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_shape);
  __Pyx_GIVEREF(__pyx_v_shape);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_shape);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_5, __pyx_t_3); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyFloat_AddObjC(__pyx_t_6, __pyx_float_1_31072000e_05, 1.31072000e+05, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
    __pyx_t_2 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_data.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_2 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_data.rcbuffer->pybuffer, (PyObject*)__pyx_v_data, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
    }
    __pyx_pybuffernd_data.diminfo[0].strides = __pyx_pybuffernd_data.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_data.diminfo[0].shape = __pyx_pybuffernd_data.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_data.diminfo[1].strides = __pyx_pybuffernd_data.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_data.diminfo[1].shape = __pyx_pybuffernd_data.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 710; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_7 = 0;
  __pyx_v_data = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":711
 *         shape = (nrays, nbins)
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 *         for nray in range(nrays):             # <<<<<<<<<<<<<<
 *             ray = sweep.ray[nray]
 *             assert ray is not NULL
 */
  __pyx_t_2 = __pyx_v_nrays;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_2; __pyx_t_11+=1) {
    __pyx_v_nray = __pyx_t_11;

    /* "pyart/io/_rsl_interface.pyx":712
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 *         for nray in range(nrays):
 *             ray = sweep.ray[nray]             # <<<<<<<<<<<<<<
 *             assert ray is not NULL
 *             nbins = ray.h.nbins
 */
    __pyx_v_ray = (__pyx_v_sweep->ray[__pyx_v_nray]);

    /* "pyart/io/_rsl_interface.pyx":713
 *         for nray in range(nrays):
 *             ray = sweep.ray[nray]
 *             assert ray is not NULL             # <<<<<<<<<<<<<<
 *             nbins = ray.h.nbins
 *             for nbin in range(nbins):
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_ray != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 713; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":714
 *             ray = sweep.ray[nray]
 *             assert ray is not NULL
 *             nbins = ray.h.nbins             # <<<<<<<<<<<<<<
 *             for nbin in range(nbins):
 *                 raw = ray.range[nbin]
 */
    __pyx_t_12 = __pyx_v_ray->h.nbins;
    __pyx_v_nbins = __pyx_t_12;

    /* "pyart/io/_rsl_interface.pyx":715
 *             assert ray is not NULL
 *             nbins = ray.h.nbins
 *             for nbin in range(nbins):             # <<<<<<<<<<<<<<
 *                 raw = ray.range[nbin]
 *                 data[nray, nbin] = ray.h.f(raw)
 */
    __pyx_t_12 = __pyx_v_nbins;
    for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
      __pyx_v_nbin = __pyx_t_13;

      /* "pyart/io/_rsl_interface.pyx":716
 *             nbins = ray.h.nbins
 *             for nbin in range(nbins):
 *                 raw = ray.range[nbin]             # <<<<<<<<<<<<<<
 *                 data[nray, nbin] = ray.h.f(raw)
 *         return data
 */
      __pyx_v_raw = (__pyx_v_ray->range[__pyx_v_nbin]);

      /* "pyart/io/_rsl_interface.pyx":717
 *             for nbin in range(nbins):
 *                 raw = ray.range[nbin]
 *                 data[nray, nbin] = ray.h.f(raw)             # <<<<<<<<<<<<<<
 *         return data
 * 
 */
      __pyx_t_14 = __pyx_v_nray;
      __pyx_t_15 = __pyx_v_nbin;
      __pyx_t_16 = -1;
      if (__pyx_t_14 < 0) {
        __pyx_t_14 += __pyx_pybuffernd_data.diminfo[0].shape;
        if (unlikely(__pyx_t_14 < 0)) __pyx_t_16 = 0;
      } else if (unlikely(__pyx_t_14 >= __pyx_pybuffernd_data.diminfo[0].shape)) __pyx_t_16 = 0;
      if (__pyx_t_15 < 0) {
        __pyx_t_15 += __pyx_pybuffernd_data.diminfo[1].shape;
        if (unlikely(__pyx_t_15 < 0)) __pyx_t_16 = 1;
      } else if (unlikely(__pyx_t_15 >= __pyx_pybuffernd_data.diminfo[1].shape)) __pyx_t_16 = 1;
      if (unlikely(__pyx_t_16 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_16);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 717; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      *__Pyx_BufPtrStrided2d(__pyx_t_5numpy_float32_t *, __pyx_pybuffernd_data.rcbuffer->pybuffer.buf, __pyx_t_14, __pyx_pybuffernd_data.diminfo[0].strides, __pyx_t_15, __pyx_pybuffernd_data.diminfo[1].strides) = __pyx_v_ray->h.f(__pyx_v_raw);
    }
  }

  /* "pyart/io/_rsl_interface.pyx":718
 *                 raw = ray.range[nbin]
 *                 data[nray, nbin] = ray.h.f(raw)
 *         return data             # <<<<<<<<<<<<<<
 * 
 *     # header properties mapped to class attributes.
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_data));
  __pyx_r = ((PyObject *)__pyx_v_data);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":692
 *         return rslray
 * 
 *     def get_data(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_data()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.get_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":722
 *     # header properties mapped to class attributes.
 *     property sweep_num:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.sweep_num
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":723
 *     property sweep_num:
 *         def __get__(self):
 *             return self._Sweep.h.sweep_num             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int sweep_num):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Sweep->h.sweep_num); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":722
 *     # header properties mapped to class attributes.
 *     property sweep_num:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.sweep_num
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.sweep_num.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":725
 *             return self._Sweep.h.sweep_num
 * 
 *         def __set__(self, int sweep_num):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.sweep_num = sweep_num
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sweep_num); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sweep_num) {
  int __pyx_v_sweep_num;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_sweep_num); {
    __pyx_v_sweep_num = __Pyx_PyInt_As_int(__pyx_arg_sweep_num); if (unlikely((__pyx_v_sweep_num == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 725; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.sweep_num.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((int)__pyx_v_sweep_num));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, int __pyx_v_sweep_num) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":726
 * 
 *         def __set__(self, int sweep_num):
 *             self._Sweep.h.sweep_num = sweep_num             # <<<<<<<<<<<<<<
 * 
 *     property elev:
 */
  __pyx_v_self->_Sweep->h.sweep_num = __pyx_v_sweep_num;

  /* "pyart/io/_rsl_interface.pyx":725
 *             return self._Sweep.h.sweep_num
 * 
 *         def __set__(self, int sweep_num):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.sweep_num = sweep_num
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":729
 * 
 *     property elev:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.elev
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4elev___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4elev___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":730
 *     property elev:
 *         def __get__(self):
 *             return self._Sweep.h.elev             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float elev):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Sweep->h.elev); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 730; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":729
 * 
 *     property elev:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.elev
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.elev.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":732
 *             return self._Sweep.h.elev
 * 
 *         def __set__(self, float elev):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.elev = elev
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_elev); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_elev) {
  float __pyx_v_elev;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_elev); {
    __pyx_v_elev = __pyx_PyFloat_AsFloat(__pyx_arg_elev); if (unlikely((__pyx_v_elev == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 732; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.elev.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((float)__pyx_v_elev));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_elev) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":733
 * 
 *         def __set__(self, float elev):
 *             self._Sweep.h.elev = elev             # <<<<<<<<<<<<<<
 * 
 *     property azimuth:
 */
  __pyx_v_self->_Sweep->h.elev = __pyx_v_elev;

  /* "pyart/io/_rsl_interface.pyx":732
 *             return self._Sweep.h.elev
 * 
 *         def __set__(self, float elev):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.elev = elev
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":736
 * 
 *     property azimuth:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.azimuth
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":737
 *     property azimuth:
 *         def __get__(self):
 *             return self._Sweep.h.azimuth             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float azimuth):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Sweep->h.azimuth); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 737; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":736
 * 
 *     property azimuth:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.azimuth
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.azimuth.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":739
 *             return self._Sweep.h.azimuth
 * 
 *         def __set__(self, float azimuth):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.azimuth = azimuth
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_azimuth); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_azimuth) {
  float __pyx_v_azimuth;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_azimuth); {
    __pyx_v_azimuth = __pyx_PyFloat_AsFloat(__pyx_arg_azimuth); if (unlikely((__pyx_v_azimuth == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 739; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.azimuth.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((float)__pyx_v_azimuth));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_azimuth) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":740
 * 
 *         def __set__(self, float azimuth):
 *             self._Sweep.h.azimuth = azimuth             # <<<<<<<<<<<<<<
 * 
 *     property beam_width:
 */
  __pyx_v_self->_Sweep->h.azimuth = __pyx_v_azimuth;

  /* "pyart/io/_rsl_interface.pyx":739
 *             return self._Sweep.h.azimuth
 * 
 *         def __set__(self, float azimuth):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.azimuth = azimuth
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":743
 * 
 *     property beam_width:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.beam_width
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":744
 *     property beam_width:
 *         def __get__(self):
 *             return self._Sweep.h.beam_width             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float beam_width):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Sweep->h.beam_width); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 744; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":743
 * 
 *     property beam_width:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.beam_width
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.beam_width.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":746
 *             return self._Sweep.h.beam_width
 * 
 *         def __set__(self, float beam_width):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.beam_width = beam_width
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_beam_width); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_beam_width) {
  float __pyx_v_beam_width;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_beam_width); {
    __pyx_v_beam_width = __pyx_PyFloat_AsFloat(__pyx_arg_beam_width); if (unlikely((__pyx_v_beam_width == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 746; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.beam_width.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((float)__pyx_v_beam_width));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_beam_width) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":747
 * 
 *         def __set__(self, float beam_width):
 *             self._Sweep.h.beam_width = beam_width             # <<<<<<<<<<<<<<
 * 
 *     property vert_half_bw:
 */
  __pyx_v_self->_Sweep->h.beam_width = __pyx_v_beam_width;

  /* "pyart/io/_rsl_interface.pyx":746
 *             return self._Sweep.h.beam_width
 * 
 *         def __set__(self, float beam_width):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.beam_width = beam_width
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":750
 * 
 *     property vert_half_bw:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.vert_half_bw
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":751
 *     property vert_half_bw:
 *         def __get__(self):
 *             return self._Sweep.h.vert_half_bw             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float vert_half_bw):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Sweep->h.vert_half_bw); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 751; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":750
 * 
 *     property vert_half_bw:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.vert_half_bw
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.vert_half_bw.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":753
 *             return self._Sweep.h.vert_half_bw
 * 
 *         def __set__(self, float vert_half_bw):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.vert_half_bw = vert_half_bw
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vert_half_bw); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vert_half_bw) {
  float __pyx_v_vert_half_bw;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_vert_half_bw); {
    __pyx_v_vert_half_bw = __pyx_PyFloat_AsFloat(__pyx_arg_vert_half_bw); if (unlikely((__pyx_v_vert_half_bw == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 753; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.vert_half_bw.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((float)__pyx_v_vert_half_bw));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_vert_half_bw) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":754
 * 
 *         def __set__(self, float vert_half_bw):
 *             self._Sweep.h.vert_half_bw = vert_half_bw             # <<<<<<<<<<<<<<
 * 
 *     property horz_half_bw:
 */
  __pyx_v_self->_Sweep->h.vert_half_bw = __pyx_v_vert_half_bw;

  /* "pyart/io/_rsl_interface.pyx":753
 *             return self._Sweep.h.vert_half_bw
 * 
 *         def __set__(self, float vert_half_bw):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.vert_half_bw = vert_half_bw
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":757
 * 
 *     property horz_half_bw:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.horz_half_bw
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":758
 *     property horz_half_bw:
 *         def __get__(self):
 *             return self._Sweep.h.horz_half_bw             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float horz_half_bw):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Sweep->h.horz_half_bw); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 758; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":757
 * 
 *     property horz_half_bw:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.horz_half_bw
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.horz_half_bw.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":760
 *             return self._Sweep.h.horz_half_bw
 * 
 *         def __set__(self, float horz_half_bw):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.horz_half_bw = horz_half_bw
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_horz_half_bw); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_horz_half_bw) {
  float __pyx_v_horz_half_bw;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_horz_half_bw); {
    __pyx_v_horz_half_bw = __pyx_PyFloat_AsFloat(__pyx_arg_horz_half_bw); if (unlikely((__pyx_v_horz_half_bw == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 760; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.horz_half_bw.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((float)__pyx_v_horz_half_bw));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, float __pyx_v_horz_half_bw) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":761
 * 
 *         def __set__(self, float horz_half_bw):
 *             self._Sweep.h.horz_half_bw = horz_half_bw             # <<<<<<<<<<<<<<
 * 
 *     property nrays:
 */
  __pyx_v_self->_Sweep->h.horz_half_bw = __pyx_v_horz_half_bw;

  /* "pyart/io/_rsl_interface.pyx":760
 *             return self._Sweep.h.horz_half_bw
 * 
 *         def __set__(self, float horz_half_bw):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.horz_half_bw = horz_half_bw
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":764
 * 
 *     property nrays:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.nrays
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":765
 *     property nrays:
 *         def __get__(self):
 *             return self._Sweep.h.nrays             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int nrays):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Sweep->h.nrays); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 765; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":764
 * 
 *     property nrays:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Sweep.h.nrays
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.nrays.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":767
 *             return self._Sweep.h.nrays
 * 
 *         def __set__(self, int nrays):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.nrays = nrays
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nrays); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nrays) {
  int __pyx_v_nrays;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_nrays); {
    __pyx_v_nrays = __Pyx_PyInt_As_int(__pyx_arg_nrays); if (unlikely((__pyx_v_nrays == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 767; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslSweep.nrays.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_self), ((int)__pyx_v_nrays));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_self, int __pyx_v_nrays) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":768
 * 
 *         def __set__(self, int nrays):
 *             self._Sweep.h.nrays = nrays             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->_Sweep->h.nrays = __pyx_v_nrays;

  /* "pyart/io/_rsl_interface.pyx":767
 *             return self._Sweep.h.nrays
 * 
 *         def __set__(self, int nrays):             # <<<<<<<<<<<<<<
 *             self._Sweep.h.nrays = nrays
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":788
 *     """
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_volume(self._Volume)
 */

/* Python wrapper */
static void __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_1__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_1__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume___dealloc__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume___dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/io/_rsl_interface.pyx":789
 * 
 *     def __dealloc__(self):
 *         if self._dealloc == 1:             # <<<<<<<<<<<<<<
 *             _rsl_h.RSL_free_volume(self._Volume)
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_dealloc == 1) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":790
 *     def __dealloc__(self):
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_volume(self._Volume)             # <<<<<<<<<<<<<<
 * 
 *     cdef load(self, _rsl_h.Volume * Volume):
 */
    RSL_free_volume(__pyx_v_self->_Volume);

    /* "pyart/io/_rsl_interface.pyx":789
 * 
 *     def __dealloc__(self):
 *         if self._dealloc == 1:             # <<<<<<<<<<<<<<
 *             _rsl_h.RSL_free_volume(self._Volume)
 * 
 */
  }

  /* "pyart/io/_rsl_interface.pyx":788
 *     """
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         if self._dealloc == 1:
 *             _rsl_h.RSL_free_volume(self._Volume)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "pyart/io/_rsl_interface.pyx":792
 *             _rsl_h.RSL_free_volume(self._Volume)
 * 
 *     cdef load(self, _rsl_h.Volume * Volume):             # <<<<<<<<<<<<<<
 *         """ Load the _RslVolume object, must be called after creation. """
 *         if Volume is NULL:
 */

static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_10_RslVolume_load(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, Volume *__pyx_v_Volume) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("load", 0);

  /* "pyart/io/_rsl_interface.pyx":794
 *     cdef load(self, _rsl_h.Volume * Volume):
 *         """ Load the _RslVolume object, must be called after creation. """
 *         if Volume is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError('cannot load _RslVolume with NULL')
 *         self._Volume = Volume
 */
  __pyx_t_1 = ((__pyx_v_Volume == NULL) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":795
 *         """ Load the _RslVolume object, must be called after creation. """
 *         if Volume is NULL:
 *             raise ValueError('cannot load _RslVolume with NULL')             # <<<<<<<<<<<<<<
 *         self._Volume = Volume
 *         self._dealloc = 0
 */
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__4, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":794
 *     cdef load(self, _rsl_h.Volume * Volume):
 *         """ Load the _RslVolume object, must be called after creation. """
 *         if Volume is NULL:             # <<<<<<<<<<<<<<
 *             raise ValueError('cannot load _RslVolume with NULL')
 *         self._Volume = Volume
 */
  }

  /* "pyart/io/_rsl_interface.pyx":796
 *         if Volume is NULL:
 *             raise ValueError('cannot load _RslVolume with NULL')
 *         self._Volume = Volume             # <<<<<<<<<<<<<<
 *         self._dealloc = 0
 * 
 */
  __pyx_v_self->_Volume = __pyx_v_Volume;

  /* "pyart/io/_rsl_interface.pyx":797
 *             raise ValueError('cannot load _RslVolume with NULL')
 *         self._Volume = Volume
 *         self._dealloc = 0             # <<<<<<<<<<<<<<
 * 
 *     def total_rays(self):
 */
  __pyx_v_self->_dealloc = 0;

  /* "pyart/io/_rsl_interface.pyx":792
 *             _rsl_h.RSL_free_volume(self._Volume)
 * 
 *     cdef load(self, _rsl_h.Volume * Volume):             # <<<<<<<<<<<<<<
 *         """ Load the _RslVolume object, must be called after creation. """
 *         if Volume is NULL:
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.load", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":799
 *         self._dealloc = 0
 * 
 *     def total_rays(self):             # <<<<<<<<<<<<<<
 *         """
 *         total_rays()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_3total_rays(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_2total_rays[] = "\n        total_rays()\n\n        Return the total number of rays present in all sweeps of the volume.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_3total_rays(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("total_rays (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_2total_rays(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_2total_rays(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("total_rays", 0);

  /* "pyart/io/_rsl_interface.pyx":805
 *         Return the total number of rays present in all sweeps of the volume.
 *         """
 *         return np.sum(self.get_nray_array())             # <<<<<<<<<<<<<<
 * 
 *     def get_nray_array(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_sum); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_nray_array); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && unlikely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_4) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_GOTREF(__pyx_t_1);
  } else {
    __pyx_t_5 = PyTuple_New(1+1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_4); PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4); __pyx_t_4 = NULL;
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_5, 0+1, __pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_1 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 805; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":799
 *         self._dealloc = 0
 * 
 *     def total_rays(self):             # <<<<<<<<<<<<<<
 *         """
 *         total_rays()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.total_rays", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":807
 *         return np.sum(self.get_nray_array())
 * 
 *     def get_nray_array(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_nray_array()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_5get_nray_array(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_4get_nray_array[] = "\n        get_nray_array()\n\n        Return an array of the number of rays for each sweep.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_5get_nray_array(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_nray_array (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_4get_nray_array(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_4get_nray_array(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  Sweep *__pyx_v_sweep;
  PyObject *__pyx_v_nrays = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_nray_array", 0);

  /* "pyart/io/_rsl_interface.pyx":814
 *         """
 *         cdef _rsl_h.Sweep * sweep
 *         nrays = np.empty((self.nsweeps), dtype='int32')             # <<<<<<<<<<<<<<
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_n_s_int32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 814; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_nrays = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":815
 *         cdef _rsl_h.Sweep * sweep
 *         nrays = np.empty((self.nsweeps), dtype='int32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 815; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":816
 *         nrays = np.empty((self.nsweeps), dtype='int32')
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             nrays[i] = sweep.h.nrays
 */
    __pyx_t_7 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_7 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 816; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[__pyx_t_7]);

    /* "pyart/io/_rsl_interface.pyx":817
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             nrays[i] = sweep.h.nrays
 *         return nrays
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 817; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":818
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 *             nrays[i] = sweep.h.nrays             # <<<<<<<<<<<<<<
 *         return nrays
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_sweep->h.nrays); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(PyObject_SetItem(__pyx_v_nrays, __pyx_v_i, __pyx_t_4) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 818; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":815
 *         cdef _rsl_h.Sweep * sweep
 *         nrays = np.empty((self.nsweeps), dtype='int32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":819
 *             assert sweep is not NULL
 *             nrays[i] = sweep.h.nrays
 *         return nrays             # <<<<<<<<<<<<<<
 * 
 *     def get_sweep(self, int sweep_number):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_nrays);
  __pyx_r = __pyx_v_nrays;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":807
 *         return np.sum(self.get_nray_array())
 * 
 *     def get_nray_array(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_nray_array()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_nray_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_nrays);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":821
 *         return nrays
 * 
 *     def get_sweep(self, int sweep_number):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep(sweep_numer)
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7get_sweep(PyObject *__pyx_v_self, PyObject *__pyx_arg_sweep_number); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_6get_sweep[] = "\n        get_sweep(sweep_numer)\n\n        Return a _RslSweep for a given sweep number.\n\n        Parameters\n        ----------\n        sweep_number : int\n            Sweep number to retrieve\n\n        Returns\n        -------\n        sweep : _RslSweep\n            _RslSweep object containing the requested sweep.\n\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7get_sweep(PyObject *__pyx_v_self, PyObject *__pyx_arg_sweep_number) {
  int __pyx_v_sweep_number;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sweep (wrapper)", 0);
  assert(__pyx_arg_sweep_number); {
    __pyx_v_sweep_number = __Pyx_PyInt_As_int(__pyx_arg_sweep_number); if (unlikely((__pyx_v_sweep_number == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_sweep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_6get_sweep(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self), ((int)__pyx_v_sweep_number));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_6get_sweep(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, int __pyx_v_sweep_number) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *__pyx_v_rslsweep = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sweep", 0);

  /* "pyart/io/_rsl_interface.pyx":838
 * 
 *         """
 *         if sweep_number < 0 or sweep_number >= self._Volume.h.nsweeps:             # <<<<<<<<<<<<<<
 *             raise ValueError('invalid sweep_number')
 * 
 */
  __pyx_t_2 = ((__pyx_v_sweep_number < 0) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_sweep_number >= __pyx_v_self->_Volume->h.nsweeps) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":839
 *         """
 *         if sweep_number < 0 or sweep_number >= self._Volume.h.nsweeps:
 *             raise ValueError('invalid sweep_number')             # <<<<<<<<<<<<<<
 * 
 *         rslsweep = _RslSweep()
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__5, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":838
 * 
 *         """
 *         if sweep_number < 0 or sweep_number >= self._Volume.h.nsweeps:             # <<<<<<<<<<<<<<
 *             raise ValueError('invalid sweep_number')
 * 
 */
  }

  /* "pyart/io/_rsl_interface.pyx":841
 *             raise ValueError('invalid sweep_number')
 * 
 *         rslsweep = _RslSweep()             # <<<<<<<<<<<<<<
 *         rslsweep.load(self._Volume.sweep[sweep_number])
 *         return rslsweep
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_5pyart_2io_14_rsl_interface__RslSweep), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_rslsweep = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":842
 * 
 *         rslsweep = _RslSweep()
 *         rslsweep.load(self._Volume.sweep[sweep_number])             # <<<<<<<<<<<<<<
 *         return rslsweep
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslSweep *)__pyx_v_rslsweep->__pyx_vtab)->load(__pyx_v_rslsweep, (__pyx_v_self->_Volume->sweep[__pyx_v_sweep_number])); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":843
 *         rslsweep = _RslSweep()
 *         rslsweep.load(self._Volume.sweep[sweep_number])
 *         return rslsweep             # <<<<<<<<<<<<<<
 * 
 *     def get_azimuth_and_elev_array(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_rslsweep));
  __pyx_r = ((PyObject *)__pyx_v_rslsweep);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":821
 *         return nrays
 * 
 *     def get_sweep(self, int sweep_number):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep(sweep_numer)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_sweep", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_rslsweep);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":845
 *         return rslsweep
 * 
 *     def get_azimuth_and_elev_array(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_azimuth_and_elev_array()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_9get_azimuth_and_elev_array(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_8get_azimuth_and_elev_array[] = "\n        get_azimuth_and_elev_array()\n\n        Return azimuth and elevation array for each sweep and ray.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_9get_azimuth_and_elev_array(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_azimuth_and_elev_array (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_8get_azimuth_and_elev_array(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_8get_azimuth_and_elev_array(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  int __pyx_v_nrays;
  int __pyx_v_ray_count;
  Sweep *__pyx_v_sweep;
  Ray *__pyx_v_ray;
  PyObject *__pyx_v_total_rays = NULL;
  PyObject *__pyx_v_azimuth = NULL;
  PyObject *__pyx_v_elev = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  Py_ssize_t __pyx_t_10;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_azimuth_and_elev_array", 0);

  /* "pyart/io/_rsl_interface.pyx":851
 *         Return azimuth and elevation array for each sweep and ray.
 *         """
 *         cdef int nrays = self._Volume.sweep[0].h.nrays             # <<<<<<<<<<<<<<
 *         cdef int ray_count
 *         cdef _rsl_h.Sweep * sweep
 */
  __pyx_t_1 = (__pyx_v_self->_Volume->sweep[0])->h.nrays;
  __pyx_v_nrays = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":857
 * 
 *         # create empty azimuth and elev output arrays
 *         total_rays = self.total_rays()             # <<<<<<<<<<<<<<
 *         azimuth = np.empty([total_rays], dtype='float32')
 *         elev = np.empty([total_rays], dtype='float32')
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_total_rays); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 857; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 857; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 857; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_total_rays = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":858
 *         # create empty azimuth and elev output arrays
 *         total_rays = self.total_rays()
 *         azimuth = np.empty([total_rays], dtype='float32')             # <<<<<<<<<<<<<<
 *         elev = np.empty([total_rays], dtype='float32')
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_total_rays);
  __Pyx_GIVEREF(__pyx_v_total_rays);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_total_rays);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 858; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_azimuth = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pyart/io/_rsl_interface.pyx":859
 *         total_rays = self.total_rays()
 *         azimuth = np.empty([total_rays], dtype='float32')
 *         elev = np.empty([total_rays], dtype='float32')             # <<<<<<<<<<<<<<
 * 
 *         # loop over the sweeps and rays storing azimuth and elev
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyList_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_total_rays);
  __Pyx_GIVEREF(__pyx_v_total_rays);
  PyList_SET_ITEM(__pyx_t_5, 0, __pyx_v_total_rays);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_elev = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":862
 * 
 *         # loop over the sweeps and rays storing azimuth and elev
 *         ray_count = 0             # <<<<<<<<<<<<<<
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 */
  __pyx_v_ray_count = 0;

  /* "pyart/io/_rsl_interface.pyx":863
 *         # loop over the sweeps and rays storing azimuth and elev
 *         ray_count = 0
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_5, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
    __pyx_t_5 = __pyx_t_3; __Pyx_INCREF(__pyx_t_5); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_5 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_7 = Py_TYPE(__pyx_t_5)->tp_iternext; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_5))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_3 = PyList_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_5)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_5, __pyx_t_6); __Pyx_INCREF(__pyx_t_3); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_3 = PySequence_ITEM(__pyx_t_5, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        #endif
      }
    } else {
      __pyx_t_3 = __pyx_t_7(__pyx_t_5);
      if (unlikely(!__pyx_t_3)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_3);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "pyart/io/_rsl_interface.pyx":864
 *         ray_count = 0
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 */
    __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 864; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[__pyx_t_8]);

    /* "pyart/io/_rsl_interface.pyx":865
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":866
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays             # <<<<<<<<<<<<<<
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]
 */
    __pyx_t_1 = __pyx_v_sweep->h.nrays;
    __pyx_v_nrays = __pyx_t_1;

    /* "pyart/io/_rsl_interface.pyx":867
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):             # <<<<<<<<<<<<<<
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 */
    __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_nrays); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (likely(PyList_CheckExact(__pyx_t_3)) || PyTuple_CheckExact(__pyx_t_3)) {
      __pyx_t_4 = __pyx_t_3; __Pyx_INCREF(__pyx_t_4); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_4 = PyObject_GetIter(__pyx_t_3); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_9 = Py_TYPE(__pyx_t_4)->tp_iternext; if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_4))) {
          if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_3 = PyList_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        } else {
          if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_4)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_4, __pyx_t_8); __Pyx_INCREF(__pyx_t_3); __pyx_t_8++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_3 = PySequence_ITEM(__pyx_t_4, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_3);
          #endif
        }
      } else {
        __pyx_t_3 = __pyx_t_9(__pyx_t_4);
        if (unlikely(!__pyx_t_3)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 867; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_3);
      }
      __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_3);
      __pyx_t_3 = 0;

      /* "pyart/io/_rsl_interface.pyx":868
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]             # <<<<<<<<<<<<<<
 *                 assert ray is not NULL
 *                 azimuth[ray_count + j] = ray.h.azimuth
 */
      __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_v_j); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 868; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ray = (__pyx_v_sweep->ray[__pyx_t_10]);

      /* "pyart/io/_rsl_interface.pyx":869
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL             # <<<<<<<<<<<<<<
 *                 azimuth[ray_count + j] = ray.h.azimuth
 *                 elev[ray_count + j] = ray.h.elev
 */
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(!Py_OptimizeFlag)) {
        if (unlikely(!((__pyx_v_ray != NULL) != 0))) {
          PyErr_SetNone(PyExc_AssertionError);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 869; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
      }
      #endif

      /* "pyart/io/_rsl_interface.pyx":870
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 *                 azimuth[ray_count + j] = ray.h.azimuth             # <<<<<<<<<<<<<<
 *                 elev[ray_count + j] = ray.h.elev
 *             ray_count += nrays
 */
      __pyx_t_3 = PyFloat_FromDouble(__pyx_v_ray->h.azimuth); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 870; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyInt_From_int(__pyx_v_ray_count); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 870; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_11 = PyNumber_Add(__pyx_t_2, __pyx_v_j); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 870; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(PyObject_SetItem(__pyx_v_azimuth, __pyx_t_11, __pyx_t_3) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 870; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "pyart/io/_rsl_interface.pyx":871
 *                 assert ray is not NULL
 *                 azimuth[ray_count + j] = ray.h.azimuth
 *                 elev[ray_count + j] = ray.h.elev             # <<<<<<<<<<<<<<
 *             ray_count += nrays
 *         return azimuth, elev
 */
      __pyx_t_3 = PyFloat_FromDouble(__pyx_v_ray->h.elev); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 871; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_11 = __Pyx_PyInt_From_int(__pyx_v_ray_count); if (unlikely(!__pyx_t_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 871; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_11);
      __pyx_t_2 = PyNumber_Add(__pyx_t_11, __pyx_v_j); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 871; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
      if (unlikely(PyObject_SetItem(__pyx_v_elev, __pyx_t_2, __pyx_t_3) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 871; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "pyart/io/_rsl_interface.pyx":867
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):             # <<<<<<<<<<<<<<
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 */
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":872
 *                 azimuth[ray_count + j] = ray.h.azimuth
 *                 elev[ray_count + j] = ray.h.elev
 *             ray_count += nrays             # <<<<<<<<<<<<<<
 *         return azimuth, elev
 * 
 */
    __pyx_v_ray_count = (__pyx_v_ray_count + __pyx_v_nrays);

    /* "pyart/io/_rsl_interface.pyx":863
 *         # loop over the sweeps and rays storing azimuth and elev
 *         ray_count = 0
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  }
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

  /* "pyart/io/_rsl_interface.pyx":873
 *                 elev[ray_count + j] = ray.h.elev
 *             ray_count += nrays
 *         return azimuth, elev             # <<<<<<<<<<<<<<
 * 
 *     def get_sweep_fix_angles(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_azimuth);
  __Pyx_GIVEREF(__pyx_v_azimuth);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_azimuth);
  __Pyx_INCREF(__pyx_v_elev);
  __Pyx_GIVEREF(__pyx_v_elev);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_v_elev);
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":845
 *         return rslsweep
 * 
 *     def get_azimuth_and_elev_array(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_azimuth_and_elev_array()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_azimuth_and_elev_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_total_rays);
  __Pyx_XDECREF(__pyx_v_azimuth);
  __Pyx_XDECREF(__pyx_v_elev);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":875
 *         return azimuth, elev
 * 
 *     def get_sweep_fix_angles(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep_fix_angles()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_11get_sweep_fix_angles(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_10get_sweep_fix_angles[] = "\n        get_sweep_fix_angles()\n\n        Return array of fix angle for each sweep.\n\n        Angles determined from the first ray in each sweep.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_11get_sweep_fix_angles(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sweep_fix_angles (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_10get_sweep_fix_angles(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_10get_sweep_fix_angles(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  Sweep *__pyx_v_sweep;
  Ray *__pyx_v_ray;
  PyObject *__pyx_v_fix_angles = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sweep_fix_angles", 0);

  /* "pyart/io/_rsl_interface.pyx":885
 *         cdef _rsl_h.Sweep * sweep
 *         cdef _rsl_h.Ray * ray
 *         fix_angles = np.empty((self.nsweeps), dtype='float32')             # <<<<<<<<<<<<<<
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 885; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_fix_angles = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":886
 *         cdef _rsl_h.Ray * ray
 *         fix_angles = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":887
 *         fix_angles = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             ray = sweep.ray[0]
 */
    __pyx_t_7 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_7 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 887; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[__pyx_t_7]);

    /* "pyart/io/_rsl_interface.pyx":888
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             ray = sweep.ray[0]
 *             assert ray is not NULL
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":889
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 *             ray = sweep.ray[0]             # <<<<<<<<<<<<<<
 *             assert ray is not NULL
 *             fix_angles[i] = ray.h.fix_angle
 */
    __pyx_v_ray = (__pyx_v_sweep->ray[0]);

    /* "pyart/io/_rsl_interface.pyx":890
 *             assert sweep is not NULL
 *             ray = sweep.ray[0]
 *             assert ray is not NULL             # <<<<<<<<<<<<<<
 *             fix_angles[i] = ray.h.fix_angle
 *         return fix_angles
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_ray != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 890; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":891
 *             ray = sweep.ray[0]
 *             assert ray is not NULL
 *             fix_angles[i] = ray.h.fix_angle             # <<<<<<<<<<<<<<
 *         return fix_angles
 * 
 */
    __pyx_t_4 = PyFloat_FromDouble(__pyx_v_ray->h.fix_angle); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 891; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(PyObject_SetItem(__pyx_v_fix_angles, __pyx_v_i, __pyx_t_4) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 891; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":886
 *         cdef _rsl_h.Ray * ray
 *         fix_angles = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":892
 *             assert ray is not NULL
 *             fix_angles[i] = ray.h.fix_angle
 *         return fix_angles             # <<<<<<<<<<<<<<
 * 
 *     def get_sweep_azimuths(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_fix_angles);
  __pyx_r = __pyx_v_fix_angles;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":875
 *         return azimuth, elev
 * 
 *     def get_sweep_fix_angles(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep_fix_angles()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_sweep_fix_angles", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_fix_angles);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":894
 *         return fix_angles
 * 
 *     def get_sweep_azimuths(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep_azimuths()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_13get_sweep_azimuths(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_12get_sweep_azimuths[] = "\n        get_sweep_azimuths()\n\n        Return azimuth array for each sweep.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_13get_sweep_azimuths(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sweep_azimuths (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12get_sweep_azimuths(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12get_sweep_azimuths(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  Sweep *__pyx_v_sweep;
  PyObject *__pyx_v_azimuth = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sweep_azimuths", 0);

  /* "pyart/io/_rsl_interface.pyx":901
 *         """
 *         cdef _rsl_h.Sweep * sweep
 *         azimuth = np.empty((self.nsweeps), dtype='float32')             # <<<<<<<<<<<<<<
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 901; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 901; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 901; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 901; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 901; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 901; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 901; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_azimuth = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":902
 *         cdef _rsl_h.Sweep * sweep
 *         azimuth = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 902; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":903
 *         azimuth = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             azimuth[i] = sweep.h.azimuth
 */
    __pyx_t_7 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_7 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 903; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[__pyx_t_7]);

    /* "pyart/io/_rsl_interface.pyx":904
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             azimuth[i] = sweep.h.azimuth
 *         return azimuth
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":905
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 *             azimuth[i] = sweep.h.azimuth             # <<<<<<<<<<<<<<
 *         return azimuth
 * 
 */
    __pyx_t_4 = PyFloat_FromDouble(__pyx_v_sweep->h.azimuth); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 905; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(PyObject_SetItem(__pyx_v_azimuth, __pyx_v_i, __pyx_t_4) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 905; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":902
 *         cdef _rsl_h.Sweep * sweep
 *         azimuth = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":906
 *             assert sweep is not NULL
 *             azimuth[i] = sweep.h.azimuth
 *         return azimuth             # <<<<<<<<<<<<<<
 * 
 *     def get_sweep_elevs(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_azimuth);
  __pyx_r = __pyx_v_azimuth;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":894
 *         return fix_angles
 * 
 *     def get_sweep_azimuths(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep_azimuths()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_sweep_azimuths", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_azimuth);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":908
 *         return azimuth
 * 
 *     def get_sweep_elevs(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep_elevs()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_15get_sweep_elevs(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_14get_sweep_elevs[] = "\n        get_sweep_elevs()\n\n        Return elevation array for each sweep.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_15get_sweep_elevs(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_sweep_elevs (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_14get_sweep_elevs(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_14get_sweep_elevs(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  Sweep *__pyx_v_sweep;
  PyObject *__pyx_v_elev = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  PyObject *(*__pyx_t_6)(PyObject *);
  Py_ssize_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_sweep_elevs", 0);

  /* "pyart/io/_rsl_interface.pyx":915
 *         """
 *         cdef _rsl_h.Sweep * sweep
 *         elev = np.empty((self.nsweeps), dtype='float32')             # <<<<<<<<<<<<<<
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 */
  __pyx_t_1 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_t_1, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 915; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_v_elev = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":916
 *         cdef _rsl_h.Sweep * sweep
 *         elev = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_1, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_1 = __pyx_t_4; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
    __pyx_t_6 = NULL;
  } else {
    __pyx_t_5 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_6 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_6)) {
      if (likely(PyList_CheckExact(__pyx_t_1))) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_4); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_6(__pyx_t_1);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 916; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":917
 *         elev = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             elev[i] = sweep.h.elev
 */
    __pyx_t_7 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_7 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 917; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[__pyx_t_7]);

    /* "pyart/io/_rsl_interface.pyx":918
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             elev[i] = sweep.h.elev
 *         return elev
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 918; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":919
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 *             elev[i] = sweep.h.elev             # <<<<<<<<<<<<<<
 *         return elev
 * 
 */
    __pyx_t_4 = PyFloat_FromDouble(__pyx_v_sweep->h.elev); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 919; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    if (unlikely(PyObject_SetItem(__pyx_v_elev, __pyx_v_i, __pyx_t_4) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 919; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":916
 *         cdef _rsl_h.Sweep * sweep
 *         elev = np.empty((self.nsweeps), dtype='float32')
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":920
 *             assert sweep is not NULL
 *             elev[i] = sweep.h.elev
 *         return elev             # <<<<<<<<<<<<<<
 * 
 *     def get_instr_params(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_elev);
  __pyx_r = __pyx_v_elev;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":908
 *         return azimuth
 * 
 *     def get_sweep_elevs(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_sweep_elevs()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_sweep_elevs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_elev);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":922
 *         return elev
 * 
 *     def get_instr_params(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_instr_params()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_17get_instr_params(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_16get_instr_params[] = "\n        get_instr_params()\n\n        Return instrumental parameter for the volume.\n\n        Returns\n        -------\n        pm_data : array, (nsweeps)\n            Array of prt modes.\n        nv_data : array, (total_rays)\n            Array of nyquist velocities.\n        pr_data : array, (total_rays)\n            Array of pulse repetition frequency in Hz.\n        ur_data : array, (total_rays)\n            Array of unambiguous ranges, in km.\n\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_17get_instr_params(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_instr_params (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_16get_instr_params(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_16get_instr_params(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  int __pyx_v_nrays;
  int __pyx_v_ray_count;
  Sweep *__pyx_v_sweep;
  Ray *__pyx_v_ray;
  PyObject *__pyx_v_total_rays = NULL;
  PyObject *__pyx_v_nyq_vel = NULL;
  PyObject *__pyx_v_valid_nyq_vel = NULL;
  PyObject *__pyx_v_pm_data = NULL;
  PyObject *__pyx_v_nv_data = NULL;
  PyObject *__pyx_v_pr_data = NULL;
  PyObject *__pyx_v_ur_data = NULL;
  PyObject *__pyx_v_i = NULL;
  PyObject *__pyx_v_j = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  PyObject *(*__pyx_t_7)(PyObject *);
  Py_ssize_t __pyx_t_8;
  PyObject *(*__pyx_t_9)(PyObject *);
  Py_ssize_t __pyx_t_10;
  int __pyx_t_11;
  PyObject *__pyx_t_12 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_instr_params", 0);

  /* "pyart/io/_rsl_interface.pyx":940
 * 
 *         """
 *         cdef int nrays = self._Volume.sweep[0].h.nrays             # <<<<<<<<<<<<<<
 *         cdef int ray_count
 *         cdef _rsl_h.Sweep * sweep
 */
  __pyx_t_1 = (__pyx_v_self->_Volume->sweep[0])->h.nrays;
  __pyx_v_nrays = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":948
 * 
 *         # initalize empty instrument parameter arrays
 *         total_rays = self.total_rays()             # <<<<<<<<<<<<<<
 *         nyq_vel = self._Volume.sweep[0].ray[0].h.nyq_vel
 *         valid_nyq_vel = abs(nyq_vel) > 0.1
 */
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_total_rays); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 948; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_4) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 948; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  } else {
    __pyx_t_2 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 948; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_total_rays = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":949
 *         # initalize empty instrument parameter arrays
 *         total_rays = self.total_rays()
 *         nyq_vel = self._Volume.sweep[0].ray[0].h.nyq_vel             # <<<<<<<<<<<<<<
 *         valid_nyq_vel = abs(nyq_vel) > 0.1
 *         pm_data = np.empty(self.nsweeps, dtype='|S24')
 */
  __pyx_t_2 = PyFloat_FromDouble(((__pyx_v_self->_Volume->sweep[0])->ray[0])->h.nyq_vel); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_v_nyq_vel = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":950
 *         total_rays = self.total_rays()
 *         nyq_vel = self._Volume.sweep[0].ray[0].h.nyq_vel
 *         valid_nyq_vel = abs(nyq_vel) > 0.1             # <<<<<<<<<<<<<<
 *         pm_data = np.empty(self.nsweeps, dtype='|S24')
 *         nv_data = np.empty((total_rays), dtype='float32')
 */
  __pyx_t_2 = PyNumber_Absolute(__pyx_v_nyq_vel); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_float_0_1, Py_GT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_valid_nyq_vel = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":951
 *         nyq_vel = self._Volume.sweep[0].ray[0].h.nyq_vel
 *         valid_nyq_vel = abs(nyq_vel) > 0.1
 *         pm_data = np.empty(self.nsweeps, dtype='|S24')             # <<<<<<<<<<<<<<
 *         nv_data = np.empty((total_rays), dtype='float32')
 *         pr_data = np.empty((total_rays), dtype='float32')
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  if (PyDict_SetItem(__pyx_t_3, __pyx_n_s_dtype, __pyx_kp_s_S24) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = __Pyx_PyObject_Call(__pyx_t_2, __pyx_t_4, __pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 951; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_pm_data = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pyart/io/_rsl_interface.pyx":952
 *         valid_nyq_vel = abs(nyq_vel) > 0.1
 *         pm_data = np.empty(self.nsweeps, dtype='|S24')
 *         nv_data = np.empty((total_rays), dtype='float32')             # <<<<<<<<<<<<<<
 *         pr_data = np.empty((total_rays), dtype='float32')
 *         ur_data = np.empty((total_rays), dtype='float32')
 */
  __pyx_t_5 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_empty); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_total_rays);
  __Pyx_GIVEREF(__pyx_v_total_rays);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_total_rays);
  __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  if (PyDict_SetItem(__pyx_t_4, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_5, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 952; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_nv_data = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":953
 *         pm_data = np.empty(self.nsweeps, dtype='|S24')
 *         nv_data = np.empty((total_rays), dtype='float32')
 *         pr_data = np.empty((total_rays), dtype='float32')             # <<<<<<<<<<<<<<
 *         ur_data = np.empty((total_rays), dtype='float32')
 * 
 */
  __pyx_t_2 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 953; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_empty); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 953; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 953; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_total_rays);
  __Pyx_GIVEREF(__pyx_v_total_rays);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_total_rays);
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 953; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 953; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_3 = __Pyx_PyObject_Call(__pyx_t_4, __pyx_t_2, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 953; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_pr_data = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":954
 *         nv_data = np.empty((total_rays), dtype='float32')
 *         pr_data = np.empty((total_rays), dtype='float32')
 *         ur_data = np.empty((total_rays), dtype='float32')             # <<<<<<<<<<<<<<
 * 
 *         # loop over sweeps and rays storing instrument parameters
 */
  __pyx_t_3 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_empty); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_total_rays);
  __Pyx_GIVEREF(__pyx_v_total_rays);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_total_rays);
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_t_2, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_t_5, __pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_ur_data = __pyx_t_4;
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":957
 * 
 *         # loop over sweeps and rays storing instrument parameters
 *         ray_count = 0             # <<<<<<<<<<<<<<
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 */
  __pyx_v_ray_count = 0;

  /* "pyart/io/_rsl_interface.pyx":958
 *         # loop over sweeps and rays storing instrument parameters
 *         ray_count = 0
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_2, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
    __pyx_t_2 = __pyx_t_4; __Pyx_INCREF(__pyx_t_2); __pyx_t_6 = 0;
    __pyx_t_7 = NULL;
  } else {
    __pyx_t_6 = -1; __pyx_t_2 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = Py_TYPE(__pyx_t_2)->tp_iternext; if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  for (;;) {
    if (likely(!__pyx_t_7)) {
      if (likely(PyList_CheckExact(__pyx_t_2))) {
        if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      } else {
        if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_2)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_2, __pyx_t_6); __Pyx_INCREF(__pyx_t_4); __pyx_t_6++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_4 = PySequence_ITEM(__pyx_t_2, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        #endif
      }
    } else {
      __pyx_t_4 = __pyx_t_7(__pyx_t_2);
      if (unlikely(!__pyx_t_4)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 958; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_4);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "pyart/io/_rsl_interface.pyx":959
 *         ray_count = 0
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 */
    __pyx_t_8 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_8 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 959; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[__pyx_t_8]);

    /* "pyart/io/_rsl_interface.pyx":960
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 960; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":961
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays             # <<<<<<<<<<<<<<
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]
 */
    __pyx_t_1 = __pyx_v_sweep->h.nrays;
    __pyx_v_nrays = __pyx_t_1;

    /* "pyart/io/_rsl_interface.pyx":962
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):             # <<<<<<<<<<<<<<
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 */
    __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_nrays); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_3, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (likely(PyList_CheckExact(__pyx_t_4)) || PyTuple_CheckExact(__pyx_t_4)) {
      __pyx_t_3 = __pyx_t_4; __Pyx_INCREF(__pyx_t_3); __pyx_t_8 = 0;
      __pyx_t_9 = NULL;
    } else {
      __pyx_t_8 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_9 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_9)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    for (;;) {
      if (likely(!__pyx_t_9)) {
        if (likely(PyList_CheckExact(__pyx_t_3))) {
          if (__pyx_t_8 >= PyList_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_4 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        } else {
          if (__pyx_t_8 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
          #if CYTHON_COMPILING_IN_CPYTHON
          __pyx_t_4 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_8); __Pyx_INCREF(__pyx_t_4); __pyx_t_8++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          #else
          __pyx_t_4 = PySequence_ITEM(__pyx_t_3, __pyx_t_8); __pyx_t_8++; if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_4);
          #endif
        }
      } else {
        __pyx_t_4 = __pyx_t_9(__pyx_t_3);
        if (unlikely(!__pyx_t_4)) {
          PyObject* exc_type = PyErr_Occurred();
          if (exc_type) {
            if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_4);
      }
      __Pyx_XDECREF_SET(__pyx_v_j, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "pyart/io/_rsl_interface.pyx":963
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]             # <<<<<<<<<<<<<<
 *                 assert ray is not NULL
 *                 if j == 0:
 */
      __pyx_t_10 = __Pyx_PyIndex_AsSsize_t(__pyx_v_j); if (unlikely((__pyx_t_10 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_ray = (__pyx_v_sweep->ray[__pyx_t_10]);

      /* "pyart/io/_rsl_interface.pyx":964
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL             # <<<<<<<<<<<<<<
 *                 if j == 0:
 *                     pm_data[i] = self._prtmode(ray.h)
 */
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(!Py_OptimizeFlag)) {
        if (unlikely(!((__pyx_v_ray != NULL) != 0))) {
          PyErr_SetNone(PyExc_AssertionError);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 964; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
      }
      #endif

      /* "pyart/io/_rsl_interface.pyx":965
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 *                 if j == 0:             # <<<<<<<<<<<<<<
 *                     pm_data[i] = self._prtmode(ray.h)
 * 
 */
      __pyx_t_4 = __Pyx_PyInt_EqObjC(__pyx_v_j, __pyx_int_0, 0, 0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_11 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_11) {

        /* "pyart/io/_rsl_interface.pyx":966
 *                 assert ray is not NULL
 *                 if j == 0:
 *                     pm_data[i] = self._prtmode(ray.h)             # <<<<<<<<<<<<<<
 * 
 *                 if valid_nyq_vel:
 */
        __pyx_t_4 = ((struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self->__pyx_vtab)->_prtmode(__pyx_v_self, __pyx_v_ray->h); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        if (unlikely(PyObject_SetItem(__pyx_v_pm_data, __pyx_v_i, __pyx_t_4) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "pyart/io/_rsl_interface.pyx":965
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 *                 if j == 0:             # <<<<<<<<<<<<<<
 *                     pm_data[i] = self._prtmode(ray.h)
 * 
 */
      }

      /* "pyart/io/_rsl_interface.pyx":968
 *                     pm_data[i] = self._prtmode(ray.h)
 * 
 *                 if valid_nyq_vel:             # <<<<<<<<<<<<<<
 *                     nv_data[ray_count + j] = ray.h.nyq_vel
 *                 else:
 */
      __pyx_t_11 = __Pyx_PyObject_IsTrue(__pyx_v_valid_nyq_vel); if (unlikely(__pyx_t_11 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 968; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      if (__pyx_t_11) {

        /* "pyart/io/_rsl_interface.pyx":969
 * 
 *                 if valid_nyq_vel:
 *                     nv_data[ray_count + j] = ray.h.nyq_vel             # <<<<<<<<<<<<<<
 *                 else:
 *                     nv_data[ray_count + j] = (ray.h.wavelength *
 */
        __pyx_t_4 = PyFloat_FromDouble(__pyx_v_ray->h.nyq_vel); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = __Pyx_PyInt_From_int(__pyx_v_ray_count); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_12 = PyNumber_Add(__pyx_t_5, __pyx_v_j); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_nv_data, __pyx_t_12, __pyx_t_4) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

        /* "pyart/io/_rsl_interface.pyx":968
 *                     pm_data[i] = self._prtmode(ray.h)
 * 
 *                 if valid_nyq_vel:             # <<<<<<<<<<<<<<
 *                     nv_data[ray_count + j] = ray.h.nyq_vel
 *                 else:
 */
        goto __pyx_L8;
      }

      /* "pyart/io/_rsl_interface.pyx":972
 *                 else:
 *                     nv_data[ray_count + j] = (ray.h.wavelength *
 *                                               ray.h.prf / 4.0)             # <<<<<<<<<<<<<<
 * 
 *                 if ray.h.prf == 0:
 */
      /*else*/ {

        /* "pyart/io/_rsl_interface.pyx":971
 *                     nv_data[ray_count + j] = ray.h.nyq_vel
 *                 else:
 *                     nv_data[ray_count + j] = (ray.h.wavelength *             # <<<<<<<<<<<<<<
 *                                               ray.h.prf / 4.0)
 * 
 */
        __pyx_t_4 = PyFloat_FromDouble(((__pyx_v_ray->h.wavelength * __pyx_v_ray->h.prf) / 4.0)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_ray_count); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 971; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __pyx_t_5 = PyNumber_Add(__pyx_t_12, __pyx_v_j); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 971; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_nv_data, __pyx_t_5, __pyx_t_4) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 971; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      }
      __pyx_L8:;

      /* "pyart/io/_rsl_interface.pyx":974
 *                                               ray.h.prf / 4.0)
 * 
 *                 if ray.h.prf == 0:             # <<<<<<<<<<<<<<
 *                     pr_data[ray_count + j] = -999.
 *                 else:
 */
      __pyx_t_11 = ((__pyx_v_ray->h.prf == 0) != 0);
      if (__pyx_t_11) {

        /* "pyart/io/_rsl_interface.pyx":975
 * 
 *                 if ray.h.prf == 0:
 *                     pr_data[ray_count + j] = -999.             # <<<<<<<<<<<<<<
 *                 else:
 *                     pr_data[ray_count + j] = 1. / ray.h.prf
 */
        __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_ray_count); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 975; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_5 = PyNumber_Add(__pyx_t_4, __pyx_v_j); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 975; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_pr_data, __pyx_t_5, __pyx_float_neg_999_) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 975; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

        /* "pyart/io/_rsl_interface.pyx":974
 *                                               ray.h.prf / 4.0)
 * 
 *                 if ray.h.prf == 0:             # <<<<<<<<<<<<<<
 *                     pr_data[ray_count + j] = -999.
 *                 else:
 */
        goto __pyx_L9;
      }

      /* "pyart/io/_rsl_interface.pyx":977
 *                     pr_data[ray_count + j] = -999.
 *                 else:
 *                     pr_data[ray_count + j] = 1. / ray.h.prf             # <<<<<<<<<<<<<<
 *                 ur_data[ray_count + j] = ray.h.unam_rng * 1000.0
 *             ray_count += nrays
 */
      /*else*/ {
        if (unlikely(__pyx_v_ray->h.prf == 0)) {
          PyErr_SetString(PyExc_ZeroDivisionError, "float division");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_5 = PyFloat_FromDouble((1. / __pyx_v_ray->h.prf)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_ray_count); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __pyx_t_12 = PyNumber_Add(__pyx_t_4, __pyx_v_j); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_12);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(PyObject_SetItem(__pyx_v_pr_data, __pyx_t_12, __pyx_t_5) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      }
      __pyx_L9:;

      /* "pyart/io/_rsl_interface.pyx":978
 *                 else:
 *                     pr_data[ray_count + j] = 1. / ray.h.prf
 *                 ur_data[ray_count + j] = ray.h.unam_rng * 1000.0             # <<<<<<<<<<<<<<
 *             ray_count += nrays
 *         return pm_data, nv_data, pr_data, ur_data
 */
      __pyx_t_5 = PyFloat_FromDouble((__pyx_v_ray->h.unam_rng * 1000.0)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 978; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_12 = __Pyx_PyInt_From_int(__pyx_v_ray_count); if (unlikely(!__pyx_t_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 978; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_12);
      __pyx_t_4 = PyNumber_Add(__pyx_t_12, __pyx_v_j); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 978; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_12); __pyx_t_12 = 0;
      if (unlikely(PyObject_SetItem(__pyx_v_ur_data, __pyx_t_4, __pyx_t_5) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 978; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

      /* "pyart/io/_rsl_interface.pyx":962
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):             # <<<<<<<<<<<<<<
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 */
    }
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pyart/io/_rsl_interface.pyx":979
 *                     pr_data[ray_count + j] = 1. / ray.h.prf
 *                 ur_data[ray_count + j] = ray.h.unam_rng * 1000.0
 *             ray_count += nrays             # <<<<<<<<<<<<<<
 *         return pm_data, nv_data, pr_data, ur_data
 * 
 */
    __pyx_v_ray_count = (__pyx_v_ray_count + __pyx_v_nrays);

    /* "pyart/io/_rsl_interface.pyx":958
 *         # loop over sweeps and rays storing instrument parameters
 *         ray_count = 0
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":980
 *                 ur_data[ray_count + j] = ray.h.unam_rng * 1000.0
 *             ray_count += nrays
 *         return pm_data, nv_data, pr_data, ur_data             # <<<<<<<<<<<<<<
 * 
 *     def get_data(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_2 = PyTuple_New(4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_pm_data);
  __Pyx_GIVEREF(__pyx_v_pm_data);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_pm_data);
  __Pyx_INCREF(__pyx_v_nv_data);
  __Pyx_GIVEREF(__pyx_v_nv_data);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_nv_data);
  __Pyx_INCREF(__pyx_v_pr_data);
  __Pyx_GIVEREF(__pyx_v_pr_data);
  PyTuple_SET_ITEM(__pyx_t_2, 2, __pyx_v_pr_data);
  __Pyx_INCREF(__pyx_v_ur_data);
  __Pyx_GIVEREF(__pyx_v_ur_data);
  PyTuple_SET_ITEM(__pyx_t_2, 3, __pyx_v_ur_data);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":922
 *         return elev
 * 
 *     def get_instr_params(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_instr_params()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_12);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_instr_params", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_total_rays);
  __Pyx_XDECREF(__pyx_v_nyq_vel);
  __Pyx_XDECREF(__pyx_v_valid_nyq_vel);
  __Pyx_XDECREF(__pyx_v_pm_data);
  __Pyx_XDECREF(__pyx_v_nv_data);
  __Pyx_XDECREF(__pyx_v_pr_data);
  __Pyx_XDECREF(__pyx_v_ur_data);
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XDECREF(__pyx_v_j);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":982
 *         return pm_data, nv_data, pr_data, ur_data
 * 
 *     def get_data(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_data()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_19get_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_18get_data[] = "\n        get_data()\n\n        Return the two-dimensional data contained in the volume.\n\n        If a given ray has few bins than the first ray, the missing bins\n        will be filled with 131072.0\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_19get_data(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_data (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_18get_data(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_18get_data(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  Range __pyx_v_raw;
  Sweep *__pyx_v_sweep;
  Ray *__pyx_v_ray;
  int __pyx_v_ray_count;
  int __pyx_v_nsweeps;
  int __pyx_v_nrays;
  int __pyx_v_nbins;
  int __pyx_v_nray;
  int __pyx_v_nsweep;
  int __pyx_v_nbin;
  PyArrayObject *__pyx_v_data = 0;
  Volume *__pyx_v_vol;
  PyObject *__pyx_v_total_rays = NULL;
  PyObject *__pyx_v_shape = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_data;
  __Pyx_Buffer __pyx_pybuffer_data;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  Volume *__pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  int __pyx_t_11;
  int __pyx_t_12;
  int __pyx_t_13;
  int __pyx_t_14;
  int __pyx_t_15;
  Py_ssize_t __pyx_t_16;
  Py_ssize_t __pyx_t_17;
  int __pyx_t_18;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_data", 0);
  __pyx_pybuffer_data.pybuffer.buf = NULL;
  __pyx_pybuffer_data.refcount = 0;
  __pyx_pybuffernd_data.data = NULL;
  __pyx_pybuffernd_data.rcbuffer = &__pyx_pybuffer_data;

  /* "pyart/io/_rsl_interface.pyx":997
 *         cdef np.ndarray[np.float32_t, ndim = 2] data
 * 
 *         vol = self._Volume             # <<<<<<<<<<<<<<
 *         nbins = vol.sweep[0].ray[0].h.nbins
 *         total_rays = self.total_rays()
 */
  __pyx_t_1 = __pyx_v_self->_Volume;
  __pyx_v_vol = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":998
 * 
 *         vol = self._Volume
 *         nbins = vol.sweep[0].ray[0].h.nbins             # <<<<<<<<<<<<<<
 *         total_rays = self.total_rays()
 *         shape = (total_rays, nbins)
 */
  __pyx_t_2 = ((__pyx_v_vol->sweep[0])->ray[0])->h.nbins;
  __pyx_v_nbins = __pyx_t_2;

  /* "pyart/io/_rsl_interface.pyx":999
 *         vol = self._Volume
 *         nbins = vol.sweep[0].ray[0].h.nbins
 *         total_rays = self.total_rays()             # <<<<<<<<<<<<<<
 *         shape = (total_rays, nbins)
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 */
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_total_rays); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  if (__pyx_t_5) {
    __pyx_t_3 = __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  } else {
    __pyx_t_3 = __Pyx_PyObject_CallNoArg(__pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 999; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_v_total_rays = __pyx_t_3;
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":1000
 *         nbins = vol.sweep[0].ray[0].h.nbins
 *         total_rays = self.total_rays()
 *         shape = (total_rays, nbins)             # <<<<<<<<<<<<<<
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 * 
 */
  __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_nbins); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1000; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_total_rays);
  __Pyx_GIVEREF(__pyx_v_total_rays);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_total_rays);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_v_shape = ((PyObject*)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyart/io/_rsl_interface.pyx":1001
 *         total_rays = self.total_rays()
 *         shape = (total_rays, nbins)
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05             # <<<<<<<<<<<<<<
 * 
 *         ray_count = 0
 */
  __pyx_t_4 = __Pyx_GetModuleGlobalName(__pyx_n_s_np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_zeros); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_INCREF(__pyx_v_shape);
  __Pyx_GIVEREF(__pyx_v_shape);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_v_shape);
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  if (PyDict_SetItem(__pyx_t_5, __pyx_n_s_dtype, __pyx_n_s_float32) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_6 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyFloat_AddObjC(__pyx_t_6, __pyx_float_1_31072000e_05, 1.31072000e+05, 0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_7 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
    __pyx_t_2 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_data.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_2 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_data.rcbuffer->pybuffer, (PyObject*)__pyx_v_data, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float32_t, PyBUF_FORMAT| PyBUF_STRIDES| PyBUF_WRITABLE, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
    }
    __pyx_pybuffernd_data.diminfo[0].strides = __pyx_pybuffernd_data.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_data.diminfo[0].shape = __pyx_pybuffernd_data.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_data.diminfo[1].strides = __pyx_pybuffernd_data.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_data.diminfo[1].shape = __pyx_pybuffernd_data.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_2 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1001; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_7 = 0;
  __pyx_v_data = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/io/_rsl_interface.pyx":1003
 *         data = np.zeros(shape, dtype='float32') + 1.31072000e+05
 * 
 *         ray_count = 0             # <<<<<<<<<<<<<<
 *         nsweeps = vol.h.nsweeps
 *         for nsweep in range(nsweeps):
 */
  __pyx_v_ray_count = 0;

  /* "pyart/io/_rsl_interface.pyx":1004
 * 
 *         ray_count = 0
 *         nsweeps = vol.h.nsweeps             # <<<<<<<<<<<<<<
 *         for nsweep in range(nsweeps):
 *             sweep = vol.sweep[nsweep]
 */
  __pyx_t_2 = __pyx_v_vol->h.nsweeps;
  __pyx_v_nsweeps = __pyx_t_2;

  /* "pyart/io/_rsl_interface.pyx":1005
 *         ray_count = 0
 *         nsweeps = vol.h.nsweeps
 *         for nsweep in range(nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = vol.sweep[nsweep]
 *             assert sweep is not NULL
 */
  __pyx_t_2 = __pyx_v_nsweeps;
  for (__pyx_t_11 = 0; __pyx_t_11 < __pyx_t_2; __pyx_t_11+=1) {
    __pyx_v_nsweep = __pyx_t_11;

    /* "pyart/io/_rsl_interface.pyx":1006
 *         nsweeps = vol.h.nsweeps
 *         for nsweep in range(nsweeps):
 *             sweep = vol.sweep[nsweep]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 */
    __pyx_v_sweep = (__pyx_v_vol->sweep[__pyx_v_nsweep]);

    /* "pyart/io/_rsl_interface.pyx":1007
 *         for nsweep in range(nsweeps):
 *             sweep = vol.sweep[nsweep]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             nrays = sweep.h.nrays
 *             for nray in range(nrays):
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1007; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":1008
 *             sweep = vol.sweep[nsweep]
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays             # <<<<<<<<<<<<<<
 *             for nray in range(nrays):
 *                 ray = sweep.ray[nray]
 */
    __pyx_t_12 = __pyx_v_sweep->h.nrays;
    __pyx_v_nrays = __pyx_t_12;

    /* "pyart/io/_rsl_interface.pyx":1009
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 *             for nray in range(nrays):             # <<<<<<<<<<<<<<
 *                 ray = sweep.ray[nray]
 *                 assert ray is not NULL
 */
    __pyx_t_12 = __pyx_v_nrays;
    for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
      __pyx_v_nray = __pyx_t_13;

      /* "pyart/io/_rsl_interface.pyx":1010
 *             nrays = sweep.h.nrays
 *             for nray in range(nrays):
 *                 ray = sweep.ray[nray]             # <<<<<<<<<<<<<<
 *                 assert ray is not NULL
 *                 nbins = ray.h.nbins
 */
      __pyx_v_ray = (__pyx_v_sweep->ray[__pyx_v_nray]);

      /* "pyart/io/_rsl_interface.pyx":1011
 *             for nray in range(nrays):
 *                 ray = sweep.ray[nray]
 *                 assert ray is not NULL             # <<<<<<<<<<<<<<
 *                 nbins = ray.h.nbins
 *                 for nbin in range(nbins):
 */
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(!Py_OptimizeFlag)) {
        if (unlikely(!((__pyx_v_ray != NULL) != 0))) {
          PyErr_SetNone(PyExc_AssertionError);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1011; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
      }
      #endif

      /* "pyart/io/_rsl_interface.pyx":1012
 *                 ray = sweep.ray[nray]
 *                 assert ray is not NULL
 *                 nbins = ray.h.nbins             # <<<<<<<<<<<<<<
 *                 for nbin in range(nbins):
 *                     raw = ray.range[nbin]
 */
      __pyx_t_14 = __pyx_v_ray->h.nbins;
      __pyx_v_nbins = __pyx_t_14;

      /* "pyart/io/_rsl_interface.pyx":1013
 *                 assert ray is not NULL
 *                 nbins = ray.h.nbins
 *                 for nbin in range(nbins):             # <<<<<<<<<<<<<<
 *                     raw = ray.range[nbin]
 *                     data[ray_count + nray, nbin] = ray.h.f(raw)
 */
      __pyx_t_14 = __pyx_v_nbins;
      for (__pyx_t_15 = 0; __pyx_t_15 < __pyx_t_14; __pyx_t_15+=1) {
        __pyx_v_nbin = __pyx_t_15;

        /* "pyart/io/_rsl_interface.pyx":1014
 *                 nbins = ray.h.nbins
 *                 for nbin in range(nbins):
 *                     raw = ray.range[nbin]             # <<<<<<<<<<<<<<
 *                     data[ray_count + nray, nbin] = ray.h.f(raw)
 *             ray_count += nrays
 */
        __pyx_v_raw = (__pyx_v_ray->range[__pyx_v_nbin]);

        /* "pyart/io/_rsl_interface.pyx":1015
 *                 for nbin in range(nbins):
 *                     raw = ray.range[nbin]
 *                     data[ray_count + nray, nbin] = ray.h.f(raw)             # <<<<<<<<<<<<<<
 *             ray_count += nrays
 *         return data
 */
        __pyx_t_16 = (__pyx_v_ray_count + __pyx_v_nray);
        __pyx_t_17 = __pyx_v_nbin;
        __pyx_t_18 = -1;
        if (__pyx_t_16 < 0) {
          __pyx_t_16 += __pyx_pybuffernd_data.diminfo[0].shape;
          if (unlikely(__pyx_t_16 < 0)) __pyx_t_18 = 0;
        } else if (unlikely(__pyx_t_16 >= __pyx_pybuffernd_data.diminfo[0].shape)) __pyx_t_18 = 0;
        if (__pyx_t_17 < 0) {
          __pyx_t_17 += __pyx_pybuffernd_data.diminfo[1].shape;
          if (unlikely(__pyx_t_17 < 0)) __pyx_t_18 = 1;
        } else if (unlikely(__pyx_t_17 >= __pyx_pybuffernd_data.diminfo[1].shape)) __pyx_t_18 = 1;
        if (unlikely(__pyx_t_18 != -1)) {
          __Pyx_RaiseBufferIndexError(__pyx_t_18);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1015; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        *__Pyx_BufPtrStrided2d(__pyx_t_5numpy_float32_t *, __pyx_pybuffernd_data.rcbuffer->pybuffer.buf, __pyx_t_16, __pyx_pybuffernd_data.diminfo[0].strides, __pyx_t_17, __pyx_pybuffernd_data.diminfo[1].strides) = __pyx_v_ray->h.f(__pyx_v_raw);
      }
    }

    /* "pyart/io/_rsl_interface.pyx":1016
 *                     raw = ray.range[nbin]
 *                     data[ray_count + nray, nbin] = ray.h.f(raw)
 *             ray_count += nrays             # <<<<<<<<<<<<<<
 *         return data
 * 
 */
    __pyx_v_ray_count = (__pyx_v_ray_count + __pyx_v_nrays);
  }

  /* "pyart/io/_rsl_interface.pyx":1017
 *                     data[ray_count + nray, nbin] = ray.h.f(raw)
 *             ray_count += nrays
 *         return data             # <<<<<<<<<<<<<<
 * 
 *     def is_range_bins_uniform(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_data));
  __pyx_r = ((PyObject *)__pyx_v_data);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":982
 *         return pm_data, nv_data, pr_data, ur_data
 * 
 *     def get_data(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_data()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.get_data", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_data.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_data);
  __Pyx_XDECREF(__pyx_v_total_rays);
  __Pyx_XDECREF(__pyx_v_shape);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1019
 *         return data
 * 
 *     def is_range_bins_uniform(self):             # <<<<<<<<<<<<<<
 *         """
 *         is_range_bins_uniform()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_21is_range_bins_uniform(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_20is_range_bins_uniform[] = "\n        is_range_bins_uniform()\n\n        Return True is the locations of the range bin are identical for all\n        rays, False if locations change in one or more rays.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_21is_range_bins_uniform(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("is_range_bins_uniform (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_20is_range_bins_uniform(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_20is_range_bins_uniform(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  int __pyx_v_nrays;
  Sweep *__pyx_v_sweep;
  Ray *__pyx_v_ray;
  int __pyx_v_ref_gate_size;
  int __pyx_v_ref_range_bin1;
  PyObject *__pyx_v_i = NULL;
  int __pyx_v_j;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  Py_ssize_t __pyx_t_4;
  PyObject *(*__pyx_t_5)(PyObject *);
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("is_range_bins_uniform", 0);

  /* "pyart/io/_rsl_interface.pyx":1026
 *         rays, False if locations change in one or more rays.
 *         """
 *         cdef int nrays = self._Volume.sweep[0].h.nrays             # <<<<<<<<<<<<<<
 *         cdef _rsl_h.Sweep * sweep
 *         cdef _rsl_h.Ray * ray
 */
  __pyx_t_1 = (__pyx_v_self->_Volume->sweep[0])->h.nrays;
  __pyx_v_nrays = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":1032
 *         # loop over the sweeps and rays checking that the gate_size and
 *         # range_bin1 are the same as the that in the first ray
 *         sweep = self._Volume.sweep[0]             # <<<<<<<<<<<<<<
 *         assert sweep is not NULL
 *         ray = sweep.ray[0]
 */
  __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[0]);

  /* "pyart/io/_rsl_interface.pyx":1033
 *         # range_bin1 are the same as the that in the first ray
 *         sweep = self._Volume.sweep[0]
 *         assert sweep is not NULL             # <<<<<<<<<<<<<<
 *         ray = sweep.ray[0]
 *         assert ray is not NULL
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif

  /* "pyart/io/_rsl_interface.pyx":1034
 *         sweep = self._Volume.sweep[0]
 *         assert sweep is not NULL
 *         ray = sweep.ray[0]             # <<<<<<<<<<<<<<
 *         assert ray is not NULL
 *         ref_gate_size = ray.h.gate_size
 */
  __pyx_v_ray = (__pyx_v_sweep->ray[0]);

  /* "pyart/io/_rsl_interface.pyx":1035
 *         assert sweep is not NULL
 *         ray = sweep.ray[0]
 *         assert ray is not NULL             # <<<<<<<<<<<<<<
 *         ref_gate_size = ray.h.gate_size
 *         ref_range_bin1 = ray.h.range_bin1
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!Py_OptimizeFlag)) {
    if (unlikely(!((__pyx_v_ray != NULL) != 0))) {
      PyErr_SetNone(PyExc_AssertionError);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1035; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif

  /* "pyart/io/_rsl_interface.pyx":1036
 *         ray = sweep.ray[0]
 *         assert ray is not NULL
 *         ref_gate_size = ray.h.gate_size             # <<<<<<<<<<<<<<
 *         ref_range_bin1 = ray.h.range_bin1
 * 
 */
  __pyx_t_1 = __pyx_v_ray->h.gate_size;
  __pyx_v_ref_gate_size = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":1037
 *         assert ray is not NULL
 *         ref_gate_size = ray.h.gate_size
 *         ref_range_bin1 = ray.h.range_bin1             # <<<<<<<<<<<<<<
 * 
 *         for i in range(self.nsweeps):
 */
  __pyx_t_1 = __pyx_v_ray->h.range_bin1;
  __pyx_v_ref_range_bin1 = __pyx_t_1;

  /* "pyart/io/_rsl_interface.pyx":1039
 *         ref_range_bin1 = ray.h.range_bin1
 * 
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  __pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_nsweeps); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyObject_Call(__pyx_builtin_range, __pyx_t_3, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
    __pyx_t_3 = __pyx_t_2; __Pyx_INCREF(__pyx_t_3); __pyx_t_4 = 0;
    __pyx_t_5 = NULL;
  } else {
    __pyx_t_4 = -1; __pyx_t_3 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = Py_TYPE(__pyx_t_3)->tp_iternext; if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  for (;;) {
    if (likely(!__pyx_t_5)) {
      if (likely(PyList_CheckExact(__pyx_t_3))) {
        if (__pyx_t_4 >= PyList_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      } else {
        if (__pyx_t_4 >= PyTuple_GET_SIZE(__pyx_t_3)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_3, __pyx_t_4); __Pyx_INCREF(__pyx_t_2); __pyx_t_4++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_3, __pyx_t_4); __pyx_t_4++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        #endif
      }
    } else {
      __pyx_t_2 = __pyx_t_5(__pyx_t_3);
      if (unlikely(!__pyx_t_2)) {
        PyObject* exc_type = PyErr_Occurred();
        if (exc_type) {
          if (likely(exc_type == PyExc_StopIteration || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
          else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        break;
      }
      __Pyx_GOTREF(__pyx_t_2);
    }
    __Pyx_XDECREF_SET(__pyx_v_i, __pyx_t_2);
    __pyx_t_2 = 0;

    /* "pyart/io/_rsl_interface.pyx":1040
 * 
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]             # <<<<<<<<<<<<<<
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 */
    __pyx_t_6 = __Pyx_PyIndex_AsSsize_t(__pyx_v_i); if (unlikely((__pyx_t_6 == (Py_ssize_t)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_sweep = (__pyx_v_self->_Volume->sweep[__pyx_t_6]);

    /* "pyart/io/_rsl_interface.pyx":1041
 *         for i in range(self.nsweeps):
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL             # <<<<<<<<<<<<<<
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):
 */
    #ifndef CYTHON_WITHOUT_ASSERTIONS
    if (unlikely(!Py_OptimizeFlag)) {
      if (unlikely(!((__pyx_v_sweep != NULL) != 0))) {
        PyErr_SetNone(PyExc_AssertionError);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1041; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
    }
    #endif

    /* "pyart/io/_rsl_interface.pyx":1042
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays             # <<<<<<<<<<<<<<
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]
 */
    __pyx_t_1 = __pyx_v_sweep->h.nrays;
    __pyx_v_nrays = __pyx_t_1;

    /* "pyart/io/_rsl_interface.pyx":1043
 *             assert sweep is not NULL
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):             # <<<<<<<<<<<<<<
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 */
    __pyx_t_1 = __pyx_v_nrays;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_1; __pyx_t_7+=1) {
      __pyx_v_j = __pyx_t_7;

      /* "pyart/io/_rsl_interface.pyx":1044
 *             nrays = sweep.h.nrays
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]             # <<<<<<<<<<<<<<
 *                 assert ray is not NULL
 *                 if ray.h.gate_size != ref_gate_size:
 */
      __pyx_v_ray = (__pyx_v_sweep->ray[__pyx_v_j]);

      /* "pyart/io/_rsl_interface.pyx":1045
 *             for j in range(nrays):
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL             # <<<<<<<<<<<<<<
 *                 if ray.h.gate_size != ref_gate_size:
 *                     return False
 */
      #ifndef CYTHON_WITHOUT_ASSERTIONS
      if (unlikely(!Py_OptimizeFlag)) {
        if (unlikely(!((__pyx_v_ray != NULL) != 0))) {
          PyErr_SetNone(PyExc_AssertionError);
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1045; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
      }
      #endif

      /* "pyart/io/_rsl_interface.pyx":1046
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 *                 if ray.h.gate_size != ref_gate_size:             # <<<<<<<<<<<<<<
 *                     return False
 *                 if ray.h.range_bin1 != ref_range_bin1:
 */
      __pyx_t_8 = ((__pyx_v_ray->h.gate_size != __pyx_v_ref_gate_size) != 0);
      if (__pyx_t_8) {

        /* "pyart/io/_rsl_interface.pyx":1047
 *                 assert ray is not NULL
 *                 if ray.h.gate_size != ref_gate_size:
 *                     return False             # <<<<<<<<<<<<<<
 *                 if ray.h.range_bin1 != ref_range_bin1:
 *                     return False
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_False);
        __pyx_r = Py_False;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "pyart/io/_rsl_interface.pyx":1046
 *                 ray = sweep.ray[j]
 *                 assert ray is not NULL
 *                 if ray.h.gate_size != ref_gate_size:             # <<<<<<<<<<<<<<
 *                     return False
 *                 if ray.h.range_bin1 != ref_range_bin1:
 */
      }

      /* "pyart/io/_rsl_interface.pyx":1048
 *                 if ray.h.gate_size != ref_gate_size:
 *                     return False
 *                 if ray.h.range_bin1 != ref_range_bin1:             # <<<<<<<<<<<<<<
 *                     return False
 *         return True
 */
      __pyx_t_8 = ((__pyx_v_ray->h.range_bin1 != __pyx_v_ref_range_bin1) != 0);
      if (__pyx_t_8) {

        /* "pyart/io/_rsl_interface.pyx":1049
 *                     return False
 *                 if ray.h.range_bin1 != ref_range_bin1:
 *                     return False             # <<<<<<<<<<<<<<
 *         return True
 * 
 */
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(Py_False);
        __pyx_r = Py_False;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        goto __pyx_L0;

        /* "pyart/io/_rsl_interface.pyx":1048
 *                 if ray.h.gate_size != ref_gate_size:
 *                     return False
 *                 if ray.h.range_bin1 != ref_range_bin1:             # <<<<<<<<<<<<<<
 *                     return False
 *         return True
 */
      }
    }

    /* "pyart/io/_rsl_interface.pyx":1039
 *         ref_range_bin1 = ray.h.range_bin1
 * 
 *         for i in range(self.nsweeps):             # <<<<<<<<<<<<<<
 *             sweep = self._Volume.sweep[i]
 *             assert sweep is not NULL
 */
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":1050
 *                 if ray.h.range_bin1 != ref_range_bin1:
 *                     return False
 *         return True             # <<<<<<<<<<<<<<
 * 
 *     cdef _prtmode(self, _rsl_h.Ray_header h):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(Py_True);
  __pyx_r = Py_True;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1019
 *         return data
 * 
 *     def is_range_bins_uniform(self):             # <<<<<<<<<<<<<<
 *         """
 *         is_range_bins_uniform()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.is_range_bins_uniform", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_i);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1052
 *         return True
 * 
 *     cdef _prtmode(self, _rsl_h.Ray_header h):             # <<<<<<<<<<<<<<
 *         """ Return the prt mode of a given Ray header. """
 *         # TODO need to add additional logic here
 */

static PyObject *__pyx_f_5pyart_2io_14_rsl_interface_10_RslVolume__prtmode(CYTHON_UNUSED struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, Ray_header __pyx_v_h) {
  PyObject *__pyx_v_mode = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_prtmode", 0);

  /* "pyart/io/_rsl_interface.pyx":1055
 *         """ Return the prt mode of a given Ray header. """
 *         # TODO need to add additional logic here
 *         if h.prf2 != h.prf:             # <<<<<<<<<<<<<<
 *             mode = 'dual                    '
 *         else:
 */
  __pyx_t_1 = ((__pyx_v_h.prf2 != __pyx_v_h.prf) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":1056
 *         # TODO need to add additional logic here
 *         if h.prf2 != h.prf:
 *             mode = 'dual                    '             # <<<<<<<<<<<<<<
 *         else:
 *             mode = 'fixed                   '
 */
    __Pyx_INCREF(__pyx_kp_s_dual);
    __pyx_v_mode = __pyx_kp_s_dual;

    /* "pyart/io/_rsl_interface.pyx":1055
 *         """ Return the prt mode of a given Ray header. """
 *         # TODO need to add additional logic here
 *         if h.prf2 != h.prf:             # <<<<<<<<<<<<<<
 *             mode = 'dual                    '
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pyart/io/_rsl_interface.pyx":1058
 *             mode = 'dual                    '
 *         else:
 *             mode = 'fixed                   '             # <<<<<<<<<<<<<<
 *         return mode
 * 
 */
  /*else*/ {
    __Pyx_INCREF(__pyx_kp_s_fixed);
    __pyx_v_mode = __pyx_kp_s_fixed;
  }
  __pyx_L3:;

  /* "pyart/io/_rsl_interface.pyx":1059
 *         else:
 *             mode = 'fixed                   '
 *         return mode             # <<<<<<<<<<<<<<
 * 
 *     # header properties mapped to class attributes.
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_mode);
  __pyx_r = __pyx_v_mode;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1052
 *         return True
 * 
 *     cdef _prtmode(self, _rsl_h.Ray_header h):             # <<<<<<<<<<<<<<
 *         """ Return the prt mode of a given Ray header. """
 *         # TODO need to add additional logic here
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_mode);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1063
 *     # header properties mapped to class attributes.
 *     property nsweeps:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Volume.h.nsweeps
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1064
 *     property nsweeps:
 *         def __get__(self):
 *             return self._Volume.h.nsweeps             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int nsweeps):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Volume->h.nsweeps); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1064; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1063
 *     # header properties mapped to class attributes.
 *     property nsweeps:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Volume.h.nsweeps
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.nsweeps.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1066
 *             return self._Volume.h.nsweeps
 * 
 *         def __set__(self, int nsweeps):             # <<<<<<<<<<<<<<
 *             self._Volume.h.nsweeps = nsweeps
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nsweeps); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nsweeps) {
  int __pyx_v_nsweeps;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_nsweeps); {
    __pyx_v_nsweeps = __Pyx_PyInt_As_int(__pyx_arg_nsweeps); if (unlikely((__pyx_v_nsweeps == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1066; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.nsweeps.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self), ((int)__pyx_v_nsweeps));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, int __pyx_v_nsweeps) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1067
 * 
 *         def __set__(self, int nsweeps):
 *             self._Volume.h.nsweeps = nsweeps             # <<<<<<<<<<<<<<
 * 
 *     property calibr_const:
 */
  __pyx_v_self->_Volume->h.nsweeps = __pyx_v_nsweeps;

  /* "pyart/io/_rsl_interface.pyx":1066
 *             return self._Volume.h.nsweeps
 * 
 *         def __set__(self, int nsweeps):             # <<<<<<<<<<<<<<
 *             self._Volume.h.nsweeps = nsweeps
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1070
 * 
 *     property calibr_const:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Volume.h.calibr_const
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1071
 *     property calibr_const:
 *         def __get__(self):
 *             return self._Volume.h.calibr_const             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float calibr_const):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Volume->h.calibr_const); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1071; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1070
 * 
 *     property calibr_const:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Volume.h.calibr_const
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.calibr_const.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1073
 *             return self._Volume.h.calibr_const
 * 
 *         def __set__(self, float calibr_const):             # <<<<<<<<<<<<<<
 *             self._Volume.h.calibr_const = calibr_const
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_calibr_const); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_calibr_const) {
  float __pyx_v_calibr_const;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_calibr_const); {
    __pyx_v_calibr_const = __pyx_PyFloat_AsFloat(__pyx_arg_calibr_const); if (unlikely((__pyx_v_calibr_const == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1073; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface._RslVolume.calibr_const.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_self), ((float)__pyx_v_calibr_const));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_self, float __pyx_v_calibr_const) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1074
 * 
 *         def __set__(self, float calibr_const):
 *             self._Volume.h.calibr_const = calibr_const             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_v_self->_Volume->h.calibr_const = __pyx_v_calibr_const;

  /* "pyart/io/_rsl_interface.pyx":1073
 *             return self._Volume.h.calibr_const
 * 
 *         def __set__(self, float calibr_const):             # <<<<<<<<<<<<<<
 *             self._Volume.h.calibr_const = calibr_const
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1127
 *     cdef _rsl_h.Ray * _Ray
 * 
 *     def __cinit__(self, filename, radar_format=None, callid=None):             # <<<<<<<<<<<<<<
 *         """ Initalize the _RslFile object. """
 *         if radar_format == 'wsr88d':
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_1__cinit__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_filename = 0;
  PyObject *__pyx_v_radar_format = 0;
  PyObject *__pyx_v_callid = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__cinit__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_filename,&__pyx_n_s_radar_format,&__pyx_n_s_callid,0};
    PyObject* values[3] = {0,0,0};
    values[1] = ((PyObject *)Py_None);
    values[2] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s_filename)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_radar_format);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_callid);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__cinit__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1127; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_filename = values[0];
    __pyx_v_radar_format = values[1];
    __pyx_v_callid = values[2];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__cinit__", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1127; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile___cinit__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), __pyx_v_filename, __pyx_v_radar_format, __pyx_v_callid);

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile___cinit__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, PyObject *__pyx_v_filename, PyObject *__pyx_v_radar_format, PyObject *__pyx_v_callid) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  char *__pyx_t_4;
  char *__pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__cinit__", 0);

  /* "pyart/io/_rsl_interface.pyx":1129
 *     def __cinit__(self, filename, radar_format=None, callid=None):
 *         """ Initalize the _RslFile object. """
 *         if radar_format == 'wsr88d':             # <<<<<<<<<<<<<<
 *             if callid is None:
 *                 raise ValueError('callid must be provided.')
 */
  __pyx_t_1 = (__Pyx_PyString_Equals(__pyx_v_radar_format, __pyx_n_s_wsr88d, Py_EQ)); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1129; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":1130
 *         """ Initalize the _RslFile object. """
 *         if radar_format == 'wsr88d':
 *             if callid is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('callid must be provided.')
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)
 */
    __pyx_t_1 = (__pyx_v_callid == Py_None);
    __pyx_t_2 = (__pyx_t_1 != 0);
    if (__pyx_t_2) {

      /* "pyart/io/_rsl_interface.pyx":1131
 *         if radar_format == 'wsr88d':
 *             if callid is None:
 *                 raise ValueError('callid must be provided.')             # <<<<<<<<<<<<<<
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)
 *         elif radar_format is None:
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__6, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/io/_rsl_interface.pyx":1130
 *         """ Initalize the _RslFile object. """
 *         if radar_format == 'wsr88d':
 *             if callid is None:             # <<<<<<<<<<<<<<
 *                 raise ValueError('callid must be provided.')
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)
 */
    }

    /* "pyart/io/_rsl_interface.pyx":1132
 *             if callid is None:
 *                 raise ValueError('callid must be provided.')
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)             # <<<<<<<<<<<<<<
 *         elif radar_format is None:
 *             self._Radar = _rsl_h.RSL_anyformat_to_radar(filename)
 */
    __pyx_t_4 = __Pyx_PyObject_AsString(__pyx_v_filename); if (unlikely((!__pyx_t_4) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_5 = __Pyx_PyObject_AsString(__pyx_v_callid); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_self->_Radar = RSL_wsr88d_to_radar(__pyx_t_4, __pyx_t_5);

    /* "pyart/io/_rsl_interface.pyx":1129
 *     def __cinit__(self, filename, radar_format=None, callid=None):
 *         """ Initalize the _RslFile object. """
 *         if radar_format == 'wsr88d':             # <<<<<<<<<<<<<<
 *             if callid is None:
 *                 raise ValueError('callid must be provided.')
 */
    goto __pyx_L3;
  }

  /* "pyart/io/_rsl_interface.pyx":1133
 *                 raise ValueError('callid must be provided.')
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)
 *         elif radar_format is None:             # <<<<<<<<<<<<<<
 *             self._Radar = _rsl_h.RSL_anyformat_to_radar(filename)
 *         else:
 */
  __pyx_t_2 = (__pyx_v_radar_format == Py_None);
  __pyx_t_1 = (__pyx_t_2 != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":1134
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)
 *         elif radar_format is None:
 *             self._Radar = _rsl_h.RSL_anyformat_to_radar(filename)             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError('invalid radar_format:', radar_format)
 */
    __pyx_t_5 = __Pyx_PyObject_AsString(__pyx_v_filename); if (unlikely((!__pyx_t_5) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1134; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_self->_Radar = RSL_anyformat_to_radar(__pyx_t_5);

    /* "pyart/io/_rsl_interface.pyx":1133
 *                 raise ValueError('callid must be provided.')
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)
 *         elif radar_format is None:             # <<<<<<<<<<<<<<
 *             self._Radar = _rsl_h.RSL_anyformat_to_radar(filename)
 *         else:
 */
    goto __pyx_L3;
  }

  /* "pyart/io/_rsl_interface.pyx":1136
 *             self._Radar = _rsl_h.RSL_anyformat_to_radar(filename)
 *         else:
 *             raise ValueError('invalid radar_format:', radar_format)             # <<<<<<<<<<<<<<
 *         if self._Radar is NULL:
 *             raise IOError('file cannot be read.')
 */
  /*else*/ {
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_kp_s_invalid_radar_format);
    __Pyx_GIVEREF(__pyx_kp_s_invalid_radar_format);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_kp_s_invalid_radar_format);
    __Pyx_INCREF(__pyx_v_radar_format);
    __Pyx_GIVEREF(__pyx_v_radar_format);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_v_radar_format);
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1136; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L3:;

  /* "pyart/io/_rsl_interface.pyx":1137
 *         else:
 *             raise ValueError('invalid radar_format:', radar_format)
 *         if self._Radar is NULL:             # <<<<<<<<<<<<<<
 *             raise IOError('file cannot be read.')
 * 
 */
  __pyx_t_1 = ((__pyx_v_self->_Radar == NULL) != 0);
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":1138
 *             raise ValueError('invalid radar_format:', radar_format)
 *         if self._Radar is NULL:
 *             raise IOError('file cannot be read.')             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
    __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_IOError, __pyx_tuple__7, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_Raise(__pyx_t_6, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":1137
 *         else:
 *             raise ValueError('invalid radar_format:', radar_format)
 *         if self._Radar is NULL:             # <<<<<<<<<<<<<<
 *             raise IOError('file cannot be read.')
 * 
 */
  }

  /* "pyart/io/_rsl_interface.pyx":1127
 *     cdef _rsl_h.Ray * _Ray
 * 
 *     def __cinit__(self, filename, radar_format=None, callid=None):             # <<<<<<<<<<<<<<
 *         """ Initalize the _RslFile object. """
 *         if radar_format == 'wsr88d':
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.__cinit__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1140
 *             raise IOError('file cannot be read.')
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         """ Free memory used by object. """
 *         _rsl_h.RSL_free_radar(self._Radar)
 */

/* Python wrapper */
static void __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_2__dealloc__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_2__dealloc__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/io/_rsl_interface.pyx":1142
 *     def __dealloc__(self):
 *         """ Free memory used by object. """
 *         _rsl_h.RSL_free_radar(self._Radar)             # <<<<<<<<<<<<<<
 * 
 *     def get_volume(self, int volume_number):
 */
  RSL_free_radar(__pyx_v_self->_Radar);

  /* "pyart/io/_rsl_interface.pyx":1140
 *             raise IOError('file cannot be read.')
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         """ Free memory used by object. """
 *         _rsl_h.RSL_free_radar(self._Radar)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "pyart/io/_rsl_interface.pyx":1144
 *         _rsl_h.RSL_free_radar(self._Radar)
 * 
 *     def get_volume(self, int volume_number):             # <<<<<<<<<<<<<<
 *         """
 *         get_volume(volume_number)
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5get_volume(PyObject *__pyx_v_self, PyObject *__pyx_arg_volume_number); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_4get_volume[] = "\n        get_volume(volume_number)\n\n        Return a _RslVolume for a given volume number.\n\n        Parameters\n        ----------\n        volume_number : int\n            Volume number to retrieve\n\n        Returns\n        -------\n        volume : _RslVolume\n            _RslVolume object containing requested volume.\n\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5get_volume(PyObject *__pyx_v_self, PyObject *__pyx_arg_volume_number) {
  int __pyx_v_volume_number;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_volume (wrapper)", 0);
  assert(__pyx_arg_volume_number); {
    __pyx_v_volume_number = __Pyx_PyInt_As_int(__pyx_arg_volume_number); if (unlikely((__pyx_v_volume_number == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1144; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.get_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4get_volume(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_volume_number));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4get_volume(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_volume_number) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *__pyx_v_rslvolume = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_volume", 0);

  /* "pyart/io/_rsl_interface.pyx":1161
 * 
 *         """
 *         if volume_number < 0 or volume_number >= self._Radar.h.nvolumes:             # <<<<<<<<<<<<<<
 *             raise ValueError('invalid volume_number')
 * 
 */
  __pyx_t_2 = ((__pyx_v_volume_number < 0) != 0);
  if (!__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L4_bool_binop_done;
  }
  __pyx_t_2 = ((__pyx_v_volume_number >= __pyx_v_self->_Radar->h.nvolumes) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L4_bool_binop_done:;
  if (__pyx_t_1) {

    /* "pyart/io/_rsl_interface.pyx":1162
 *         """
 *         if volume_number < 0 or volume_number >= self._Radar.h.nvolumes:
 *             raise ValueError('invalid volume_number')             # <<<<<<<<<<<<<<
 * 
 *         rslvolume = _RslVolume()
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__8, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/io/_rsl_interface.pyx":1161
 * 
 *         """
 *         if volume_number < 0 or volume_number >= self._Radar.h.nvolumes:             # <<<<<<<<<<<<<<
 *             raise ValueError('invalid volume_number')
 * 
 */
  }

  /* "pyart/io/_rsl_interface.pyx":1164
 *             raise ValueError('invalid volume_number')
 * 
 *         rslvolume = _RslVolume()             # <<<<<<<<<<<<<<
 *         rslvolume.load(self._Radar.v[volume_number])
 *         return rslvolume
 */
  __pyx_t_3 = __Pyx_PyObject_Call(((PyObject *)__pyx_ptype_5pyart_2io_14_rsl_interface__RslVolume), __pyx_empty_tuple, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1164; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_v_rslvolume = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":1165
 * 
 *         rslvolume = _RslVolume()
 *         rslvolume.load(self._Radar.v[volume_number])             # <<<<<<<<<<<<<<
 *         return rslvolume
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume *)__pyx_v_rslvolume->__pyx_vtab)->load(__pyx_v_rslvolume, (__pyx_v_self->_Radar->v[__pyx_v_volume_number])); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pyart/io/_rsl_interface.pyx":1166
 *         rslvolume = _RslVolume()
 *         rslvolume.load(self._Radar.v[volume_number])
 *         return rslvolume             # <<<<<<<<<<<<<<
 * 
 *     def available_moments(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_rslvolume));
  __pyx_r = ((PyObject *)__pyx_v_rslvolume);
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1144
 *         _rsl_h.RSL_free_radar(self._Radar)
 * 
 *     def get_volume(self, int volume_number):             # <<<<<<<<<<<<<<
 *         """
 *         get_volume(volume_number)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.get_volume", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_rslvolume);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1168
 *         return rslvolume
 * 
 *     def available_moments(self):             # <<<<<<<<<<<<<<
 *         """
 *         available_moments()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_7available_moments(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_6available_moments[] = "\n        available_moments()\n\n        Return a list of available volume moments.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_7available_moments(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("available_moments (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6available_moments(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6available_moments(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_v_av = NULL;
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("available_moments", 0);

  /* "pyart/io/_rsl_interface.pyx":1174
 *         Return a list of available volume moments.
 *         """
 *         av = []             # <<<<<<<<<<<<<<
 *         for i in range(self._Radar.h.nvolumes):
 *             if self._Radar.v[i] is not NULL:
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1174; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_av = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":1175
 *         """
 *         av = []
 *         for i in range(self._Radar.h.nvolumes):             # <<<<<<<<<<<<<<
 *             if self._Radar.v[i] is not NULL:
 *                 av.append(i)
 */
  __pyx_t_2 = __pyx_v_self->_Radar->h.nvolumes;
  for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
    __pyx_v_i = __pyx_t_3;

    /* "pyart/io/_rsl_interface.pyx":1176
 *         av = []
 *         for i in range(self._Radar.h.nvolumes):
 *             if self._Radar.v[i] is not NULL:             # <<<<<<<<<<<<<<
 *                 av.append(i)
 *         return av
 */
    __pyx_t_4 = (((__pyx_v_self->_Radar->v[__pyx_v_i]) != NULL) != 0);
    if (__pyx_t_4) {

      /* "pyart/io/_rsl_interface.pyx":1177
 *         for i in range(self._Radar.h.nvolumes):
 *             if self._Radar.v[i] is not NULL:
 *                 av.append(i)             # <<<<<<<<<<<<<<
 *         return av
 * 
 */
      __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_i); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_av, __pyx_t_1); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1177; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

      /* "pyart/io/_rsl_interface.pyx":1176
 *         av = []
 *         for i in range(self._Radar.h.nvolumes):
 *             if self._Radar.v[i] is not NULL:             # <<<<<<<<<<<<<<
 *                 av.append(i)
 *         return av
 */
    }
  }

  /* "pyart/io/_rsl_interface.pyx":1178
 *             if self._Radar.v[i] is not NULL:
 *                 av.append(i)
 *         return av             # <<<<<<<<<<<<<<
 * 
 *     def get_radar_header(self):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_av);
  __pyx_r = __pyx_v_av;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1168
 *         return rslvolume
 * 
 *     def available_moments(self):             # <<<<<<<<<<<<<<
 *         """
 *         available_moments()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.available_moments", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_av);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1180
 *         return av
 * 
 *     def get_radar_header(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_radar_headers()
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9get_radar_header(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_8get_radar_header[] = "\n        get_radar_headers()\n\n        Return a dictionary of radar header parameters.\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9get_radar_header(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_radar_header (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8get_radar_header(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8get_radar_header(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_radar_header", 0);

  /* "pyart/io/_rsl_interface.pyx":1186
 *         Return a dictionary of radar header parameters.
 *         """
 *         return self._Radar.h             # <<<<<<<<<<<<<<
 * 
 *     def get_volume_array(self, int volume_num):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_convert__to_py_Radar_header(__pyx_v_self->_Radar->h); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1186; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1180
 *         return av
 * 
 *     def get_radar_header(self):             # <<<<<<<<<<<<<<
 *         """
 *         get_radar_headers()
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.get_radar_header", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1188
 *         return self._Radar.h
 * 
 *     def get_volume_array(self, int volume_num):             # <<<<<<<<<<<<<<
 *         """
 *         get_volume_array(volume_number)
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_11get_volume_array(PyObject *__pyx_v_self, PyObject *__pyx_arg_volume_num); /*proto*/
static char __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_10get_volume_array[] = "\n        get_volume_array(volume_number)\n\n        Return the three-dimensional data contained in a given volume.\n\n        Parameters\n        ----------\n        volume_number : int\n\n        Returns\n        -------\n        volume : array (nsweep, nrays, nbins), float32\n            Array containing  data for the given volume.\n\n        ";
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_11get_volume_array(PyObject *__pyx_v_self, PyObject *__pyx_arg_volume_num) {
  int __pyx_v_volume_num;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("get_volume_array (wrapper)", 0);
  assert(__pyx_arg_volume_num); {
    __pyx_v_volume_num = __Pyx_PyInt_As_int(__pyx_arg_volume_num); if (unlikely((__pyx_v_volume_num == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.get_volume_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_10get_volume_array(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_volume_num));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_10get_volume_array(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_volume_num) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("get_volume_array", 0);

  /* "pyart/io/_rsl_interface.pyx":1204
 * 
 *         """
 *         return self.get_volume(volume_num).get_data()             # <<<<<<<<<<<<<<
 * 
 *     # header properties mapped to class attributes.
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_get_volume); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_volume_num); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (!__pyx_t_5) {
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_GOTREF(__pyx_t_2);
  } else {
    __pyx_t_6 = PyTuple_New(1+1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_GIVEREF(__pyx_t_5); PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_5); __pyx_t_5 = NULL;
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_6, 0+1, __pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_2 = __Pyx_PyObject_Call(__pyx_t_3, __pyx_t_6, NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  }
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_get_data); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_COMPILING_IN_CPYTHON && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  if (__pyx_t_2) {
    __pyx_t_1 = __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  } else {
    __pyx_t_1 = __Pyx_PyObject_CallNoArg(__pyx_t_3); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1188
 *         return self._Radar.h
 * 
 *     def get_volume_array(self, int volume_num):             # <<<<<<<<<<<<<<
 *         """
 *         get_volume_array(volume_number)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.get_volume_array", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1208
 *     # header properties mapped to class attributes.
 *     property month:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.month
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5month_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5month_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_5month___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_5month___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1209
 *     property month:
 *         def __get__(self):
 *             return self._Radar.h.month             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int month):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.month); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1208
 *     # header properties mapped to class attributes.
 *     property month:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.month
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.month.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1211
 *             return self._Radar.h.month
 * 
 *         def __set__(self, int month):             # <<<<<<<<<<<<<<
 *             self._Radar.h.month = month
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5month_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_month); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5month_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_month) {
  int __pyx_v_month;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_month); {
    __pyx_v_month = __Pyx_PyInt_As_int(__pyx_arg_month); if (unlikely((__pyx_v_month == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1211; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.month.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_5month_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_month));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_5month_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_month) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1212
 * 
 *         def __set__(self, int month):
 *             self._Radar.h.month = month             # <<<<<<<<<<<<<<
 * 
 *     property day:
 */
  __pyx_v_self->_Radar->h.month = __pyx_v_month;

  /* "pyart/io/_rsl_interface.pyx":1211
 *             return self._Radar.h.month
 * 
 *         def __set__(self, int month):             # <<<<<<<<<<<<<<
 *             self._Radar.h.month = month
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1215
 * 
 *     property day:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.day
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3day_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3day_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3day___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3day___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1216
 *     property day:
 *         def __get__(self):
 *             return self._Radar.h.day             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int day):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.day); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1216; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1215
 * 
 *     property day:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.day
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.day.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1218
 *             return self._Radar.h.day
 * 
 *         def __set__(self, int day):             # <<<<<<<<<<<<<<
 *             self._Radar.h.day = day
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3day_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_day); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3day_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_day) {
  int __pyx_v_day;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_day); {
    __pyx_v_day = __Pyx_PyInt_As_int(__pyx_arg_day); if (unlikely((__pyx_v_day == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1218; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.day.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3day_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_day));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3day_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_day) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1219
 * 
 *         def __set__(self, int day):
 *             self._Radar.h.day = day             # <<<<<<<<<<<<<<
 * 
 *     property year:
 */
  __pyx_v_self->_Radar->h.day = __pyx_v_day;

  /* "pyart/io/_rsl_interface.pyx":1218
 *             return self._Radar.h.day
 * 
 *         def __set__(self, int day):             # <<<<<<<<<<<<<<
 *             self._Radar.h.day = day
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1222
 * 
 *     property year:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.year
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4year_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4year_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4year___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4year___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1223
 *     property year:
 *         def __get__(self):
 *             return self._Radar.h.year             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int year):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.year); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1223; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1222
 * 
 *     property year:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.year
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.year.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1225
 *             return self._Radar.h.year
 * 
 *         def __set__(self, int year):             # <<<<<<<<<<<<<<
 *             self._Radar.h.year = year
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4year_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_year); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4year_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_year) {
  int __pyx_v_year;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_year); {
    __pyx_v_year = __Pyx_PyInt_As_int(__pyx_arg_year); if (unlikely((__pyx_v_year == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1225; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.year.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4year_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_year));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4year_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_year) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1226
 * 
 *         def __set__(self, int year):
 *             self._Radar.h.year = year             # <<<<<<<<<<<<<<
 * 
 *     property hour:
 */
  __pyx_v_self->_Radar->h.year = __pyx_v_year;

  /* "pyart/io/_rsl_interface.pyx":1225
 *             return self._Radar.h.year
 * 
 *         def __set__(self, int year):             # <<<<<<<<<<<<<<
 *             self._Radar.h.year = year
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1229
 * 
 *     property hour:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.hour
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4hour_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4hour_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4hour___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4hour___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1230
 *     property hour:
 *         def __get__(self):
 *             return self._Radar.h.hour             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int hour):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.hour); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1230; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1229
 * 
 *     property hour:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.hour
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.hour.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1232
 *             return self._Radar.h.hour
 * 
 *         def __set__(self, int hour):             # <<<<<<<<<<<<<<
 *             self._Radar.h.hour = hour
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4hour_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_hour); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4hour_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_hour) {
  int __pyx_v_hour;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_hour); {
    __pyx_v_hour = __Pyx_PyInt_As_int(__pyx_arg_hour); if (unlikely((__pyx_v_hour == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1232; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.hour.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4hour_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_hour));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4hour_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_hour) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1233
 * 
 *         def __set__(self, int hour):
 *             self._Radar.h.hour = hour             # <<<<<<<<<<<<<<
 * 
 *     property minute:
 */
  __pyx_v_self->_Radar->h.hour = __pyx_v_hour;

  /* "pyart/io/_rsl_interface.pyx":1232
 *             return self._Radar.h.hour
 * 
 *         def __set__(self, int hour):             # <<<<<<<<<<<<<<
 *             self._Radar.h.hour = hour
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1236
 * 
 *     property minute:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.minute
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6minute_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6minute_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6minute___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6minute___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1237
 *     property minute:
 *         def __get__(self):
 *             return self._Radar.h.minute             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int minute):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.minute); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1236
 * 
 *     property minute:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.minute
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.minute.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1239
 *             return self._Radar.h.minute
 * 
 *         def __set__(self, int minute):             # <<<<<<<<<<<<<<
 *             self._Radar.h.minute = minute
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6minute_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_minute); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6minute_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_minute) {
  int __pyx_v_minute;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_minute); {
    __pyx_v_minute = __Pyx_PyInt_As_int(__pyx_arg_minute); if (unlikely((__pyx_v_minute == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1239; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.minute.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6minute_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_minute));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6minute_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_minute) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1240
 * 
 *         def __set__(self, int minute):
 *             self._Radar.h.minute = minute             # <<<<<<<<<<<<<<
 * 
 *     property sec:
 */
  __pyx_v_self->_Radar->h.minute = __pyx_v_minute;

  /* "pyart/io/_rsl_interface.pyx":1239
 *             return self._Radar.h.minute
 * 
 *         def __set__(self, int minute):             # <<<<<<<<<<<<<<
 *             self._Radar.h.minute = minute
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1243
 * 
 *     property sec:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.sec
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3sec_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3sec_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3sec___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3sec___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1244
 *     property sec:
 *         def __get__(self):
 *             return self._Radar.h.sec             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, float sec):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_self->_Radar->h.sec); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1244; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1243
 * 
 *     property sec:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.sec
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.sec.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1246
 *             return self._Radar.h.sec
 * 
 *         def __set__(self, float sec):             # <<<<<<<<<<<<<<
 *             self._Radar.h.sec = sec
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3sec_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sec); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3sec_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_sec) {
  float __pyx_v_sec;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_sec); {
    __pyx_v_sec = __pyx_PyFloat_AsFloat(__pyx_arg_sec); if (unlikely((__pyx_v_sec == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1246; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.sec.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3sec_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((float)__pyx_v_sec));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3sec_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, float __pyx_v_sec) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1247
 * 
 *         def __set__(self, float sec):
 *             self._Radar.h.sec = sec             # <<<<<<<<<<<<<<
 * 
 *     property nvolumes:
 */
  __pyx_v_self->_Radar->h.sec = __pyx_v_sec;

  /* "pyart/io/_rsl_interface.pyx":1246
 *             return self._Radar.h.sec
 * 
 *         def __set__(self, float sec):             # <<<<<<<<<<<<<<
 *             self._Radar.h.sec = sec
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1250
 * 
 *     property nvolumes:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.nvolumes
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1251
 *     property nvolumes:
 *         def __get__(self):
 *             return self._Radar.h.nvolumes             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int nvolumes):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.nvolumes); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1251; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1250
 * 
 *     property nvolumes:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.nvolumes
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.nvolumes.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1253
 *             return self._Radar.h.nvolumes
 * 
 *         def __set__(self, int nvolumes):             # <<<<<<<<<<<<<<
 *             self._Radar.h.nvolumes = nvolumes
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nvolumes); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_nvolumes) {
  int __pyx_v_nvolumes;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_nvolumes); {
    __pyx_v_nvolumes = __Pyx_PyInt_As_int(__pyx_arg_nvolumes); if (unlikely((__pyx_v_nvolumes == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1253; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.nvolumes.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_nvolumes));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_nvolumes) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1254
 * 
 *         def __set__(self, int nvolumes):
 *             self._Radar.h.nvolumes = nvolumes             # <<<<<<<<<<<<<<
 * 
 *     property number:
 */
  __pyx_v_self->_Radar->h.nvolumes = __pyx_v_nvolumes;

  /* "pyart/io/_rsl_interface.pyx":1253
 *             return self._Radar.h.nvolumes
 * 
 *         def __set__(self, int nvolumes):             # <<<<<<<<<<<<<<
 *             self._Radar.h.nvolumes = nvolumes
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1257
 * 
 *     property number:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.number
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6number_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6number_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6number___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6number___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1258
 *     property number:
 *         def __get__(self):
 *             return self._Radar.h.number             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int number):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.number); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1257
 * 
 *     property number:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.number
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.number.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1260
 *             return self._Radar.h.number
 * 
 *         def __set__(self, int number):             # <<<<<<<<<<<<<<
 *             self._Radar.h.number = number
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6number_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_number); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6number_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_number) {
  int __pyx_v_number;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_number); {
    __pyx_v_number = __Pyx_PyInt_As_int(__pyx_arg_number); if (unlikely((__pyx_v_number == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.number.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6number_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_number));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6number_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_number) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1261
 * 
 *         def __set__(self, int number):
 *             self._Radar.h.number = number             # <<<<<<<<<<<<<<
 * 
 *     property latd:
 */
  __pyx_v_self->_Radar->h.number = __pyx_v_number;

  /* "pyart/io/_rsl_interface.pyx":1260
 *             return self._Radar.h.number
 * 
 *         def __set__(self, int number):             # <<<<<<<<<<<<<<
 *             self._Radar.h.number = number
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1264
 * 
 *     property latd:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.latd
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latd_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latd_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latd___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latd___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1265
 *     property latd:
 *         def __get__(self):
 *             return self._Radar.h.latd             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int latd):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.latd); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1264
 * 
 *     property latd:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.latd
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.latd.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1267
 *             return self._Radar.h.latd
 * 
 *         def __set__(self, int latd):             # <<<<<<<<<<<<<<
 *             self._Radar.h.latd = latd
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latd_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_latd); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latd_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_latd) {
  int __pyx_v_latd;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_latd); {
    __pyx_v_latd = __Pyx_PyInt_As_int(__pyx_arg_latd); if (unlikely((__pyx_v_latd == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1267; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.latd.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latd_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_latd));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latd_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_latd) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1268
 * 
 *         def __set__(self, int latd):
 *             self._Radar.h.latd = latd             # <<<<<<<<<<<<<<
 * 
 *     property latm:
 */
  __pyx_v_self->_Radar->h.latd = __pyx_v_latd;

  /* "pyart/io/_rsl_interface.pyx":1267
 *             return self._Radar.h.latd
 * 
 *         def __set__(self, int latd):             # <<<<<<<<<<<<<<
 *             self._Radar.h.latd = latd
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1271
 * 
 *     property latm:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.latm
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latm_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latm_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latm___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latm___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1272
 *     property latm:
 *         def __get__(self):
 *             return self._Radar.h.latm             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int latm):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.latm); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1272; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1271
 * 
 *     property latm:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.latm
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.latm.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1274
 *             return self._Radar.h.latm
 * 
 *         def __set__(self, int latm):             # <<<<<<<<<<<<<<
 *             self._Radar.h.latm = latm
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latm_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_latm); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latm_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_latm) {
  int __pyx_v_latm;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_latm); {
    __pyx_v_latm = __Pyx_PyInt_As_int(__pyx_arg_latm); if (unlikely((__pyx_v_latm == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1274; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.latm.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latm_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_latm));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4latm_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_latm) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1275
 * 
 *         def __set__(self, int latm):
 *             self._Radar.h.latm = latm             # <<<<<<<<<<<<<<
 * 
 *     property lats:
 */
  __pyx_v_self->_Radar->h.latm = __pyx_v_latm;

  /* "pyart/io/_rsl_interface.pyx":1274
 *             return self._Radar.h.latm
 * 
 *         def __set__(self, int latm):             # <<<<<<<<<<<<<<
 *             self._Radar.h.latm = latm
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1278
 * 
 *     property lats:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lats
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lats_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lats_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lats___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lats___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1279
 *     property lats:
 *         def __get__(self):
 *             return self._Radar.h.lats             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int lats):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.lats); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1279; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1278
 * 
 *     property lats:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lats
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lats.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1281
 *             return self._Radar.h.lats
 * 
 *         def __set__(self, int lats):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lats = lats
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lats_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lats); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lats_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lats) {
  int __pyx_v_lats;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_lats); {
    __pyx_v_lats = __Pyx_PyInt_As_int(__pyx_arg_lats); if (unlikely((__pyx_v_lats == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1281; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lats.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lats_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_lats));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lats_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lats) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1282
 * 
 *         def __set__(self, int lats):
 *             self._Radar.h.lats = lats             # <<<<<<<<<<<<<<
 * 
 *     property lond:
 */
  __pyx_v_self->_Radar->h.lats = __pyx_v_lats;

  /* "pyart/io/_rsl_interface.pyx":1281
 *             return self._Radar.h.lats
 * 
 *         def __set__(self, int lats):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lats = lats
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1285
 * 
 *     property lond:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lond
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lond_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lond_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lond___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lond___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1286
 *     property lond:
 *         def __get__(self):
 *             return self._Radar.h.lond             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int lond):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.lond); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1286; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1285
 * 
 *     property lond:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lond
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lond.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1288
 *             return self._Radar.h.lond
 * 
 *         def __set__(self, int lond):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lond = lond
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lond_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lond); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lond_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lond) {
  int __pyx_v_lond;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_lond); {
    __pyx_v_lond = __Pyx_PyInt_As_int(__pyx_arg_lond); if (unlikely((__pyx_v_lond == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1288; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lond.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lond_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_lond));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lond_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lond) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1289
 * 
 *         def __set__(self, int lond):
 *             self._Radar.h.lond = lond             # <<<<<<<<<<<<<<
 * 
 *     property lonm:
 */
  __pyx_v_self->_Radar->h.lond = __pyx_v_lond;

  /* "pyart/io/_rsl_interface.pyx":1288
 *             return self._Radar.h.lond
 * 
 *         def __set__(self, int lond):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lond = lond
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1292
 * 
 *     property lonm:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lonm
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lonm_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lonm_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lonm___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lonm___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1293
 *     property lonm:
 *         def __get__(self):
 *             return self._Radar.h.lonm             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int lonm):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.lonm); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1292
 * 
 *     property lonm:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lonm
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lonm.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1295
 *             return self._Radar.h.lonm
 * 
 *         def __set__(self, int lonm):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lonm = lonm
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lonm_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lonm); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lonm_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lonm) {
  int __pyx_v_lonm;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_lonm); {
    __pyx_v_lonm = __Pyx_PyInt_As_int(__pyx_arg_lonm); if (unlikely((__pyx_v_lonm == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1295; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lonm.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lonm_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_lonm));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lonm_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lonm) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1296
 * 
 *         def __set__(self, int lonm):
 *             self._Radar.h.lonm = lonm             # <<<<<<<<<<<<<<
 * 
 *     property lons:
 */
  __pyx_v_self->_Radar->h.lonm = __pyx_v_lonm;

  /* "pyart/io/_rsl_interface.pyx":1295
 *             return self._Radar.h.lonm
 * 
 *         def __set__(self, int lonm):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lonm = lonm
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1299
 * 
 *     property lons:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lons
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lons_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lons_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lons___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lons___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1300
 *     property lons:
 *         def __get__(self):
 *             return self._Radar.h.lons             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int lons):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.lons); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1300; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1299
 * 
 *     property lons:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lons
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lons.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1302
 *             return self._Radar.h.lons
 * 
 *         def __set__(self, int lons):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lons = lons
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lons_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lons); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lons_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lons) {
  int __pyx_v_lons;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_lons); {
    __pyx_v_lons = __Pyx_PyInt_As_int(__pyx_arg_lons); if (unlikely((__pyx_v_lons == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1302; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lons.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lons_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_lons));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_4lons_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lons) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1303
 * 
 *         def __set__(self, int lons):
 *             self._Radar.h.lons = lons             # <<<<<<<<<<<<<<
 * 
 *     property height:
 */
  __pyx_v_self->_Radar->h.lons = __pyx_v_lons;

  /* "pyart/io/_rsl_interface.pyx":1302
 *             return self._Radar.h.lons
 * 
 *         def __set__(self, int lons):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lons = lons
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1306
 * 
 *     property height:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.height
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6height_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6height_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6height___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6height___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1307
 *     property height:
 *         def __get__(self):
 *             return self._Radar.h.height             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int height):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.height); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1307; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1306
 * 
 *     property height:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.height
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.height.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1309
 *             return self._Radar.h.height
 * 
 *         def __set__(self, int height):             # <<<<<<<<<<<<<<
 *             self._Radar.h.height = height
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6height_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_height); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6height_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_height) {
  int __pyx_v_height;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_height); {
    __pyx_v_height = __Pyx_PyInt_As_int(__pyx_arg_height); if (unlikely((__pyx_v_height == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1309; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.height.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6height_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_height));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6height_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_height) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1310
 * 
 *         def __set__(self, int height):
 *             self._Radar.h.height = height             # <<<<<<<<<<<<<<
 * 
 *     property spulse:
 */
  __pyx_v_self->_Radar->h.height = __pyx_v_height;

  /* "pyart/io/_rsl_interface.pyx":1309
 *             return self._Radar.h.height
 * 
 *         def __set__(self, int height):             # <<<<<<<<<<<<<<
 *             self._Radar.h.height = height
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1313
 * 
 *     property spulse:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.spulse
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6spulse_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6spulse_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6spulse___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6spulse___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1314
 *     property spulse:
 *         def __get__(self):
 *             return self._Radar.h.spulse             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int spulse):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.spulse); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1314; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1313
 * 
 *     property spulse:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.spulse
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.spulse.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1316
 *             return self._Radar.h.spulse
 * 
 *         def __set__(self, int spulse):             # <<<<<<<<<<<<<<
 *             self._Radar.h.spulse = spulse
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6spulse_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_spulse); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6spulse_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_spulse) {
  int __pyx_v_spulse;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_spulse); {
    __pyx_v_spulse = __Pyx_PyInt_As_int(__pyx_arg_spulse); if (unlikely((__pyx_v_spulse == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1316; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.spulse.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6spulse_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_spulse));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6spulse_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_spulse) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1317
 * 
 *         def __set__(self, int spulse):
 *             self._Radar.h.spulse = spulse             # <<<<<<<<<<<<<<
 * 
 *     property lpulse:
 */
  __pyx_v_self->_Radar->h.spulse = __pyx_v_spulse;

  /* "pyart/io/_rsl_interface.pyx":1316
 *             return self._Radar.h.spulse
 * 
 *         def __set__(self, int spulse):             # <<<<<<<<<<<<<<
 *             self._Radar.h.spulse = spulse
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1320
 * 
 *     property lpulse:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lpulse
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6lpulse___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6lpulse___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1321
 *     property lpulse:
 *         def __get__(self):
 *             return self._Radar.h.lpulse             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int lpulse):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.lpulse); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1321; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1320
 * 
 *     property lpulse:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.lpulse
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lpulse.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1323
 *             return self._Radar.h.lpulse
 * 
 *         def __set__(self, int lpulse):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lpulse = lpulse
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lpulse); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_lpulse) {
  int __pyx_v_lpulse;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_lpulse); {
    __pyx_v_lpulse = __Pyx_PyInt_As_int(__pyx_arg_lpulse); if (unlikely((__pyx_v_lpulse == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1323; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.lpulse.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_lpulse));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_lpulse) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1324
 * 
 *         def __set__(self, int lpulse):
 *             self._Radar.h.lpulse = lpulse             # <<<<<<<<<<<<<<
 * 
 *     property scan_mode:
 */
  __pyx_v_self->_Radar->h.lpulse = __pyx_v_lpulse;

  /* "pyart/io/_rsl_interface.pyx":1323
 *             return self._Radar.h.lpulse
 * 
 *         def __set__(self, int lpulse):             # <<<<<<<<<<<<<<
 *             self._Radar.h.lpulse = lpulse
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1327
 * 
 *     property scan_mode:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.scan_mode
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1328
 *     property scan_mode:
 *         def __get__(self):
 *             return self._Radar.h.scan_mode             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int scan_mode):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.scan_mode); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1328; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1327
 * 
 *     property scan_mode:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.scan_mode
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.scan_mode.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1330
 *             return self._Radar.h.scan_mode
 * 
 *         def __set__(self, int scan_mode):             # <<<<<<<<<<<<<<
 *             self._Radar.h.scan_mode = scan_mode
 * 
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_scan_mode); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_scan_mode) {
  int __pyx_v_scan_mode;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_scan_mode); {
    __pyx_v_scan_mode = __Pyx_PyInt_As_int(__pyx_arg_scan_mode); if (unlikely((__pyx_v_scan_mode == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1330; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.scan_mode.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_scan_mode));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_scan_mode) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1331
 * 
 *         def __set__(self, int scan_mode):
 *             self._Radar.h.scan_mode = scan_mode             # <<<<<<<<<<<<<<
 * 
 *     property vcp:
 */
  __pyx_v_self->_Radar->h.scan_mode = __pyx_v_scan_mode;

  /* "pyart/io/_rsl_interface.pyx":1330
 *             return self._Radar.h.scan_mode
 * 
 *         def __set__(self, int scan_mode):             # <<<<<<<<<<<<<<
 *             self._Radar.h.scan_mode = scan_mode
 * 
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1334
 * 
 *     property vcp:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.vcp
 * 
 */

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3vcp_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3vcp_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3vcp___get__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3vcp___get__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);

  /* "pyart/io/_rsl_interface.pyx":1335
 *     property vcp:
 *         def __get__(self):
 *             return self._Radar.h.vcp             # <<<<<<<<<<<<<<
 * 
 *         def __set__(self, int vcp):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_v_self->_Radar->h.vcp); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1335; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "pyart/io/_rsl_interface.pyx":1334
 * 
 *     property vcp:
 *         def __get__(self):             # <<<<<<<<<<<<<<
 *             return self._Radar.h.vcp
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.vcp.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/io/_rsl_interface.pyx":1337
 *             return self._Radar.h.vcp
 * 
 *         def __set__(self, int vcp):             # <<<<<<<<<<<<<<
 *             self._Radar.h.vcp = vcp
 */

/* Python wrapper */
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3vcp_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vcp); /*proto*/
static int __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3vcp_3__set__(PyObject *__pyx_v_self, PyObject *__pyx_arg_vcp) {
  int __pyx_v_vcp;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__ (wrapper)", 0);
  assert(__pyx_arg_vcp); {
    __pyx_v_vcp = __Pyx_PyInt_As_int(__pyx_arg_vcp); if (unlikely((__pyx_v_vcp == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1337; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.io._rsl_interface.RslFile.vcp.__set__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3vcp_2__set__(((struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *)__pyx_v_self), ((int)__pyx_v_vcp));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5pyart_2io_14_rsl_interface_7RslFile_3vcp_2__set__(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile *__pyx_v_self, int __pyx_v_vcp) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__set__", 0);

  /* "pyart/io/_rsl_interface.pyx":1338
 * 
 *         def __set__(self, int vcp):
 *             self._Radar.h.vcp = vcp             # <<<<<<<<<<<<<<
 */
  __pyx_v_self->_Radar->h.vcp = __pyx_v_vcp;

  /* "pyart/io/_rsl_interface.pyx":1337
 *             return self._Radar.h.vcp
 * 
 *         def __set__(self, int vcp):             # <<<<<<<<<<<<<<
 *             self._Radar.h.vcp = vcp
 */

  /* function exit code */
  __pyx_r = 0;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":197
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5numpy_7ndarray___getbuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_copy_shape;
  int __pyx_v_i;
  int __pyx_v_ndim;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  int __pyx_v_t;
  char *__pyx_v_f;
  PyArray_Descr *__pyx_v_descr = 0;
  int __pyx_v_offset;
  int __pyx_v_hasfields;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  char *__pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  if (__pyx_v_info != NULL) {
    __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(__pyx_v_info->obj);
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":203
 *             # of flags
 * 
 *             if info == NULL: return             # <<<<<<<<<<<<<<
 * 
 *             cdef int copy_shape, i, ndim
 */
  __pyx_t_1 = ((__pyx_v_info == NULL) != 0);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":206
 * 
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 */
  __pyx_v_endian_detector = 1;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":207
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 * 
 *             ndim = PyArray_NDIM(self)
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":209
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 *             ndim = PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_v_ndim = PyArray_NDIM(__pyx_v_self);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":211
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":212
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 copy_shape = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 copy_shape = 0
 */
    __pyx_v_copy_shape = 1;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":211
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
    goto __pyx_L4;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":214
 *                 copy_shape = 1
 *             else:
 *                 copy_shape = 0             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 */
  /*else*/ {
    __pyx_v_copy_shape = 0;
  }
  __pyx_L4:;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":216
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_C_CONTIGUOUS) == PyBUF_C_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L6_bool_binop_done;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":217
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_C_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L6_bool_binop_done:;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":216
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":218
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__9, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":216
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":220
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  __pyx_t_2 = (((__pyx_v_flags & PyBUF_F_CONTIGUOUS) == PyBUF_F_CONTIGUOUS) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L9_bool_binop_done;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":221
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 */
  __pyx_t_2 = ((!(PyArray_CHKFLAGS(__pyx_v_self, NPY_F_CONTIGUOUS) != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L9_bool_binop_done:;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":220
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":222
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
    __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__10, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 222; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 222; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":220
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":224
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 *             info.buf = PyArray_DATA(self)             # <<<<<<<<<<<<<<
 *             info.ndim = ndim
 *             if copy_shape:
 */
  __pyx_v_info->buf = PyArray_DATA(__pyx_v_self);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":225
 * 
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim             # <<<<<<<<<<<<<<
 *             if copy_shape:
 *                 # Allocate new buffer for strides and shape info.
 */
  __pyx_v_info->ndim = __pyx_v_ndim;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":226
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
  __pyx_t_1 = (__pyx_v_copy_shape != 0);
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":229
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)             # <<<<<<<<<<<<<<
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 */
    __pyx_v_info->strides = ((Py_ssize_t *)malloc((((sizeof(Py_ssize_t)) * ((size_t)__pyx_v_ndim)) * 2)));

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":230
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim             # <<<<<<<<<<<<<<
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 */
    __pyx_v_info->shape = (__pyx_v_info->strides + __pyx_v_ndim);

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":231
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):             # <<<<<<<<<<<<<<
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 */
    __pyx_t_4 = __pyx_v_ndim;
    for (__pyx_t_5 = 0; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
      __pyx_v_i = __pyx_t_5;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":232
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]             # <<<<<<<<<<<<<<
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 */
      (__pyx_v_info->strides[__pyx_v_i]) = (PyArray_STRIDES(__pyx_v_self)[__pyx_v_i]);

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":233
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 */
      (__pyx_v_info->shape[__pyx_v_i]) = (PyArray_DIMS(__pyx_v_self)[__pyx_v_i]);
    }

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":226
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
    goto __pyx_L11;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":235
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 */
  /*else*/ {
    __pyx_v_info->strides = ((Py_ssize_t *)PyArray_STRIDES(__pyx_v_self));

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":236
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 */
    __pyx_v_info->shape = ((Py_ssize_t *)PyArray_DIMS(__pyx_v_self));
  }
  __pyx_L11:;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":237
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 */
  __pyx_v_info->suboffsets = NULL;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":238
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)             # <<<<<<<<<<<<<<
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 * 
 */
  __pyx_v_info->itemsize = PyArray_ITEMSIZE(__pyx_v_self);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":239
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)             # <<<<<<<<<<<<<<
 * 
 *             cdef int t
 */
  __pyx_v_info->readonly = (!(PyArray_ISWRITEABLE(__pyx_v_self) != 0));

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":242
 * 
 *             cdef int t
 *             cdef char* f = NULL             # <<<<<<<<<<<<<<
 *             cdef dtype descr = self.descr
 *             cdef int offset
 */
  __pyx_v_f = NULL;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":243
 *             cdef int t
 *             cdef char* f = NULL
 *             cdef dtype descr = self.descr             # <<<<<<<<<<<<<<
 *             cdef int offset
 * 
 */
  __pyx_t_3 = ((PyObject *)__pyx_v_self->descr);
  __Pyx_INCREF(__pyx_t_3);
  __pyx_v_descr = ((PyArray_Descr *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":246
 *             cdef int offset
 * 
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields and not copy_shape:
 */
  __pyx_v_hasfields = PyDataType_HASFIELDS(__pyx_v_descr);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":248
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
  __pyx_t_2 = ((!(__pyx_v_hasfields != 0)) != 0);
  if (__pyx_t_2) {
  } else {
    __pyx_t_1 = __pyx_t_2;
    goto __pyx_L15_bool_binop_done;
  }
  __pyx_t_2 = ((!(__pyx_v_copy_shape != 0)) != 0);
  __pyx_t_1 = __pyx_t_2;
  __pyx_L15_bool_binop_done:;
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":250
 *             if not hasfields and not copy_shape:
 *                 # do not call releasebuffer
 *                 info.obj = None             # <<<<<<<<<<<<<<
 *             else:
 *                 # need to call releasebuffer
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = Py_None;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":248
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
    goto __pyx_L14;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":253
 *             else:
 *                 # need to call releasebuffer
 *                 info.obj = self             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields:
 */
  /*else*/ {
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = ((PyObject *)__pyx_v_self);
  }
  __pyx_L14:;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":255
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  __pyx_t_1 = ((!(__pyx_v_hasfields != 0)) != 0);
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":256
 * 
 *             if not hasfields:
 *                 t = descr.type_num             # <<<<<<<<<<<<<<
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 */
    __pyx_t_4 = __pyx_v_descr->type_num;
    __pyx_v_t = __pyx_t_4;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":257
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '>') != 0);
    if (!__pyx_t_2) {
      goto __pyx_L20_next_or;
    } else {
    }
    __pyx_t_2 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_L20_next_or:;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":258
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 */
    __pyx_t_2 = ((__pyx_v_descr->byteorder == '<') != 0);
    if (__pyx_t_2) {
    } else {
      __pyx_t_1 = __pyx_t_2;
      goto __pyx_L19_bool_binop_done;
    }
    __pyx_t_2 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_1 = __pyx_t_2;
    __pyx_L19_bool_binop_done:;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":257
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    if (__pyx_t_1) {

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":259
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__11, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":257
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":260
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 */
    switch (__pyx_v_t) {
      case NPY_BYTE:
      __pyx_v_f = __pyx_k_b;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":261
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 */
      case NPY_UBYTE:
      __pyx_v_f = __pyx_k_B;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":262
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 */
      case NPY_SHORT:
      __pyx_v_f = __pyx_k_h;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":263
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 */
      case NPY_USHORT:
      __pyx_v_f = __pyx_k_H;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":264
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 */
      case NPY_INT:
      __pyx_v_f = __pyx_k_i;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":265
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 */
      case NPY_UINT:
      __pyx_v_f = __pyx_k_I;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":266
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 */
      case NPY_LONG:
      __pyx_v_f = __pyx_k_l;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":267
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 */
      case NPY_ULONG:
      __pyx_v_f = __pyx_k_L;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":268
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 */
      case NPY_LONGLONG:
      __pyx_v_f = __pyx_k_q;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":269
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 */
      case NPY_ULONGLONG:
      __pyx_v_f = __pyx_k_Q;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":270
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 */
      case NPY_FLOAT:
      __pyx_v_f = __pyx_k_f;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":271
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 */
      case NPY_DOUBLE:
      __pyx_v_f = __pyx_k_d;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":272
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 */
      case NPY_LONGDOUBLE:
      __pyx_v_f = __pyx_k_g;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":273
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 */
      case NPY_CFLOAT:
      __pyx_v_f = __pyx_k_Zf;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":274
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"
 */
      case NPY_CDOUBLE:
      __pyx_v_f = __pyx_k_Zd;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":275
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 */
      case NPY_CLONGDOUBLE:
      __pyx_v_f = __pyx_k_Zg;
      break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":276
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      case NPY_OBJECT:
      __pyx_v_f = __pyx_k_O;
      break;
      default:

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":278
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *                 info.format = f
 *                 return
 */
      __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_t); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_6 = PyUnicode_Format(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_t_3); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_6);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_6);
      __pyx_t_6 = 0;
      __pyx_t_6 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_3, NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __Pyx_Raise(__pyx_t_6, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 278; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      break;
    }

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":279
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
    __pyx_v_info->format = __pyx_v_f;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":280
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 */
    __pyx_r = 0;
    goto __pyx_L0;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":255
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":282
 *                 return
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)             # <<<<<<<<<<<<<<
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 */
  /*else*/ {
    __pyx_v_info->format = ((char *)malloc(0xFF));

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":283
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment             # <<<<<<<<<<<<<<
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,
 */
    (__pyx_v_info->format[0]) = '^';

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":284
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0             # <<<<<<<<<<<<<<
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 */
    __pyx_v_offset = 0;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":285
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,             # <<<<<<<<<<<<<<
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 */
    __pyx_t_7 = __pyx_f_5numpy__util_dtypestring(__pyx_v_descr, (__pyx_v_info->format + 1), (__pyx_v_info->format + 0xFF), (&__pyx_v_offset)); if (unlikely(__pyx_t_7 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 285; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_f = __pyx_t_7;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":288
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 *                 f[0] = c'\0' # Terminate format string             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 */
    (__pyx_v_f[0]) = '\x00';
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":197
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("numpy.ndarray.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info != NULL && __pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = NULL;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info != NULL && __pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(Py_None);
    __Pyx_DECREF(Py_None); __pyx_v_info->obj = NULL;
  }
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_descr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":290
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 */

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_5numpy_7ndarray_2__releasebuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":291
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_t_1 = (PyArray_HASFIELDS(__pyx_v_self) != 0);
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":292
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)
 */
    free(__pyx_v_info->format);

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":291
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":293
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  __pyx_t_1 = (((sizeof(npy_intp)) != (sizeof(Py_ssize_t))) != 0);
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":294
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)             # <<<<<<<<<<<<<<
 *                 # info.shape was stored after info.strides in the same block
 * 
 */
    free(__pyx_v_info->strides);

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":293
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":290
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":770
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":771
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":770
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":773
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":774
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 774; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":773
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":776
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":777
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 777; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":776
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":779
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":780
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":779
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":782
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":783
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 783; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":782
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":785
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *__pyx_v_descr, char *__pyx_v_f, char *__pyx_v_end, int *__pyx_v_offset) {
  PyArray_Descr *__pyx_v_child = 0;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_childname = NULL;
  PyObject *__pyx_v_new_offset = NULL;
  PyObject *__pyx_v_t = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  long __pyx_t_8;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_util_dtypestring", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":790
 * 
 *     cdef dtype child
 *     cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 *     cdef tuple fields
 */
  __pyx_v_endian_detector = 1;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":791
 *     cdef dtype child
 *     cdef int endian_detector = 1
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 *     cdef tuple fields
 * 
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":794
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  if (unlikely(__pyx_v_descr->names == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = __pyx_v_descr->names; __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    #endif
    __Pyx_XDECREF_SET(__pyx_v_childname, __pyx_t_3);
    __pyx_t_3 = 0;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":795
 * 
 *     for childname in descr.names:
 *         fields = descr.fields[childname]             # <<<<<<<<<<<<<<
 *         child, new_offset = fields
 * 
 */
    if (unlikely(__pyx_v_descr->fields == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_3 = __Pyx_PyDict_GetItem(__pyx_v_descr->fields, __pyx_v_childname); if (unlikely(__pyx_t_3 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_t_3)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF_SET(__pyx_v_fields, ((PyObject*)__pyx_t_3));
    __pyx_t_3 = 0;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":796
 *     for childname in descr.names:
 *         fields = descr.fields[childname]
 *         child, new_offset = fields             # <<<<<<<<<<<<<<
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 */
    if (likely(__pyx_v_fields != Py_None)) {
      PyObject* sequence = __pyx_v_fields;
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      #endif
    } else {
      __Pyx_RaiseNoneNotIterableError(); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF_SET(__pyx_v_child, ((PyArray_Descr *)__pyx_t_3));
    __pyx_t_3 = 0;
    __Pyx_XDECREF_SET(__pyx_v_new_offset, __pyx_t_4);
    __pyx_t_4 = 0;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":798
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    __pyx_t_4 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyNumber_Subtract(__pyx_v_new_offset, __pyx_t_4); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_3); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = ((((__pyx_v_end - __pyx_v_f) - ((int)__pyx_t_5)) < 15) != 0);
    if (__pyx_t_6) {

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":799
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__12, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":798
 *         child, new_offset = fields
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    }

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '>') != 0);
    if (!__pyx_t_7) {
      goto __pyx_L8_next_or;
    } else {
    }
    __pyx_t_7 = (__pyx_v_little_endian != 0);
    if (!__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_L8_next_or:;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":802
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *             raise ValueError(u"Non-native byte order not supported")
 *             # One could encode it in the format string and have Cython
 */
    __pyx_t_7 = ((__pyx_v_child->byteorder == '<') != 0);
    if (__pyx_t_7) {
    } else {
      __pyx_t_6 = __pyx_t_7;
      goto __pyx_L7_bool_binop_done;
    }
    __pyx_t_7 = ((!(__pyx_v_little_endian != 0)) != 0);
    __pyx_t_6 = __pyx_t_7;
    __pyx_L7_bool_binop_done:;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    if (__pyx_t_6) {

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
      __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_tuple__13, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_Raise(__pyx_t_3, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    }

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":813
 * 
 *         # Output padding bytes
 *         while offset[0] < new_offset:             # <<<<<<<<<<<<<<
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 */
    while (1) {
      __pyx_t_3 = __Pyx_PyInt_From_int((__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_t_3, __pyx_v_new_offset, Py_LT); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (!__pyx_t_6) break;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":814
 *         # Output padding bytes
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte             # <<<<<<<<<<<<<<
 *             f += 1
 *             offset[0] += 1
 */
      (__pyx_v_f[0]) = 0x78;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":815
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte
 *             f += 1             # <<<<<<<<<<<<<<
 *             offset[0] += 1
 * 
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":816
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 *             offset[0] += 1             # <<<<<<<<<<<<<<
 * 
 *         offset[0] += child.itemsize
 */
      __pyx_t_8 = 0;
      (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + 1);
    }

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":818
 *             offset[0] += 1
 * 
 *         offset[0] += child.itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not PyDataType_HASFIELDS(child):
 */
    __pyx_t_8 = 0;
    (__pyx_v_offset[__pyx_t_8]) = ((__pyx_v_offset[__pyx_t_8]) + __pyx_v_child->elsize);

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":820
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
    __pyx_t_6 = ((!(PyDataType_HASFIELDS(__pyx_v_child) != 0)) != 0);
    if (__pyx_t_6) {

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":821
 * 
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num             # <<<<<<<<<<<<<<
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")
 */
      __pyx_t_4 = __Pyx_PyInt_From_int(__pyx_v_child->type_num); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_XDECREF_SET(__pyx_v_t, __pyx_t_4);
      __pyx_t_4 = 0;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":822
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      __pyx_t_6 = (((__pyx_v_end - __pyx_v_f) < 5) != 0);
      if (__pyx_t_6) {

        /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
        __pyx_t_4 = __Pyx_PyObject_Call(__pyx_builtin_RuntimeError, __pyx_tuple__14, NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_Raise(__pyx_t_4, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":822
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":826
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_BYTE); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 98;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":827
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"             # <<<<<<<<<<<<<<
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UBYTE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 66;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":828
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"             # <<<<<<<<<<<<<<
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_SHORT); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x68;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":829
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"             # <<<<<<<<<<<<<<
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_USHORT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 72;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":830
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_INT); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x69;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":831
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_UINT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 73;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":832
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONG); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x6C;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":833
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 76;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":834
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGLONG); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x71;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":835
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_ULONGLONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 81;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":836
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"             # <<<<<<<<<<<<<<
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_FLOAT); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x66;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":837
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_DOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x64;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":838
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"             # <<<<<<<<<<<<<<
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_LONGDOUBLE); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 0x67;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":839
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf             # <<<<<<<<<<<<<<
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CFLOAT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x66;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":840
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd             # <<<<<<<<<<<<<<
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CDOUBLE); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x64;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":841
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg             # <<<<<<<<<<<<<<
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 */
      __pyx_t_3 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_CLONGDOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 0x67;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":842
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_t_4 = __Pyx_PyInt_From_enum__NPY_TYPES(NPY_OBJECT); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_4, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_6) {
        (__pyx_v_f[0]) = 79;
        goto __pyx_L15;
      }

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":844
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *             f += 1
 *         else:
 */
      /*else*/ {
        __pyx_t_3 = PyUnicode_Format(__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_v_t); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        __Pyx_GIVEREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
        __pyx_t_3 = 0;
        __pyx_t_3 = __Pyx_PyObject_Call(__pyx_builtin_ValueError, __pyx_t_4, NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L15:;

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":845
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *             f += 1             # <<<<<<<<<<<<<<
 *         else:
 *             # Cython ignores struct boundary information ("T{...}"),
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":820
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
      goto __pyx_L13;
    }

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":849
 *             # Cython ignores struct boundary information ("T{...}"),
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
    /*else*/ {
      __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_child, __pyx_v_f, __pyx_v_end, __pyx_v_offset); if (unlikely(__pyx_t_9 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_f = __pyx_t_9;
    }
    __pyx_L13:;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":794
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":850
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":785
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("numpy._util_dtypestring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_childname);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_baseptr;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":968
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
  __pyx_t_1 = (__pyx_v_base == Py_None);
  __pyx_t_2 = (__pyx_t_1 != 0);
  if (__pyx_t_2) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":969
 *      cdef PyObject* baseptr
 *      if base is None:
 *          baseptr = NULL             # <<<<<<<<<<<<<<
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 */
    __pyx_v_baseptr = NULL;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":968
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
    goto __pyx_L3;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":971
 *          baseptr = NULL
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!             # <<<<<<<<<<<<<<
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 */
  /*else*/ {
    Py_INCREF(__pyx_v_base);

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":972
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base             # <<<<<<<<<<<<<<
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr
 */
    __pyx_v_baseptr = ((PyObject *)__pyx_v_base);
  }
  __pyx_L3:;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":973
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)             # <<<<<<<<<<<<<<
 *      arr.base = baseptr
 * 
 */
  Py_XDECREF(__pyx_v_arr->base);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":974
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_v_arr->base = __pyx_v_baseptr;

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":966
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

  /* function exit code */
  __Pyx_RefNannyFinishContext();
}

/* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":976
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":977
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = ((__pyx_v_arr->base == NULL) != 0);
  if (__pyx_t_1) {

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":978
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>arr.base
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;

    /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":977
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":980
 *         return None
 *     else:
 *         return <object>arr.base             # <<<<<<<<<<<<<<
 */
  /*else*/ {
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_arr->base));
    __pyx_r = ((PyObject *)__pyx_v_arr->base);
    goto __pyx_L0;
  }

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":976
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

  /* function exit code */
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_float____Range___to_py")
 * cdef object __Pyx_CFunc_float____Range___to_py(float (*f)(Range) except *):
 *     def wrap(Range x):             # <<<<<<<<<<<<<<
 *         """wrap(x: 'Range') -> 'float'"""
 *         return f(x)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_1wrap(PyObject *__pyx_self, PyObject *__pyx_arg_x); /*proto*/
static char __pyx_doc_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_wrap[] = "wrap(x: 'Range') -> 'float'";
static PyMethodDef __pyx_mdef_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_1wrap = {"wrap", (PyCFunction)__pyx_pw_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_1wrap, METH_O, __pyx_doc_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_wrap};
static PyObject *__pyx_pw_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_1wrap(PyObject *__pyx_self, PyObject *__pyx_arg_x) {
  __pyx_t_5pyart_2io_14_rsl_interface_Range __pyx_v_x;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrap (wrapper)", 0);
  assert(__pyx_arg_x); {
    __pyx_v_x = __Pyx_PyInt_As_unsigned_short(__pyx_arg_x); if (unlikely((__pyx_v_x == (unsigned short)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_float____Range___to_py.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_wrap(__pyx_self, ((__pyx_t_5pyart_2io_14_rsl_interface_Range)__pyx_v_x));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_wrap(PyObject *__pyx_self, __pyx_t_5pyart_2io_14_rsl_interface_Range __pyx_v_x) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py *__pyx_cur_scope;
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  float __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrap", 0);
  __pyx_outer_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cfunc.to_py":67
 *     def wrap(Range x):
 *         """wrap(x: 'Range') -> 'float'"""
 *         return f(x)             # <<<<<<<<<<<<<<
 *     return wrap
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_f(__pyx_v_x); if (unlikely(PyErr_Occurred())) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = PyFloat_FromDouble(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_float____Range___to_py")
 * cdef object __Pyx_CFunc_float____Range___to_py(float (*f)(Range) except *):
 *     def wrap(Range x):             # <<<<<<<<<<<<<<
 *         """wrap(x: 'Range') -> 'float'"""
 *         return f(x)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_float____Range___to_py.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_float____Range___to_py")
 * cdef object __Pyx_CFunc_float____Range___to_py(float (*f)(Range) except *):             # <<<<<<<<<<<<<<
 *     def wrap(Range x):
 *         """wrap(x: 'Range') -> 'float'"""
 */

static PyObject *__Pyx_CFunc_float____Range___to_py(float (*__pyx_v_f)(__pyx_t_5pyart_2io_14_rsl_interface_Range)) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py *__pyx_cur_scope;
  PyObject *__pyx_v_wrap = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_CFunc_float____Range___to_py", 0);
  __pyx_cur_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_float____Range___to_py(__pyx_ptype___pyx_scope_struct____Pyx_CFunc_float____Range___to_py, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return 0;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_float____Range___to_py")
 * cdef object __Pyx_CFunc_float____Range___to_py(float (*f)(Range) except *):
 *     def wrap(Range x):             # <<<<<<<<<<<<<<
 *         """wrap(x: 'Range') -> 'float'"""
 *         return f(x)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_11cfunc_dot_to_py_34__Pyx_CFunc_float____Range___to_py_1wrap, 0, __pyx_n_s_Pyx_CFunc_float____Range___to, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cfunc_to_py, __pyx_d, ((PyObject *)__pyx_codeobj__16)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_wrap = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cfunc.to_py":68
 *         """wrap(x: 'Range') -> 'float'"""
 *         return f(x)
 *     return wrap             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrap);
  __pyx_r = __pyx_v_wrap;
  goto __pyx_L0;

  /* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_float____Range___to_py")
 * cdef object __Pyx_CFunc_float____Range___to_py(float (*f)(Range) except *):             # <<<<<<<<<<<<<<
 *     def wrap(Range x):
 *         """wrap(x: 'Range') -> 'float'"""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_float____Range___to_py", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrap);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_Range____float___to_py")
 * cdef object __Pyx_CFunc_Range____float___to_py(Range (*f)(float) except *):
 *     def wrap(float x):             # <<<<<<<<<<<<<<
 *         """wrap(x: 'float') -> 'Range'"""
 *         return f(x)
 */

/* Python wrapper */
static PyObject *__pyx_pw_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_1wrap(PyObject *__pyx_self, PyObject *__pyx_arg_x); /*proto*/
static char __pyx_doc_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_wrap[] = "wrap(x: 'float') -> 'Range'";
static PyMethodDef __pyx_mdef_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_1wrap = {"wrap", (PyCFunction)__pyx_pw_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_1wrap, METH_O, __pyx_doc_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_wrap};
static PyObject *__pyx_pw_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_1wrap(PyObject *__pyx_self, PyObject *__pyx_arg_x) {
  float __pyx_v_x;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("wrap (wrapper)", 0);
  assert(__pyx_arg_x); {
    __pyx_v_x = __pyx_PyFloat_AsFloat(__pyx_arg_x); if (unlikely((__pyx_v_x == (float)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_Range____float___to_py.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_wrap(__pyx_self, ((float)__pyx_v_x));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_wrap(PyObject *__pyx_self, float __pyx_v_x) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py *__pyx_cur_scope;
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py *__pyx_outer_scope;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __pyx_t_5pyart_2io_14_rsl_interface_Range __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("wrap", 0);
  __pyx_outer_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py *) __Pyx_CyFunction_GetClosure(__pyx_self);
  __pyx_cur_scope = __pyx_outer_scope;

  /* "cfunc.to_py":67
 *     def wrap(float x):
 *         """wrap(x: 'float') -> 'Range'"""
 *         return f(x)             # <<<<<<<<<<<<<<
 *     return wrap
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_cur_scope->__pyx_v_f(__pyx_v_x); if (unlikely(PyErr_Occurred())) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_2 = __Pyx_PyInt_From_unsigned_short(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 67; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_r = __pyx_t_2;
  __pyx_t_2 = 0;
  goto __pyx_L0;

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_Range____float___to_py")
 * cdef object __Pyx_CFunc_Range____float___to_py(Range (*f)(float) except *):
 *     def wrap(float x):             # <<<<<<<<<<<<<<
 *         """wrap(x: 'float') -> 'Range'"""
 *         return f(x)
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_Range____float___to_py.wrap", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_Range____float___to_py")
 * cdef object __Pyx_CFunc_Range____float___to_py(Range (*f)(float) except *):             # <<<<<<<<<<<<<<
 *     def wrap(float x):
 *         """wrap(x: 'float') -> 'Range'"""
 */

static PyObject *__Pyx_CFunc_Range____float___to_py(__pyx_t_5pyart_2io_14_rsl_interface_Range (*__pyx_v_f)(float)) {
  struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py *__pyx_cur_scope;
  PyObject *__pyx_v_wrap = 0;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_CFunc_Range____float___to_py", 0);
  __pyx_cur_scope = (struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py *)__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_Range____float___to_py(__pyx_ptype___pyx_scope_struct____Pyx_CFunc_Range____float___to_py, __pyx_empty_tuple, NULL);
  if (unlikely(!__pyx_cur_scope)) {
    __Pyx_RefNannyFinishContext();
    return 0;
  }
  __Pyx_GOTREF(__pyx_cur_scope);
  __pyx_cur_scope->__pyx_v_f = __pyx_v_f;

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_Range____float___to_py")
 * cdef object __Pyx_CFunc_Range____float___to_py(Range (*f)(float) except *):
 *     def wrap(float x):             # <<<<<<<<<<<<<<
 *         """wrap(x: 'float') -> 'Range'"""
 *         return f(x)
 */
  __pyx_t_1 = __Pyx_CyFunction_NewEx(&__pyx_mdef_11cfunc_dot_to_py_34__Pyx_CFunc_Range____float___to_py_1wrap, 0, __pyx_n_s_Pyx_CFunc_Range____float___to, ((PyObject*)__pyx_cur_scope), __pyx_n_s_cfunc_to_py, __pyx_d, ((PyObject *)__pyx_codeobj__18)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_wrap = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "cfunc.to_py":68
 *         """wrap(x: 'float') -> 'Range'"""
 *         return f(x)
 *     return wrap             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_wrap);
  __pyx_r = __pyx_v_wrap;
  goto __pyx_L0;

  /* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_Range____float___to_py")
 * cdef object __Pyx_CFunc_Range____float___to_py(Range (*f)(float) except *):             # <<<<<<<<<<<<<<
 *     def wrap(float x):
 *         """wrap(x: 'float') -> 'Range'"""
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("cfunc.to_py.__Pyx_CFunc_Range____float___to_py", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_wrap);
  __Pyx_DECREF(((PyObject *)__pyx_cur_scope));
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslVolume __pyx_vtable_5pyart_2io_14_rsl_interface__RslVolume;

static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface__RslVolume(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslVolume;
  return o;
}

static void __pyx_tp_dealloc_5pyart_2io_14_rsl_interface__RslVolume(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_1__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_10_RslVolume_nsweeps(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_10_RslVolume_nsweeps(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7nsweeps_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_10_RslVolume_calibr_const(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_10_RslVolume_calibr_const(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_12calibr_const_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_5pyart_2io_14_rsl_interface__RslVolume[] = {
  {"total_rays", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_3total_rays, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_2total_rays},
  {"get_nray_array", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_5get_nray_array, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_4get_nray_array},
  {"get_sweep", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_7get_sweep, METH_O, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_6get_sweep},
  {"get_azimuth_and_elev_array", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_9get_azimuth_and_elev_array, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_8get_azimuth_and_elev_array},
  {"get_sweep_fix_angles", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_11get_sweep_fix_angles, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_10get_sweep_fix_angles},
  {"get_sweep_azimuths", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_13get_sweep_azimuths, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_12get_sweep_azimuths},
  {"get_sweep_elevs", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_15get_sweep_elevs, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_14get_sweep_elevs},
  {"get_instr_params", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_17get_instr_params, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_16get_instr_params},
  {"get_data", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_19get_data, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_18get_data},
  {"is_range_bins_uniform", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_10_RslVolume_21is_range_bins_uniform, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_10_RslVolume_20is_range_bins_uniform},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_5pyart_2io_14_rsl_interface__RslVolume[] = {
  {(char *)"nsweeps", __pyx_getprop_5pyart_2io_14_rsl_interface_10_RslVolume_nsweeps, __pyx_setprop_5pyart_2io_14_rsl_interface_10_RslVolume_nsweeps, 0, 0},
  {(char *)"calibr_const", __pyx_getprop_5pyart_2io_14_rsl_interface_10_RslVolume_calibr_const, __pyx_setprop_5pyart_2io_14_rsl_interface_10_RslVolume_calibr_const, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5pyart_2io_14_rsl_interface__RslVolume = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyart.io._rsl_interface._RslVolume", /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_2io_14_rsl_interface__RslVolume, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "\n    A object for accessing RSL Volume data and header information.\n\n    This class should not be initalized from within Python.  _RslVolume\n    objects are returned from the :py:func:`RslFile.get_volume` and other\n    functions/methods.\n\n    Attributes\n    ----------\n    nsweeps : int\n        Sweep number.\n    calibr_const : float\n        Calibration constant.\n\n    ", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_2io_14_rsl_interface__RslVolume, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_5pyart_2io_14_rsl_interface__RslVolume, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_2io_14_rsl_interface__RslVolume, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslRay __pyx_vtable_5pyart_2io_14_rsl_interface__RslRay;

static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface__RslRay(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslRay;
  return o;
}

static void __pyx_tp_dealloc_5pyart_2io_14_rsl_interface__RslRay(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_1__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_month(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5month_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_month(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5month_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_day(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3day_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_day(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3day_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_year(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4year_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_year(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4year_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_hour(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4hour_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_hour(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4hour_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_minute(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6minute_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_minute(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6minute_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_sec(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3sec_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_sec(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3sec_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_unam_rng(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_unam_rng(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8unam_rng_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_azimuth(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_azimuth(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7azimuth_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_ray_num(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_ray_num(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7ray_num_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_elev(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4elev_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_elev(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4elev_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_elev_num(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_elev_num(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8elev_num_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_range_bin1(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_range_bin1(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10range_bin1_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_gate_size(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_gate_size(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9gate_size_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_res(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_res(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7vel_res_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_sweep_rate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_sweep_rate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10sweep_rate_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_prf(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3prf_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_prf(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3prf_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_prf2(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_prf2(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4prf2_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_azim_rate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_azim_rate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9azim_rate_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_fix_angle(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_fix_angle(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9fix_angle_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5pitch_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_roll(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4roll_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_roll(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_4roll_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_heading(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7heading_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_heading(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7heading_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch_rate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch_rate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10pitch_rate_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_roll_rate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_roll_rate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9roll_rate_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_heading_rate(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_heading_rate(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_12heading_rate_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_lat(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lat_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_lat(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lat_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_lon(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lon_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_lon(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3lon_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_alt(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3alt_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_alt(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3alt_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_rvc(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_rvc(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3rvc_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_east(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_east(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_8vel_east_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_north(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_north(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9vel_north_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_up(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_up(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_6vel_up_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_count(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_count(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_count_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_width(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_width(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_11pulse_width_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_beam_width(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_beam_width(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10beam_width_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_frequency(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_frequency(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_9frequency_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_wavelength(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_wavelength(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_10wavelength_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_nyq_vel(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_nyq_vel(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_7nyq_vel_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_nbins(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_nbins(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5nbins_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_5pyart_2io_14_rsl_interface__RslRay[] = {
  {"get_datetime", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_3get_datetime, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_7_RslRay_2get_datetime},
  {"get_data", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_7_RslRay_5get_data, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_7_RslRay_4get_data},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_5pyart_2io_14_rsl_interface__RslRay[] = {
  {(char *)"month", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_month, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_month, 0, 0},
  {(char *)"day", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_day, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_day, 0, 0},
  {(char *)"year", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_year, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_year, 0, 0},
  {(char *)"hour", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_hour, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_hour, 0, 0},
  {(char *)"minute", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_minute, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_minute, 0, 0},
  {(char *)"sec", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_sec, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_sec, 0, 0},
  {(char *)"unam_rng", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_unam_rng, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_unam_rng, 0, 0},
  {(char *)"azimuth", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_azimuth, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_azimuth, 0, 0},
  {(char *)"ray_num", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_ray_num, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_ray_num, 0, 0},
  {(char *)"elev", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_elev, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_elev, 0, 0},
  {(char *)"elev_num", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_elev_num, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_elev_num, 0, 0},
  {(char *)"range_bin1", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_range_bin1, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_range_bin1, 0, 0},
  {(char *)"gate_size", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_gate_size, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_gate_size, 0, 0},
  {(char *)"vel_res", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_res, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_res, 0, 0},
  {(char *)"sweep_rate", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_sweep_rate, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_sweep_rate, 0, 0},
  {(char *)"prf", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_prf, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_prf, 0, 0},
  {(char *)"prf2", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_prf2, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_prf2, 0, 0},
  {(char *)"azim_rate", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_azim_rate, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_azim_rate, 0, 0},
  {(char *)"fix_angle", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_fix_angle, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_fix_angle, 0, 0},
  {(char *)"pitch", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch, 0, 0},
  {(char *)"roll", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_roll, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_roll, 0, 0},
  {(char *)"heading", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_heading, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_heading, 0, 0},
  {(char *)"pitch_rate", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch_rate, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pitch_rate, 0, 0},
  {(char *)"roll_rate", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_roll_rate, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_roll_rate, 0, 0},
  {(char *)"heading_rate", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_heading_rate, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_heading_rate, 0, 0},
  {(char *)"lat", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_lat, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_lat, 0, 0},
  {(char *)"lon", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_lon, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_lon, 0, 0},
  {(char *)"alt", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_alt, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_alt, 0, 0},
  {(char *)"rvc", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_rvc, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_rvc, 0, 0},
  {(char *)"vel_east", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_east, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_east, 0, 0},
  {(char *)"vel_north", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_north, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_north, 0, 0},
  {(char *)"vel_up", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_up, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_vel_up, 0, 0},
  {(char *)"pulse_count", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_count, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_count, 0, 0},
  {(char *)"pulse_width", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_width, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_pulse_width, 0, 0},
  {(char *)"beam_width", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_beam_width, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_beam_width, 0, 0},
  {(char *)"frequency", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_frequency, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_frequency, 0, 0},
  {(char *)"wavelength", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_wavelength, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_wavelength, 0, 0},
  {(char *)"nyq_vel", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_nyq_vel, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_nyq_vel, 0, 0},
  {(char *)"nbins", __pyx_getprop_5pyart_2io_14_rsl_interface_7_RslRay_nbins, __pyx_setprop_5pyart_2io_14_rsl_interface_7_RslRay_nbins, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5pyart_2io_14_rsl_interface__RslRay = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyart.io._rsl_interface._RslRay", /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_2io_14_rsl_interface__RslRay, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "\n    A object for accessing RSL Ray data and header information\n\n    This class should not be initalized from within Python.  _RslRay object are\n    returned from the :py:func:`_RslSweep.get_ray` method.\n\n    Attributes\n    ----------\n    month : int\n        Date for this ray, month (1-12).\n    day : int\n        Date for this ray, day (1-31).\n    year : int\n        Date for this ray, year (eg. 1993).\n    hour : int\n        Time for this ray, hour (0-23).\n    minute : int\n        Time for this ray, minute (0-59).\n    sec : float\n        Time for this ray, second + fractor of second.\n    unam_rng : float\n        Unambiguous range in km.\n    azimuth : float\n        Mean azimuth angle in degrees for the ray, must be positive.\n        0 for north, 90 for east, 270 for west.\n    ray_num : int\n        Ray number within a scan.\n    elev : float\n        Elevation angle in degrees.\n    elev_num : int\n        Elevation number within the volume scan.\n    range_bin1 : int\n        Range to first gate in meters.\n    gate_size : int\n        Gate size in meters.\n    vel_res : float\n        Doppler velocity resolution.\n    sweep_rate : float\n        Sweep rate, full sweeps / minute.\n    prf : int\n        Pulse repetition frequency in Hz.\n    prf2 : int\n        Second pulse repition frequenct for dual PRF data.\n    azim_rate : float\n        Sweep rate in degrees / second.\n    fix_angle : float\n        Elevation angle for the sweep in degrees.\n    pitch : float\n        Pitch angle.\n    roll : float\n        Roll angle.\n    heading : float\n        Heading.\n    pitch_rate : float\n        Pitch rate in angle / sec.\n    roll_rate : float\n        Roll rate in angle / sec.\n    heading_rate : float\n        Heading rate in angle / sec.\n    lat : float\n        Latitude in degrees.\n    lon : float\n        Longitude in degrees.\n    alt : int\n        Altitude in meters.\n    rvs : float\n        Radial velocity correction in meters / second.\n    vel_east : float\n        Platform velocity to the east in meters / second.  Negative values for\n        velocity to the west.\n    vel_north : float\n        Platform velocity to the north in meters / second.  Negative values for\n        velocity to the south.\n    vel_up : float\n        Platform velocity upward in meters / second.  Negative values for\n        velocity downward.\n    pulse_count : int\n        Pulses used in a single dwell time.\n    pulse_width : float\n        Pulse width in microseconds.\n    beam_width : float\n        Beamwidth in degrees.\n    frequency : float\n        Carrier frequency in GHz.\n    wavelength : float\n        Wavelength in meters.\n    nyq_vel : float\n        Nyquist velocity in meters / second.\n    nbins : int\n        Number of array elements in ray data.\n\n    ", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_2io_14_rsl_interface__RslRay, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_5pyart_2io_14_rsl_interface__RslRay, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_2io_14_rsl_interface__RslRay, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};
static struct __pyx_vtabstruct_5pyart_2io_14_rsl_interface__RslSweep __pyx_vtable_5pyart_2io_14_rsl_interface__RslSweep;

static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface__RslSweep(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *p;
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  p = ((struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslSweep;
  return o;
}

static void __pyx_tp_dealloc_5pyart_2io_14_rsl_interface__RslSweep(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_1__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_sweep_num(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_sweep_num(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_9sweep_num_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_elev(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_elev(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_4elev_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_azimuth(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_azimuth(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_7azimuth_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_beam_width(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_beam_width(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_10beam_width_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_vert_half_bw(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_vert_half_bw(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12vert_half_bw_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_horz_half_bw(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_horz_half_bw(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_12horz_half_bw_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_nrays(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_nrays(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5nrays_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_5pyart_2io_14_rsl_interface__RslSweep[] = {
  {"get_ray", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_3get_ray, METH_O, __pyx_doc_5pyart_2io_14_rsl_interface_9_RslSweep_2get_ray},
  {"get_data", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_9_RslSweep_5get_data, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_9_RslSweep_4get_data},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_5pyart_2io_14_rsl_interface__RslSweep[] = {
  {(char *)"sweep_num", __pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_sweep_num, __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_sweep_num, 0, 0},
  {(char *)"elev", __pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_elev, __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_elev, 0, 0},
  {(char *)"azimuth", __pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_azimuth, __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_azimuth, 0, 0},
  {(char *)"beam_width", __pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_beam_width, __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_beam_width, 0, 0},
  {(char *)"vert_half_bw", __pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_vert_half_bw, __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_vert_half_bw, 0, 0},
  {(char *)"horz_half_bw", __pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_horz_half_bw, __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_horz_half_bw, 0, 0},
  {(char *)"nrays", __pyx_getprop_5pyart_2io_14_rsl_interface_9_RslSweep_nrays, __pyx_setprop_5pyart_2io_14_rsl_interface_9_RslSweep_nrays, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5pyart_2io_14_rsl_interface__RslSweep = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyart.io._rsl_interface._RslSweep", /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_2io_14_rsl_interface__RslSweep, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "\n    A object for accessing RSL Sweep data and header information.\n\n    This class should not be initalized from within Python.  _RslSweep objects\n    are returned from the :py:func:`_RslVolume.get_sweep` method.\n\n    Attributes\n    ----------\n    sweep_num : int\n        Interger sweep number.\n    elev : float\n        Mean elevation angle for thr sweep.  -999.0 for RHI sweeps.\n    azimuth : float\n        Azumuth for the sweep.  -999.0 for PPI scans.\n    beam_width : float\n        Beam width in degrees.  Can also be found in _RslRay objects.\n    vert_half_bw : float\n        Vertical beam width divided by 2.\n    horz_half_bw : float\n        Horizontal beam width divided by 2.\n    nrays : int\n        Number of rays in the sweep.\n\n    ", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_2io_14_rsl_interface__RslSweep, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_5pyart_2io_14_rsl_interface__RslSweep, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_2io_14_rsl_interface__RslSweep, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyObject *__pyx_tp_new_5pyart_2io_14_rsl_interface_RslFile(PyTypeObject *t, PyObject *a, PyObject *k) {
  PyObject *o;
  if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
    o = (*t->tp_alloc)(t, 0);
  } else {
    o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
  }
  if (unlikely(!o)) return 0;
  if (unlikely(__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_1__cinit__(o, a, k) < 0)) {
    Py_DECREF(o); o = 0;
  }
  return o;
}

static void __pyx_tp_dealloc_5pyart_2io_14_rsl_interface_RslFile(PyObject *o) {
  #if PY_VERSION_HEX >= 0x030400a1
  if (unlikely(Py_TYPE(o)->tp_finalize) && (!PyType_IS_GC(Py_TYPE(o)) || !_PyGC_FINALIZED(o))) {
    if (PyObject_CallFinalizerFromDealloc(o)) return;
  }
  #endif
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3__dealloc__(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_month(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5month_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_month(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5month_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_day(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3day_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_day(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3day_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_year(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4year_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_year(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4year_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_hour(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4hour_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_hour(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4hour_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_minute(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6minute_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_minute(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6minute_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_sec(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3sec_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_sec(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3sec_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_nvolumes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_nvolumes(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_8nvolumes_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_number(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6number_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_number(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6number_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_latd(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latd_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_latd(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latd_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_latm(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latm_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_latm(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4latm_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lats(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lats_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lats(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lats_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lond(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lond_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lond(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lond_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lonm(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lonm_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lonm(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lonm_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lons(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lons_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lons(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_4lons_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_height(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6height_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_height(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6height_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_spulse(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6spulse_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_spulse(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6spulse_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lpulse(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lpulse(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_6lpulse_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_scan_mode(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_scan_mode(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9scan_mode_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyObject *__pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_vcp(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3vcp_1__get__(o);
}

static int __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_vcp(PyObject *o, PyObject *v, CYTHON_UNUSED void *x) {
  if (v) {
    return __pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_3vcp_3__set__(o, v);
  }
  else {
    PyErr_SetString(PyExc_NotImplementedError, "__del__");
    return -1;
  }
}

static PyMethodDef __pyx_methods_5pyart_2io_14_rsl_interface_RslFile[] = {
  {"get_volume", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_5get_volume, METH_O, __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_4get_volume},
  {"available_moments", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_7available_moments, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_6available_moments},
  {"get_radar_header", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_9get_radar_header, METH_NOARGS, __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_8get_radar_header},
  {"get_volume_array", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_7RslFile_11get_volume_array, METH_O, __pyx_doc_5pyart_2io_14_rsl_interface_7RslFile_10get_volume_array},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_5pyart_2io_14_rsl_interface_RslFile[] = {
  {(char *)"month", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_month, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_month, 0, 0},
  {(char *)"day", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_day, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_day, 0, 0},
  {(char *)"year", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_year, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_year, 0, 0},
  {(char *)"hour", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_hour, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_hour, 0, 0},
  {(char *)"minute", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_minute, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_minute, 0, 0},
  {(char *)"sec", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_sec, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_sec, 0, 0},
  {(char *)"nvolumes", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_nvolumes, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_nvolumes, 0, 0},
  {(char *)"number", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_number, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_number, 0, 0},
  {(char *)"latd", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_latd, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_latd, 0, 0},
  {(char *)"latm", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_latm, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_latm, 0, 0},
  {(char *)"lats", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lats, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lats, 0, 0},
  {(char *)"lond", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lond, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lond, 0, 0},
  {(char *)"lonm", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lonm, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lonm, 0, 0},
  {(char *)"lons", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lons, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lons, 0, 0},
  {(char *)"height", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_height, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_height, 0, 0},
  {(char *)"spulse", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_spulse, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_spulse, 0, 0},
  {(char *)"lpulse", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_lpulse, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_lpulse, 0, 0},
  {(char *)"scan_mode", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_scan_mode, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_scan_mode, 0, 0},
  {(char *)"vcp", __pyx_getprop_5pyart_2io_14_rsl_interface_7RslFile_vcp, __pyx_setprop_5pyart_2io_14_rsl_interface_7RslFile_vcp, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyTypeObject __pyx_type_5pyart_2io_14_rsl_interface_RslFile = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyart.io._rsl_interface.RslFile", /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_2io_14_rsl_interface_RslFile), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_2io_14_rsl_interface_RslFile, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  "\n    RslFile(filename)\n\n    A object for accessing Radar data and parameter using the RSL library.\n\n    Parameters\n    ----------\n    filename : str\n        Radar file to read.\n\n    Attributes\n    ----------\n    month : int\n        Date, month (1-12).\n    day : int\n        Date, day (1-31).\n    year : int\n        Date, year (eg. 1993).\n    hour : int\n        Time, hour (0-23).\n    minute : int\n        Time, minute (0-59).\n    sec : float\n        Time, second + fractions of second.\n    nvolumes : int\n        Number of volume slots in the file.\n    number : int\n        Arbitrary number for this radar site.\n    latd, latm, lats : int\n        Latitude degrees, minutes and seconds for the site.\n    lond, lonm, lons : int\n        Longitude degrees, minutes and seconds for the site.\n    height : int\n        Height of site in meters above sea level.\n    spulse : int\n        Length of short pulse in ns.\n    lpulse : int\n        Length of long pulse in ns.\n    scan_mode : int\n        Scan mode, 0 for PPI, 1 for RHI.\n    vcp : int\n        Volume coverage pattern, WSR-88D only.\n\n    ", /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_2io_14_rsl_interface_RslFile, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_5pyart_2io_14_rsl_interface_RslFile, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_2io_14_rsl_interface_RslFile, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py *__pyx_freelist___pyx_scope_struct____Pyx_CFunc_float____Range___to_py[8];
static int __pyx_freecount___pyx_scope_struct____Pyx_CFunc_float____Range___to_py = 0;

static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_float____Range___to_py(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount___pyx_scope_struct____Pyx_CFunc_float____Range___to_py > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py)))) {
    o = (PyObject*)__pyx_freelist___pyx_scope_struct____Pyx_CFunc_float____Range___to_py[--__pyx_freecount___pyx_scope_struct____Pyx_CFunc_float____Range___to_py];
    memset(o, 0, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py));
    (void) PyObject_INIT(o, t);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_float____Range___to_py(PyObject *o) {
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount___pyx_scope_struct____Pyx_CFunc_float____Range___to_py < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py)))) {
    __pyx_freelist___pyx_scope_struct____Pyx_CFunc_float____Range___to_py[__pyx_freecount___pyx_scope_struct____Pyx_CFunc_float____Range___to_py++] = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyTypeObject __pyx_scope_struct____Pyx_CFunc_float____Range___to_py = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyart.io._rsl_interface.__pyx_scope_struct____Pyx_CFunc_float____Range___to_py", /*tp_name*/
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_float____Range___to_py), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_float____Range___to_py, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___pyx_scope_struct____Pyx_CFunc_float____Range___to_py, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py *__pyx_freelist___pyx_scope_struct____Pyx_CFunc_Range____float___to_py[8];
static int __pyx_freecount___pyx_scope_struct____Pyx_CFunc_Range____float___to_py = 0;

static PyObject *__pyx_tp_new___pyx_scope_struct____Pyx_CFunc_Range____float___to_py(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  PyObject *o;
  if (CYTHON_COMPILING_IN_CPYTHON && likely((__pyx_freecount___pyx_scope_struct____Pyx_CFunc_Range____float___to_py > 0) & (t->tp_basicsize == sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py)))) {
    o = (PyObject*)__pyx_freelist___pyx_scope_struct____Pyx_CFunc_Range____float___to_py[--__pyx_freecount___pyx_scope_struct____Pyx_CFunc_Range____float___to_py];
    memset(o, 0, sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py));
    (void) PyObject_INIT(o, t);
  } else {
    o = (*t->tp_alloc)(t, 0);
    if (unlikely(!o)) return 0;
  }
  return o;
}

static void __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_Range____float___to_py(PyObject *o) {
  if (CYTHON_COMPILING_IN_CPYTHON && ((__pyx_freecount___pyx_scope_struct____Pyx_CFunc_Range____float___to_py < 8) & (Py_TYPE(o)->tp_basicsize == sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py)))) {
    __pyx_freelist___pyx_scope_struct____Pyx_CFunc_Range____float___to_py[__pyx_freecount___pyx_scope_struct____Pyx_CFunc_Range____float___to_py++] = ((struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py *)o);
  } else {
    (*Py_TYPE(o)->tp_free)(o);
  }
}

static PyTypeObject __pyx_scope_struct____Pyx_CFunc_Range____float___to_py = {
  PyVarObject_HEAD_INIT(0, 0)
  "pyart.io._rsl_interface.__pyx_scope_struct____Pyx_CFunc_Range____float___to_py", /*tp_name*/
  sizeof(struct __pyx_obj___pyx_scope_struct____Pyx_CFunc_Range____float___to_py), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc___pyx_scope_struct____Pyx_CFunc_Range____float___to_py, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #endif
  #if PY_MAJOR_VERSION >= 3
  0, /*tp_as_async*/
  #endif
  0, /*tp_repr*/
  0, /*tp_as_number*/
  0, /*tp_as_sequence*/
  0, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  0, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  0, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new___pyx_scope_struct____Pyx_CFunc_Range____float___to_py, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  0, /*tp_version_tag*/
  #if PY_VERSION_HEX >= 0x030400a1
  0, /*tp_finalize*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {"copy_volume", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_1copy_volume, METH_O, __pyx_doc_5pyart_2io_14_rsl_interface_copy_volume},
  {"create_volume", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_3create_volume, METH_VARARGS|METH_KEYWORDS, __pyx_doc_5pyart_2io_14_rsl_interface_2create_volume},
  {"_label_volume", (PyCFunction)__pyx_pw_5pyart_2io_14_rsl_interface_5_label_volume, METH_VARARGS|METH_KEYWORDS, __pyx_doc_5pyart_2io_14_rsl_interface_4_label_volume},
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
  #if PY_VERSION_HEX < 0x03020000
    { PyObject_HEAD_INIT(NULL) NULL, 0, NULL },
  #else
    PyModuleDef_HEAD_INIT,
  #endif
    "_rsl_interface",
    __pyx_k_pyart_io__rsl_interface_Cython, /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_Format_string_allocated_too_shor, __pyx_k_Format_string_allocated_too_shor, sizeof(__pyx_k_Format_string_allocated_too_shor), 0, 1, 0, 0},
  {&__pyx_kp_u_Format_string_allocated_too_shor_2, __pyx_k_Format_string_allocated_too_shor_2, sizeof(__pyx_k_Format_string_allocated_too_shor_2), 0, 1, 0, 0},
  {&__pyx_n_s_IOError, __pyx_k_IOError, sizeof(__pyx_k_IOError), 0, 0, 1, 1},
  {&__pyx_kp_u_Non_native_byte_order_not_suppor, __pyx_k_Non_native_byte_order_not_suppor, sizeof(__pyx_k_Non_native_byte_order_not_suppor), 0, 1, 0, 0},
  {&__pyx_n_s_Pyx_CFunc_Range____float___to, __pyx_k_Pyx_CFunc_Range____float___to, sizeof(__pyx_k_Pyx_CFunc_Range____float___to), 0, 0, 1, 1},
  {&__pyx_n_s_Pyx_CFunc_float____Range___to, __pyx_k_Pyx_CFunc_float____Range___to, sizeof(__pyx_k_Pyx_CFunc_float____Range___to), 0, 0, 1, 1},
  {&__pyx_n_s_RSL_VERSION_STR, __pyx_k_RSL_VERSION_STR, sizeof(__pyx_k_RSL_VERSION_STR), 0, 0, 1, 1},
  {&__pyx_n_s_RuntimeError, __pyx_k_RuntimeError, sizeof(__pyx_k_RuntimeError), 0, 0, 1, 1},
  {&__pyx_kp_s_S24, __pyx_k_S24, sizeof(__pyx_k_S24), 0, 0, 1, 0},
  {&__pyx_n_s_ValueError, __pyx_k_ValueError, sizeof(__pyx_k_ValueError), 0, 0, 1, 1},
  {&__pyx_n_s_altitude, __pyx_k_altitude, sizeof(__pyx_k_altitude), 0, 0, 1, 1},
  {&__pyx_n_s_arr, __pyx_k_arr, sizeof(__pyx_k_arr), 0, 0, 1, 1},
  {&__pyx_n_s_azimuth, __pyx_k_azimuth, sizeof(__pyx_k_azimuth), 0, 0, 1, 1},
  {&__pyx_n_s_callid, __pyx_k_callid, sizeof(__pyx_k_callid), 0, 0, 1, 1},
  {&__pyx_kp_s_callid_must_be_provided, __pyx_k_callid_must_be_provided, sizeof(__pyx_k_callid_must_be_provided), 0, 0, 1, 0},
  {&__pyx_kp_s_cannot_load__RslRay_with_NULL, __pyx_k_cannot_load__RslRay_with_NULL, sizeof(__pyx_k_cannot_load__RslRay_with_NULL), 0, 0, 1, 0},
  {&__pyx_kp_s_cannot_load__RslSweep_with_NULL, __pyx_k_cannot_load__RslSweep_with_NULL, sizeof(__pyx_k_cannot_load__RslSweep_with_NULL), 0, 0, 1, 0},
  {&__pyx_kp_s_cannot_load__RslVolume_with_NULL, __pyx_k_cannot_load__RslVolume_with_NULL, sizeof(__pyx_k_cannot_load__RslVolume_with_NULL), 0, 0, 1, 0},
  {&__pyx_n_s_cfunc_to_py, __pyx_k_cfunc_to_py, sizeof(__pyx_k_cfunc_to_py), 0, 0, 1, 1},
  {&__pyx_n_s_city, __pyx_k_city, sizeof(__pyx_k_city), 0, 0, 1, 1},
  {&__pyx_n_s_country, __pyx_k_country, sizeof(__pyx_k_country), 0, 0, 1, 1},
  {&__pyx_n_s_data, __pyx_k_data, sizeof(__pyx_k_data), 0, 0, 1, 1},
  {&__pyx_n_s_datetime, __pyx_k_datetime, sizeof(__pyx_k_datetime), 0, 0, 1, 1},
  {&__pyx_n_s_day, __pyx_k_day, sizeof(__pyx_k_day), 0, 0, 1, 1},
  {&__pyx_n_s_dtype, __pyx_k_dtype, sizeof(__pyx_k_dtype), 0, 0, 1, 1},
  {&__pyx_kp_s_dual, __pyx_k_dual, sizeof(__pyx_k_dual), 0, 0, 1, 0},
  {&__pyx_n_s_elevation, __pyx_k_elevation, sizeof(__pyx_k_elevation), 0, 0, 1, 1},
  {&__pyx_n_s_empty, __pyx_k_empty, sizeof(__pyx_k_empty), 0, 0, 1, 1},
  {&__pyx_kp_s_file_cannot_be_read, __pyx_k_file_cannot_be_read, sizeof(__pyx_k_file_cannot_be_read), 0, 0, 1, 0},
  {&__pyx_n_s_filename, __pyx_k_filename, sizeof(__pyx_k_filename), 0, 0, 1, 1},
  {&__pyx_kp_s_fixed, __pyx_k_fixed, sizeof(__pyx_k_fixed), 0, 0, 1, 0},
  {&__pyx_n_s_float32, __pyx_k_float32, sizeof(__pyx_k_float32), 0, 0, 1, 1},
  {&__pyx_n_s_get_data, __pyx_k_get_data, sizeof(__pyx_k_get_data), 0, 0, 1, 1},
  {&__pyx_n_s_get_nray_array, __pyx_k_get_nray_array, sizeof(__pyx_k_get_nray_array), 0, 0, 1, 1},
  {&__pyx_n_s_get_volume, __pyx_k_get_volume, sizeof(__pyx_k_get_volume), 0, 0, 1, 1},
  {&__pyx_n_s_height, __pyx_k_height, sizeof(__pyx_k_height), 0, 0, 1, 1},
  {&__pyx_n_s_hour, __pyx_k_hour, sizeof(__pyx_k_hour), 0, 0, 1, 1},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_n_s_instrument_parameters, __pyx_k_instrument_parameters, sizeof(__pyx_k_instrument_parameters), 0, 0, 1, 1},
  {&__pyx_n_s_int32, __pyx_k_int32, sizeof(__pyx_k_int32), 0, 0, 1, 1},
  {&__pyx_kp_s_invalid_radar_format, __pyx_k_invalid_radar_format, sizeof(__pyx_k_invalid_radar_format), 0, 0, 1, 0},
  {&__pyx_kp_s_invalid_ray_number, __pyx_k_invalid_ray_number, sizeof(__pyx_k_invalid_ray_number), 0, 0, 1, 0},
  {&__pyx_kp_s_invalid_sweep_number, __pyx_k_invalid_sweep_number, sizeof(__pyx_k_invalid_sweep_number), 0, 0, 1, 0},
  {&__pyx_kp_s_invalid_volume_number, __pyx_k_invalid_volume_number, sizeof(__pyx_k_invalid_volume_number), 0, 0, 1, 0},
  {&__pyx_n_s_latd, __pyx_k_latd, sizeof(__pyx_k_latd), 0, 0, 1, 1},
  {&__pyx_n_s_latm, __pyx_k_latm, sizeof(__pyx_k_latm), 0, 0, 1, 1},
  {&__pyx_n_s_lats, __pyx_k_lats, sizeof(__pyx_k_lats), 0, 0, 1, 1},
  {&__pyx_n_s_lond, __pyx_k_lond, sizeof(__pyx_k_lond), 0, 0, 1, 1},
  {&__pyx_n_s_lonm, __pyx_k_lonm, sizeof(__pyx_k_lonm), 0, 0, 1, 1},
  {&__pyx_n_s_lons, __pyx_k_lons, sizeof(__pyx_k_lons), 0, 0, 1, 1},
  {&__pyx_n_s_lpulse, __pyx_k_lpulse, sizeof(__pyx_k_lpulse), 0, 0, 1, 1},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_n_s_meters_between_gates, __pyx_k_meters_between_gates, sizeof(__pyx_k_meters_between_gates), 0, 0, 1, 1},
  {&__pyx_n_s_meters_to_center_of_first_gate, __pyx_k_meters_to_center_of_first_gate, sizeof(__pyx_k_meters_to_center_of_first_gate), 0, 0, 1, 1},
  {&__pyx_n_s_minute, __pyx_k_minute, sizeof(__pyx_k_minute), 0, 0, 1, 1},
  {&__pyx_n_s_month, __pyx_k_month, sizeof(__pyx_k_month), 0, 0, 1, 1},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_kp_u_ndarray_is_not_C_contiguous, __pyx_k_ndarray_is_not_C_contiguous, sizeof(__pyx_k_ndarray_is_not_C_contiguous), 0, 1, 0, 0},
  {&__pyx_kp_u_ndarray_is_not_Fortran_contiguou, __pyx_k_ndarray_is_not_Fortran_contiguou, sizeof(__pyx_k_ndarray_is_not_Fortran_contiguou), 0, 1, 0, 0},
  {&__pyx_n_s_np, __pyx_k_np, sizeof(__pyx_k_np), 0, 0, 1, 1},
  {&__pyx_n_s_nsweeps, __pyx_k_nsweeps, sizeof(__pyx_k_nsweeps), 0, 0, 1, 1},
  {&__pyx_n_s_number, __pyx_k_number, sizeof(__pyx_k_number), 0, 0, 1, 1},
  {&__pyx_n_s_numpy, __pyx_k_numpy, sizeof(__pyx_k_numpy), 0, 0, 1, 1},
  {&__pyx_n_s_nvolumes, __pyx_k_nvolumes, sizeof(__pyx_k_nvolumes), 0, 0, 1, 1},
  {&__pyx_n_s_nyquist_velocity, __pyx_k_nyquist_velocity, sizeof(__pyx_k_nyquist_velocity), 0, 0, 1, 1},
  {&__pyx_n_s_project, __pyx_k_project, sizeof(__pyx_k_project), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_radar, __pyx_k_radar, sizeof(__pyx_k_radar), 0, 0, 1, 1},
  {&__pyx_n_s_radar_format, __pyx_k_radar_format, sizeof(__pyx_k_radar_format), 0, 0, 1, 1},
  {&__pyx_n_s_radar_name, __pyx_k_radar_name, sizeof(__pyx_k_radar_name), 0, 0, 1, 1},
  {&__pyx_n_s_radar_type, __pyx_k_radar_type, sizeof(__pyx_k_radar_type), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_n_s_rays_per_sweep, __pyx_k_rays_per_sweep, sizeof(__pyx_k_rays_per_sweep), 0, 0, 1, 1},
  {&__pyx_n_s_scan_mode, __pyx_k_scan_mode, sizeof(__pyx_k_scan_mode), 0, 0, 1, 1},
  {&__pyx_n_s_sec, __pyx_k_sec, sizeof(__pyx_k_sec), 0, 0, 1, 1},
  {&__pyx_n_s_seconds, __pyx_k_seconds, sizeof(__pyx_k_seconds), 0, 0, 1, 1},
  {&__pyx_n_s_shape, __pyx_k_shape, sizeof(__pyx_k_shape), 0, 0, 1, 1},
  {&__pyx_n_s_spulse, __pyx_k_spulse, sizeof(__pyx_k_spulse), 0, 0, 1, 1},
  {&__pyx_n_s_state, __pyx_k_state, sizeof(__pyx_k_state), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_sum, __pyx_k_sum, sizeof(__pyx_k_sum), 0, 0, 1, 1},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_timedelta, __pyx_k_timedelta, sizeof(__pyx_k_timedelta), 0, 0, 1, 1},
  {&__pyx_n_s_total_rays, __pyx_k_total_rays, sizeof(__pyx_k_total_rays), 0, 0, 1, 1},
  {&__pyx_kp_u_unknown_dtype_code_in_numpy_pxd, __pyx_k_unknown_dtype_code_in_numpy_pxd, sizeof(__pyx_k_unknown_dtype_code_in_numpy_pxd), 0, 1, 0, 0},
  {&__pyx_n_s_vcp, __pyx_k_vcp, sizeof(__pyx_k_vcp), 0, 0, 1, 1},
  {&__pyx_n_s_vol_num, __pyx_k_vol_num, sizeof(__pyx_k_vol_num), 0, 0, 1, 1},
  {&__pyx_n_s_volume, __pyx_k_volume, sizeof(__pyx_k_volume), 0, 0, 1, 1},
  {&__pyx_n_s_wrap, __pyx_k_wrap, sizeof(__pyx_k_wrap), 0, 0, 1, 1},
  {&__pyx_n_s_wsr88d, __pyx_k_wsr88d, sizeof(__pyx_k_wsr88d), 0, 0, 1, 1},
  {&__pyx_n_s_x, __pyx_k_x, sizeof(__pyx_k_x), 0, 0, 1, 1},
  {&__pyx_n_s_year, __pyx_k_year, sizeof(__pyx_k_year), 0, 0, 1, 1},
  {&__pyx_n_s_zeros, __pyx_k_zeros, sizeof(__pyx_k_zeros), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 128; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_ValueError = __Pyx_GetBuiltinName(__pyx_n_s_ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_IOError = __Pyx_GetBuiltinName(__pyx_n_s_IOError); if (!__pyx_builtin_IOError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_RuntimeError = __Pyx_GetBuiltinName(__pyx_n_s_RuntimeError); if (!__pyx_builtin_RuntimeError) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "pyart/io/_rsl_interface.pyx":313
 *         """ Load the _RslRay object, must be called after creation. """
 *         if Ray is NULL:
 *             raise ValueError('cannot load _RslRay with NULL')             # <<<<<<<<<<<<<<
 *         self._Ray = Ray
 *         self._dealloc = 0
 */
  __pyx_tuple_ = PyTuple_Pack(1, __pyx_kp_s_cannot_load__RslRay_with_NULL); if (unlikely(!__pyx_tuple_)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 313; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple_);
  __Pyx_GIVEREF(__pyx_tuple_);

  /* "pyart/io/_rsl_interface.pyx":665
 *         """ Load the _RslSweep object, must be called after creation. """
 *         if Sweep is NULL:
 *             raise ValueError("cannot load _RslSweep with NULL")             # <<<<<<<<<<<<<<
 *         self._Sweep = Sweep
 *         self._dealloc = 0
 */
  __pyx_tuple__2 = PyTuple_Pack(1, __pyx_kp_s_cannot_load__RslSweep_with_NULL); if (unlikely(!__pyx_tuple__2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 665; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__2);
  __Pyx_GIVEREF(__pyx_tuple__2);

  /* "pyart/io/_rsl_interface.pyx":687
 *         """
 *         if ray_number < 0 or ray_number >= self._Sweep.h.nrays:
 *             raise ValueError('invalid ray_number')             # <<<<<<<<<<<<<<
 *         rslray = _RslRay()
 *         rslray.load(self._Sweep.ray[ray_number])
 */
  __pyx_tuple__3 = PyTuple_Pack(1, __pyx_kp_s_invalid_ray_number); if (unlikely(!__pyx_tuple__3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 687; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__3);
  __Pyx_GIVEREF(__pyx_tuple__3);

  /* "pyart/io/_rsl_interface.pyx":795
 *         """ Load the _RslVolume object, must be called after creation. """
 *         if Volume is NULL:
 *             raise ValueError('cannot load _RslVolume with NULL')             # <<<<<<<<<<<<<<
 *         self._Volume = Volume
 *         self._dealloc = 0
 */
  __pyx_tuple__4 = PyTuple_Pack(1, __pyx_kp_s_cannot_load__RslVolume_with_NULL); if (unlikely(!__pyx_tuple__4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__4);
  __Pyx_GIVEREF(__pyx_tuple__4);

  /* "pyart/io/_rsl_interface.pyx":839
 *         """
 *         if sweep_number < 0 or sweep_number >= self._Volume.h.nsweeps:
 *             raise ValueError('invalid sweep_number')             # <<<<<<<<<<<<<<
 * 
 *         rslsweep = _RslSweep()
 */
  __pyx_tuple__5 = PyTuple_Pack(1, __pyx_kp_s_invalid_sweep_number); if (unlikely(!__pyx_tuple__5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__5);
  __Pyx_GIVEREF(__pyx_tuple__5);

  /* "pyart/io/_rsl_interface.pyx":1131
 *         if radar_format == 'wsr88d':
 *             if callid is None:
 *                 raise ValueError('callid must be provided.')             # <<<<<<<<<<<<<<
 *             self._Radar = _rsl_h.RSL_wsr88d_to_radar(filename, callid)
 *         elif radar_format is None:
 */
  __pyx_tuple__6 = PyTuple_Pack(1, __pyx_kp_s_callid_must_be_provided); if (unlikely(!__pyx_tuple__6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1131; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);

  /* "pyart/io/_rsl_interface.pyx":1138
 *             raise ValueError('invalid radar_format:', radar_format)
 *         if self._Radar is NULL:
 *             raise IOError('file cannot be read.')             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
  __pyx_tuple__7 = PyTuple_Pack(1, __pyx_kp_s_file_cannot_be_read); if (unlikely(!__pyx_tuple__7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1138; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__7);
  __Pyx_GIVEREF(__pyx_tuple__7);

  /* "pyart/io/_rsl_interface.pyx":1162
 *         """
 *         if volume_number < 0 or volume_number >= self._Radar.h.nvolumes:
 *             raise ValueError('invalid volume_number')             # <<<<<<<<<<<<<<
 * 
 *         rslvolume = _RslVolume()
 */
  __pyx_tuple__8 = PyTuple_Pack(1, __pyx_kp_s_invalid_volume_number); if (unlikely(!__pyx_tuple__8)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1162; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__8);
  __Pyx_GIVEREF(__pyx_tuple__8);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":218
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
  __pyx_tuple__9 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_C_contiguous); if (unlikely(!__pyx_tuple__9)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__9);
  __Pyx_GIVEREF(__pyx_tuple__9);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":222
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
  __pyx_tuple__10 = PyTuple_Pack(1, __pyx_kp_u_ndarray_is_not_Fortran_contiguou); if (unlikely(!__pyx_tuple__10)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 222; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__10);
  __Pyx_GIVEREF(__pyx_tuple__10);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":259
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
  __pyx_tuple__11 = PyTuple_Pack(1, __pyx_kp_u_Non_native_byte_order_not_suppor); if (unlikely(!__pyx_tuple__11)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__11);
  __Pyx_GIVEREF(__pyx_tuple__11);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":799
 * 
 *         if (end - f) - <int>(new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
  __pyx_tuple__12 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor); if (unlikely(!__pyx_tuple__12)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__12);
  __Pyx_GIVEREF(__pyx_tuple__12);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
  __pyx_tuple__13 = PyTuple_Pack(1, __pyx_kp_u_Non_native_byte_order_not_suppor); if (unlikely(!__pyx_tuple__13)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__13);
  __Pyx_GIVEREF(__pyx_tuple__13);

  /* "../../../../anaconda/lib/python3.5/site-packages/Cython/Includes/numpy/__init__.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
  __pyx_tuple__14 = PyTuple_Pack(1, __pyx_kp_u_Format_string_allocated_too_shor_2); if (unlikely(!__pyx_tuple__14)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__14);
  __Pyx_GIVEREF(__pyx_tuple__14);

  /* "cfunc.to_py":65
 * @cname("__Pyx_CFunc_float____Range___to_py")
 * cdef object __Pyx_CFunc_float____Range___to_py(float (*f)(Range) except *):
 *     def wrap(Range x):             # <<<<<<<<<<<<<<
 *         """wrap(x: 'Range') -> 'float'"""
 *         return f(x)
 */
  __pyx_tuple__15 = PyTuple_Pack(2, __pyx_n_s_x, __pyx_n_s_x); if (unlikely(!__pyx_tuple__15)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__15);
  __Pyx_GIVEREF(__pyx_tuple__15);
  __pyx_codeobj__16 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__15, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_wrap, 65, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__16)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_tuple__17 = PyTuple_Pack(2, __pyx_n_s_x, __pyx_n_s_x); if (unlikely(!__pyx_tuple__17)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_tuple__17);
  __Pyx_GIVEREF(__pyx_tuple__17);
  __pyx_codeobj__18 = (PyObject*)__Pyx_PyCode_New(1, 0, 2, 0, 0, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__17, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_wrap, 65, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__18)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 65; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_float_0_1 = PyFloat_FromDouble(0.1); if (unlikely(!__pyx_float_0_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_float_1e6 = PyFloat_FromDouble(1e6); if (unlikely(!__pyx_float_1e6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_float_1_31072000e_05 = PyFloat_FromDouble(1.31072000e+05); if (unlikely(!__pyx_float_1_31072000e_05)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_float_neg_999_ = PyFloat_FromDouble(-999.); if (unlikely(!__pyx_float_neg_999_)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_23 = PyInt_FromLong(23); if (unlikely(!__pyx_int_23)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_int_24 = PyInt_FromLong(24); if (unlikely(!__pyx_int_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC init_rsl_interface(void); /*proto*/
PyMODINIT_FUNC init_rsl_interface(void)
#else
PyMODINIT_FUNC PyInit__rsl_interface(void); /*proto*/
PyMODINIT_FUNC PyInit__rsl_interface(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit__rsl_interface(void)", 0);
  if (__Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("_rsl_interface", __pyx_methods, __pyx_k_pyart_io__rsl_interface_Cython, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  if (__pyx_module_is_main_pyart__io___rsl_interface) {
    if (PyObject_SetAttrString(__pyx_m, "__name__", __pyx_n_s_main) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "pyart.io._rsl_interface")) {
      if (unlikely(PyDict_SetItemString(modules, "pyart.io._rsl_interface", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslVolume = &__pyx_vtable_5pyart_2io_14_rsl_interface__RslVolume;
  __pyx_vtable_5pyart_2io_14_rsl_interface__RslVolume.load = (PyObject *(*)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *, Volume *))__pyx_f_5pyart_2io_14_rsl_interface_10_RslVolume_load;
  __pyx_vtable_5pyart_2io_14_rsl_interface__RslVolume._prtmode = (PyObject *(*)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslVolume *, Ray_header))__pyx_f_5pyart_2io_14_rsl_interface_10_RslVolume__prtmode;
  if (PyType_Ready(&__pyx_type_5pyart_2io_14_rsl_interface__RslVolume) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5pyart_2io_14_rsl_interface__RslVolume.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_5pyart_2io_14_rsl_interface__RslVolume.tp_dict, __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslVolume) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttrString(__pyx_m, "_RslVolume", (PyObject *)&__pyx_type_5pyart_2io_14_rsl_interface__RslVolume) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 771; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_2io_14_rsl_interface__RslVolume = &__pyx_type_5pyart_2io_14_rsl_interface__RslVolume;
  __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslRay = &__pyx_vtable_5pyart_2io_14_rsl_interface__RslRay;
  __pyx_vtable_5pyart_2io_14_rsl_interface__RslRay.load = (PyObject *(*)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslRay *, Ray *))__pyx_f_5pyart_2io_14_rsl_interface_7_RslRay_load;
  if (PyType_Ready(&__pyx_type_5pyart_2io_14_rsl_interface__RslRay) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5pyart_2io_14_rsl_interface__RslRay.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_5pyart_2io_14_rsl_interface__RslRay.tp_dict, __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslRay) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttrString(__pyx_m, "_RslRay", (PyObject *)&__pyx_type_5pyart_2io_14_rsl_interface__RslRay) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 209; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_2io_14_rsl_interface__RslRay = &__pyx_type_5pyart_2io_14_rsl_interface__RslRay;
  __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslSweep = &__pyx_vtable_5pyart_2io_14_rsl_interface__RslSweep;
  __pyx_vtable_5pyart_2io_14_rsl_interface__RslSweep.load = (PyObject *(*)(struct __pyx_obj_5pyart_2io_14_rsl_interface__RslSweep *, Sweep *))__pyx_f_5pyart_2io_14_rsl_interface_9_RslSweep_load;
  if (PyType_Ready(&__pyx_type_5pyart_2io_14_rsl_interface__RslSweep) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5pyart_2io_14_rsl_interface__RslSweep.tp_print = 0;
  if (__Pyx_SetVtable(__pyx_type_5pyart_2io_14_rsl_interface__RslSweep.tp_dict, __pyx_vtabptr_5pyart_2io_14_rsl_interface__RslSweep) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttrString(__pyx_m, "_RslSweep", (PyObject *)&__pyx_type_5pyart_2io_14_rsl_interface__RslSweep) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 629; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_2io_14_rsl_interface__RslSweep = &__pyx_type_5pyart_2io_14_rsl_interface__RslSweep;
  if (PyType_Ready(&__pyx_type_5pyart_2io_14_rsl_interface_RslFile) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_type_5pyart_2io_14_rsl_interface_RslFile.tp_print = 0;
  if (PyObject_SetAttrString(__pyx_m, "RslFile", (PyObject *)&__pyx_type_5pyart_2io_14_rsl_interface_RslFile) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1077; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_2io_14_rsl_interface_RslFile = &__pyx_type_5pyart_2io_14_rsl_interface_RslFile;
  if (PyType_Ready(&__pyx_scope_struct____Pyx_CFunc_float____Range___to_py) < 0) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_scope_struct____Pyx_CFunc_float____Range___to_py.tp_print = 0;
  __pyx_ptype___pyx_scope_struct____Pyx_CFunc_float____Range___to_py = &__pyx_scope_struct____Pyx_CFunc_float____Range___to_py;
  if (PyType_Ready(&__pyx_scope_struct____Pyx_CFunc_Range____float___to_py) < 0) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 64; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_scope_struct____Pyx_CFunc_Range____float___to_py.tp_print = 0;
  __pyx_ptype___pyx_scope_struct____Pyx_CFunc_Range____float___to_py = &__pyx_scope_struct____Pyx_CFunc_Range____float___to_py;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "type", 
  #if CYTHON_COMPILING_IN_PYPY
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  0); if (unlikely(!__pyx_ptype_7cpython_4type_type)) {__pyx_filename = __pyx_f[3]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType("numpy", "dtype", sizeof(PyArray_Descr), 0); if (unlikely(!__pyx_ptype_5numpy_dtype)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType("numpy", "flatiter", sizeof(PyArrayIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_flatiter)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 168; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType("numpy", "broadcast", sizeof(PyArrayMultiIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_broadcast)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 172; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_5numpy_ndarray)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 181; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType("numpy", "ufunc", sizeof(PyUFuncObject), 0); if (unlikely(!__pyx_ptype_5numpy_ufunc)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 861; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif

  /* "pyart/io/_rsl_interface.pyx":30
 * # properly wrapped as Cython does not export the typedef from _rsl_h
 * ctypedef unsigned short Range
 * import numpy as np             # <<<<<<<<<<<<<<
 * cimport numpy as np
 * from datetime import datetime, timedelta
 */
  __pyx_t_1 = __Pyx_Import(__pyx_n_s_numpy, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_np, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 30; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/io/_rsl_interface.pyx":32
 * import numpy as np
 * cimport numpy as np
 * from datetime import datetime, timedelta             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = PyList_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_n_s_datetime);
  __Pyx_GIVEREF(__pyx_n_s_datetime);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_n_s_datetime);
  __Pyx_INCREF(__pyx_n_s_timedelta);
  __Pyx_GIVEREF(__pyx_n_s_timedelta);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_n_s_timedelta);
  __pyx_t_2 = __Pyx_Import(__pyx_n_s_datetime, __pyx_t_1, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_datetime); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_datetime, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_ImportFrom(__pyx_t_2, __pyx_n_s_timedelta); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_timedelta, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 32; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":35
 * 
 * 
 * _RSL_VERSION_STR = _rsl_h._RSL_VERSION_STR             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = __Pyx_PyObject_FromString(RSL_VERSION_STR); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_RSL_VERSION_STR, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 35; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyart/io/_rsl_interface.pyx":1
 * """             # <<<<<<<<<<<<<<
 * pyart.io._rsl_interface
 * =======================
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "cfunc.to_py":64
 * 
 * @cname("__Pyx_CFunc_Range____float___to_py")
 * cdef object __Pyx_CFunc_Range____float___to_py(Range (*f)(float) except *):             # <<<<<<<<<<<<<<
 *     def wrap(float x):
 *         """wrap(x: 'float') -> 'Range'"""
 */

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init pyart.io._rsl_interface", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init pyart.io._rsl_interface");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* --- Runtime support code --- */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

static void __Pyx_RaiseArgumentTypeInvalid(const char* name, PyObject *obj, PyTypeObject *type) {
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
}
static CYTHON_INLINE int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (none_allowed && obj == Py_None) return 1;
    else if (exact) {
        if (likely(Py_TYPE(obj) == type)) return 1;
        #if PY_MAJOR_VERSION == 2
        else if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(PyObject_TypeCheck(obj, type))) return 1;
    }
    __Pyx_RaiseArgumentTypeInvalid(name, obj, type);
    return 0;
}

static CYTHON_INLINE int __Pyx_IsLittleEndian(void) {
  unsigned int n = 1;
  return *(unsigned char*)(&n) != 0;
}
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t < '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1)
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparseable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count;
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break;
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue;
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static CYTHON_INLINE PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number;
    int ndim = ctx->head->field->type->ndim;
;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    while (*ts && *ts != ')') {
        switch (*ts) {
            case ' ': case '\f': case '\r': case '\n': case '\t': case '\v':  continue;
            default:  break;
        }
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        return ts;
      case ' ':
      case '\r':
      case '\n':
        ++ts;
        break;
      case '<':
        if (!__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T':
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}':
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0;
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }
      case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 'p':
        if (ctx->enc_type == *ts && got_Z == ctx->is_complex &&
            ctx->enc_packmode == ctx->new_packmode) {
          ctx->enc_count += ctx->new_count;
          ctx->new_count = 1;
          got_Z = 0;
          ++ts;
          break;
        }
      case 's':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->enc_count = ctx->new_count;
        ctx->enc_packmode = ctx->new_packmode;
        ctx->enc_type = *ts;
        ctx->is_complex = got_Z;
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}
static CYTHON_INLINE void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static CYTHON_INLINE int __Pyx_GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  if (obj == Py_None || obj == NULL) {
    __Pyx_ZeroBuffer(buf);
    return 0;
  }
  buf->buf = NULL;
  if (__Pyx_GetBuffer(obj, buf, flags) == -1) goto fail;
  if (buf->ndim != nd) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if ((unsigned)buf->itemsize != dtype->size) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_ZeroBuffer(buf);
  return -1;
}
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (info->buf == NULL) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}

static void __Pyx_RaiseBufferIndexError(int axis) {
  PyErr_Format(PyExc_IndexError,
     "Out of bounds on buffer access (axis %d)", axis);
}

#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS && PY_MAJOR_VERSION >= 3
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    }
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    }
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    }
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    }
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    }
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
                    }
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static double __Pyx__PyObject_AsDouble(PyObject* obj) {
    PyObject* float_value;
#if CYTHON_COMPILING_IN_PYPY
    float_value = PyNumber_Float(obj);  if (0) goto bad;
#else
    PyNumberMethods *nb = Py_TYPE(obj)->tp_as_number;
    if (likely(nb) && likely(nb->nb_float)) {
        float_value = nb->nb_float(obj);
        if (likely(float_value) && unlikely(!PyFloat_Check(float_value))) {
            PyErr_Format(PyExc_TypeError,
                "__float__ returned non-float (type %.200s)",
                Py_TYPE(float_value)->tp_name);
            Py_DECREF(float_value);
            goto bad;
        }
    } else if (PyUnicode_CheckExact(obj) || PyBytes_CheckExact(obj)) {
#if PY_MAJOR_VERSION >= 3
        float_value = PyFloat_FromString(obj);
#else
        float_value = PyFloat_FromString(obj, 0);
#endif
    } else {
        PyObject* args = PyTuple_New(1);
        if (unlikely(!args)) goto bad;
        PyTuple_SET_ITEM(args, 0, obj);
        float_value = PyObject_Call((PyObject*)&PyFloat_Type, args, 0);
        PyTuple_SET_ITEM(args, 0, 0);
        Py_DECREF(args);
    }
#endif
    if (likely(float_value)) {
        double value = PyFloat_AS_DOUBLE(float_value);
        Py_DECREF(float_value);
        return value;
    }
bad:
    return (double)-1;
}

static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyList_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (wraparound & unlikely(i < 0)) i += PyTuple_GET_SIZE(o);
    if ((!boundscheck) || likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely((n >= 0) & (n < PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (PyErr_ExceptionMatches(PyExc_OverflowError))
                        PyErr_Clear();
                    else
                        return NULL;
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
#if PY_VERSION_HEX >= 0x03030000
    if (cause) {
#else
    if (cause && cause != Py_None) {
#endif
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%.1s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx_PyInt_EqObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, CYTHON_UNUSED int inplace) {
    if (op1 == op2) {
        Py_RETURN_TRUE;
    }
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long a = PyInt_AS_LONG(op1);
        if (a == b) {
            Py_RETURN_TRUE;
        } else {
            Py_RETURN_FALSE;
        }
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS && PY_MAJOR_VERSION >= 3
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a;
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
                    }
                #if PyLong_SHIFT < 30 && PyLong_SHIFT != 15
                default: return PyLong_Type.tp_richcompare(op1, op2, Py_EQ);
                #else
                default: Py_RETURN_FALSE;
                #endif
            }
        }
            if (a == b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            if ((double)a == (double)b) {
                Py_RETURN_TRUE;
            } else {
                Py_RETURN_FALSE;
            }
    }
    return PyObject_RichCompare(op1, op2, Py_EQ);
}
#endif

static CYTHON_INLINE PyObject *__Pyx_GetModuleGlobalName(PyObject *name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON
    result = PyDict_GetItem(__pyx_d, name);
    if (likely(result)) {
        Py_INCREF(result);
    } else {
#else
    result = PyObject_GetItem(__pyx_d, name);
    if (!result) {
        PyErr_Clear();
#endif
        result = __Pyx_GetBuiltinName(name);
    }
    return result;
}

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx_PyFloat_AddObjC(PyObject *op1, PyObject *op2, double floatval, CYTHON_UNUSED int inplace) {
    const double b = floatval;
    double a, result;
    if (likely(PyFloat_CheckExact(op1))) {
        a = PyFloat_AS_DOUBLE(op1);
    } else
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        a = (double) PyInt_AS_LONG(op1);
    } else
    #endif
    if (likely(PyLong_CheckExact(op1))) {
        #if CYTHON_USE_PYLONG_INTERNALS && PY_MAJOR_VERSION >= 3
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        switch (size) {
            case  0: a = 0.0; break;
            case -1: a = -(double) digits[0]; break;
            case  1: a = (double) digits[0]; break;
            case -2:
            case 2:
                if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (1 * PyLong_SHIFT < 53))) {
                    a = (double) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53) || (a < (double) (1L<<53))) {
                        if (size == -2)
                            a = -a;
                        break;
                    }
                }
            case -3:
            case 3:
                if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (2 * PyLong_SHIFT < 53))) {
                    a = (double) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53) || (a < (double) (1L<<53))) {
                        if (size == -3)
                            a = -a;
                        break;
                    }
                }
            case -4:
            case 4:
                if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT && ((8 * sizeof(unsigned long) < 53) || (3 * PyLong_SHIFT < 53))) {
                    a = (double) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                    if ((8 * sizeof(unsigned long) < 53) || (4 * PyLong_SHIFT < 53) || (a < (double) (1L<<53))) {
                        if (size == -4)
                            a = -a;
                        break;
                    }
                }
            default:
        #else
        {
        #endif
            a = PyLong_AsDouble(op1);
            if (unlikely(a == -1.0 && PyErr_Occurred())) return NULL;
        }
    } else {
        return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
    }
        PyFPE_START_PROTECT("add", return NULL)
        result = a + b;
        PyFPE_END_PROTECT(result)
        return PyFloat_FromDouble(result);
}
#endif

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static void __Pyx_RaiseBufferFallbackError(void) {
  PyErr_SetString(PyExc_ValueError,
     "Buffer acquisition failed on assignment; and then reacquiring the old buffer failed too!");
}

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || PyObject_TypeCheck(func, __pyx_CyFunctionType))) {
#else
    if (likely(PyCFunction_Check(func))) {
#endif
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

static PyTypeObject* __Pyx_FetchCommonType(PyTypeObject* type) {
    PyObject* fake_module;
    PyTypeObject* cached_type = NULL;
    fake_module = PyImport_AddModule((char*) "_cython_" CYTHON_ABI);
    if (!fake_module) return NULL;
    Py_INCREF(fake_module);
    cached_type = (PyTypeObject*) PyObject_GetAttrString(fake_module, type->tp_name);
    if (cached_type) {
        if (!PyType_Check((PyObject*)cached_type)) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s is not a type object",
                type->tp_name);
            goto bad;
        }
        if (cached_type->tp_basicsize != type->tp_basicsize) {
            PyErr_Format(PyExc_TypeError,
                "Shared Cython type %.200s has the wrong size, try recompiling",
                type->tp_name);
            goto bad;
        }
    } else {
        if (!PyErr_ExceptionMatches(PyExc_AttributeError)) goto bad;
        PyErr_Clear();
        if (PyType_Ready(type) < 0) goto bad;
        if (PyObject_SetAttrString(fake_module, type->tp_name, (PyObject*) type) < 0)
            goto bad;
        Py_INCREF(type);
        cached_type = type;
    }
done:
    Py_DECREF(fake_module);
    return cached_type;
bad:
    Py_XDECREF(cached_type);
    cached_type = NULL;
    goto done;
}

static PyObject *
__Pyx_CyFunction_get_doc(__pyx_CyFunctionObject *op, CYTHON_UNUSED void *closure)
{
    if (unlikely(op->func_doc == NULL)) {
        if (op->func.m_ml->ml_doc) {
#if PY_MAJOR_VERSION >= 3
            op->func_doc = PyUnicode_FromString(op->func.m_ml->ml_doc);
#else
            op->func_doc = PyString_FromString(op->func.m_ml->ml_doc);
#endif
            if (unlikely(op->func_doc == NULL))
                return NULL;
        } else {
            Py_INCREF(Py_None);
            return Py_None;
        }
    }
    Py_INCREF(op->func_doc);
    return op->func_doc;
}
static int
__Pyx_CyFunction_set_doc(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp = op->func_doc;
    if (value == NULL) {
        value = Py_None;
    }
    Py_INCREF(value);
    op->func_doc = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_name(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_name == NULL)) {
#if PY_MAJOR_VERSION >= 3
        op->func_name = PyUnicode_InternFromString(op->func.m_ml->ml_name);
#else
        op->func_name = PyString_InternFromString(op->func.m_ml->ml_name);
#endif
        if (unlikely(op->func_name == NULL))
            return NULL;
    }
    Py_INCREF(op->func_name);
    return op->func_name;
}
static int
__Pyx_CyFunction_set_name(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__name__ must be set to a string object");
        return -1;
    }
    tmp = op->func_name;
    Py_INCREF(value);
    op->func_name = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_qualname(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_qualname);
    return op->func_qualname;
}
static int
__Pyx_CyFunction_set_qualname(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
#if PY_MAJOR_VERSION >= 3
    if (unlikely(value == NULL || !PyUnicode_Check(value))) {
#else
    if (unlikely(value == NULL || !PyString_Check(value))) {
#endif
        PyErr_SetString(PyExc_TypeError,
                        "__qualname__ must be set to a string object");
        return -1;
    }
    tmp = op->func_qualname;
    Py_INCREF(value);
    op->func_qualname = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_self(__pyx_CyFunctionObject *m, CYTHON_UNUSED void *closure)
{
    PyObject *self;
    self = m->func_closure;
    if (self == NULL)
        self = Py_None;
    Py_INCREF(self);
    return self;
}
static PyObject *
__Pyx_CyFunction_get_dict(__pyx_CyFunctionObject *op)
{
    if (unlikely(op->func_dict == NULL)) {
        op->func_dict = PyDict_New();
        if (unlikely(op->func_dict == NULL))
            return NULL;
    }
    Py_INCREF(op->func_dict);
    return op->func_dict;
}
static int
__Pyx_CyFunction_set_dict(__pyx_CyFunctionObject *op, PyObject *value)
{
    PyObject *tmp;
    if (unlikely(value == NULL)) {
        PyErr_SetString(PyExc_TypeError,
               "function's dictionary may not be deleted");
        return -1;
    }
    if (unlikely(!PyDict_Check(value))) {
        PyErr_SetString(PyExc_TypeError,
               "setting function's dictionary to a non-dict");
        return -1;
    }
    tmp = op->func_dict;
    Py_INCREF(value);
    op->func_dict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_globals(__pyx_CyFunctionObject *op)
{
    Py_INCREF(op->func_globals);
    return op->func_globals;
}
static PyObject *
__Pyx_CyFunction_get_closure(CYTHON_UNUSED __pyx_CyFunctionObject *op)
{
    Py_INCREF(Py_None);
    return Py_None;
}
static PyObject *
__Pyx_CyFunction_get_code(__pyx_CyFunctionObject *op)
{
    PyObject* result = (op->func_code) ? op->func_code : Py_None;
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_init_defaults(__pyx_CyFunctionObject *op) {
    int result = 0;
    PyObject *res = op->defaults_getter((PyObject *) op);
    if (unlikely(!res))
        return -1;
    #if CYTHON_COMPILING_IN_CPYTHON
    op->defaults_tuple = PyTuple_GET_ITEM(res, 0);
    Py_INCREF(op->defaults_tuple);
    op->defaults_kwdict = PyTuple_GET_ITEM(res, 1);
    Py_INCREF(op->defaults_kwdict);
    #else
    op->defaults_tuple = PySequence_ITEM(res, 0);
    if (unlikely(!op->defaults_tuple)) result = -1;
    else {
        op->defaults_kwdict = PySequence_ITEM(res, 1);
        if (unlikely(!op->defaults_kwdict)) result = -1;
    }
    #endif
    Py_DECREF(res);
    return result;
}
static int
__Pyx_CyFunction_set_defaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyTuple_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__defaults__ must be set to a tuple object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_tuple;
    op->defaults_tuple = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_defaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_tuple;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_tuple;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_kwdefaults(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value) {
        value = Py_None;
    } else if (value != Py_None && !PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__kwdefaults__ must be set to a dict object");
        return -1;
    }
    Py_INCREF(value);
    tmp = op->defaults_kwdict;
    op->defaults_kwdict = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_kwdefaults(__pyx_CyFunctionObject *op) {
    PyObject* result = op->defaults_kwdict;
    if (unlikely(!result)) {
        if (op->defaults_getter) {
            if (__Pyx_CyFunction_init_defaults(op) < 0) return NULL;
            result = op->defaults_kwdict;
        } else {
            result = Py_None;
        }
    }
    Py_INCREF(result);
    return result;
}
static int
__Pyx_CyFunction_set_annotations(__pyx_CyFunctionObject *op, PyObject* value) {
    PyObject* tmp;
    if (!value || value == Py_None) {
        value = NULL;
    } else if (!PyDict_Check(value)) {
        PyErr_SetString(PyExc_TypeError,
                        "__annotations__ must be set to a dict object");
        return -1;
    }
    Py_XINCREF(value);
    tmp = op->func_annotations;
    op->func_annotations = value;
    Py_XDECREF(tmp);
    return 0;
}
static PyObject *
__Pyx_CyFunction_get_annotations(__pyx_CyFunctionObject *op) {
    PyObject* result = op->func_annotations;
    if (unlikely(!result)) {
        result = PyDict_New();
        if (unlikely(!result)) return NULL;
        op->func_annotations = result;
    }
    Py_INCREF(result);
    return result;
}
static PyGetSetDef __pyx_CyFunction_getsets[] = {
    {(char *) "func_doc", (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "__doc__",  (getter)__Pyx_CyFunction_get_doc, (setter)__Pyx_CyFunction_set_doc, 0, 0},
    {(char *) "func_name", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__name__", (getter)__Pyx_CyFunction_get_name, (setter)__Pyx_CyFunction_set_name, 0, 0},
    {(char *) "__qualname__", (getter)__Pyx_CyFunction_get_qualname, (setter)__Pyx_CyFunction_set_qualname, 0, 0},
    {(char *) "__self__", (getter)__Pyx_CyFunction_get_self, 0, 0, 0},
    {(char *) "func_dict", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "__dict__", (getter)__Pyx_CyFunction_get_dict, (setter)__Pyx_CyFunction_set_dict, 0, 0},
    {(char *) "func_globals", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "__globals__", (getter)__Pyx_CyFunction_get_globals, 0, 0, 0},
    {(char *) "func_closure", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "__closure__", (getter)__Pyx_CyFunction_get_closure, 0, 0, 0},
    {(char *) "func_code", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "__code__", (getter)__Pyx_CyFunction_get_code, 0, 0, 0},
    {(char *) "func_defaults", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__defaults__", (getter)__Pyx_CyFunction_get_defaults, (setter)__Pyx_CyFunction_set_defaults, 0, 0},
    {(char *) "__kwdefaults__", (getter)__Pyx_CyFunction_get_kwdefaults, (setter)__Pyx_CyFunction_set_kwdefaults, 0, 0},
    {(char *) "__annotations__", (getter)__Pyx_CyFunction_get_annotations, (setter)__Pyx_CyFunction_set_annotations, 0, 0},
    {0, 0, 0, 0, 0}
};
static PyMemberDef __pyx_CyFunction_members[] = {
    {(char *) "__module__", T_OBJECT, offsetof(__pyx_CyFunctionObject, func.m_module), PY_WRITE_RESTRICTED, 0},
    {0, 0, 0,  0, 0}
};
static PyObject *
__Pyx_CyFunction_reduce(__pyx_CyFunctionObject *m, CYTHON_UNUSED PyObject *args)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromString(m->func.m_ml->ml_name);
#else
    return PyString_FromString(m->func.m_ml->ml_name);
#endif
}
static PyMethodDef __pyx_CyFunction_methods[] = {
    {"__reduce__", (PyCFunction)__Pyx_CyFunction_reduce, METH_VARARGS, 0},
    {0, 0, 0, 0}
};
#if PY_VERSION_HEX < 0x030500A0
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func_weakreflist)
#else
#define __Pyx_CyFunction_weakreflist(cyfunc) ((cyfunc)->func.m_weakreflist)
#endif
static PyObject *__Pyx_CyFunction_New(PyTypeObject *type, PyMethodDef *ml, int flags, PyObject* qualname,
                                      PyObject *closure, PyObject *module, PyObject* globals, PyObject* code) {
    __pyx_CyFunctionObject *op = PyObject_GC_New(__pyx_CyFunctionObject, type);
    if (op == NULL)
        return NULL;
    op->flags = flags;
    __Pyx_CyFunction_weakreflist(op) = NULL;
    op->func.m_ml = ml;
    op->func.m_self = (PyObject *) op;
    Py_XINCREF(closure);
    op->func_closure = closure;
    Py_XINCREF(module);
    op->func.m_module = module;
    op->func_dict = NULL;
    op->func_name = NULL;
    Py_INCREF(qualname);
    op->func_qualname = qualname;
    op->func_doc = NULL;
    op->func_classobj = NULL;
    op->func_globals = globals;
    Py_INCREF(op->func_globals);
    Py_XINCREF(code);
    op->func_code = code;
    op->defaults_pyobjects = 0;
    op->defaults = NULL;
    op->defaults_tuple = NULL;
    op->defaults_kwdict = NULL;
    op->defaults_getter = NULL;
    op->func_annotations = NULL;
    PyObject_GC_Track(op);
    return (PyObject *) op;
}
static int
__Pyx_CyFunction_clear(__pyx_CyFunctionObject *m)
{
    Py_CLEAR(m->func_closure);
    Py_CLEAR(m->func.m_module);
    Py_CLEAR(m->func_dict);
    Py_CLEAR(m->func_name);
    Py_CLEAR(m->func_qualname);
    Py_CLEAR(m->func_doc);
    Py_CLEAR(m->func_globals);
    Py_CLEAR(m->func_code);
    Py_CLEAR(m->func_classobj);
    Py_CLEAR(m->defaults_tuple);
    Py_CLEAR(m->defaults_kwdict);
    Py_CLEAR(m->func_annotations);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_XDECREF(pydefaults[i]);
        PyMem_Free(m->defaults);
        m->defaults = NULL;
    }
    return 0;
}
static void __Pyx_CyFunction_dealloc(__pyx_CyFunctionObject *m)
{
    PyObject_GC_UnTrack(m);
    if (__Pyx_CyFunction_weakreflist(m) != NULL)
        PyObject_ClearWeakRefs((PyObject *) m);
    __Pyx_CyFunction_clear(m);
    PyObject_GC_Del(m);
}
static int __Pyx_CyFunction_traverse(__pyx_CyFunctionObject *m, visitproc visit, void *arg)
{
    Py_VISIT(m->func_closure);
    Py_VISIT(m->func.m_module);
    Py_VISIT(m->func_dict);
    Py_VISIT(m->func_name);
    Py_VISIT(m->func_qualname);
    Py_VISIT(m->func_doc);
    Py_VISIT(m->func_globals);
    Py_VISIT(m->func_code);
    Py_VISIT(m->func_classobj);
    Py_VISIT(m->defaults_tuple);
    Py_VISIT(m->defaults_kwdict);
    if (m->defaults) {
        PyObject **pydefaults = __Pyx_CyFunction_Defaults(PyObject *, m);
        int i;
        for (i = 0; i < m->defaults_pyobjects; i++)
            Py_VISIT(pydefaults[i]);
    }
    return 0;
}
static PyObject *__Pyx_CyFunction_descr_get(PyObject *func, PyObject *obj, PyObject *type)
{
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    if (m->flags & __Pyx_CYFUNCTION_STATICMETHOD) {
        Py_INCREF(func);
        return func;
    }
    if (m->flags & __Pyx_CYFUNCTION_CLASSMETHOD) {
        if (type == NULL)
            type = (PyObject *)(Py_TYPE(obj));
        return __Pyx_PyMethod_New(func, type, (PyObject *)(Py_TYPE(type)));
    }
    if (obj == Py_None)
        obj = NULL;
    return __Pyx_PyMethod_New(func, obj, type);
}
static PyObject*
__Pyx_CyFunction_repr(__pyx_CyFunctionObject *op)
{
#if PY_MAJOR_VERSION >= 3
    return PyUnicode_FromFormat("<cyfunction %U at %p>",
                                op->func_qualname, (void *)op);
#else
    return PyString_FromFormat("<cyfunction %s at %p>",
                               PyString_AsString(op->func_qualname), (void *)op);
#endif
}
#if CYTHON_COMPILING_IN_PYPY
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyCFunctionObject* f = (PyCFunctionObject*)func;
    PyCFunction meth = f->m_ml->ml_meth;
    PyObject *self = f->m_self;
    Py_ssize_t size;
    switch (f->m_ml->ml_flags & (METH_VARARGS | METH_KEYWORDS | METH_NOARGS | METH_O)) {
    case METH_VARARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0))
            return (*meth)(self, arg);
        break;
    case METH_VARARGS | METH_KEYWORDS:
        return (*(PyCFunctionWithKeywords)meth)(self, arg, kw);
    case METH_NOARGS:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 0))
                return (*meth)(self, NULL);
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes no arguments (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    case METH_O:
        if (likely(kw == NULL || PyDict_Size(kw) == 0)) {
            size = PyTuple_GET_SIZE(arg);
            if (likely(size == 1)) {
                PyObject *result, *arg0 = PySequence_ITEM(arg, 0);
                if (unlikely(!arg0)) return NULL;
                result = (*meth)(self, arg0);
                Py_DECREF(arg0);
                return result;
            }
            PyErr_Format(PyExc_TypeError,
                "%.200s() takes exactly one argument (%" CYTHON_FORMAT_SSIZE_T "d given)",
                f->m_ml->ml_name, size);
            return NULL;
        }
        break;
    default:
        PyErr_SetString(PyExc_SystemError, "Bad call flags in "
                        "__Pyx_CyFunction_Call. METH_OLDARGS is no "
                        "longer supported!");
        return NULL;
    }
    PyErr_Format(PyExc_TypeError, "%.200s() takes no keyword arguments",
                 f->m_ml->ml_name);
    return NULL;
}
#else
static PyObject * __Pyx_CyFunction_Call(PyObject *func, PyObject *arg, PyObject *kw) {
	return PyCFunction_Call(func, arg, kw);
}
#endif
static PyTypeObject __pyx_CyFunctionType_type = {
    PyVarObject_HEAD_INIT(0, 0)
    "cython_function_or_method",
    sizeof(__pyx_CyFunctionObject),
    0,
    (destructor) __Pyx_CyFunction_dealloc,
    0,
    0,
    0,
#if PY_MAJOR_VERSION < 3
    0,
#else
    0,
#endif
    (reprfunc) __Pyx_CyFunction_repr,
    0,
    0,
    0,
    0,
    __Pyx_CyFunction_Call,
    0,
    0,
    0,
    0,
    Py_TPFLAGS_DEFAULT | Py_TPFLAGS_HAVE_GC,
    0,
    (traverseproc) __Pyx_CyFunction_traverse,
    (inquiry) __Pyx_CyFunction_clear,
    0,
#if PY_VERSION_HEX < 0x030500A0
    offsetof(__pyx_CyFunctionObject, func_weakreflist),
#else
    offsetof(PyCFunctionObject, m_weakreflist),
#endif
    0,
    0,
    __pyx_CyFunction_methods,
    __pyx_CyFunction_members,
    __pyx_CyFunction_getsets,
    0,
    0,
    __Pyx_CyFunction_descr_get,
    0,
    offsetof(__pyx_CyFunctionObject, func_dict),
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
    0,
#if PY_VERSION_HEX >= 0x030400a1
    0,
#endif
};
static int __pyx_CyFunction_init(void) {
#if !CYTHON_COMPILING_IN_PYPY
    __pyx_CyFunctionType_type.tp_call = PyCFunction_Call;
#endif
    __pyx_CyFunctionType = __Pyx_FetchCommonType(&__pyx_CyFunctionType_type);
    if (__pyx_CyFunctionType == NULL) {
        return -1;
    }
    return 0;
}
static CYTHON_INLINE void *__Pyx_CyFunction_InitDefaults(PyObject *func, size_t size, int pyobjects) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults = PyMem_Malloc(size);
    if (!m->defaults)
        return PyErr_NoMemory();
    memset(m->defaults, 0, size);
    m->defaults_pyobjects = pyobjects;
    return m->defaults;
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsTuple(PyObject *func, PyObject *tuple) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_tuple = tuple;
    Py_INCREF(tuple);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetDefaultsKwDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->defaults_kwdict = dict;
    Py_INCREF(dict);
}
static CYTHON_INLINE void __Pyx_CyFunction_SetAnnotationsDict(PyObject *func, PyObject *dict) {
    __pyx_CyFunctionObject *m = (__pyx_CyFunctionObject *) func;
    m->func_annotations = dict;
    Py_INCREF(dict);
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_VERSION_HEX < 0x03030000
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                #if PY_VERSION_HEX < 0x03030000
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                #else
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                #endif
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_VERSION_HEX < 0x03030000
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_VERSION_HEX < 0x03030000
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, (size_t)new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        __pyx_d,      /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) return __pyx_pw_5numpy_7ndarray_1__getbuffer__(obj, view, flags);
    PyErr_Format(PyExc_TypeError, "'%.200s' does not have the buffer interface", Py_TYPE(obj)->tp_name);
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    if (!obj) return;
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) { __pyx_pw_5numpy_7ndarray_3__releasebuffer__(obj, view); return; }
    Py_DECREF(obj);
    view->obj = NULL;
}
#endif


                #define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

static CYTHON_INLINE Range __Pyx_PyInt_As_Range(PyObject *x) {
    const Range neg_one = (Range) -1, const_zero = (Range) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(Range) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(Range, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (Range) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (Range) 0;
                case  1: __PYX_VERIFY_RETURN_INT(Range, digit, digits[0])
                case 2:
                    if (8 * sizeof(Range) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) >= 2 * PyLong_SHIFT) {
                            return (Range) (((((Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(Range) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) >= 3 * PyLong_SHIFT) {
                            return (Range) (((((((Range)digits[2]) << PyLong_SHIFT) | (Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(Range) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) >= 4 * PyLong_SHIFT) {
                            return (Range) (((((((((Range)digits[3]) << PyLong_SHIFT) | (Range)digits[2]) << PyLong_SHIFT) | (Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (Range) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(Range) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(Range, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(Range) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(Range, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (Range) 0;
                case -1: __PYX_VERIFY_RETURN_INT(Range, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(Range,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(Range) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) - 1 > 2 * PyLong_SHIFT) {
                            return (Range) (((Range)-1)*(((((Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(Range) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) - 1 > 2 * PyLong_SHIFT) {
                            return (Range) ((((((Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(Range) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) - 1 > 3 * PyLong_SHIFT) {
                            return (Range) (((Range)-1)*(((((((Range)digits[2]) << PyLong_SHIFT) | (Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(Range) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) - 1 > 3 * PyLong_SHIFT) {
                            return (Range) ((((((((Range)digits[2]) << PyLong_SHIFT) | (Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(Range) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) - 1 > 4 * PyLong_SHIFT) {
                            return (Range) (((Range)-1)*(((((((((Range)digits[3]) << PyLong_SHIFT) | (Range)digits[2]) << PyLong_SHIFT) | (Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(Range) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Range, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Range) - 1 > 4 * PyLong_SHIFT) {
                            return (Range) ((((((((((Range)digits[3]) << PyLong_SHIFT) | (Range)digits[2]) << PyLong_SHIFT) | (Range)digits[1]) << PyLong_SHIFT) | (Range)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(Range) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(Range, long, PyLong_AsLong(x))
            } else if (sizeof(Range) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(Range, PY_LONG_LONG, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            Range val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (Range) -1;
        }
    } else {
        Range val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (Range) -1;
        val = __Pyx_PyInt_As_Range(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to Range");
    return (Range) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to Range");
    return (Range) -1;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_Range(Range value) {
    const Range neg_one = (Range) -1, const_zero = (Range) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(Range) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(Range) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(Range) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
        }
    } else {
        if (sizeof(Range) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(Range) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(Range),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_Py_intptr_t(Py_intptr_t value) {
    const Py_intptr_t neg_one = (Py_intptr_t) -1, const_zero = (Py_intptr_t) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(Py_intptr_t) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(Py_intptr_t) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(Py_intptr_t) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
        }
    } else {
        if (sizeof(Py_intptr_t) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(Py_intptr_t) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(Py_intptr_t),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE Py_intptr_t __Pyx_PyInt_As_Py_intptr_t(PyObject *x) {
    const Py_intptr_t neg_one = (Py_intptr_t) -1, const_zero = (Py_intptr_t) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(Py_intptr_t) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (Py_intptr_t) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (Py_intptr_t) 0;
                case  1: __PYX_VERIFY_RETURN_INT(Py_intptr_t, digit, digits[0])
                case 2:
                    if (8 * sizeof(Py_intptr_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) >= 2 * PyLong_SHIFT) {
                            return (Py_intptr_t) (((((Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(Py_intptr_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) >= 3 * PyLong_SHIFT) {
                            return (Py_intptr_t) (((((((Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(Py_intptr_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) >= 4 * PyLong_SHIFT) {
                            return (Py_intptr_t) (((((((((Py_intptr_t)digits[3]) << PyLong_SHIFT) | (Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (Py_intptr_t) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(Py_intptr_t) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(Py_intptr_t) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (Py_intptr_t) 0;
                case -1: __PYX_VERIFY_RETURN_INT(Py_intptr_t, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(Py_intptr_t,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(Py_intptr_t) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) - 1 > 2 * PyLong_SHIFT) {
                            return (Py_intptr_t) (((Py_intptr_t)-1)*(((((Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(Py_intptr_t) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) - 1 > 2 * PyLong_SHIFT) {
                            return (Py_intptr_t) ((((((Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(Py_intptr_t) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) - 1 > 3 * PyLong_SHIFT) {
                            return (Py_intptr_t) (((Py_intptr_t)-1)*(((((((Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(Py_intptr_t) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) - 1 > 3 * PyLong_SHIFT) {
                            return (Py_intptr_t) ((((((((Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(Py_intptr_t) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) - 1 > 4 * PyLong_SHIFT) {
                            return (Py_intptr_t) (((Py_intptr_t)-1)*(((((((((Py_intptr_t)digits[3]) << PyLong_SHIFT) | (Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(Py_intptr_t) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(Py_intptr_t, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(Py_intptr_t) - 1 > 4 * PyLong_SHIFT) {
                            return (Py_intptr_t) ((((((((((Py_intptr_t)digits[3]) << PyLong_SHIFT) | (Py_intptr_t)digits[2]) << PyLong_SHIFT) | (Py_intptr_t)digits[1]) << PyLong_SHIFT) | (Py_intptr_t)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(Py_intptr_t) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, long, PyLong_AsLong(x))
            } else if (sizeof(Py_intptr_t) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(Py_intptr_t, PY_LONG_LONG, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            Py_intptr_t val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (Py_intptr_t) -1;
        }
    } else {
        Py_intptr_t val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (Py_intptr_t) -1;
        val = __Pyx_PyInt_As_Py_intptr_t(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to Py_intptr_t");
    return (Py_intptr_t) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to Py_intptr_t");
    return (Py_intptr_t) -1;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_npy_int32(npy_int32 value) {
    const npy_int32 neg_one = (npy_int32) -1, const_zero = (npy_int32) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(npy_int32) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int32) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(npy_int32) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
        }
    } else {
        if (sizeof(npy_int32) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(npy_int32) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(npy_int32),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) -1, const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

static PyObject* __pyx_convert__to_py_Radar_header(Radar_header s) {
                  PyObject* res;
                  PyObject* member;
                  res = PyDict_New(); if (res == NULL) return NULL;
                  member = __Pyx_PyInt_From_int(s.month); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_month, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.day); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_day, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.year); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_year, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.hour); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_hour, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.minute); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_minute, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = PyFloat_FromDouble(s.sec); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_sec, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyObject_FromString(s.radar_type); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_radar_type, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.nvolumes); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_nvolumes, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.number); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_number, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyObject_FromString(s.name); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_name, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyObject_FromString(s.radar_name); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_radar_name, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyObject_FromString(s.project); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_project, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyObject_FromString(s.city); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_city, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyObject_FromString(s.state); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_state, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyObject_FromString(s.country); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_country, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.latd); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_latd, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.latm); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_latm, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.lats); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_lats, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.lond); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_lond, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.lonm); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_lonm, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.lons); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_lons, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.height); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_height, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.spulse); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_spulse, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.lpulse); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_lpulse, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.scan_mode); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_scan_mode, member) < 0) goto bad;
                  Py_DECREF(member);
                  member = __Pyx_PyInt_From_int(s.vcp); if (member == NULL) goto bad;
                  if (PyDict_SetItem(res, __pyx_n_s_vcp, member) < 0) goto bad;
                  Py_DECREF(member);
                  return res;
                  bad:
                  Py_XDECREF(member);
                  Py_DECREF(res);
                  return NULL;
                }
                #if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        float denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(a, a);
                    case 3:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, a);
                    case 4:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_absf(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        double denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(a, a);
                    case 3:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, a);
                    case 4:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_abs(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_enum__NPY_TYPES(enum NPY_TYPES value) {
    const enum NPY_TYPES neg_one = (enum NPY_TYPES) -1, const_zero = (enum NPY_TYPES) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(enum NPY_TYPES) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(enum NPY_TYPES) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
        }
    } else {
        if (sizeof(enum NPY_TYPES) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(enum NPY_TYPES) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(enum NPY_TYPES),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_As_unsigned_short(PyObject *x) {
    const unsigned short neg_one = (unsigned short) -1, const_zero = (unsigned short) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(unsigned short) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(unsigned short, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (unsigned short) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (unsigned short) 0;
                case  1: __PYX_VERIFY_RETURN_INT(unsigned short, digit, digits[0])
                case 2:
                    if (8 * sizeof(unsigned short) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) >= 2 * PyLong_SHIFT) {
                            return (unsigned short) (((((unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(unsigned short) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) >= 3 * PyLong_SHIFT) {
                            return (unsigned short) (((((((unsigned short)digits[2]) << PyLong_SHIFT) | (unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(unsigned short) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) >= 4 * PyLong_SHIFT) {
                            return (unsigned short) (((((((((unsigned short)digits[3]) << PyLong_SHIFT) | (unsigned short)digits[2]) << PyLong_SHIFT) | (unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (unsigned short) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(unsigned short) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned short, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(unsigned short) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned short, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (unsigned short) 0;
                case -1: __PYX_VERIFY_RETURN_INT(unsigned short, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(unsigned short,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(unsigned short) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) - 1 > 2 * PyLong_SHIFT) {
                            return (unsigned short) (((unsigned short)-1)*(((((unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(unsigned short) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) - 1 > 2 * PyLong_SHIFT) {
                            return (unsigned short) ((((((unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(unsigned short) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) - 1 > 3 * PyLong_SHIFT) {
                            return (unsigned short) (((unsigned short)-1)*(((((((unsigned short)digits[2]) << PyLong_SHIFT) | (unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(unsigned short) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) - 1 > 3 * PyLong_SHIFT) {
                            return (unsigned short) ((((((((unsigned short)digits[2]) << PyLong_SHIFT) | (unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(unsigned short) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) - 1 > 4 * PyLong_SHIFT) {
                            return (unsigned short) (((unsigned short)-1)*(((((((((unsigned short)digits[3]) << PyLong_SHIFT) | (unsigned short)digits[2]) << PyLong_SHIFT) | (unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(unsigned short) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(unsigned short, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(unsigned short) - 1 > 4 * PyLong_SHIFT) {
                            return (unsigned short) ((((((((((unsigned short)digits[3]) << PyLong_SHIFT) | (unsigned short)digits[2]) << PyLong_SHIFT) | (unsigned short)digits[1]) << PyLong_SHIFT) | (unsigned short)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(unsigned short) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned short, long, PyLong_AsLong(x))
            } else if (sizeof(unsigned short) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(unsigned short, PY_LONG_LONG, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            unsigned short val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (unsigned short) -1;
        }
    } else {
        unsigned short val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned short) -1;
        val = __Pyx_PyInt_As_unsigned_short(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to unsigned short");
    return (unsigned short) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to unsigned short");
    return (unsigned short) -1;
}

static CYTHON_INLINE PyObject* __Pyx_PyInt_From_unsigned_short(unsigned short value) {
    const unsigned short neg_one = (unsigned short) -1, const_zero = (unsigned short) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(unsigned short) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned short) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
        } else if (sizeof(unsigned short) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
        }
    } else {
        if (sizeof(unsigned short) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(unsigned short) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(unsigned short),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) -1, const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_Int(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if (!strict && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    else if ((size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
static CYTHON_INLINE char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if CYTHON_COMPILING_IN_CPYTHON && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
#if PY_VERSION_HEX < 0x03030000
        char* defenc_c;
        PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
        if (!defenc) return NULL;
        defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        {
            char* end = defenc_c + PyBytes_GET_SIZE(defenc);
            char* c;
            for (c = defenc_c; c < end; c++) {
                if ((unsigned char) (*c) >= 128) {
                    PyUnicode_AsASCIIString(o);
                    return NULL;
                }
            }
        }
#endif
        *length = PyBytes_GET_SIZE(defenc);
        return defenc_c;
#else
        if (__Pyx_PyUnicode_READY(o) == -1) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
        if (PyUnicode_IS_ASCII(o)) {
            *length = PyUnicode_GET_LENGTH(o);
            return PyUnicode_AsUTF8(o);
        } else {
            PyUnicode_AsASCIIString(o);
            return NULL;
        }
#else
        return PyUnicode_AsUTF8AndSize(o, length);
#endif
#endif
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return __Pyx_NewRef(x);
  m = Py_TYPE(x)->tp_as_number;
#if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_MAJOR_VERSION < 3
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%.4s__ returned non-%.4s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(x);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
