/* Generated by Cython 0.17.4 on Fri Apr 19 15:20:40 2013 */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02040000
    #error Cython requires Python 2.4+.
#else
#include <stddef.h> /* For offsetof */
#ifndef offsetof
#define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
#define CYTHON_COMPILING_IN_PYPY 1
#define CYTHON_COMPILING_IN_CPYTHON 0
#else
#define CYTHON_COMPILING_IN_PYPY 0
#define CYTHON_COMPILING_IN_CPYTHON 1
#endif
#if PY_VERSION_HEX < 0x02050000
  typedef int Py_ssize_t;
  #define PY_SSIZE_T_MAX INT_MAX
  #define PY_SSIZE_T_MIN INT_MIN
  #define PY_FORMAT_SIZE_T ""
  #define CYTHON_FORMAT_SSIZE_T ""
  #define PyInt_FromSsize_t(z) PyInt_FromLong(z)
  #define PyInt_AsSsize_t(o)   __Pyx_PyInt_AsInt(o)
  #define PyNumber_Index(o)    ((PyNumber_Check(o) && !PyFloat_Check(o)) ? PyNumber_Int(o) : \
                                (PyErr_Format(PyExc_TypeError, \
                                              "expected index value, got %.200s", Py_TYPE(o)->tp_name), \
                                 (PyObject*)0))
  #define __Pyx_PyIndex_Check(o) (PyNumber_Check(o) && !PyFloat_Check(o) && \
                                  !PyComplex_Check(o))
  #define PyIndex_Check __Pyx_PyIndex_Check
  #define PyErr_WarnEx(category, message, stacklevel) PyErr_Warn(category, message)
  #define __PYX_BUILD_PY_SSIZE_T "i"
#else
  #define __PYX_BUILD_PY_SSIZE_T "n"
  #define CYTHON_FORMAT_SSIZE_T "z"
  #define __Pyx_PyIndex_Check PyIndex_Check
#endif
#if PY_VERSION_HEX < 0x02060000
  #define Py_REFCNT(ob) (((PyObject*)(ob))->ob_refcnt)
  #define Py_TYPE(ob)   (((PyObject*)(ob))->ob_type)
  #define Py_SIZE(ob)   (((PyVarObject*)(ob))->ob_size)
  #define PyVarObject_HEAD_INIT(type, size) \
          PyObject_HEAD_INIT(type) size,
  #define PyType_Modified(t)
  typedef struct {
     void *buf;
     PyObject *obj;
     Py_ssize_t len;
     Py_ssize_t itemsize;
     int readonly;
     int ndim;
     char *format;
     Py_ssize_t *shape;
     Py_ssize_t *strides;
     Py_ssize_t *suboffsets;
     void *internal;
  } Py_buffer;
  #define PyBUF_SIMPLE 0
  #define PyBUF_WRITABLE 0x0001
  #define PyBUF_FORMAT 0x0004
  #define PyBUF_ND 0x0008
  #define PyBUF_STRIDES (0x0010 | PyBUF_ND)
  #define PyBUF_C_CONTIGUOUS (0x0020 | PyBUF_STRIDES)
  #define PyBUF_F_CONTIGUOUS (0x0040 | PyBUF_STRIDES)
  #define PyBUF_ANY_CONTIGUOUS (0x0080 | PyBUF_STRIDES)
  #define PyBUF_INDIRECT (0x0100 | PyBUF_STRIDES)
  #define PyBUF_RECORDS (PyBUF_STRIDES | PyBUF_FORMAT | PyBUF_WRITABLE)
  #define PyBUF_FULL (PyBUF_INDIRECT | PyBUF_FORMAT | PyBUF_WRITABLE)
  typedef int (*getbufferproc)(PyObject *, Py_buffer *, int);
  typedef void (*releasebufferproc)(PyObject *, Py_buffer *);
#endif
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos) \
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
#if PY_MAJOR_VERSION < 3 && PY_MINOR_VERSION < 6
  #define PyUnicode_FromString(s) PyUnicode_Decode(s, strlen(s), "UTF-8", "strict")
#endif
#if PY_MAJOR_VERSION >= 3
  #define Py_TPFLAGS_CHECKTYPES 0
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#if (PY_VERSION_HEX < 0x02060000) || (PY_MAJOR_VERSION >= 3)
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ? \
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
#else
  #define CYTHON_PEP393_ENABLED 0
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((k=k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PyBytesObject                PyStringObject
  #define PyBytes_Type                 PyString_Type
  #define PyBytes_Check                PyString_Check
  #define PyBytes_CheckExact           PyString_CheckExact
  #define PyBytes_FromString           PyString_FromString
  #define PyBytes_FromStringAndSize    PyString_FromStringAndSize
  #define PyBytes_FromFormat           PyString_FromFormat
  #define PyBytes_DecodeEscape         PyString_DecodeEscape
  #define PyBytes_AsString             PyString_AsString
  #define PyBytes_AsStringAndSize      PyString_AsStringAndSize
  #define PyBytes_Size                 PyString_Size
  #define PyBytes_AS_STRING            PyString_AS_STRING
  #define PyBytes_GET_SIZE             PyString_GET_SIZE
  #define PyBytes_Repr                 PyString_Repr
  #define PyBytes_Concat               PyString_Concat
  #define PyBytes_ConcatAndDel         PyString_ConcatAndDel
#endif
#if PY_VERSION_HEX < 0x02060000
  #define PySet_Check(obj)             PyObject_TypeCheck(obj, &PySet_Type)
  #define PyFrozenSet_Check(obj)       PyObject_TypeCheck(obj, &PyFrozenSet_Type)
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_VERSION_HEX < 0x03020000
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if (PY_MAJOR_VERSION < 3) || (PY_VERSION_HEX >= 0x03010300)
  #define __Pyx_PySequence_GetSlice(obj, a, b) PySequence_GetSlice(obj, a, b)
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) PySequence_SetSlice(obj, a, b, value)
  #define __Pyx_PySequence_DelSlice(obj, a, b) PySequence_DelSlice(obj, a, b)
#else
  #define __Pyx_PySequence_GetSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), (PyObject*)0) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_GetSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object is unsliceable", (obj)->ob_type->tp_name), (PyObject*)0)))
  #define __Pyx_PySequence_SetSlice(obj, a, b, value) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_SetSlice(obj, a, b, value)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice assignment", (obj)->ob_type->tp_name), -1)))
  #define __Pyx_PySequence_DelSlice(obj, a, b) (unlikely(!(obj)) ? \
        (PyErr_SetString(PyExc_SystemError, "null argument to internal routine"), -1) : \
        (likely((obj)->ob_type->tp_as_mapping) ? (PySequence_DelSlice(obj, a, b)) : \
            (PyErr_Format(PyExc_TypeError, "'%.200s' object doesn't support slice deletion", (obj)->ob_type->tp_name), -1)))
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyMethod_New(func, self, klass) ((self) ? PyMethod_New(func, self) : PyInstanceMethod_New(func))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),((char *)(n)))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),((char *)(n)),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),((char *)(n)))
#else
  #define __Pyx_GetAttrString(o,n)   PyObject_GetAttrString((o),(n))
  #define __Pyx_SetAttrString(o,n,a) PyObject_SetAttrString((o),(n),(a))
  #define __Pyx_DelAttrString(o,n)   PyObject_DelAttrString((o),(n))
#endif
#if PY_VERSION_HEX < 0x02050000
  #define __Pyx_NAMESTR(n) ((char *)(n))
  #define __Pyx_DOCSTR(n)  ((char *)(n))
#else
  #define __Pyx_NAMESTR(n) (n)
  #define __Pyx_DOCSTR(n)  (n)
#endif


#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
#define _USE_MATH_DEFINES
#endif
#include <math.h>
#define __PYX_HAVE__pyart__map__ckdtree
#define __PYX_HAVE_API__pyart__map__ckdtree
#include "stdio.h"
#include "stdlib.h"
#include "numpy/arrayobject.h"
#include "numpy/ufuncobject.h"
#include "limits.h"
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#ifdef PYREX_WITHOUT_ASSERTIONS
#define CYTHON_WITHOUT_ASSERTIONS
#endif


/* inline attribute */
#ifndef CYTHON_INLINE
  #if defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

/* unused attribute */
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif

typedef struct {PyObject **p; char *s; const long n; const char* encoding; const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry; /*proto*/


/* Type Conversion Predeclarations */

#define __Pyx_PyBytes_FromUString(s) PyBytes_FromString((char*)s)
#define __Pyx_PyBytes_AsUString(s)   ((unsigned char*) PyBytes_AsString(s))

#define __Pyx_Owned_Py_None(b) (Py_INCREF(Py_None), Py_None)
#define __Pyx_PyBool_FromLong(b) ((b) ? (Py_INCREF(Py_True), Py_True) : (Py_INCREF(Py_False), Py_False))
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x);

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject*);

#if CYTHON_COMPILING_IN_CPYTHON
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))

#ifdef __GNUC__
  /* Test for GCC > 2.95 */
  #if __GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95))
    #define likely(x)   __builtin_expect(!!(x), 1)
    #define unlikely(x) __builtin_expect(!!(x), 0)
  #else /* __GNUC__ > 2 ... */
    #define likely(x)   (x)
    #define unlikely(x) (x)
  #endif /* __GNUC__ > 2 ... */
#else /* __GNUC__ */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
    
static PyObject *__pyx_m;
static PyObject *__pyx_b;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;

#if !defined(CYTHON_CCOMPLEX)
  #if defined(__cplusplus)
    #define CYTHON_CCOMPLEX 1
  #elif defined(_Complex_I)
    #define CYTHON_CCOMPLEX 1
  #else
    #define CYTHON_CCOMPLEX 0
  #endif
#endif
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #include <complex>
  #else
    #include <complex.h>
  #endif
#endif
#if CYTHON_CCOMPLEX && !defined(__cplusplus) && defined(__sun__) && defined(__GNUC__)
  #undef _Complex_I
  #define _Complex_I 1.0fj
#endif


static const char *__pyx_f[] = {
  "ckdtree.pyx",
  "numpy.pxd",
  "type.pxd",
};
#define IS_UNSIGNED(type) (((type) -1) > 0)
struct __Pyx_StructField_;
#define __PYX_BUF_FLAGS_PACKED_STRUCT (1 << 0)
typedef struct {
  const char* name; /* for error messages only */
  struct __Pyx_StructField_* fields;
  size_t size;     /* sizeof(type) */
  size_t arraysize[8]; /* length of array in each dimension */
  int ndim;
  char typegroup; /* _R_eal, _C_omplex, Signed _I_nt, _U_nsigned int, _S_truct, _P_ointer, _O_bject, c_H_ar */
  char is_unsigned;
  int flags;
} __Pyx_TypeInfo;
typedef struct __Pyx_StructField_ {
  __Pyx_TypeInfo* type;
  const char* name;
  size_t offset;
} __Pyx_StructField;
typedef struct {
  __Pyx_StructField* field;
  size_t parent_offset;
} __Pyx_BufFmt_StackElem;
typedef struct {
  __Pyx_StructField root;
  __Pyx_BufFmt_StackElem* head;
  size_t fmt_offset;
  size_t new_count, enc_count;
  size_t struct_alignment;
  int is_complex;
  char enc_type;
  char new_packmode;
  char enc_packmode;
  char is_valid_array;
} __Pyx_BufFmt_Context;


/* "numpy.pxd":723
 * # in Cython to enable them only on the right systems.
 * 
 * ctypedef npy_int8       int8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 */
typedef npy_int8 __pyx_t_5numpy_int8_t;

/* "numpy.pxd":724
 * 
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t
 */
typedef npy_int16 __pyx_t_5numpy_int16_t;

/* "numpy.pxd":725
 * ctypedef npy_int8       int8_t
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_int64      int64_t
 * #ctypedef npy_int96      int96_t
 */
typedef npy_int32 __pyx_t_5numpy_int32_t;

/* "numpy.pxd":726
 * ctypedef npy_int16      int16_t
 * ctypedef npy_int32      int32_t
 * ctypedef npy_int64      int64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_int96      int96_t
 * #ctypedef npy_int128     int128_t
 */
typedef npy_int64 __pyx_t_5numpy_int64_t;

/* "numpy.pxd":730
 * #ctypedef npy_int128     int128_t
 * 
 * ctypedef npy_uint8      uint8_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 */
typedef npy_uint8 __pyx_t_5numpy_uint8_t;

/* "numpy.pxd":731
 * 
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t
 */
typedef npy_uint16 __pyx_t_5numpy_uint16_t;

/* "numpy.pxd":732
 * ctypedef npy_uint8      uint8_t
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uint64     uint64_t
 * #ctypedef npy_uint96     uint96_t
 */
typedef npy_uint32 __pyx_t_5numpy_uint32_t;

/* "numpy.pxd":733
 * ctypedef npy_uint16     uint16_t
 * ctypedef npy_uint32     uint32_t
 * ctypedef npy_uint64     uint64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_uint96     uint96_t
 * #ctypedef npy_uint128    uint128_t
 */
typedef npy_uint64 __pyx_t_5numpy_uint64_t;

/* "numpy.pxd":737
 * #ctypedef npy_uint128    uint128_t
 * 
 * ctypedef npy_float32    float32_t             # <<<<<<<<<<<<<<
 * ctypedef npy_float64    float64_t
 * #ctypedef npy_float80    float80_t
 */
typedef npy_float32 __pyx_t_5numpy_float32_t;

/* "numpy.pxd":738
 * 
 * ctypedef npy_float32    float32_t
 * ctypedef npy_float64    float64_t             # <<<<<<<<<<<<<<
 * #ctypedef npy_float80    float80_t
 * #ctypedef npy_float128   float128_t
 */
typedef npy_float64 __pyx_t_5numpy_float64_t;

/* "numpy.pxd":747
 * # The int types are mapped a bit surprising --
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t
 */
typedef npy_long __pyx_t_5numpy_int_t;

/* "numpy.pxd":748
 * # numpy.int corresponds to 'l' and numpy.long to 'q'
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longlong   longlong_t
 * 
 */
typedef npy_longlong __pyx_t_5numpy_long_t;

/* "numpy.pxd":749
 * ctypedef npy_long       int_t
 * ctypedef npy_longlong   long_t
 * ctypedef npy_longlong   longlong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_ulong      uint_t
 */
typedef npy_longlong __pyx_t_5numpy_longlong_t;

/* "numpy.pxd":751
 * ctypedef npy_longlong   longlong_t
 * 
 * ctypedef npy_ulong      uint_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t
 */
typedef npy_ulong __pyx_t_5numpy_uint_t;

/* "numpy.pxd":752
 * 
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t             # <<<<<<<<<<<<<<
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 */
typedef npy_ulonglong __pyx_t_5numpy_ulong_t;

/* "numpy.pxd":753
 * ctypedef npy_ulong      uint_t
 * ctypedef npy_ulonglong  ulong_t
 * ctypedef npy_ulonglong  ulonglong_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_intp       intp_t
 */
typedef npy_ulonglong __pyx_t_5numpy_ulonglong_t;

/* "numpy.pxd":755
 * ctypedef npy_ulonglong  ulonglong_t
 * 
 * ctypedef npy_intp       intp_t             # <<<<<<<<<<<<<<
 * ctypedef npy_uintp      uintp_t
 * 
 */
typedef npy_intp __pyx_t_5numpy_intp_t;

/* "numpy.pxd":756
 * 
 * ctypedef npy_intp       intp_t
 * ctypedef npy_uintp      uintp_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_double     float_t
 */
typedef npy_uintp __pyx_t_5numpy_uintp_t;

/* "numpy.pxd":758
 * ctypedef npy_uintp      uintp_t
 * 
 * ctypedef npy_double     float_t             # <<<<<<<<<<<<<<
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t
 */
typedef npy_double __pyx_t_5numpy_float_t;

/* "numpy.pxd":759
 * 
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t             # <<<<<<<<<<<<<<
 * ctypedef npy_longdouble longdouble_t
 * 
 */
typedef npy_double __pyx_t_5numpy_double_t;

/* "numpy.pxd":760
 * ctypedef npy_double     float_t
 * ctypedef npy_double     double_t
 * ctypedef npy_longdouble longdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cfloat      cfloat_t
 */
typedef npy_longdouble __pyx_t_5numpy_longdouble_t;
#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< float > __pyx_t_float_complex;
  #else
    typedef float _Complex __pyx_t_float_complex;
  #endif
#else
    typedef struct { float real, imag; } __pyx_t_float_complex;
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    typedef ::std::complex< double > __pyx_t_double_complex;
  #else
    typedef double _Complex __pyx_t_double_complex;
  #endif
#else
    typedef struct { double real, imag; } __pyx_t_double_complex;
#endif


/*--- Type declarations ---*/
struct __pyx_obj_5pyart_3map_7ckdtree_heap;
struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries;
struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker;
struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle;
struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree;
struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker;

/* "numpy.pxd":762
 * ctypedef npy_longdouble longdouble_t
 * 
 * ctypedef npy_cfloat      cfloat_t             # <<<<<<<<<<<<<<
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t
 */
typedef npy_cfloat __pyx_t_5numpy_cfloat_t;

/* "numpy.pxd":763
 * 
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t             # <<<<<<<<<<<<<<
 * ctypedef npy_clongdouble clongdouble_t
 * 
 */
typedef npy_cdouble __pyx_t_5numpy_cdouble_t;

/* "numpy.pxd":764
 * ctypedef npy_cfloat      cfloat_t
 * ctypedef npy_cdouble     cdouble_t
 * ctypedef npy_clongdouble clongdouble_t             # <<<<<<<<<<<<<<
 * 
 * ctypedef npy_cdouble     complex_t
 */
typedef npy_clongdouble __pyx_t_5numpy_clongdouble_t;

/* "numpy.pxd":766
 * ctypedef npy_clongdouble clongdouble_t
 * 
 * ctypedef npy_cdouble     complex_t             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 */
typedef npy_cdouble __pyx_t_5numpy_complex_t;
union __pyx_t_5pyart_3map_7ckdtree_heapcontents;
struct __pyx_t_5pyart_3map_7ckdtree_heapitem;
struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item;
struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item;
struct __pyx_t_5pyart_3map_7ckdtree_innernode;
struct __pyx_t_5pyart_3map_7ckdtree_leafnode;
struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo;

/* "pyart/map/ckdtree.pyx":124
 * # Priority queue
 * # ==============
 * cdef union heapcontents:    # FIXME: Unions are not always portable, verify this             # <<<<<<<<<<<<<<
 *     np.intp_t intdata     # union is never used in an ABI dependent way.
 *     char* ptrdata
 */
union __pyx_t_5pyart_3map_7ckdtree_heapcontents {
  __pyx_t_5numpy_intp_t intdata;
  char *ptrdata;
};

/* "pyart/map/ckdtree.pyx":128
 *     char* ptrdata
 * 
 * cdef struct heapitem:             # <<<<<<<<<<<<<<
 *     np.float64_t priority
 *     heapcontents contents
 */
struct __pyx_t_5pyart_3map_7ckdtree_heapitem {
  __pyx_t_5numpy_float64_t priority;
  union __pyx_t_5pyart_3map_7ckdtree_heapcontents contents;
};

/* "pyart/map/ckdtree.pyx":447
 * # dist_tracker.pop()
 * 
 * cdef struct RR_stack_item:             # <<<<<<<<<<<<<<
 *     np.intp_t which
 *     np.intp_t split_dim
 */
struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item {
  __pyx_t_5numpy_intp_t which;
  __pyx_t_5numpy_intp_t split_dim;
  double min_along_dim;
  double max_along_dim;
  __pyx_t_5numpy_float64_t min_distance;
  __pyx_t_5numpy_float64_t max_distance;
};

/* "pyart/map/ckdtree.pyx":630
 * # dist_tracker.pop()
 * 
 * cdef struct RP_stack_item:             # <<<<<<<<<<<<<<
 *     np.intp_t split_dim
 *     double min_along_dim, max_along_dim
 */
struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item {
  __pyx_t_5numpy_intp_t split_dim;
  double min_along_dim;
  double max_along_dim;
  __pyx_t_5numpy_float64_t min_distance;
  __pyx_t_5numpy_float64_t max_distance;
};

/* "pyart/map/ckdtree.pyx":766
 * # Tree structure
 * # ==============
 * cdef struct innernode:             # <<<<<<<<<<<<<<
 *     np.intp_t split_dim
 *     np.intp_t children
 */
struct __pyx_t_5pyart_3map_7ckdtree_innernode {
  __pyx_t_5numpy_intp_t split_dim;
  __pyx_t_5numpy_intp_t children;
  __pyx_t_5numpy_float64_t split;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *less;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *greater;
};

/* "pyart/map/ckdtree.pyx":773
 *     innernode* greater
 * 
 * cdef struct leafnode:             # <<<<<<<<<<<<<<
 *     np.intp_t split_dim
 *     np.intp_t children
 */
struct __pyx_t_5pyart_3map_7ckdtree_leafnode {
  __pyx_t_5numpy_intp_t split_dim;
  __pyx_t_5numpy_intp_t children;
  __pyx_t_5numpy_intp_t start_idx;
  __pyx_t_5numpy_intp_t end_idx;
};

/* "pyart/map/ckdtree.pyx":783
 * # malloc sizeof(nodeinfo)+self.m*sizeof(np.float64_t) bytes.
 * 
 * cdef struct nodeinfo:             # <<<<<<<<<<<<<<
 *     innernode* node
 *     np.float64_t side_distances[0]  # FIXME: Only valid in C99, invalid C++ and C89
 */
struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo {
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *node;
  __pyx_t_5numpy_float64_t side_distances[0];
};

/* "pyart/map/ckdtree.pyx":132
 *     heapcontents contents
 * 
 * cdef class heap(object):             # <<<<<<<<<<<<<<
 *     cdef np.intp_t n
 *     cdef heapitem* heap
 */
struct __pyx_obj_5pyart_3map_7ckdtree_heap {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *__pyx_vtab;
  __pyx_t_5numpy_intp_t n;
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem *heap;
  __pyx_t_5numpy_intp_t space;
};


/* "pyart/map/ckdtree.pyx":237
 * 
 * # Utility for building a coo matrix incrementally
 * cdef class coo_entries:             # <<<<<<<<<<<<<<
 *     cdef:
 *         np.intp_t n, n_max
 */
struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_3map_7ckdtree_coo_entries *__pyx_vtab;
  __pyx_t_5numpy_intp_t n;
  __pyx_t_5numpy_intp_t n_max;
  PyArrayObject *i;
  PyArrayObject *j;
  PyArrayObject *v;
  __pyx_t_5numpy_intp_t *i_data;
  __pyx_t_5numpy_intp_t *j_data;
  __pyx_t_5numpy_float64_t *v_data;
};


/* "pyart/map/ckdtree.pyx":635
 *     np.float64_t min_distance, max_distance
 * 
 * cdef class PointRectDistanceTracker(object):             # <<<<<<<<<<<<<<
 *     cdef Rectangle rect
 *     cdef np.float64_t *pt
 */
struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_vtab;
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *rect;
  __pyx_t_5numpy_float64_t *pt;
  __pyx_t_5numpy_float64_t p;
  __pyx_t_5numpy_float64_t epsfac;
  __pyx_t_5numpy_float64_t upper_bound;
  __pyx_t_5numpy_float64_t min_distance;
  __pyx_t_5numpy_float64_t max_distance;
  __pyx_t_5numpy_intp_t stack_size;
  __pyx_t_5numpy_intp_t stack_max_size;
  struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item *stack;
};


/* "pyart/map/ckdtree.pyx":325
 * # ===================
 * 
 * cdef class Rectangle:             # <<<<<<<<<<<<<<
 *     cdef np.intp_t m
 *     cdef np.float64_t *mins
 */
struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle {
  PyObject_HEAD
  __pyx_t_5numpy_intp_t m;
  __pyx_t_5numpy_float64_t *mins;
  __pyx_t_5numpy_float64_t *maxes;
  PyArrayObject *mins_arr;
  PyArrayObject *maxes_arr;
};


/* "pyart/map/ckdtree.pyx":790
 * # Main class
 * # ==========
 * cdef class cKDTree:             # <<<<<<<<<<<<<<
 *     """
 *     cKDTree(data, int leafsize=10)
 */
struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *__pyx_vtab;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *tree;
  PyArrayObject *data;
  __pyx_t_5numpy_float64_t *raw_data;
  __pyx_t_5numpy_intp_t n;
  __pyx_t_5numpy_intp_t m;
  __pyx_t_5numpy_intp_t leafsize;
  PyArrayObject *maxes;
  __pyx_t_5numpy_float64_t *raw_maxes;
  PyArrayObject *mins;
  __pyx_t_5numpy_float64_t *raw_mins;
  PyArrayObject *indices;
  __pyx_t_5numpy_intp_t *raw_indices;
};


/* "pyart/map/ckdtree.pyx":456
 * cdef np.intp_t GREATER = 2
 * 
 * cdef class RectRectDistanceTracker(object):             # <<<<<<<<<<<<<<
 *     cdef Rectangle rect1, rect2
 *     cdef np.float64_t p, epsfac, upper_bound
 */
struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker {
  PyObject_HEAD
  struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_vtab;
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *rect1;
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *rect2;
  __pyx_t_5numpy_float64_t p;
  __pyx_t_5numpy_float64_t epsfac;
  __pyx_t_5numpy_float64_t upper_bound;
  __pyx_t_5numpy_float64_t min_distance;
  __pyx_t_5numpy_float64_t max_distance;
  __pyx_t_5numpy_intp_t stack_size;
  __pyx_t_5numpy_intp_t stack_max_size;
  struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item *stack;
};



struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker {
  int (*_init_stack)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);
  int (*_resize_stack)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t);
  int (*_free_stack)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);
  int (*push)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t);
  int (*push_less_of)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*push_greater_of)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*pop)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_vtabptr_5pyart_3map_7ckdtree_RectRectDistanceTracker;
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);


/* "pyart/map/ckdtree.pyx":635
 *     np.float64_t min_distance, max_distance
 * 
 * cdef class PointRectDistanceTracker(object):             # <<<<<<<<<<<<<<
 *     cdef Rectangle rect
 *     cdef np.float64_t *pt
 */

struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker {
  int (*_init_stack)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *);
  int (*_resize_stack)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, __pyx_t_5numpy_intp_t);
  int (*_free_stack)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *);
  PyObject *(*init)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, __pyx_t_5numpy_float64_t *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t);
  int (*push)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t);
  int (*push_less_of)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*push_greater_of)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*pop)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *);
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_vtabptr_5pyart_3map_7ckdtree_PointRectDistanceTracker;
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_less_of(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_greater_of(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_pop(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *);


/* "pyart/map/ckdtree.pyx":132
 *     heapcontents contents
 * 
 * cdef class heap(object):             # <<<<<<<<<<<<<<
 *     cdef np.intp_t n
 *     cdef heapitem* heap
 */

struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap {
  int (*_resize)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, __pyx_t_5numpy_intp_t);
  int (*push)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, struct __pyx_t_5pyart_3map_7ckdtree_heapitem);
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem (*peek)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *);
  int (*remove)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *);
  int (*pop)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, struct __pyx_t_5pyart_3map_7ckdtree_heapitem *);
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *__pyx_vtabptr_5pyart_3map_7ckdtree_heap;
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_4heap__resize(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, __pyx_t_5numpy_intp_t);
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_4heap_push(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, struct __pyx_t_5pyart_3map_7ckdtree_heapitem);


/* "pyart/map/ckdtree.pyx":237
 * 
 * # Utility for building a coo matrix incrementally
 * cdef class coo_entries:             # <<<<<<<<<<<<<<
 *     cdef:
 *         np.intp_t n, n_max
 */

struct __pyx_vtabstruct_5pyart_3map_7ckdtree_coo_entries {
  void (*add)(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t);
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_coo_entries *__pyx_vtabptr_5pyart_3map_7ckdtree_coo_entries;


/* "pyart/map/ckdtree.pyx":790
 * # Main class
 * # ==========
 * cdef class cKDTree:             # <<<<<<<<<<<<<<
 *     """
 *     cKDTree(data, int leafsize=10)
 */

struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree {
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *(*__pyx___build)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t *);
  PyObject *(*__pyx___free_tree)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*__pyx___query)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_intp_t *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t);
  int (*__pyx___query_ball_point_traverse_no_checking)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*__pyx___query_ball_point_traverse_checking)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *);
  PyObject *(*__pyx___query_ball_point)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t);
  int (*__pyx___query_ball_tree_traverse_no_checking)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*__pyx___query_ball_tree_traverse_checking)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);
  int (*__pyx___query_pairs_traverse_no_checking)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *);
  int (*__pyx___query_pairs_traverse_checking)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);
  int (*__pyx___count_neighbors_traverse)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_intp_t *, __pyx_t_5numpy_intp_t *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);
  int (*__pyx___sparse_distance_matrix_traverse)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *);
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *__pyx_vtabptr_5pyart_3map_7ckdtree_cKDTree;
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname); /*proto*/
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          if (acquire_gil) { \
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure(); \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
              PyGILState_Release(__pyx_gilstate_save); \
          } else { \
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__); \
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil) \
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext() \
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif /* CYTHON_REFNANNY */
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name); /*proto*/

#if PY_VERSION_HEX < 0x02050000
#ifndef PyAnySet_CheckExact
#define PyAnySet_CheckExact(ob) \
    ((ob)->ob_type == &PySet_Type || \
     (ob)->ob_type == &PyFrozenSet_Type)
#define PySet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PySet_Type, (iterable), NULL)
#define Pyx_PyFrozenSet_New(iterable) \
    PyObject_CallFunctionObjArgs((PyObject *)&PyFrozenSet_Type, (iterable), NULL)
#define PySet_Size(anyset) \
    PyObject_Size((anyset))
#define PySet_Contains(anyset, key) \
    PySequence_Contains((anyset), (key))
#define PySet_Pop(set) \
    PyObject_CallMethod(set, (char *)"pop", NULL)
static CYTHON_INLINE int PySet_Clear(PyObject *set) {
    PyObject *ret = PyObject_CallMethod(set, (char *)"clear", NULL);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Discard(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char *)"discard", (char *)"O", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
static CYTHON_INLINE int PySet_Add(PyObject *set, PyObject *key) {
    PyObject *ret = PyObject_CallMethod(set, (char *)"add", (char *)"O", key);
    if (!ret) return -1;
    Py_DECREF(ret); return 0;
}
#endif /* PyAnySet_CheckExact (<= Py2.4) */
#endif /* < Py2.5  */

static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name); /*proto*/

static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[], \
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args, \
    const char* function_name); /*proto*/

static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found); /*proto*/

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb); /*proto*/
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause); /*proto*/

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(PyObject *kwdict, const char* function_name, int kw_allowed); /*proto*/

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type); /*proto*/

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact); /*proto*/

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected);

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index);

static CYTHON_INLINE int __Pyx_IterFinish(void); /*proto*/

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected); /*proto*/

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb); /*proto*/

static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
#define __Pyx_GetItemInt_List(o, i, size, to_py_func) (((size) <= sizeof(Py_ssize_t)) ? \
                                                    __Pyx_GetItemInt_List_Fast(o, i) : \
                                                    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely((0 <= i) & (i < PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    else if ((-PyList_GET_SIZE(o) <= i) & (i < 0)) {
        PyObject *r = PyList_GET_ITEM(o, PyList_GET_SIZE(o) + i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
#define __Pyx_GetItemInt_Tuple(o, i, size, to_py_func) (((size) <= sizeof(Py_ssize_t)) ? \
                                                    __Pyx_GetItemInt_Tuple_Fast(o, i) : \
                                                    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (likely((0 <= i) & (i < PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, i);
        Py_INCREF(r);
        return r;
    }
    else if ((-PyTuple_GET_SIZE(o) <= i) & (i < 0)) {
        PyObject *r = PyTuple_GET_ITEM(o, PyTuple_GET_SIZE(o) + i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
#define __Pyx_GetItemInt(o, i, size, to_py_func) (((size) <= sizeof(Py_ssize_t)) ? \
                                                    __Pyx_GetItemInt_Fast(o, i) : \
                                                    __Pyx_GetItemInt_Generic(o, to_py_func(i)))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i) {
#if CYTHON_COMPILING_IN_CPYTHON
    if (PyList_CheckExact(o)) {
        Py_ssize_t n = (likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if (likely((n >= 0) & (n < PyList_GET_SIZE(o)))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = (likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if (likely((n >= 0) & (n < PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {  /* inlined PySequence_GetItem() */
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (unlikely(l < 0)) return NULL;
                i += l;
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

static CYTHON_INLINE int  __Pyx_GetBufferAndValidate(Py_buffer* buf, PyObject* obj,
    __Pyx_TypeInfo* dtype, int flags, int nd, int cast, __Pyx_BufFmt_StackElem* stack);
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info);

static void __Pyx_RaiseBufferFallbackError(void); /*proto*/

#define __Pyx_BufPtrStrided2d(type, buf, i0, s0, i1, s1) (type)((char*)buf + i0 * s0 + i1 * s1)
static void __Pyx_RaiseBufferIndexError(int axis); /*proto*/

#define __Pyx_BufPtrCContig1d(type, buf, i0, s0) ((type)buf + i0)
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len)) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        Py_SIZE(list) = len+1;
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

#define __Pyx_BufPtrStrided1d(type, buf, i0, s0) (type)((char*)buf + i0 * s0)
static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void);

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_Py_intptr_t(Py_intptr_t);

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb); /*proto*/
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb); /*proto*/

typedef struct {
  Py_ssize_t shape, strides, suboffsets;
} __Pyx_Buf_DimInfo;
typedef struct {
  size_t refcount;
  Py_buffer pybuffer;
} __Pyx_Buffer;
typedef struct {
  __Pyx_Buffer *rcbuffer;
  char *data;
  __Pyx_Buf_DimInfo diminfo[8];
} __Pyx_LocalBuf_ND;

#if PY_MAJOR_VERSION < 3
    static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags);
    static void __Pyx_ReleaseBuffer(Py_buffer *view);
#else
    #define __Pyx_GetBuffer PyObject_GetBuffer
    #define __Pyx_ReleaseBuffer PyBuffer_Release
#endif


static Py_ssize_t __Pyx_zeros[] = {0, 0, 0, 0, 0, 0, 0, 0};
static Py_ssize_t __Pyx_minusones[] = {-1, -1, -1, -1, -1, -1, -1, -1};

static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, long level); /*proto*/

static CYTHON_INLINE Py_intptr_t __Pyx_PyInt_from_py_Py_intptr_t(PyObject *);

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    #define __Pyx_CREAL(z) ((z).real())
    #define __Pyx_CIMAG(z) ((z).imag())
  #else
    #define __Pyx_CREAL(z) (__real__(z))
    #define __Pyx_CIMAG(z) (__imag__(z))
  #endif
#else
    #define __Pyx_CREAL(z) ((z).real)
    #define __Pyx_CIMAG(z) ((z).imag)
#endif
#if defined(_WIN32) && defined(__cplusplus) && CYTHON_CCOMPLEX
    #define __Pyx_SET_CREAL(z,x) ((z).real(x))
    #define __Pyx_SET_CIMAG(z,y) ((z).imag(y))
#else
    #define __Pyx_SET_CREAL(z,x) __Pyx_CREAL(z) = (x)
    #define __Pyx_SET_CIMAG(z,y) __Pyx_CIMAG(z) = (y)
#endif

static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float, float);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eqf(a, b)   ((a)==(b))
    #define __Pyx_c_sumf(a, b)  ((a)+(b))
    #define __Pyx_c_difff(a, b) ((a)-(b))
    #define __Pyx_c_prodf(a, b) ((a)*(b))
    #define __Pyx_c_quotf(a, b) ((a)/(b))
    #define __Pyx_c_negf(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zerof(z) ((z)==(float)0)
    #define __Pyx_c_conjf(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_absf(z)     (::std::abs(z))
        #define __Pyx_c_powf(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zerof(z) ((z)==0)
    #define __Pyx_c_conjf(z)    (conjf(z))
    #if 1
        #define __Pyx_c_absf(z)     (cabsf(z))
        #define __Pyx_c_powf(a, b)  (cpowf(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex, __pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex);
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex);
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex);
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex);
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex, __pyx_t_float_complex);
    #endif
#endif

static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double, double);

#if CYTHON_CCOMPLEX
    #define __Pyx_c_eq(a, b)   ((a)==(b))
    #define __Pyx_c_sum(a, b)  ((a)+(b))
    #define __Pyx_c_diff(a, b) ((a)-(b))
    #define __Pyx_c_prod(a, b) ((a)*(b))
    #define __Pyx_c_quot(a, b) ((a)/(b))
    #define __Pyx_c_neg(a)     (-(a))
  #ifdef __cplusplus
    #define __Pyx_c_is_zero(z) ((z)==(double)0)
    #define __Pyx_c_conj(z)    (::std::conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (::std::abs(z))
        #define __Pyx_c_pow(a, b)  (::std::pow(a, b))
    #endif
  #else
    #define __Pyx_c_is_zero(z) ((z)==0)
    #define __Pyx_c_conj(z)    (conj(z))
    #if 1
        #define __Pyx_c_abs(z)     (cabs(z))
        #define __Pyx_c_pow(a, b)  (cpow(a, b))
    #endif
 #endif
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex, __pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex);
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex);
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex);
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex);
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex, __pyx_t_double_complex);
    #endif
#endif

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject *);

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject *);

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject *);

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject *);

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject *);

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject *);

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject *);

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject *);

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject *);

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject *);

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject *);

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject *);

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject *);

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject *);

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject *);

static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename); /*proto*/

static int __Pyx_check_binary_version(void);

static int __Pyx_SetVtable(PyObject *dict, void *vtable); /*proto*/

#if !defined(__Pyx_PyIdentifier_FromString)
#if PY_MAJOR_VERSION < 3
  #define __Pyx_PyIdentifier_FromString(s) PyString_FromString(s)
#else
  #define __Pyx_PyIdentifier_FromString(s) PyUnicode_FromString(s)
#endif
#endif

static PyObject *__Pyx_ImportModule(const char *name); /*proto*/

static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name, size_t size, int strict);  /*proto*/

typedef struct {
    int code_line;
    PyCodeObject* code_object;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename); /*proto*/

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t); /*proto*/


/* Module declarations from 'cpython.buffer' */

/* Module declarations from 'cpython.ref' */

/* Module declarations from 'libc.stdio' */

/* Module declarations from 'cpython.object' */

/* Module declarations from '__builtin__' */

/* Module declarations from 'cpython.type' */
static PyTypeObject *__pyx_ptype_7cpython_4type_type = 0;

/* Module declarations from 'libc.stdlib' */

/* Module declarations from 'numpy' */

/* Module declarations from 'numpy' */
static PyTypeObject *__pyx_ptype_5numpy_dtype = 0;
static PyTypeObject *__pyx_ptype_5numpy_flatiter = 0;
static PyTypeObject *__pyx_ptype_5numpy_broadcast = 0;
static PyTypeObject *__pyx_ptype_5numpy_ndarray = 0;
static PyTypeObject *__pyx_ptype_5numpy_ufunc = 0;
static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *, char *, char *, int *); /*proto*/

/* Module declarations from 'cython' */

/* Module declarations from 'pyart.map.ckdtree' */
static PyTypeObject *__pyx_ptype_5pyart_3map_7ckdtree_heap = 0;
static PyTypeObject *__pyx_ptype_5pyart_3map_7ckdtree_coo_entries = 0;
static PyTypeObject *__pyx_ptype_5pyart_3map_7ckdtree_Rectangle = 0;
static PyTypeObject *__pyx_ptype_5pyart_3map_7ckdtree_RectRectDistanceTracker = 0;
static PyTypeObject *__pyx_ptype_5pyart_3map_7ckdtree_PointRectDistanceTracker = 0;
static PyTypeObject *__pyx_ptype_5pyart_3map_7ckdtree_cKDTree = 0;
static __pyx_t_5numpy_float64_t __pyx_v_5pyart_3map_7ckdtree_infinity;
static __pyx_t_5numpy_intp_t __pyx_v_5pyart_3map_7ckdtree_LESS;
static __pyx_t_5numpy_intp_t __pyx_v_5pyart_3map_7ckdtree_GREATER;
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_set_add_ordered_pair(PyObject *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t); /*proto*/
static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_list_append(PyObject *, __pyx_t_5numpy_intp_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_dabs(__pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree__distance_p(__pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_point_interval_p(__pyx_t_5numpy_float64_t *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_point_interval_p(__pyx_t_5numpy_float64_t *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_interval_interval_p(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_interval_interval_p(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_point_rect_p_inf(__pyx_t_5numpy_float64_t *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_point_rect_p_inf(__pyx_t_5numpy_float64_t *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_rect_rect_p_inf(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *); /*proto*/
static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_rect_rect_p_inf(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *); /*proto*/
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t = { "float64_t", NULL, sizeof(__pyx_t_5numpy_float64_t), { 0 }, 0, 'R', 0, 0 };
static __Pyx_TypeInfo __Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t = { "intp_t", NULL, sizeof(__pyx_t_5numpy_intp_t), { 0 }, 0, IS_UNSIGNED(__pyx_t_5numpy_intp_t) ? 'U' : 'I', IS_UNSIGNED(__pyx_t_5numpy_intp_t), 0 };
#define __Pyx_MODULE_NAME "pyart.map.ckdtree"
int __pyx_module_is_main_pyart__map__ckdtree = 0;

/* Implementation of 'pyart.map.ckdtree' */
static PyObject *__pyx_builtin_MemoryError;
static PyObject *__pyx_builtin_ValueError;
static PyObject *__pyx_builtin_range;
static PyObject *__pyx_builtin_RuntimeError;
static int __pyx_pf_5pyart_3map_7ckdtree_4heap___init__(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_initial_size); /* proto */
static void __pyx_pf_5pyart_3map_7ckdtree_4heap_2__dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_3map_7ckdtree_11coo_entries___init__(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_11coo_entries_2to_matrix(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *__pyx_v_self, PyObject *__pyx_v_shape); /* proto */
static int __pyx_pf_5pyart_3map_7ckdtree_9Rectangle___init__(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_self, PyObject *__pyx_v_mins_arr, PyObject *__pyx_v_maxes_arr); /* proto */
static int __pyx_pf_5pyart_3map_7ckdtree_23RectRectDistanceTracker___init__(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect1, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect2, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps, __pyx_t_5numpy_float64_t __pyx_v_upper_bound); /* proto */
static void __pyx_pf_5pyart_3map_7ckdtree_23RectRectDistanceTracker_2__dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self); /* proto */
static void __pyx_pf_5pyart_3map_7ckdtree_24PointRectDistanceTracker___dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self); /* proto */
static int __pyx_pf_5pyart_3map_7ckdtree_7cKDTree___init__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_data, __pyx_t_5numpy_intp_t __pyx_v_leafsize); /* proto */
static void __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_2__dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4query(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_x, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_eps, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_distance_upper_bound); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_6query_ball_point(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_x, __pyx_t_5numpy_float64_t __pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_8query_ball_tree(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, __pyx_t_5numpy_float64_t __pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_10query_pairs(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_12count_neighbors(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, PyObject *__pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_14sparse_distance_matrix(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, __pyx_t_5numpy_float64_t __pyx_v_max_distance, __pyx_t_5numpy_float64_t __pyx_v_p); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4data___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_1n___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_1m___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_8leafsize___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_5maxes___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4mins___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self); /* proto */
static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /* proto */
static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info); /* proto */
static char __pyx_k_1[] = "Heap containing %d items cannot be resized to %d";
static char __pyx_k_2[] = "rect1 and rect2 have different dimensions";
static char __pyx_k_4[] = "leafsize must be at least 1";
static char __pyx_k_7[] = "distance_upper_bound";
static char __pyx_k_9[] = "x must consist of vectors of length %d but hasshape %s";
static char __pyx_k_10[] = "Only p-norms with 1<=p<=infinity permitted";
static char __pyx_k_19[] = "Searching for a %d-dimensional point in a %d-dimensional KDTree";
static char __pyx_k_20[] = "Trees passed to query_ball_trees have different dimensionality";
static char __pyx_k_23[] = "r must be either a single value or a one-dimensional array of values";
static char __pyx_k_26[] = "ndarray is not C contiguous";
static char __pyx_k_28[] = "ndarray is not Fortran contiguous";
static char __pyx_k_30[] = "Non-native byte order not supported";
static char __pyx_k_32[] = "unknown dtype code in numpy.pxd (%d)";
static char __pyx_k_33[] = "Format string allocated too short, see comment in numpy.pxd";
static char __pyx_k_36[] = "Format string allocated too short.";
static char __pyx_k_38[] = "\nCopyright (c) 2001, 2002 Enthought, Inc.\nAll rights reserved.\n\nCopyright (c) 2003-2012 SciPy Developers.\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without\nmodification, are permitted provided that the following conditions are met:\n\n  a. Redistributions of source code must retain the above copyright notice,\n     this list of conditions and the following disclaimer.\n  b. Redistributions in binary form must reproduce the above copyright\n     notice, this list of conditions and the following disclaimer in the\n     documentation and/or other materials provided with the distribution.\n  c. Neither the name of Enthought nor the names of the SciPy Developers\n     may be used to endorse or promote products derived from this software\n     without specific prior written permission.\n\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS \"AS IS\"\nAND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE\nIMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE\nARE DISCLAIMED. IN NO EVENT SHALL THE REGENTS OR CONTRIBUTORS BE LIABLE FOR\nANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL\nDAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR\nSERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER\nCAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT\nLIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY\nOUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH\nDAMAGE.\n\n";
static char __pyx_k_39[] = "scipy.sparse";
static char __pyx_k_40[] = "cKDTree.query_ball_point (line 1380)";
static char __pyx_k_41[] = "query_ball_point(self, x, r, p, eps)\n        \n        Find all points within distance r of point(s) x.\n\n        Parameters\n        ----------\n        x : array_like, shape tuple + (self.m,)\n            The point or points to search for neighbors of.\n        r : positive float\n            The radius of points to return.\n        p : float, optional\n            Which Minkowski p-norm to use.  Should be in the range [1, inf].\n        eps : nonnegative float, optional\n            Approximate search. Branches of the tree are not explored if their\n            nearest points are further than ``r / (1 + eps)``, and branches are\n            added in bulk if their furthest points are nearer than\n            ``r * (1 + eps)``.\n\n        Returns\n        -------\n        results : list or array of lists\n            If `x` is a single point, returns a list of the indices of the\n            neighbors of `x`. If `x` is an array of points, returns an object\n            array of shape tuple containing lists of neighbors.\n\n        Notes\n        -----\n        If you have many points whose neighbors you want to find, you may save\n        substantial amounts of time by putting them in a cKDTree and using\n        query_ball_tree.\n\n        Examples\n        --------\n        >>> from scipy import spatial\n        >>> x, y = np.mgrid[0:4, 0:4]\n        >>> points = zip(x.ravel(), y.ravel())\n        >>> tree = spatial.cKDTree(points)\n        >>> tree.query_ball_point([2, 0], 1)\n        [4, 8, 9, 12]\n\n        ";
static char __pyx_k__B[] = "B";
static char __pyx_k__C[] = "C";
static char __pyx_k__H[] = "H";
static char __pyx_k__I[] = "I";
static char __pyx_k__L[] = "L";
static char __pyx_k__O[] = "O";
static char __pyx_k__Q[] = "Q";
static char __pyx_k__b[] = "b";
static char __pyx_k__d[] = "d";
static char __pyx_k__f[] = "f";
static char __pyx_k__g[] = "g";
static char __pyx_k__h[] = "h";
static char __pyx_k__i[] = "i";
static char __pyx_k__k[] = "k";
static char __pyx_k__l[] = "l";
static char __pyx_k__p[] = "p";
static char __pyx_k__q[] = "q";
static char __pyx_k__r[] = "r";
static char __pyx_k__x[] = "x";
static char __pyx_k__Zd[] = "Zd";
static char __pyx_k__Zf[] = "Zf";
static char __pyx_k__Zg[] = "Zg";
static char __pyx_k__np[] = "np";
static char __pyx_k__eps[] = "eps";
static char __pyx_k__inf[] = "inf";
static char __pyx_k__amax[] = "amax";
static char __pyx_k__amin[] = "amin";
static char __pyx_k__axis[] = "axis";
static char __pyx_k__data[] = "data";
static char __pyx_k__fill[] = "fill";
static char __pyx_k__intp[] = "intp";
static char __pyx_k__prod[] = "prod";
static char __pyx_k__array[] = "array";
static char __pyx_k__dtype[] = "dtype";
static char __pyx_k__empty[] = "empty";
static char __pyx_k__numpy[] = "numpy";
static char __pyx_k__order[] = "order";
static char __pyx_k__other[] = "other";
static char __pyx_k__range[] = "range";
static char __pyx_k__rect1[] = "rect1";
static char __pyx_k__rect2[] = "rect2";
static char __pyx_k__scipy[] = "scipy";
static char __pyx_k__shape[] = "shape";
static char __pyx_k__todok[] = "todok";
static char __pyx_k__zeros[] = "zeros";
static char __pyx_k__arange[] = "arange";
static char __pyx_k__astype[] = "astype";
static char __pyx_k__object[] = "object";
static char __pyx_k__resize[] = "resize";
static char __pyx_k__sparse[] = "sparse";
static char __pyx_k____all__[] = "__all__";
static char __pyx_k__asarray[] = "asarray";
static char __pyx_k__cKDTree[] = "cKDTree";
static char __pyx_k__float64[] = "float64";
static char __pyx_k__ndindex[] = "ndindex";
static char __pyx_k__newaxis[] = "newaxis";
static char __pyx_k__reshape[] = "reshape";
static char __pyx_k____main__[] = "__main__";
static char __pyx_k____test__[] = "__test__";
static char __pyx_k__leafsize[] = "leafsize";
static char __pyx_k__mins_arr[] = "mins_arr";
static char __pyx_k__maxes_arr[] = "maxes_arr";
static char __pyx_k__to_matrix[] = "to_matrix";
static char __pyx_k__ValueError[] = "ValueError";
static char __pyx_k__coo_matrix[] = "coo_matrix";
static char __pyx_k__MemoryError[] = "MemoryError";
static char __pyx_k__upper_bound[] = "upper_bound";
static char __pyx_k__RuntimeError[] = "RuntimeError";
static char __pyx_k__initial_size[] = "initial_size";
static char __pyx_k__max_distance[] = "max_distance";
static char __pyx_k__ascontiguousarray[] = "ascontiguousarray";
static PyObject *__pyx_kp_s_1;
static PyObject *__pyx_kp_s_10;
static PyObject *__pyx_kp_s_19;
static PyObject *__pyx_kp_s_2;
static PyObject *__pyx_kp_s_20;
static PyObject *__pyx_kp_s_23;
static PyObject *__pyx_kp_u_26;
static PyObject *__pyx_kp_u_28;
static PyObject *__pyx_kp_u_30;
static PyObject *__pyx_kp_u_32;
static PyObject *__pyx_kp_u_33;
static PyObject *__pyx_kp_u_36;
static PyObject *__pyx_n_s_39;
static PyObject *__pyx_kp_s_4;
static PyObject *__pyx_kp_u_40;
static PyObject *__pyx_kp_u_41;
static PyObject *__pyx_n_s_7;
static PyObject *__pyx_kp_s_9;
static PyObject *__pyx_n_s__C;
static PyObject *__pyx_n_s__MemoryError;
static PyObject *__pyx_n_s__RuntimeError;
static PyObject *__pyx_n_s__ValueError;
static PyObject *__pyx_n_s____all__;
static PyObject *__pyx_n_s____main__;
static PyObject *__pyx_n_s____test__;
static PyObject *__pyx_n_s__amax;
static PyObject *__pyx_n_s__amin;
static PyObject *__pyx_n_s__arange;
static PyObject *__pyx_n_s__array;
static PyObject *__pyx_n_s__asarray;
static PyObject *__pyx_n_s__ascontiguousarray;
static PyObject *__pyx_n_s__astype;
static PyObject *__pyx_n_s__axis;
static PyObject *__pyx_n_s__cKDTree;
static PyObject *__pyx_n_s__coo_matrix;
static PyObject *__pyx_n_s__data;
static PyObject *__pyx_n_s__dtype;
static PyObject *__pyx_n_s__empty;
static PyObject *__pyx_n_s__eps;
static PyObject *__pyx_n_s__fill;
static PyObject *__pyx_n_s__float64;
static PyObject *__pyx_n_s__inf;
static PyObject *__pyx_n_s__initial_size;
static PyObject *__pyx_n_s__intp;
static PyObject *__pyx_n_s__k;
static PyObject *__pyx_n_s__leafsize;
static PyObject *__pyx_n_s__max_distance;
static PyObject *__pyx_n_s__maxes_arr;
static PyObject *__pyx_n_s__mins_arr;
static PyObject *__pyx_n_s__ndindex;
static PyObject *__pyx_n_s__newaxis;
static PyObject *__pyx_n_s__np;
static PyObject *__pyx_n_s__numpy;
static PyObject *__pyx_n_s__object;
static PyObject *__pyx_n_s__order;
static PyObject *__pyx_n_s__other;
static PyObject *__pyx_n_s__p;
static PyObject *__pyx_n_s__prod;
static PyObject *__pyx_n_s__r;
static PyObject *__pyx_n_s__range;
static PyObject *__pyx_n_s__rect1;
static PyObject *__pyx_n_s__rect2;
static PyObject *__pyx_n_s__reshape;
static PyObject *__pyx_n_s__resize;
static PyObject *__pyx_n_s__scipy;
static PyObject *__pyx_n_s__shape;
static PyObject *__pyx_n_s__sparse;
static PyObject *__pyx_n_s__to_matrix;
static PyObject *__pyx_n_s__todok;
static PyObject *__pyx_n_s__upper_bound;
static PyObject *__pyx_n_s__x;
static PyObject *__pyx_n_s__zeros;
static PyObject *__pyx_int_0;
static PyObject *__pyx_int_12;
static PyObject *__pyx_int_15;
static __pyx_t_5numpy_float64_t __pyx_k_8;
static PyObject *__pyx_k_tuple_3;
static PyObject *__pyx_k_tuple_5;
static PyObject *__pyx_k_tuple_6;
static PyObject *__pyx_k_slice_12;
static PyObject *__pyx_k_tuple_11;
static PyObject *__pyx_k_tuple_13;
static PyObject *__pyx_k_tuple_14;
static PyObject *__pyx_k_tuple_15;
static PyObject *__pyx_k_tuple_16;
static PyObject *__pyx_k_tuple_17;
static PyObject *__pyx_k_tuple_18;
static PyObject *__pyx_k_tuple_21;
static PyObject *__pyx_k_tuple_22;
static PyObject *__pyx_k_tuple_24;
static PyObject *__pyx_k_tuple_25;
static PyObject *__pyx_k_tuple_27;
static PyObject *__pyx_k_tuple_29;
static PyObject *__pyx_k_tuple_31;
static PyObject *__pyx_k_tuple_34;
static PyObject *__pyx_k_tuple_35;
static PyObject *__pyx_k_tuple_37;

/* "pyart/map/ckdtree.pyx":77
 * # test is optimized away.
 * 
 * cdef inline int set_add_pair(set results,             # <<<<<<<<<<<<<<
 *                              np.intp_t i,
 *                              np.intp_t j) except -1:
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_set_add_pair(PyObject *__pyx_v_results, __pyx_t_5numpy_intp_t __pyx_v_i, __pyx_t_5numpy_intp_t __pyx_v_j) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_add_pair", 0);

  /* "pyart/map/ckdtree.pyx":81
 *                              np.intp_t j) except -1:
 * 
 *     if sizeof(long) < sizeof(np.intp_t):             # <<<<<<<<<<<<<<
 *         # Win 64
 *         results.add((int(i), int(j)))
 */
  __pyx_t_1 = ((sizeof(long)) < (sizeof(__pyx_t_5numpy_intp_t)));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":83
 *     if sizeof(long) < sizeof(np.intp_t):
 *         # Win 64
 *         results.add((int(i), int(j)))             # <<<<<<<<<<<<<<
 *     else:
 *         # Other platforms
 */
    if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_j); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = PySet_Add(__pyx_v_results, ((PyObject *)__pyx_t_4)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 83; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":86
 *     else:
 *         # Other platforms
 *         results.add((i, j))             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_4 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_j); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_4 = 0;
    __pyx_t_3 = 0;
    __pyx_t_5 = PySet_Add(__pyx_v_results, ((PyObject *)__pyx_t_2)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 86; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":87
 *         # Other platforms
 *         results.add((i, j))
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.map.ckdtree.set_add_pair", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":90
 * 
 * 
 * cdef inline int set_add_ordered_pair(set results,             # <<<<<<<<<<<<<<
 *                                      np.intp_t i,
 *                                      np.intp_t j) except -1:
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_set_add_ordered_pair(PyObject *__pyx_v_results, __pyx_t_5numpy_intp_t __pyx_v_i, __pyx_t_5numpy_intp_t __pyx_v_j) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("set_add_ordered_pair", 0);

  /* "pyart/map/ckdtree.pyx":94
 *                                      np.intp_t j) except -1:
 * 
 *     if sizeof(long) < sizeof(np.intp_t):             # <<<<<<<<<<<<<<
 *         # Win 64
 *         if i < j:
 */
  __pyx_t_1 = ((sizeof(long)) < (sizeof(__pyx_t_5numpy_intp_t)));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":96
 *     if sizeof(long) < sizeof(np.intp_t):
 *         # Win 64
 *         if i < j:             # <<<<<<<<<<<<<<
 *             results.add((int(i), int(j)))
 *         else:
 */
    __pyx_t_1 = (__pyx_v_i < __pyx_v_j);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":97
 *         # Win 64
 *         if i < j:
 *             results.add((int(i), int(j)))             # <<<<<<<<<<<<<<
 *         else:
 *             results.add((int(j), int(i)))
 */
      if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_j); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_2 = 0;
      __pyx_t_3 = 0;
      __pyx_t_5 = PySet_Add(__pyx_v_results, ((PyObject *)__pyx_t_4)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 97; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":99
 *             results.add((int(i), int(j)))
 *         else:
 *             results.add((int(j), int(i)))             # <<<<<<<<<<<<<<
 *     else:
 *         # Other platforms
 */
      if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_4 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_j); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      __pyx_t_4 = 0;
      __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_3 = 0;
      __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_3 = 0;
      __pyx_t_5 = PySet_Add(__pyx_v_results, ((PyObject *)__pyx_t_2)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 99; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":102
 *     else:
 *         # Other platforms
 *         if i < j:             # <<<<<<<<<<<<<<
 *             results.add((i, j))
 *         else:
 */
    __pyx_t_1 = (__pyx_v_i < __pyx_v_j);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":103
 *         # Other platforms
 *         if i < j:
 *             results.add((i, j))             # <<<<<<<<<<<<<<
 *         else:
 *             results.add((j, i))
 */
      if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_j); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_2 = 0;
      __pyx_t_3 = 0;
      __pyx_t_5 = PySet_Add(__pyx_v_results, ((PyObject *)__pyx_t_4)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 103; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":105
 *             results.add((i, j))
 *         else:
 *             results.add((j, i))             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
      if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "add");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_4 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_j); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
      __Pyx_GIVEREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
      __Pyx_GIVEREF(__pyx_t_3);
      __pyx_t_4 = 0;
      __pyx_t_3 = 0;
      __pyx_t_5 = PySet_Add(__pyx_v_results, ((PyObject *)__pyx_t_2)); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    }
    __pyx_L5:;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":106
 *         else:
 *             results.add((j, i))
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * cdef inline int list_append(list results, np.intp_t i) except -1:
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.map.ckdtree.set_add_ordered_pair", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":108
 *     return 0
 * 
 * cdef inline int list_append(list results, np.intp_t i) except -1:             # <<<<<<<<<<<<<<
 *     if sizeof(long) < sizeof(np.intp_t):
 *         # Win 64
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_list_append(PyObject *__pyx_v_results, __pyx_t_5numpy_intp_t __pyx_v_i) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("list_append", 0);

  /* "pyart/map/ckdtree.pyx":109
 * 
 * cdef inline int list_append(list results, np.intp_t i) except -1:
 *     if sizeof(long) < sizeof(np.intp_t):             # <<<<<<<<<<<<<<
 *         # Win 64
 *         if i <= <np.intp_t>LONG_MAX:  # CHECK COMPARISON DIRECTION
 */
  __pyx_t_1 = ((sizeof(long)) < (sizeof(__pyx_t_5numpy_intp_t)));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":111
 *     if sizeof(long) < sizeof(np.intp_t):
 *         # Win 64
 *         if i <= <np.intp_t>LONG_MAX:  # CHECK COMPARISON DIRECTION             # <<<<<<<<<<<<<<
 *             results.append(int(i))
 *         else:
 */
    __pyx_t_1 = (__pyx_v_i <= ((__pyx_t_5numpy_intp_t)LONG_MAX));
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":112
 *         # Win 64
 *         if i <= <np.intp_t>LONG_MAX:  # CHECK COMPARISON DIRECTION
 *             results.append(int(i))             # <<<<<<<<<<<<<<
 *         else:
 *             results.append(i)
 */
      if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
      __pyx_t_4 = PyList_Append(__pyx_v_results, __pyx_t_2); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 112; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      goto __pyx_L4;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":114
 *             results.append(int(i))
 *         else:
 *             results.append(i)             # <<<<<<<<<<<<<<
 *     else:
 *         # Other platforms
 */
      if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyList_Append(__pyx_v_results, __pyx_t_2); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 114; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":117
 *     else:
 *         # Other platforms
 *         results.append(i)             # <<<<<<<<<<<<<<
 *     return 0
 * 
 */
    if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%s'", "append");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_i); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyList_Append(__pyx_v_results, __pyx_t_2); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 117; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":118
 *         # Other platforms
 *         results.append(i)
 *     return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_AddTraceback("pyart.map.ckdtree.list_append", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_5pyart_3map_7ckdtree_4heap_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5pyart_3map_7ckdtree_4heap_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_intp_t __pyx_v_initial_size;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__initial_size,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__initial_size)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_initial_size = __Pyx_PyInt_from_py_Py_intptr_t(values[0]); if (unlikely((__pyx_v_initial_size == (npy_intp)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 137; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.heap.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_4heap___init__(((struct __pyx_obj_5pyart_3map_7ckdtree_heap *)__pyx_v_self), __pyx_v_initial_size);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":137
 *     cdef np.intp_t space
 * 
 *     def __init__(heap self, np.intp_t initial_size):             # <<<<<<<<<<<<<<
 *         cdef void *tmp
 *         self.space = initial_size
 */

static int __pyx_pf_5pyart_3map_7ckdtree_4heap___init__(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_initial_size) {
  void *__pyx_v_tmp;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyart/map/ckdtree.pyx":139
 *     def __init__(heap self, np.intp_t initial_size):
 *         cdef void *tmp
 *         self.space = initial_size             # <<<<<<<<<<<<<<
 *         self.heap = <heapitem*> NULL
 *         tmp = stdlib.malloc(sizeof(heapitem)*self.space)
 */
  __pyx_v_self->space = __pyx_v_initial_size;

  /* "pyart/map/ckdtree.pyx":140
 *         cdef void *tmp
 *         self.space = initial_size
 *         self.heap = <heapitem*> NULL             # <<<<<<<<<<<<<<
 *         tmp = stdlib.malloc(sizeof(heapitem)*self.space)
 *         if tmp == NULL:
 */
  __pyx_v_self->heap = ((struct __pyx_t_5pyart_3map_7ckdtree_heapitem *)NULL);

  /* "pyart/map/ckdtree.pyx":141
 *         self.space = initial_size
 *         self.heap = <heapitem*> NULL
 *         tmp = stdlib.malloc(sizeof(heapitem)*self.space)             # <<<<<<<<<<<<<<
 *         if tmp == NULL:
 *             raise MemoryError
 */
  __pyx_v_tmp = malloc(((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_heapitem)) * __pyx_v_self->space));

  /* "pyart/map/ckdtree.pyx":142
 *         self.heap = <heapitem*> NULL
 *         tmp = stdlib.malloc(sizeof(heapitem)*self.space)
 *         if tmp == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.heap = <heapitem*> tmp
 */
  __pyx_t_1 = (__pyx_v_tmp == NULL);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":143
 *         tmp = stdlib.malloc(sizeof(heapitem)*self.space)
 *         if tmp == NULL:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.heap = <heapitem*> tmp
 *         self.n = 0
 */
    PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":144
 *         if tmp == NULL:
 *             raise MemoryError
 *         self.heap = <heapitem*> tmp             # <<<<<<<<<<<<<<
 *         self.n = 0
 * 
 */
  __pyx_v_self->heap = ((struct __pyx_t_5pyart_3map_7ckdtree_heapitem *)__pyx_v_tmp);

  /* "pyart/map/ckdtree.pyx":145
 *             raise MemoryError
 *         self.heap = <heapitem*> tmp
 *         self.n = 0             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(heap self):
 */
  __pyx_v_self->n = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.heap.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static void __pyx_pw_5pyart_3map_7ckdtree_4heap_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_3map_7ckdtree_4heap_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_3map_7ckdtree_4heap_2__dealloc__(((struct __pyx_obj_5pyart_3map_7ckdtree_heap *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":147
 *         self.n = 0
 * 
 *     def __dealloc__(heap self):             # <<<<<<<<<<<<<<
 *         if self.heap != <heapitem*> NULL:
 *             stdlib.free(self.heap)
 */

static void __pyx_pf_5pyart_3map_7ckdtree_4heap_2__dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/map/ckdtree.pyx":148
 * 
 *     def __dealloc__(heap self):
 *         if self.heap != <heapitem*> NULL:             # <<<<<<<<<<<<<<
 *             stdlib.free(self.heap)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->heap != ((struct __pyx_t_5pyart_3map_7ckdtree_heapitem *)NULL));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":149
 *     def __dealloc__(heap self):
 *         if self.heap != <heapitem*> NULL:
 *             stdlib.free(self.heap)             # <<<<<<<<<<<<<<
 * 
 *     cdef inline int _resize(heap self, np.intp_t new_space) except -1:
 */
    free(__pyx_v_self->heap);
    goto __pyx_L3;
  }
  __pyx_L3:;

  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":151
 *             stdlib.free(self.heap)
 * 
 *     cdef inline int _resize(heap self, np.intp_t new_space) except -1:             # <<<<<<<<<<<<<<
 *         cdef void *tmp
 *         if new_space < self.n:
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_4heap__resize(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_new_space) {
  void *__pyx_v_tmp;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_resize", 0);

  /* "pyart/map/ckdtree.pyx":153
 *     cdef inline int _resize(heap self, np.intp_t new_space) except -1:
 *         cdef void *tmp
 *         if new_space < self.n:             # <<<<<<<<<<<<<<
 *             raise ValueError("Heap containing %d items cannot be resized to %d" % (int(self.n), int(new_space)))
 *         self.space = new_space
 */
  __pyx_t_1 = (__pyx_v_new_space < __pyx_v_self->n);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":154
 *         cdef void *tmp
 *         if new_space < self.n:
 *             raise ValueError("Heap containing %d items cannot be resized to %d" % (int(self.n), int(new_space)))             # <<<<<<<<<<<<<<
 *         self.space = new_space
 *         tmp = stdlib.realloc(<void*>self.heap, new_space*sizeof(heapitem))
 */
    __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_new_space); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_2 = 0;
    __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_1), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_3));
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_3));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_Raise(__pyx_t_3, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":155
 *         if new_space < self.n:
 *             raise ValueError("Heap containing %d items cannot be resized to %d" % (int(self.n), int(new_space)))
 *         self.space = new_space             # <<<<<<<<<<<<<<
 *         tmp = stdlib.realloc(<void*>self.heap, new_space*sizeof(heapitem))
 *         if tmp == NULL:
 */
  __pyx_v_self->space = __pyx_v_new_space;

  /* "pyart/map/ckdtree.pyx":156
 *             raise ValueError("Heap containing %d items cannot be resized to %d" % (int(self.n), int(new_space)))
 *         self.space = new_space
 *         tmp = stdlib.realloc(<void*>self.heap, new_space*sizeof(heapitem))             # <<<<<<<<<<<<<<
 *         if tmp == NULL:
 *             raise MemoryError
 */
  __pyx_v_tmp = realloc(((void *)__pyx_v_self->heap), (__pyx_v_new_space * (sizeof(struct __pyx_t_5pyart_3map_7ckdtree_heapitem))));

  /* "pyart/map/ckdtree.pyx":157
 *         self.space = new_space
 *         tmp = stdlib.realloc(<void*>self.heap, new_space*sizeof(heapitem))
 *         if tmp == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.heap = <heapitem*> tmp
 */
  __pyx_t_1 = (__pyx_v_tmp == NULL);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":158
 *         tmp = stdlib.realloc(<void*>self.heap, new_space*sizeof(heapitem))
 *         if tmp == NULL:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.heap = <heapitem*> tmp
 *         return 0
 */
    PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 158; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "pyart/map/ckdtree.pyx":159
 *         if tmp == NULL:
 *             raise MemoryError
 *         self.heap = <heapitem*> tmp             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  __pyx_v_self->heap = ((struct __pyx_t_5pyart_3map_7ckdtree_heapitem *)__pyx_v_tmp);

  /* "pyart/map/ckdtree.pyx":160
 *             raise MemoryError
 *         self.heap = <heapitem*> tmp
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     @cython.cdivision(True)
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.map.ckdtree.heap._resize", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":163
 * 
 *     @cython.cdivision(True)
 *     cdef inline int push(heap self, heapitem item) except -1:             # <<<<<<<<<<<<<<
 *         cdef np.intp_t i
 *         cdef heapitem t
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_4heap_push(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self, struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_v_item) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_v_t;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push", 0);

  /* "pyart/map/ckdtree.pyx":167
 *         cdef heapitem t
 * 
 *         self.n += 1             # <<<<<<<<<<<<<<
 *         if self.n > self.space:
 *             self._resize(2 * self.space + 1)
 */
  __pyx_v_self->n = (__pyx_v_self->n + 1);

  /* "pyart/map/ckdtree.pyx":168
 * 
 *         self.n += 1
 *         if self.n > self.space:             # <<<<<<<<<<<<<<
 *             self._resize(2 * self.space + 1)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->n > __pyx_v_self->space);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":169
 *         self.n += 1
 *         if self.n > self.space:
 *             self._resize(2 * self.space + 1)             # <<<<<<<<<<<<<<
 * 
 *         i = self.n - 1
 */
    __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_4heap__resize(__pyx_v_self, ((2 * __pyx_v_self->space) + 1)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":171
 *             self._resize(2 * self.space + 1)
 * 
 *         i = self.n - 1             # <<<<<<<<<<<<<<
 *         self.heap[i] = item
 * 
 */
  __pyx_v_i = (__pyx_v_self->n - 1);

  /* "pyart/map/ckdtree.pyx":172
 * 
 *         i = self.n - 1
 *         self.heap[i] = item             # <<<<<<<<<<<<<<
 * 
 *         while i > 0 and self.heap[i].priority < self.heap[(i - 1) // 2].priority:
 */
  (__pyx_v_self->heap[__pyx_v_i]) = __pyx_v_item;

  /* "pyart/map/ckdtree.pyx":174
 *         self.heap[i] = item
 * 
 *         while i > 0 and self.heap[i].priority < self.heap[(i - 1) // 2].priority:             # <<<<<<<<<<<<<<
 *             t = self.heap[(i - 1) // 2]
 *             self.heap[(i - 1) // 2] = self.heap[i]
 */
  while (1) {
    __pyx_t_1 = (__pyx_v_i > 0);
    if (__pyx_t_1) {
      __pyx_t_3 = ((__pyx_v_self->heap[__pyx_v_i]).priority < (__pyx_v_self->heap[((__pyx_v_i - 1) / 2)]).priority);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = __pyx_t_1;
    }
    if (!__pyx_t_4) break;

    /* "pyart/map/ckdtree.pyx":175
 * 
 *         while i > 0 and self.heap[i].priority < self.heap[(i - 1) // 2].priority:
 *             t = self.heap[(i - 1) // 2]             # <<<<<<<<<<<<<<
 *             self.heap[(i - 1) // 2] = self.heap[i]
 *             self.heap[i] = t
 */
    __pyx_v_t = (__pyx_v_self->heap[((__pyx_v_i - 1) / 2)]);

    /* "pyart/map/ckdtree.pyx":176
 *         while i > 0 and self.heap[i].priority < self.heap[(i - 1) // 2].priority:
 *             t = self.heap[(i - 1) // 2]
 *             self.heap[(i - 1) // 2] = self.heap[i]             # <<<<<<<<<<<<<<
 *             self.heap[i] = t
 *             i = (i - 1) // 2
 */
    (__pyx_v_self->heap[((__pyx_v_i - 1) / 2)]) = (__pyx_v_self->heap[__pyx_v_i]);

    /* "pyart/map/ckdtree.pyx":177
 *             t = self.heap[(i - 1) // 2]
 *             self.heap[(i - 1) // 2] = self.heap[i]
 *             self.heap[i] = t             # <<<<<<<<<<<<<<
 *             i = (i - 1) // 2
 *         return 0
 */
    (__pyx_v_self->heap[__pyx_v_i]) = __pyx_v_t;

    /* "pyart/map/ckdtree.pyx":178
 *             self.heap[(i - 1) // 2] = self.heap[i]
 *             self.heap[i] = t
 *             i = (i - 1) // 2             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
    __pyx_v_i = ((__pyx_v_i - 1) / 2);
  }

  /* "pyart/map/ckdtree.pyx":179
 *             self.heap[i] = t
 *             i = (i - 1) // 2
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.heap.push", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":182
 * 
 * 
 *     cdef heapitem peek(heap self):             # <<<<<<<<<<<<<<
 *         return self.heap[0]
 * 
 */

static struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_f_5pyart_3map_7ckdtree_4heap_peek(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self) {
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("peek", 0);

  /* "pyart/map/ckdtree.pyx":183
 * 
 *     cdef heapitem peek(heap self):
 *         return self.heap[0]             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = (__pyx_v_self->heap[0]);
  goto __pyx_L0;

  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":187
 * 
 *     @cython.cdivision(True)
 *     cdef int remove(heap self) except -1:             # <<<<<<<<<<<<<<
 *         cdef heapitem t
 *         cdef np.intp_t i, j, k, l
 */

static int __pyx_f_5pyart_3map_7ckdtree_4heap_remove(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self) {
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_v_t;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  __pyx_t_5numpy_intp_t __pyx_v_k;
  __pyx_t_5numpy_intp_t __pyx_v_l;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  int __pyx_t_4;
  __Pyx_RefNannySetupContext("remove", 0);

  /* "pyart/map/ckdtree.pyx":191
 *         cdef np.intp_t i, j, k, l
 * 
 *         self.heap[0] = self.heap[self.n-1]             # <<<<<<<<<<<<<<
 *         self.n -= 1
 *         # No point in freeing up space as the heap empties.
 */
  (__pyx_v_self->heap[0]) = (__pyx_v_self->heap[(__pyx_v_self->n - 1)]);

  /* "pyart/map/ckdtree.pyx":192
 * 
 *         self.heap[0] = self.heap[self.n-1]
 *         self.n -= 1             # <<<<<<<<<<<<<<
 *         # No point in freeing up space as the heap empties.
 *         # The whole heap gets deallocated at the end of any query below
 */
  __pyx_v_self->n = (__pyx_v_self->n - 1);

  /* "pyart/map/ckdtree.pyx":197
 *         #if self.n < self.space//4 and self.space>40: #FIXME: magic number
 *         #    self._resize(self.space // 2 + 1)
 *         i=0             # <<<<<<<<<<<<<<
 *         j=1
 *         k=2
 */
  __pyx_v_i = 0;

  /* "pyart/map/ckdtree.pyx":198
 *         #    self._resize(self.space // 2 + 1)
 *         i=0
 *         j=1             # <<<<<<<<<<<<<<
 *         k=2
 *         while ((j<self.n and
 */
  __pyx_v_j = 1;

  /* "pyart/map/ckdtree.pyx":199
 *         i=0
 *         j=1
 *         k=2             # <<<<<<<<<<<<<<
 *         while ((j<self.n and
 *                     self.heap[i].priority > self.heap[j].priority or
 */
  __pyx_v_k = 2;

  /* "pyart/map/ckdtree.pyx":200
 *         j=1
 *         k=2
 *         while ((j<self.n and             # <<<<<<<<<<<<<<
 *                     self.heap[i].priority > self.heap[j].priority or
 *                 k<self.n and
 */
  while (1) {

    /* "pyart/map/ckdtree.pyx":201
 *         k=2
 *         while ((j<self.n and
 *                     self.heap[i].priority > self.heap[j].priority or             # <<<<<<<<<<<<<<
 *                 k<self.n and
 *                     self.heap[i].priority > self.heap[k].priority)):
 */
    __pyx_t_1 = (__pyx_v_j < __pyx_v_self->n);
    if (__pyx_t_1) {
      __pyx_t_2 = ((__pyx_v_self->heap[__pyx_v_i]).priority > (__pyx_v_self->heap[__pyx_v_j]).priority);
      __pyx_t_3 = __pyx_t_2;
    } else {
      __pyx_t_3 = __pyx_t_1;
    }
    if (!__pyx_t_3) {

      /* "pyart/map/ckdtree.pyx":202
 *         while ((j<self.n and
 *                     self.heap[i].priority > self.heap[j].priority or
 *                 k<self.n and             # <<<<<<<<<<<<<<
 *                     self.heap[i].priority > self.heap[k].priority)):
 *             if k<self.n and self.heap[j].priority>self.heap[k].priority:
 */
      __pyx_t_1 = (__pyx_v_k < __pyx_v_self->n);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":203
 *                     self.heap[i].priority > self.heap[j].priority or
 *                 k<self.n and
 *                     self.heap[i].priority > self.heap[k].priority)):             # <<<<<<<<<<<<<<
 *             if k<self.n and self.heap[j].priority>self.heap[k].priority:
 *                 l = k
 */
        __pyx_t_2 = ((__pyx_v_self->heap[__pyx_v_i]).priority > (__pyx_v_self->heap[__pyx_v_k]).priority);
        __pyx_t_4 = __pyx_t_2;
      } else {
        __pyx_t_4 = __pyx_t_1;
      }
      __pyx_t_1 = __pyx_t_4;
    } else {
      __pyx_t_1 = __pyx_t_3;
    }
    if (!__pyx_t_1) break;

    /* "pyart/map/ckdtree.pyx":204
 *                 k<self.n and
 *                     self.heap[i].priority > self.heap[k].priority)):
 *             if k<self.n and self.heap[j].priority>self.heap[k].priority:             # <<<<<<<<<<<<<<
 *                 l = k
 *             else:
 */
    __pyx_t_1 = (__pyx_v_k < __pyx_v_self->n);
    if (__pyx_t_1) {
      __pyx_t_3 = ((__pyx_v_self->heap[__pyx_v_j]).priority > (__pyx_v_self->heap[__pyx_v_k]).priority);
      __pyx_t_4 = __pyx_t_3;
    } else {
      __pyx_t_4 = __pyx_t_1;
    }
    if (__pyx_t_4) {

      /* "pyart/map/ckdtree.pyx":205
 *                     self.heap[i].priority > self.heap[k].priority)):
 *             if k<self.n and self.heap[j].priority>self.heap[k].priority:
 *                 l = k             # <<<<<<<<<<<<<<
 *             else:
 *                 l = j
 */
      __pyx_v_l = __pyx_v_k;
      goto __pyx_L5;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":207
 *                 l = k
 *             else:
 *                 l = j             # <<<<<<<<<<<<<<
 *             t = self.heap[l]
 *             self.heap[l] = self.heap[i]
 */
      __pyx_v_l = __pyx_v_j;
    }
    __pyx_L5:;

    /* "pyart/map/ckdtree.pyx":208
 *             else:
 *                 l = j
 *             t = self.heap[l]             # <<<<<<<<<<<<<<
 *             self.heap[l] = self.heap[i]
 *             self.heap[i] = t
 */
    __pyx_v_t = (__pyx_v_self->heap[__pyx_v_l]);

    /* "pyart/map/ckdtree.pyx":209
 *                 l = j
 *             t = self.heap[l]
 *             self.heap[l] = self.heap[i]             # <<<<<<<<<<<<<<
 *             self.heap[i] = t
 *             i = l
 */
    (__pyx_v_self->heap[__pyx_v_l]) = (__pyx_v_self->heap[__pyx_v_i]);

    /* "pyart/map/ckdtree.pyx":210
 *             t = self.heap[l]
 *             self.heap[l] = self.heap[i]
 *             self.heap[i] = t             # <<<<<<<<<<<<<<
 *             i = l
 *             j = 2*i+1
 */
    (__pyx_v_self->heap[__pyx_v_i]) = __pyx_v_t;

    /* "pyart/map/ckdtree.pyx":211
 *             self.heap[l] = self.heap[i]
 *             self.heap[i] = t
 *             i = l             # <<<<<<<<<<<<<<
 *             j = 2*i+1
 *             k = 2*i+2
 */
    __pyx_v_i = __pyx_v_l;

    /* "pyart/map/ckdtree.pyx":212
 *             self.heap[i] = t
 *             i = l
 *             j = 2*i+1             # <<<<<<<<<<<<<<
 *             k = 2*i+2
 *         return 0
 */
    __pyx_v_j = ((2 * __pyx_v_i) + 1);

    /* "pyart/map/ckdtree.pyx":213
 *             i = l
 *             j = 2*i+1
 *             k = 2*i+2             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
    __pyx_v_k = ((2 * __pyx_v_i) + 2);
  }

  /* "pyart/map/ckdtree.pyx":214
 *             j = 2*i+1
 *             k = 2*i+2
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef int pop(heap self, heapitem *it) except -1:
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":216
 *         return 0
 * 
 *     cdef int pop(heap self, heapitem *it) except -1:             # <<<<<<<<<<<<<<
 *         it[0] = self.peek()
 *         self.remove()
 */

static int __pyx_f_5pyart_3map_7ckdtree_4heap_pop(struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_self, struct __pyx_t_5pyart_3map_7ckdtree_heapitem *__pyx_v_it) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pop", 0);

  /* "pyart/map/ckdtree.pyx":217
 * 
 *     cdef int pop(heap self, heapitem *it) except -1:
 *         it[0] = self.peek()             # <<<<<<<<<<<<<<
 *         self.remove()
 *         return 0
 */
  (__pyx_v_it[0]) = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *)__pyx_v_self->__pyx_vtab)->peek(__pyx_v_self);

  /* "pyart/map/ckdtree.pyx":218
 *     cdef int pop(heap self, heapitem *it) except -1:
 *         it[0] = self.peek()
 *         self.remove()             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *)__pyx_v_self->__pyx_vtab)->remove(__pyx_v_self); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 218; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":219
 *         it[0] = self.peek()
 *         self.remove()
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.heap.pop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":224
 * # Utility functions
 * # =================
 * cdef inline np.float64_t dmax(np.float64_t x, np.float64_t y):             # <<<<<<<<<<<<<<
 *     if x>y:
 *         return x
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_t_5numpy_float64_t __pyx_v_x, __pyx_t_5numpy_float64_t __pyx_v_y) {
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("dmax", 0);

  /* "pyart/map/ckdtree.pyx":225
 * # =================
 * cdef inline np.float64_t dmax(np.float64_t x, np.float64_t y):
 *     if x>y:             # <<<<<<<<<<<<<<
 *         return x
 *     else:
 */
  __pyx_t_1 = (__pyx_v_x > __pyx_v_y);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":226
 * cdef inline np.float64_t dmax(np.float64_t x, np.float64_t y):
 *     if x>y:
 *         return x             # <<<<<<<<<<<<<<
 *     else:
 *         return y
 */
    __pyx_r = __pyx_v_x;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":228
 *         return x
 *     else:
 *         return y             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t dabs(np.float64_t x):
 */
    __pyx_r = __pyx_v_y;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":230
 *         return y
 * 
 * cdef inline np.float64_t dabs(np.float64_t x):             # <<<<<<<<<<<<<<
 *     if x>0:
 *         return x
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_dabs(__pyx_t_5numpy_float64_t __pyx_v_x) {
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("dabs", 0);

  /* "pyart/map/ckdtree.pyx":231
 * 
 * cdef inline np.float64_t dabs(np.float64_t x):
 *     if x>0:             # <<<<<<<<<<<<<<
 *         return x
 *     else:
 */
  __pyx_t_1 = (__pyx_v_x > 0.0);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":232
 * cdef inline np.float64_t dabs(np.float64_t x):
 *     if x>0:
 *         return x             # <<<<<<<<<<<<<<
 *     else:
 *         return -x
 */
    __pyx_r = __pyx_v_x;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":234
 *         return x
 *     else:
 *         return -x             # <<<<<<<<<<<<<<
 * 
 * # Utility for building a coo matrix incrementally
 */
    __pyx_r = (-__pyx_v_x);
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_5pyart_3map_7ckdtree_11coo_entries_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5pyart_3map_7ckdtree_11coo_entries_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  if (unlikely(PyTuple_GET_SIZE(__pyx_args) > 0)) {
    __Pyx_RaiseArgtupleInvalid("__init__", 1, 0, 0, PyTuple_GET_SIZE(__pyx_args)); return -1;}
  if (unlikely(__pyx_kwds) && unlikely(PyDict_Size(__pyx_kwds) > 0) && unlikely(!__Pyx_CheckKeywordStrings(__pyx_kwds, "__init__", 0))) return -1;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_11coo_entries___init__(((struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":245
 *         np.float64_t *v_data
 * 
 *     def __init__(self):             # <<<<<<<<<<<<<<
 *         self.n = 0
 *         self.n_max = 10
 */

static int __pyx_pf_5pyart_3map_7ckdtree_11coo_entries___init__(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyart/map/ckdtree.pyx":246
 * 
 *     def __init__(self):
 *         self.n = 0             # <<<<<<<<<<<<<<
 *         self.n_max = 10
 *         self.i = np.empty(self.n_max, dtype=np.intp)
 */
  __pyx_v_self->n = 0;

  /* "pyart/map/ckdtree.pyx":247
 *     def __init__(self):
 *         self.n = 0
 *         self.n_max = 10             # <<<<<<<<<<<<<<
 *         self.i = np.empty(self.n_max, dtype=np.intp)
 *         self.j = np.empty(self.n_max, dtype=np.intp)
 */
  __pyx_v_self->n_max = 10;

  /* "pyart/map/ckdtree.pyx":248
 *         self.n = 0
 *         self.n_max = 10
 *         self.i = np.empty(self.n_max, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         self.j = np.empty(self.n_max, dtype=np.intp)
 *         self.v = np.empty(self.n_max, dtype=np.float64)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n_max); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__intp); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->i);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->i));
  __pyx_v_self->i = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":249
 *         self.n_max = 10
 *         self.i = np.empty(self.n_max, dtype=np.intp)
 *         self.j = np.empty(self.n_max, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         self.v = np.empty(self.n_max, dtype=np.float64)
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__empty); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n_max); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_5 = 0;
  __pyx_t_5 = PyDict_New(); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__intp); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_5, ((PyObject *)__pyx_n_s__dtype), __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->j);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->j));
  __pyx_v_self->j = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyart/map/ckdtree.pyx":250
 *         self.i = np.empty(self.n_max, dtype=np.intp)
 *         self.j = np.empty(self.n_max, dtype=np.intp)
 *         self.v = np.empty(self.n_max, dtype=np.float64)             # <<<<<<<<<<<<<<
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 */
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__empty); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n_max); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_4));
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__float64); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->v);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->v));
  __pyx_v_self->v = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":251
 *         self.j = np.empty(self.n_max, dtype=np.intp)
 *         self.v = np.empty(self.n_max, dtype=np.float64)
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)             # <<<<<<<<<<<<<<
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_self->i);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_self->i_data = ((__pyx_t_5numpy_intp_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_2)));
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":252
 *         self.v = np.empty(self.n_max, dtype=np.float64)
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)             # <<<<<<<<<<<<<<
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 * 
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_self->j);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_self->j_data = ((__pyx_t_5numpy_intp_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_2)));
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":253
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)             # <<<<<<<<<<<<<<
 * 
 *     cdef void add(coo_entries self, np.intp_t i, np.intp_t j, np.float64_t v):
 */
  __pyx_t_2 = ((PyObject *)__pyx_v_self->v);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v_self->v_data = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_2)));
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyart.map.ckdtree.coo_entries.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":255
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 * 
 *     cdef void add(coo_entries self, np.intp_t i, np.intp_t j, np.float64_t v):             # <<<<<<<<<<<<<<
 *         cdef np.intp_t k
 *         if self.n == self.n_max:
 */

static void __pyx_f_5pyart_3map_7ckdtree_11coo_entries_add(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_i, __pyx_t_5numpy_intp_t __pyx_v_j, __pyx_t_5numpy_float64_t __pyx_v_v) {
  __pyx_t_5numpy_intp_t __pyx_v_k;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  __pyx_t_5numpy_intp_t __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("add", 0);

  /* "pyart/map/ckdtree.pyx":257
 *     cdef void add(coo_entries self, np.intp_t i, np.intp_t j, np.float64_t v):
 *         cdef np.intp_t k
 *         if self.n == self.n_max:             # <<<<<<<<<<<<<<
 *             self.n_max *= 2
 *             self.i.resize(self.n_max)
 */
  __pyx_t_1 = (__pyx_v_self->n == __pyx_v_self->n_max);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":258
 *         cdef np.intp_t k
 *         if self.n == self.n_max:
 *             self.n_max *= 2             # <<<<<<<<<<<<<<
 *             self.i.resize(self.n_max)
 *             self.j.resize(self.n_max)
 */
    __pyx_v_self->n_max = (__pyx_v_self->n_max * 2);

    /* "pyart/map/ckdtree.pyx":259
 *         if self.n == self.n_max:
 *             self.n_max *= 2
 *             self.i.resize(self.n_max)             # <<<<<<<<<<<<<<
 *             self.j.resize(self.n_max)
 *             self.v.resize(self.n_max)
 */
    __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_self->i), __pyx_n_s__resize); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n_max); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

    /* "pyart/map/ckdtree.pyx":260
 *             self.n_max *= 2
 *             self.i.resize(self.n_max)
 *             self.j.resize(self.n_max)             # <<<<<<<<<<<<<<
 *             self.v.resize(self.n_max)
 *             self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 */
    __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_self->j), __pyx_n_s__resize); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n_max); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
    __Pyx_GIVEREF(__pyx_t_4);
    __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/map/ckdtree.pyx":261
 *             self.i.resize(self.n_max)
 *             self.j.resize(self.n_max)
 *             self.v.resize(self.n_max)             # <<<<<<<<<<<<<<
 *             self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *             self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 */
    __pyx_t_4 = PyObject_GetAttr(((PyObject *)__pyx_v_self->v), __pyx_n_s__resize); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n_max); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyart/map/ckdtree.pyx":262
 *             self.j.resize(self.n_max)
 *             self.v.resize(self.n_max)
 *             self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)             # <<<<<<<<<<<<<<
 *             self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *             self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->i);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_self->i_data = ((__pyx_t_5numpy_intp_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_2)));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyart/map/ckdtree.pyx":263
 *             self.v.resize(self.n_max)
 *             self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *             self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)             # <<<<<<<<<<<<<<
 *             self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 *         k = self.n
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->j);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_self->j_data = ((__pyx_t_5numpy_intp_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_2)));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyart/map/ckdtree.pyx":264
 *             self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *             self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *             self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)             # <<<<<<<<<<<<<<
 *         k = self.n
 *         self.i_data[k] = i
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->v);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_self->v_data = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_2)));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":265
 *             self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *             self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 *         k = self.n             # <<<<<<<<<<<<<<
 *         self.i_data[k] = i
 *         self.j_data[k] = j
 */
  __pyx_t_5 = __pyx_v_self->n;
  __pyx_v_k = __pyx_t_5;

  /* "pyart/map/ckdtree.pyx":266
 *             self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 *         k = self.n
 *         self.i_data[k] = i             # <<<<<<<<<<<<<<
 *         self.j_data[k] = j
 *         self.v_data[k] = v
 */
  (__pyx_v_self->i_data[__pyx_v_k]) = __pyx_v_i;

  /* "pyart/map/ckdtree.pyx":267
 *         k = self.n
 *         self.i_data[k] = i
 *         self.j_data[k] = j             # <<<<<<<<<<<<<<
 *         self.v_data[k] = v
 *         self.n += 1
 */
  (__pyx_v_self->j_data[__pyx_v_k]) = __pyx_v_j;

  /* "pyart/map/ckdtree.pyx":268
 *         self.i_data[k] = i
 *         self.j_data[k] = j
 *         self.v_data[k] = v             # <<<<<<<<<<<<<<
 *         self.n += 1
 * 
 */
  (__pyx_v_self->v_data[__pyx_v_k]) = __pyx_v_v;

  /* "pyart/map/ckdtree.pyx":269
 *         self.j_data[k] = j
 *         self.v_data[k] = v
 *         self.n += 1             # <<<<<<<<<<<<<<
 * 
 *     def to_matrix(coo_entries self, shape=None):
 */
  __pyx_v_self->n = (__pyx_v_self->n + 1);

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("pyart.map.ckdtree.coo_entries.add", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_11coo_entries_3to_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_11coo_entries_3to_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_shape = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("to_matrix (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__shape,0};
    PyObject* values[1] = {0};

    /* "pyart/map/ckdtree.pyx":271
 *         self.n += 1
 * 
 *     def to_matrix(coo_entries self, shape=None):             # <<<<<<<<<<<<<<
 *         # Shrink arrays to size
 *         self.i.resize(self.n)
 */
    values[0] = ((PyObject *)Py_None);
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__shape);
          if (value) { values[0] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "to_matrix") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_shape = values[0];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("to_matrix", 0, 0, 1, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 271; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.coo_entries.to_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_11coo_entries_2to_matrix(((struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *)__pyx_v_self), __pyx_v_shape);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_11coo_entries_2to_matrix(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *__pyx_v_self, PyObject *__pyx_v_shape) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  __pyx_t_5numpy_intp_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("to_matrix", 0);

  /* "pyart/map/ckdtree.pyx":273
 *     def to_matrix(coo_entries self, shape=None):
 *         # Shrink arrays to size
 *         self.i.resize(self.n)             # <<<<<<<<<<<<<<
 *         self.j.resize(self.n)
 *         self.v.resize(self.n)
 */
  __pyx_t_1 = PyObject_GetAttr(((PyObject *)__pyx_v_self->i), __pyx_n_s__resize); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 273; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":274
 *         # Shrink arrays to size
 *         self.i.resize(self.n)
 *         self.j.resize(self.n)             # <<<<<<<<<<<<<<
 *         self.v.resize(self.n)
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 */
  __pyx_t_2 = PyObject_GetAttr(((PyObject *)__pyx_v_self->j), __pyx_n_s__resize); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 274; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pyart/map/ckdtree.pyx":275
 *         self.i.resize(self.n)
 *         self.j.resize(self.n)
 *         self.v.resize(self.n)             # <<<<<<<<<<<<<<
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 */
  __pyx_t_3 = PyObject_GetAttr(((PyObject *)__pyx_v_self->v), __pyx_n_s__resize); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":276
 *         self.j.resize(self.n)
 *         self.v.resize(self.n)
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)             # <<<<<<<<<<<<<<
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->i);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_self->i_data = ((__pyx_t_5numpy_intp_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_1)));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":277
 *         self.v.resize(self.n)
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)             # <<<<<<<<<<<<<<
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 *         self.n_max = self.n
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->j);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_self->j_data = ((__pyx_t_5numpy_intp_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_1)));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":278
 *         self.i_data = <np.intp_t *>np.PyArray_DATA(self.i)
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)             # <<<<<<<<<<<<<<
 *         self.n_max = self.n
 *         return scipy.sparse.coo_matrix((self.v, (self.i, self.j)),
 */
  __pyx_t_1 = ((PyObject *)__pyx_v_self->v);
  __Pyx_INCREF(__pyx_t_1);
  __pyx_v_self->v_data = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_1)));
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":279
 *         self.j_data = <np.intp_t *>np.PyArray_DATA(self.j)
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 *         self.n_max = self.n             # <<<<<<<<<<<<<<
 *         return scipy.sparse.coo_matrix((self.v, (self.i, self.j)),
 *                                        shape=shape)
 */
  __pyx_t_4 = __pyx_v_self->n;
  __pyx_v_self->n_max = __pyx_t_4;

  /* "pyart/map/ckdtree.pyx":280
 *         self.v_data = <np.float64_t*>np.PyArray_DATA(self.v)
 *         self.n_max = self.n
 *         return scipy.sparse.coo_matrix((self.v, (self.i, self.j)),             # <<<<<<<<<<<<<<
 *                                        shape=shape)
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__scipy); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__sparse); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__coo_matrix); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->i));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self->i));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->i));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->j));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self->j));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->j));
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->v));
  PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_v_self->v));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->v));
  PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_t_3 = 0;
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));

  /* "pyart/map/ckdtree.pyx":281
 *         self.n_max = self.n
 *         return scipy.sparse.coo_matrix((self.v, (self.i, self.j)),
 *                                        shape=shape)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__shape), __pyx_v_shape) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyart.map.ckdtree.coo_entries.to_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":286
 * # Measuring distances
 * # ===================
 * cdef inline np.float64_t _distance_p(np.float64_t *x, np.float64_t *y,             # <<<<<<<<<<<<<<
 *                                      np.float64_t p, np.intp_t k,
 *                                      np.float64_t upperbound):
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree__distance_p(__pyx_t_5numpy_float64_t *__pyx_v_x, __pyx_t_5numpy_float64_t *__pyx_v_y, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_upperbound) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_v_r;
  __pyx_t_5numpy_float64_t __pyx_v_z;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  __Pyx_RefNannySetupContext("_distance_p", 0);

  /* "pyart/map/ckdtree.pyx":297
 *     cdef np.intp_t i
 *     cdef np.float64_t r, z
 *     r = 0             # <<<<<<<<<<<<<<
 *     if p==2:
 *         for i in range(k):
 */
  __pyx_v_r = 0.0;

  /* "pyart/map/ckdtree.pyx":298
 *     cdef np.float64_t r, z
 *     r = 0
 *     if p==2:             # <<<<<<<<<<<<<<
 *         for i in range(k):
 *             z = x[i] - y[i]
 */
  __pyx_t_1 = (__pyx_v_p == 2.0);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":299
 *     r = 0
 *     if p==2:
 *         for i in range(k):             # <<<<<<<<<<<<<<
 *             z = x[i] - y[i]
 *             r += z*z
 */
    __pyx_t_2 = __pyx_v_k;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "pyart/map/ckdtree.pyx":300
 *     if p==2:
 *         for i in range(k):
 *             z = x[i] - y[i]             # <<<<<<<<<<<<<<
 *             r += z*z
 *             if r>upperbound:
 */
      __pyx_v_z = ((__pyx_v_x[__pyx_v_i]) - (__pyx_v_y[__pyx_v_i]));

      /* "pyart/map/ckdtree.pyx":301
 *         for i in range(k):
 *             z = x[i] - y[i]
 *             r += z*z             # <<<<<<<<<<<<<<
 *             if r>upperbound:
 *                 return r
 */
      __pyx_v_r = (__pyx_v_r + (__pyx_v_z * __pyx_v_z));

      /* "pyart/map/ckdtree.pyx":302
 *             z = x[i] - y[i]
 *             r += z*z
 *             if r>upperbound:             # <<<<<<<<<<<<<<
 *                 return r
 *     elif p==infinity:
 */
      __pyx_t_1 = (__pyx_v_r > __pyx_v_upperbound);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":303
 *             r += z*z
 *             if r>upperbound:
 *                 return r             # <<<<<<<<<<<<<<
 *     elif p==infinity:
 *         for i in range(k):
 */
        __pyx_r = __pyx_v_r;
        goto __pyx_L0;
        goto __pyx_L6;
      }
      __pyx_L6:;
    }
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":304
 *             if r>upperbound:
 *                 return r
 *     elif p==infinity:             # <<<<<<<<<<<<<<
 *         for i in range(k):
 *             r = dmax(r,dabs(x[i]-y[i]))
 */
  __pyx_t_1 = (__pyx_v_p == __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":305
 *                 return r
 *     elif p==infinity:
 *         for i in range(k):             # <<<<<<<<<<<<<<
 *             r = dmax(r,dabs(x[i]-y[i]))
 *             if r>upperbound:
 */
    __pyx_t_2 = __pyx_v_k;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "pyart/map/ckdtree.pyx":306
 *     elif p==infinity:
 *         for i in range(k):
 *             r = dmax(r,dabs(x[i]-y[i]))             # <<<<<<<<<<<<<<
 *             if r>upperbound:
 *                 return r
 */
      __pyx_v_r = __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_v_r, __pyx_f_5pyart_3map_7ckdtree_dabs(((__pyx_v_x[__pyx_v_i]) - (__pyx_v_y[__pyx_v_i]))));

      /* "pyart/map/ckdtree.pyx":307
 *         for i in range(k):
 *             r = dmax(r,dabs(x[i]-y[i]))
 *             if r>upperbound:             # <<<<<<<<<<<<<<
 *                 return r
 *     elif p==1:
 */
      __pyx_t_1 = (__pyx_v_r > __pyx_v_upperbound);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":308
 *             r = dmax(r,dabs(x[i]-y[i]))
 *             if r>upperbound:
 *                 return r             # <<<<<<<<<<<<<<
 *     elif p==1:
 *         for i in range(k):
 */
        __pyx_r = __pyx_v_r;
        goto __pyx_L0;
        goto __pyx_L9;
      }
      __pyx_L9:;
    }
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":309
 *             if r>upperbound:
 *                 return r
 *     elif p==1:             # <<<<<<<<<<<<<<
 *         for i in range(k):
 *             r += dabs(x[i]-y[i])
 */
  __pyx_t_1 = (__pyx_v_p == 1.0);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":310
 *                 return r
 *     elif p==1:
 *         for i in range(k):             # <<<<<<<<<<<<<<
 *             r += dabs(x[i]-y[i])
 *             if r>upperbound:
 */
    __pyx_t_2 = __pyx_v_k;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "pyart/map/ckdtree.pyx":311
 *     elif p==1:
 *         for i in range(k):
 *             r += dabs(x[i]-y[i])             # <<<<<<<<<<<<<<
 *             if r>upperbound:
 *                 return r
 */
      __pyx_v_r = (__pyx_v_r + __pyx_f_5pyart_3map_7ckdtree_dabs(((__pyx_v_x[__pyx_v_i]) - (__pyx_v_y[__pyx_v_i]))));

      /* "pyart/map/ckdtree.pyx":312
 *         for i in range(k):
 *             r += dabs(x[i]-y[i])
 *             if r>upperbound:             # <<<<<<<<<<<<<<
 *                 return r
 *     else:
 */
      __pyx_t_1 = (__pyx_v_r > __pyx_v_upperbound);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":313
 *             r += dabs(x[i]-y[i])
 *             if r>upperbound:
 *                 return r             # <<<<<<<<<<<<<<
 *     else:
 *         for i in range(k):
 */
        __pyx_r = __pyx_v_r;
        goto __pyx_L0;
        goto __pyx_L12;
      }
      __pyx_L12:;
    }
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":315
 *                 return r
 *     else:
 *         for i in range(k):             # <<<<<<<<<<<<<<
 *             r += dabs(x[i]-y[i])**p
 *             if r>upperbound:
 */
    __pyx_t_2 = __pyx_v_k;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "pyart/map/ckdtree.pyx":316
 *     else:
 *         for i in range(k):
 *             r += dabs(x[i]-y[i])**p             # <<<<<<<<<<<<<<
 *             if r>upperbound:
 *                 return r
 */
      __pyx_v_r = (__pyx_v_r + pow(__pyx_f_5pyart_3map_7ckdtree_dabs(((__pyx_v_x[__pyx_v_i]) - (__pyx_v_y[__pyx_v_i]))), __pyx_v_p));

      /* "pyart/map/ckdtree.pyx":317
 *         for i in range(k):
 *             r += dabs(x[i]-y[i])**p
 *             if r>upperbound:             # <<<<<<<<<<<<<<
 *                 return r
 *     return r
 */
      __pyx_t_1 = (__pyx_v_r > __pyx_v_upperbound);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":318
 *             r += dabs(x[i]-y[i])**p
 *             if r>upperbound:
 *                 return r             # <<<<<<<<<<<<<<
 *     return r
 * 
 */
        __pyx_r = __pyx_v_r;
        goto __pyx_L0;
        goto __pyx_L15;
      }
      __pyx_L15:;
    }
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":319
 *             if r>upperbound:
 *                 return r
 *     return r             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_r;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_5pyart_3map_7ckdtree_9Rectangle_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5pyart_3map_7ckdtree_9Rectangle_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_mins_arr = 0;
  PyObject *__pyx_v_maxes_arr = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__mins_arr,&__pyx_n_s__maxes_arr,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__mins_arr)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__maxes_arr)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 2) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    }
    __pyx_v_mins_arr = values[0];
    __pyx_v_maxes_arr = values[1];
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 2, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 331; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.Rectangle.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_9Rectangle___init__(((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_v_self), __pyx_v_mins_arr, __pyx_v_maxes_arr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":331
 *     cdef np.ndarray mins_arr, maxes_arr
 * 
 *     def __init__(self, mins_arr, maxes_arr):             # <<<<<<<<<<<<<<
 *         # Copy array data
 *         self.mins_arr = np.array(mins_arr, dtype=np.float64, order='C')
 */

static int __pyx_pf_5pyart_3map_7ckdtree_9Rectangle___init__(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_self, PyObject *__pyx_v_mins_arr, PyObject *__pyx_v_maxes_arr) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyart/map/ckdtree.pyx":333
 *     def __init__(self, mins_arr, maxes_arr):
 *         # Copy array data
 *         self.mins_arr = np.array(mins_arr, dtype=np.float64, order='C')             # <<<<<<<<<<<<<<
 *         self.maxes_arr = np.array(maxes_arr, dtype=np.float64, order='C')
 *         self.mins = <np.float64_t*>np.PyArray_DATA(self.mins_arr)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__array); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_mins_arr);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_mins_arr);
  __Pyx_GIVEREF(__pyx_v_mins_arr);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__float64); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__dtype), __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__order), ((PyObject *)__pyx_n_s__C)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 333; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->mins_arr);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->mins_arr));
  __pyx_v_self->mins_arr = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":334
 *         # Copy array data
 *         self.mins_arr = np.array(mins_arr, dtype=np.float64, order='C')
 *         self.maxes_arr = np.array(maxes_arr, dtype=np.float64, order='C')             # <<<<<<<<<<<<<<
 *         self.mins = <np.float64_t*>np.PyArray_DATA(self.mins_arr)
 *         self.maxes = <np.float64_t*>np.PyArray_DATA(self.maxes_arr)
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__array); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(__pyx_v_maxes_arr);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_v_maxes_arr);
  __Pyx_GIVEREF(__pyx_v_maxes_arr);
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__float64); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_4) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__order), ((PyObject *)__pyx_n_s__C)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_4) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_4, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 334; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_4);
  __Pyx_GOTREF(__pyx_v_self->maxes_arr);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->maxes_arr));
  __pyx_v_self->maxes_arr = ((PyArrayObject *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyart/map/ckdtree.pyx":335
 *         self.mins_arr = np.array(mins_arr, dtype=np.float64, order='C')
 *         self.maxes_arr = np.array(maxes_arr, dtype=np.float64, order='C')
 *         self.mins = <np.float64_t*>np.PyArray_DATA(self.mins_arr)             # <<<<<<<<<<<<<<
 *         self.maxes = <np.float64_t*>np.PyArray_DATA(self.maxes_arr)
 *         self.m = self.mins_arr.shape[0]
 */
  __pyx_t_4 = ((PyObject *)__pyx_v_self->mins_arr);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_self->mins = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_4)));
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyart/map/ckdtree.pyx":336
 *         self.maxes_arr = np.array(maxes_arr, dtype=np.float64, order='C')
 *         self.mins = <np.float64_t*>np.PyArray_DATA(self.mins_arr)
 *         self.maxes = <np.float64_t*>np.PyArray_DATA(self.maxes_arr)             # <<<<<<<<<<<<<<
 *         self.m = self.mins_arr.shape[0]
 * 
 */
  __pyx_t_4 = ((PyObject *)__pyx_v_self->maxes_arr);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_self->maxes = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_4)));
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

  /* "pyart/map/ckdtree.pyx":337
 *         self.mins = <np.float64_t*>np.PyArray_DATA(self.mins_arr)
 *         self.maxes = <np.float64_t*>np.PyArray_DATA(self.maxes_arr)
 *         self.m = self.mins_arr.shape[0]             # <<<<<<<<<<<<<<
 * 
 * # 1-d pieces
 */
  __pyx_v_self->m = (__pyx_v_self->mins_arr->dimensions[0]);

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyart.map.ckdtree.Rectangle.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":341
 * # 1-d pieces
 * # These should only be used if p != infinity
 * cdef inline np.float64_t min_dist_point_interval_p(np.float64_t* x,             # <<<<<<<<<<<<<<
 *                                                    Rectangle rect,
 *                                                    np.intp_t k,
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_point_interval_p(__pyx_t_5numpy_float64_t *__pyx_v_x, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_p) {
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("min_dist_point_interval_p", 0);

  /* "pyart/map/ckdtree.pyx":348
 *     a point in the hyperrectangle.
 *     """
 *     return dmax(0, dmax(rect.mins[k] - x[k], x[k] - rect.maxes[k])) ** p             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t max_dist_point_interval_p(np.float64_t* x,
 */
  __pyx_r = pow(__pyx_f_5pyart_3map_7ckdtree_dmax(0.0, __pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect->mins[__pyx_v_k]) - (__pyx_v_x[__pyx_v_k])), ((__pyx_v_x[__pyx_v_k]) - (__pyx_v_rect->maxes[__pyx_v_k])))), __pyx_v_p);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":350
 *     return dmax(0, dmax(rect.mins[k] - x[k], x[k] - rect.maxes[k])) ** p
 * 
 * cdef inline np.float64_t max_dist_point_interval_p(np.float64_t* x,             # <<<<<<<<<<<<<<
 *                                                    Rectangle rect,
 *                                                    np.intp_t k,
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_point_interval_p(__pyx_t_5numpy_float64_t *__pyx_v_x, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_p) {
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("max_dist_point_interval_p", 0);

  /* "pyart/map/ckdtree.pyx":357
 *     a point in the hyperrectangle.
 *     """
 *     return dmax(rect.maxes[k] - x[k], x[k] - rect.mins[k]) ** p             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t min_dist_interval_interval_p(Rectangle rect1,
 */
  __pyx_r = pow(__pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect->maxes[__pyx_v_k]) - (__pyx_v_x[__pyx_v_k])), ((__pyx_v_x[__pyx_v_k]) - (__pyx_v_rect->mins[__pyx_v_k]))), __pyx_v_p);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":359
 *     return dmax(rect.maxes[k] - x[k], x[k] - rect.mins[k]) ** p
 * 
 * cdef inline np.float64_t min_dist_interval_interval_p(Rectangle rect1,             # <<<<<<<<<<<<<<
 *                                                       Rectangle rect2,
 *                                                       np.intp_t k,
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_interval_interval_p(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect1, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect2, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_p) {
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("min_dist_interval_interval_p", 0);

  /* "pyart/map/ckdtree.pyx":367
 *     """
 *     return dmax(0, dmax(rect1.mins[k] - rect2.maxes[k],
 *                         rect2.mins[k] - rect1.maxes[k])) ** p             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t max_dist_interval_interval_p(Rectangle rect1,
 */
  __pyx_r = pow(__pyx_f_5pyart_3map_7ckdtree_dmax(0.0, __pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect1->mins[__pyx_v_k]) - (__pyx_v_rect2->maxes[__pyx_v_k])), ((__pyx_v_rect2->mins[__pyx_v_k]) - (__pyx_v_rect1->maxes[__pyx_v_k])))), __pyx_v_p);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":369
 *                         rect2.mins[k] - rect1.maxes[k])) ** p
 * 
 * cdef inline np.float64_t max_dist_interval_interval_p(Rectangle rect1,             # <<<<<<<<<<<<<<
 *                                                       Rectangle rect2,
 *                                                       np.intp_t k,
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_interval_interval_p(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect1, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect2, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_p) {
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("max_dist_interval_interval_p", 0);

  /* "pyart/map/ckdtree.pyx":376
 *     two hyperrectangles.
 *     """
 *     return dmax(rect1.maxes[k] - rect2.mins[k], rect2.maxes[k] - rect1.mins[k]) ** p             # <<<<<<<<<<<<<<
 * 
 * # Interval arithmetic in m-D
 */
  __pyx_r = pow(__pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect1->maxes[__pyx_v_k]) - (__pyx_v_rect2->mins[__pyx_v_k])), ((__pyx_v_rect2->maxes[__pyx_v_k]) - (__pyx_v_rect1->mins[__pyx_v_k]))), __pyx_v_p);
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":382
 * 
 * # These should be used only for p == infinity
 * cdef inline np.float64_t min_dist_point_rect_p_inf(np.float64_t* x,             # <<<<<<<<<<<<<<
 *                                                    Rectangle rect):
 *     """Compute the minimum distance between x and the given hyperrectangle."""
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_point_rect_p_inf(__pyx_t_5numpy_float64_t *__pyx_v_x, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_v_min_dist;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_intp_t __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __Pyx_RefNannySetupContext("min_dist_point_rect_p_inf", 0);

  /* "pyart/map/ckdtree.pyx":386
 *     """Compute the minimum distance between x and the given hyperrectangle."""
 *     cdef np.intp_t i
 *     cdef np.float64_t min_dist = 0.             # <<<<<<<<<<<<<<
 *     for i in range(rect.m):
 *         min_dist = dmax(min_dist, dmax(rect.mins[i]-x[i], x[i]-rect.maxes[i]))
 */
  __pyx_v_min_dist = 0.;

  /* "pyart/map/ckdtree.pyx":387
 *     cdef np.intp_t i
 *     cdef np.float64_t min_dist = 0.
 *     for i in range(rect.m):             # <<<<<<<<<<<<<<
 *         min_dist = dmax(min_dist, dmax(rect.mins[i]-x[i], x[i]-rect.maxes[i]))
 *     return min_dist
 */
  __pyx_t_1 = __pyx_v_rect->m;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "pyart/map/ckdtree.pyx":388
 *     cdef np.float64_t min_dist = 0.
 *     for i in range(rect.m):
 *         min_dist = dmax(min_dist, dmax(rect.mins[i]-x[i], x[i]-rect.maxes[i]))             # <<<<<<<<<<<<<<
 *     return min_dist
 * 
 */
    __pyx_v_min_dist = __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_v_min_dist, __pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect->mins[__pyx_v_i]) - (__pyx_v_x[__pyx_v_i])), ((__pyx_v_x[__pyx_v_i]) - (__pyx_v_rect->maxes[__pyx_v_i]))));
  }

  /* "pyart/map/ckdtree.pyx":389
 *     for i in range(rect.m):
 *         min_dist = dmax(min_dist, dmax(rect.mins[i]-x[i], x[i]-rect.maxes[i]))
 *     return min_dist             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t max_dist_point_rect_p_inf(np.float64_t* x,
 */
  __pyx_r = __pyx_v_min_dist;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":391
 *     return min_dist
 * 
 * cdef inline np.float64_t max_dist_point_rect_p_inf(np.float64_t* x,             # <<<<<<<<<<<<<<
 *                                                    Rectangle rect):
 *     """Compute the maximum distance between x and the given hyperrectangle."""
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_point_rect_p_inf(__pyx_t_5numpy_float64_t *__pyx_v_x, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_v_max_dist;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_intp_t __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __Pyx_RefNannySetupContext("max_dist_point_rect_p_inf", 0);

  /* "pyart/map/ckdtree.pyx":395
 *     """Compute the maximum distance between x and the given hyperrectangle."""
 *     cdef np.intp_t i
 *     cdef np.float64_t max_dist = 0.             # <<<<<<<<<<<<<<
 *     for i in range(rect.m):
 *         max_dist = dmax(max_dist, dmax(rect.maxes[i]-x[i], x[i]-rect.mins[i]))
 */
  __pyx_v_max_dist = 0.;

  /* "pyart/map/ckdtree.pyx":396
 *     cdef np.intp_t i
 *     cdef np.float64_t max_dist = 0.
 *     for i in range(rect.m):             # <<<<<<<<<<<<<<
 *         max_dist = dmax(max_dist, dmax(rect.maxes[i]-x[i], x[i]-rect.mins[i]))
 *     return max_dist
 */
  __pyx_t_1 = __pyx_v_rect->m;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "pyart/map/ckdtree.pyx":397
 *     cdef np.float64_t max_dist = 0.
 *     for i in range(rect.m):
 *         max_dist = dmax(max_dist, dmax(rect.maxes[i]-x[i], x[i]-rect.mins[i]))             # <<<<<<<<<<<<<<
 *     return max_dist
 * 
 */
    __pyx_v_max_dist = __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_v_max_dist, __pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect->maxes[__pyx_v_i]) - (__pyx_v_x[__pyx_v_i])), ((__pyx_v_x[__pyx_v_i]) - (__pyx_v_rect->mins[__pyx_v_i]))));
  }

  /* "pyart/map/ckdtree.pyx":398
 *     for i in range(rect.m):
 *         max_dist = dmax(max_dist, dmax(rect.maxes[i]-x[i], x[i]-rect.mins[i]))
 *     return max_dist             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t min_dist_rect_rect_p_inf(Rectangle rect1,
 */
  __pyx_r = __pyx_v_max_dist;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":400
 *     return max_dist
 * 
 * cdef inline np.float64_t min_dist_rect_rect_p_inf(Rectangle rect1,             # <<<<<<<<<<<<<<
 *                                                   Rectangle rect2):
 *     """Compute the minimum distance between points in two hyperrectangles."""
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_min_dist_rect_rect_p_inf(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect1, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect2) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_v_min_dist;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_intp_t __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __Pyx_RefNannySetupContext("min_dist_rect_rect_p_inf", 0);

  /* "pyart/map/ckdtree.pyx":404
 *     """Compute the minimum distance between points in two hyperrectangles."""
 *     cdef np.intp_t i
 *     cdef np.float64_t min_dist = 0.             # <<<<<<<<<<<<<<
 *     for i in range(rect1.m):
 *         min_dist = dmax(min_dist, dmax(rect1.mins[i] - rect2.maxes[i],
 */
  __pyx_v_min_dist = 0.;

  /* "pyart/map/ckdtree.pyx":405
 *     cdef np.intp_t i
 *     cdef np.float64_t min_dist = 0.
 *     for i in range(rect1.m):             # <<<<<<<<<<<<<<
 *         min_dist = dmax(min_dist, dmax(rect1.mins[i] - rect2.maxes[i],
 *                                        rect2.mins[i] - rect1.maxes[i]))
 */
  __pyx_t_1 = __pyx_v_rect1->m;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "pyart/map/ckdtree.pyx":407
 *     for i in range(rect1.m):
 *         min_dist = dmax(min_dist, dmax(rect1.mins[i] - rect2.maxes[i],
 *                                        rect2.mins[i] - rect1.maxes[i]))             # <<<<<<<<<<<<<<
 *     return min_dist
 * 
 */
    __pyx_v_min_dist = __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_v_min_dist, __pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect1->mins[__pyx_v_i]) - (__pyx_v_rect2->maxes[__pyx_v_i])), ((__pyx_v_rect2->mins[__pyx_v_i]) - (__pyx_v_rect1->maxes[__pyx_v_i]))));
  }

  /* "pyart/map/ckdtree.pyx":408
 *         min_dist = dmax(min_dist, dmax(rect1.mins[i] - rect2.maxes[i],
 *                                        rect2.mins[i] - rect1.maxes[i]))
 *     return min_dist             # <<<<<<<<<<<<<<
 * 
 * cdef inline np.float64_t max_dist_rect_rect_p_inf(Rectangle rect1,
 */
  __pyx_r = __pyx_v_min_dist;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":410
 *     return min_dist
 * 
 * cdef inline np.float64_t max_dist_rect_rect_p_inf(Rectangle rect1,             # <<<<<<<<<<<<<<
 *                                                   Rectangle rect2):
 *     """Compute the maximum distance between points in two hyperrectangles."""
 */

static CYTHON_INLINE __pyx_t_5numpy_float64_t __pyx_f_5pyart_3map_7ckdtree_max_dist_rect_rect_p_inf(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect1, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect2) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_v_max_dist;
  __pyx_t_5numpy_float64_t __pyx_r;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_intp_t __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __Pyx_RefNannySetupContext("max_dist_rect_rect_p_inf", 0);

  /* "pyart/map/ckdtree.pyx":414
 *     """Compute the maximum distance between points in two hyperrectangles."""
 *     cdef np.intp_t i
 *     cdef np.float64_t max_dist = 0.             # <<<<<<<<<<<<<<
 *     for i in range(rect1.m):
 *         max_dist = dmax(max_dist, dmax(rect1.maxes[i] - rect2.mins[i],
 */
  __pyx_v_max_dist = 0.;

  /* "pyart/map/ckdtree.pyx":415
 *     cdef np.intp_t i
 *     cdef np.float64_t max_dist = 0.
 *     for i in range(rect1.m):             # <<<<<<<<<<<<<<
 *         max_dist = dmax(max_dist, dmax(rect1.maxes[i] - rect2.mins[i],
 *                                        rect2.maxes[i] - rect1.mins[i]))
 */
  __pyx_t_1 = __pyx_v_rect1->m;
  for (__pyx_t_2 = 0; __pyx_t_2 < __pyx_t_1; __pyx_t_2+=1) {
    __pyx_v_i = __pyx_t_2;

    /* "pyart/map/ckdtree.pyx":417
 *     for i in range(rect1.m):
 *         max_dist = dmax(max_dist, dmax(rect1.maxes[i] - rect2.mins[i],
 *                                        rect2.maxes[i] - rect1.mins[i]))             # <<<<<<<<<<<<<<
 *     return max_dist
 * 
 */
    __pyx_v_max_dist = __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_v_max_dist, __pyx_f_5pyart_3map_7ckdtree_dmax(((__pyx_v_rect1->maxes[__pyx_v_i]) - (__pyx_v_rect2->mins[__pyx_v_i])), ((__pyx_v_rect2->maxes[__pyx_v_i]) - (__pyx_v_rect1->mins[__pyx_v_i]))));
  }

  /* "pyart/map/ckdtree.pyx":418
 *         max_dist = dmax(max_dist, dmax(rect1.maxes[i] - rect2.mins[i],
 *                                        rect2.maxes[i] - rect1.mins[i]))
 *     return max_dist             # <<<<<<<<<<<<<<
 * 
 * # Rectangle-to-rectangle distance tracker
 */
  __pyx_r = __pyx_v_max_dist;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":465
 * 
 *     # Stack handling
 *     cdef int _init_stack(self) except -1:             # <<<<<<<<<<<<<<
 *         cdef void *tmp
 *         self.stack_max_size = 10
 */

static int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker__init_stack(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self) {
  void *__pyx_v_tmp;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_init_stack", 0);

  /* "pyart/map/ckdtree.pyx":467
 *     cdef int _init_stack(self) except -1:
 *         cdef void *tmp
 *         self.stack_max_size = 10             # <<<<<<<<<<<<<<
 *         tmp = stdlib.malloc(sizeof(RR_stack_item) *
 *                             self.stack_max_size)
 */
  __pyx_v_self->stack_max_size = 10;

  /* "pyart/map/ckdtree.pyx":469
 *         self.stack_max_size = 10
 *         tmp = stdlib.malloc(sizeof(RR_stack_item) *
 *                             self.stack_max_size)             # <<<<<<<<<<<<<<
 *         if tmp == NULL:
 *             raise MemoryError
 */
  __pyx_v_tmp = malloc(((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item)) * __pyx_v_self->stack_max_size));

  /* "pyart/map/ckdtree.pyx":470
 *         tmp = stdlib.malloc(sizeof(RR_stack_item) *
 *                             self.stack_max_size)
 *         if tmp == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.stack = <RR_stack_item*> tmp
 */
  __pyx_t_1 = (__pyx_v_tmp == NULL);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":471
 *                             self.stack_max_size)
 *         if tmp == NULL:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.stack = <RR_stack_item*> tmp
 *         self.stack_size = 0
 */
    PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 471; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":472
 *         if tmp == NULL:
 *             raise MemoryError
 *         self.stack = <RR_stack_item*> tmp             # <<<<<<<<<<<<<<
 *         self.stack_size = 0
 *         return 0
 */
  __pyx_v_self->stack = ((struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item *)__pyx_v_tmp);

  /* "pyart/map/ckdtree.pyx":473
 *             raise MemoryError
 *         self.stack = <RR_stack_item*> tmp
 *         self.stack_size = 0             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  __pyx_v_self->stack_size = 0;

  /* "pyart/map/ckdtree.pyx":474
 *         self.stack = <RR_stack_item*> tmp
 *         self.stack_size = 0
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef int _resize_stack(self, np.intp_t new_max_size) except -1:
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker._init_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":476
 *         return 0
 * 
 *     cdef int _resize_stack(self, np.intp_t new_max_size) except -1:             # <<<<<<<<<<<<<<
 *         cdef void *tmp
 *         self.stack_max_size = new_max_size
 */

static int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker__resize_stack(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_new_max_size) {
  void *__pyx_v_tmp;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_resize_stack", 0);

  /* "pyart/map/ckdtree.pyx":478
 *     cdef int _resize_stack(self, np.intp_t new_max_size) except -1:
 *         cdef void *tmp
 *         self.stack_max_size = new_max_size             # <<<<<<<<<<<<<<
 *         tmp = stdlib.realloc(<RR_stack_item*> self.stack,
 *                              new_max_size * sizeof(RR_stack_item))
 */
  __pyx_v_self->stack_max_size = __pyx_v_new_max_size;

  /* "pyart/map/ckdtree.pyx":480
 *         self.stack_max_size = new_max_size
 *         tmp = stdlib.realloc(<RR_stack_item*> self.stack,
 *                              new_max_size * sizeof(RR_stack_item))             # <<<<<<<<<<<<<<
 *         if tmp == NULL:
 *             raise MemoryError
 */
  __pyx_v_tmp = realloc(((struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item *)__pyx_v_self->stack), (__pyx_v_new_max_size * (sizeof(struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item))));

  /* "pyart/map/ckdtree.pyx":481
 *         tmp = stdlib.realloc(<RR_stack_item*> self.stack,
 *                              new_max_size * sizeof(RR_stack_item))
 *         if tmp == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.stack = <RR_stack_item*> tmp
 */
  __pyx_t_1 = (__pyx_v_tmp == NULL);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":482
 *                              new_max_size * sizeof(RR_stack_item))
 *         if tmp == NULL:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.stack = <RR_stack_item*> tmp
 *         return 0
 */
    PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 482; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":483
 *         if tmp == NULL:
 *             raise MemoryError
 *         self.stack = <RR_stack_item*> tmp             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  __pyx_v_self->stack = ((struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item *)__pyx_v_tmp);

  /* "pyart/map/ckdtree.pyx":484
 *             raise MemoryError
 *         self.stack = <RR_stack_item*> tmp
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef int _free_stack(self) except -1:
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker._resize_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":486
 *         return 0
 * 
 *     cdef int _free_stack(self) except -1:             # <<<<<<<<<<<<<<
 *         if self.stack != <RR_stack_item*> NULL:
 *             stdlib.free(self.stack)
 */

static int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker__free_stack(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_free_stack", 0);

  /* "pyart/map/ckdtree.pyx":487
 * 
 *     cdef int _free_stack(self) except -1:
 *         if self.stack != <RR_stack_item*> NULL:             # <<<<<<<<<<<<<<
 *             stdlib.free(self.stack)
 *         return 0
 */
  __pyx_t_1 = (__pyx_v_self->stack != ((struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item *)NULL));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":488
 *     cdef int _free_stack(self) except -1:
 *         if self.stack != <RR_stack_item*> NULL:
 *             stdlib.free(self.stack)             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
    free(__pyx_v_self->stack);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":489
 *         if self.stack != <RR_stack_item*> NULL:
 *             stdlib.free(self.stack)
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_5pyart_3map_7ckdtree_23RectRectDistanceTracker_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5pyart_3map_7ckdtree_23RectRectDistanceTracker_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect1 = 0;
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect2 = 0;
  __pyx_t_5numpy_float64_t __pyx_v_p;
  __pyx_t_5numpy_float64_t __pyx_v_eps;
  __pyx_t_5numpy_float64_t __pyx_v_upper_bound;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__rect1,&__pyx_n_s__rect2,&__pyx_n_s__p,&__pyx_n_s__eps,&__pyx_n_s__upper_bound,0};
    PyObject* values[5] = {0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__rect1)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__rect2)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 5, 5, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (likely((values[2] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__p)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 5, 5, 2); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  3:
        if (likely((values[3] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__eps)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 5, 5, 3); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  4:
        if (likely((values[4] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__upper_bound)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("__init__", 1, 5, 5, 4); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 5) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
      values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
    }
    __pyx_v_rect1 = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)values[0]);
    __pyx_v_rect2 = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)values[1]);
    __pyx_v_p = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_p == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 493; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_eps = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_eps == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 493; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    __pyx_v_upper_bound = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_upper_bound == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 493; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 5, 5, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_rect1), __pyx_ptype_5pyart_3map_7ckdtree_Rectangle, 1, "rect1", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_rect2), __pyx_ptype_5pyart_3map_7ckdtree_Rectangle, 1, "rect2", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 492; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_23RectRectDistanceTracker___init__(((struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_v_self), __pyx_v_rect1, __pyx_v_rect2, __pyx_v_p, __pyx_v_eps, __pyx_v_upper_bound);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":492
 * 
 * 
 *     def __init__(self, Rectangle rect1, Rectangle rect2,             # <<<<<<<<<<<<<<
 *                  np.float64_t p, np.float64_t eps, np.float64_t upper_bound):
 * 
 */

static int __pyx_pf_5pyart_3map_7ckdtree_23RectRectDistanceTracker___init__(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect1, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect2, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps, __pyx_t_5numpy_float64_t __pyx_v_upper_bound) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_t_4;
  __pyx_t_5numpy_float64_t __pyx_t_5;
  int __pyx_t_6;
  __pyx_t_5numpy_intp_t __pyx_t_7;
  __pyx_t_5numpy_intp_t __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyart/map/ckdtree.pyx":495
 *                  np.float64_t p, np.float64_t eps, np.float64_t upper_bound):
 * 
 *         if rect1.m != rect2.m:             # <<<<<<<<<<<<<<
 *             raise ValueError("rect1 and rect2 have different dimensions")
 * 
 */
  __pyx_t_1 = (__pyx_v_rect1->m != __pyx_v_rect2->m);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":496
 * 
 *         if rect1.m != rect2.m:
 *             raise ValueError("rect1 and rect2 have different dimensions")             # <<<<<<<<<<<<<<
 * 
 *         self.rect1 = rect1
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":498
 *             raise ValueError("rect1 and rect2 have different dimensions")
 * 
 *         self.rect1 = rect1             # <<<<<<<<<<<<<<
 *         self.rect2 = rect2
 *         self.p = p
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_rect1));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_rect1));
  __Pyx_GOTREF(__pyx_v_self->rect1);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->rect1));
  __pyx_v_self->rect1 = __pyx_v_rect1;

  /* "pyart/map/ckdtree.pyx":499
 * 
 *         self.rect1 = rect1
 *         self.rect2 = rect2             # <<<<<<<<<<<<<<
 *         self.p = p
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_rect2));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_rect2));
  __Pyx_GOTREF(__pyx_v_self->rect2);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->rect2));
  __pyx_v_self->rect2 = __pyx_v_rect2;

  /* "pyart/map/ckdtree.pyx":500
 *         self.rect1 = rect1
 *         self.rect2 = rect2
 *         self.p = p             # <<<<<<<<<<<<<<
 * 
 *         # internally we represent all distances as distance ** p
 */
  __pyx_v_self->p = __pyx_v_p;

  /* "pyart/map/ckdtree.pyx":503
 * 
 *         # internally we represent all distances as distance ** p
 *         if p != infinity and upper_bound != infinity:             # <<<<<<<<<<<<<<
 *             self.upper_bound = upper_bound ** p
 *         else:
 */
  __pyx_t_1 = (__pyx_v_p != __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {
    __pyx_t_3 = (__pyx_v_upper_bound != __pyx_v_5pyart_3map_7ckdtree_infinity);
    __pyx_t_4 = __pyx_t_3;
  } else {
    __pyx_t_4 = __pyx_t_1;
  }
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":504
 *         # internally we represent all distances as distance ** p
 *         if p != infinity and upper_bound != infinity:
 *             self.upper_bound = upper_bound ** p             # <<<<<<<<<<<<<<
 *         else:
 *             self.upper_bound = upper_bound
 */
    __pyx_v_self->upper_bound = pow(__pyx_v_upper_bound, __pyx_v_p);
    goto __pyx_L4;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":506
 *             self.upper_bound = upper_bound ** p
 *         else:
 *             self.upper_bound = upper_bound             # <<<<<<<<<<<<<<
 * 
 *         # fiddle approximation factor
 */
    __pyx_v_self->upper_bound = __pyx_v_upper_bound;
  }
  __pyx_L4:;

  /* "pyart/map/ckdtree.pyx":509
 * 
 *         # fiddle approximation factor
 *         if eps == 0:             # <<<<<<<<<<<<<<
 *             self.epsfac = 1
 *         elif p == infinity:
 */
  __pyx_t_4 = (__pyx_v_eps == 0.0);
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":510
 *         # fiddle approximation factor
 *         if eps == 0:
 *             self.epsfac = 1             # <<<<<<<<<<<<<<
 *         elif p == infinity:
 *             self.epsfac = 1 / (1 + eps)
 */
    __pyx_v_self->epsfac = 1.0;
    goto __pyx_L5;
  }

  /* "pyart/map/ckdtree.pyx":511
 *         if eps == 0:
 *             self.epsfac = 1
 *         elif p == infinity:             # <<<<<<<<<<<<<<
 *             self.epsfac = 1 / (1 + eps)
 *         else:
 */
  __pyx_t_4 = (__pyx_v_p == __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":512
 *             self.epsfac = 1
 *         elif p == infinity:
 *             self.epsfac = 1 / (1 + eps)             # <<<<<<<<<<<<<<
 *         else:
 *             self.epsfac = 1 / (1 + eps) ** p
 */
    __pyx_t_5 = (1.0 + __pyx_v_eps);
    if (unlikely(__pyx_t_5 == 0)) {
      PyErr_Format(PyExc_ZeroDivisionError, "float division");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_v_self->epsfac = (1.0 / __pyx_t_5);
    goto __pyx_L5;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":514
 *             self.epsfac = 1 / (1 + eps)
 *         else:
 *             self.epsfac = 1 / (1 + eps) ** p             # <<<<<<<<<<<<<<
 * 
 *         self._init_stack()
 */
    __pyx_t_5 = pow((1.0 + __pyx_v_eps), __pyx_v_p);
    if (unlikely(__pyx_t_5 == 0)) {
      PyErr_Format(PyExc_ZeroDivisionError, "float division");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_v_self->epsfac = (1.0 / __pyx_t_5);
  }
  __pyx_L5:;

  /* "pyart/map/ckdtree.pyx":516
 *             self.epsfac = 1 / (1 + eps) ** p
 * 
 *         self._init_stack()             # <<<<<<<<<<<<<<
 * 
 *         # Compute initial min and max distances
 */
  __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->_init_stack(__pyx_v_self); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 516; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":519
 * 
 *         # Compute initial min and max distances
 *         if self.p == infinity:             # <<<<<<<<<<<<<<
 *             self.min_distance = min_dist_rect_rect_p_inf(rect1, rect2)
 *             self.max_distance = max_dist_rect_rect_p_inf(rect1, rect2)
 */
  __pyx_t_4 = (__pyx_v_self->p == __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":520
 *         # Compute initial min and max distances
 *         if self.p == infinity:
 *             self.min_distance = min_dist_rect_rect_p_inf(rect1, rect2)             # <<<<<<<<<<<<<<
 *             self.max_distance = max_dist_rect_rect_p_inf(rect1, rect2)
 *         else:
 */
    __pyx_v_self->min_distance = __pyx_f_5pyart_3map_7ckdtree_min_dist_rect_rect_p_inf(__pyx_v_rect1, __pyx_v_rect2);

    /* "pyart/map/ckdtree.pyx":521
 *         if self.p == infinity:
 *             self.min_distance = min_dist_rect_rect_p_inf(rect1, rect2)
 *             self.max_distance = max_dist_rect_rect_p_inf(rect1, rect2)             # <<<<<<<<<<<<<<
 *         else:
 *             self.min_distance = 0.
 */
    __pyx_v_self->max_distance = __pyx_f_5pyart_3map_7ckdtree_max_dist_rect_rect_p_inf(__pyx_v_rect1, __pyx_v_rect2);
    goto __pyx_L6;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":523
 *             self.max_distance = max_dist_rect_rect_p_inf(rect1, rect2)
 *         else:
 *             self.min_distance = 0.             # <<<<<<<<<<<<<<
 *             self.max_distance = 0.
 *             for i in range(rect1.m):
 */
    __pyx_v_self->min_distance = 0.;

    /* "pyart/map/ckdtree.pyx":524
 *         else:
 *             self.min_distance = 0.
 *             self.max_distance = 0.             # <<<<<<<<<<<<<<
 *             for i in range(rect1.m):
 *                 self.min_distance += min_dist_interval_interval_p(rect1, rect2, i, p)
 */
    __pyx_v_self->max_distance = 0.;

    /* "pyart/map/ckdtree.pyx":525
 *             self.min_distance = 0.
 *             self.max_distance = 0.
 *             for i in range(rect1.m):             # <<<<<<<<<<<<<<
 *                 self.min_distance += min_dist_interval_interval_p(rect1, rect2, i, p)
 *                 self.max_distance += max_dist_interval_interval_p(rect1, rect2, i, p)
 */
    __pyx_t_7 = __pyx_v_rect1->m;
    for (__pyx_t_8 = 0; __pyx_t_8 < __pyx_t_7; __pyx_t_8+=1) {
      __pyx_v_i = __pyx_t_8;

      /* "pyart/map/ckdtree.pyx":526
 *             self.max_distance = 0.
 *             for i in range(rect1.m):
 *                 self.min_distance += min_dist_interval_interval_p(rect1, rect2, i, p)             # <<<<<<<<<<<<<<
 *                 self.max_distance += max_dist_interval_interval_p(rect1, rect2, i, p)
 * 
 */
      __pyx_v_self->min_distance = (__pyx_v_self->min_distance + __pyx_f_5pyart_3map_7ckdtree_min_dist_interval_interval_p(__pyx_v_rect1, __pyx_v_rect2, __pyx_v_i, __pyx_v_p));

      /* "pyart/map/ckdtree.pyx":527
 *             for i in range(rect1.m):
 *                 self.min_distance += min_dist_interval_interval_p(rect1, rect2, i, p)
 *                 self.max_distance += max_dist_interval_interval_p(rect1, rect2, i, p)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
      __pyx_v_self->max_distance = (__pyx_v_self->max_distance + __pyx_f_5pyart_3map_7ckdtree_max_dist_interval_interval_p(__pyx_v_rect1, __pyx_v_rect2, __pyx_v_i, __pyx_v_p));
    }
  }
  __pyx_L6:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static void __pyx_pw_5pyart_3map_7ckdtree_23RectRectDistanceTracker_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_3map_7ckdtree_23RectRectDistanceTracker_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_3map_7ckdtree_23RectRectDistanceTracker_2__dealloc__(((struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":529
 *                 self.max_distance += max_dist_interval_interval_p(rect1, rect2, i, p)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self._free_stack()
 * 
 */

static void __pyx_pf_5pyart_3map_7ckdtree_23RectRectDistanceTracker_2__dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/map/ckdtree.pyx":530
 * 
 *     def __dealloc__(self):
 *         self._free_stack()             # <<<<<<<<<<<<<<
 * 
 *     cdef int push(self, np.intp_t which, np.intp_t direction,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->_free_stack(__pyx_v_self); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":532
 *         self._free_stack()
 * 
 *     cdef int push(self, np.intp_t which, np.intp_t direction,             # <<<<<<<<<<<<<<
 *                   np.intp_t split_dim,
 *                   np.float64_t split_val) except -1:
 */

static int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_which, __pyx_t_5numpy_intp_t __pyx_v_direction, __pyx_t_5numpy_intp_t __pyx_v_split_dim, __pyx_t_5numpy_float64_t __pyx_v_split_val) {
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect = 0;
  struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item *__pyx_v_item;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  __pyx_t_5numpy_float64_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push", 0);

  /* "pyart/map/ckdtree.pyx":537
 * 
 *         cdef Rectangle rect
 *         if which == 1:             # <<<<<<<<<<<<<<
 *             rect = self.rect1
 *         else:
 */
  __pyx_t_1 = (__pyx_v_which == 1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":538
 *         cdef Rectangle rect
 *         if which == 1:
 *             rect = self.rect1             # <<<<<<<<<<<<<<
 *         else:
 *             rect = self.rect2
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect1);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_rect = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2);
    __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":540
 *             rect = self.rect1
 *         else:
 *             rect = self.rect2             # <<<<<<<<<<<<<<
 * 
 *         # Push onto stack
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_rect = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2);
    __pyx_t_2 = 0;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":543
 * 
 *         # Push onto stack
 *         if self.stack_size == self.stack_max_size:             # <<<<<<<<<<<<<<
 *             self._resize_stack(self.stack_max_size * 2)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->stack_size == __pyx_v_self->stack_max_size);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":544
 *         # Push onto stack
 *         if self.stack_size == self.stack_max_size:
 *             self._resize_stack(self.stack_max_size * 2)             # <<<<<<<<<<<<<<
 * 
 *         cdef RR_stack_item *item = &self.stack[self.stack_size]
 */
    __pyx_t_3 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->_resize_stack(__pyx_v_self, (__pyx_v_self->stack_max_size * 2)); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 544; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "pyart/map/ckdtree.pyx":546
 *             self._resize_stack(self.stack_max_size * 2)
 * 
 *         cdef RR_stack_item *item = &self.stack[self.stack_size]             # <<<<<<<<<<<<<<
 *         self.stack_size += 1
 *         item.which = which
 */
  __pyx_v_item = (&(__pyx_v_self->stack[__pyx_v_self->stack_size]));

  /* "pyart/map/ckdtree.pyx":547
 * 
 *         cdef RR_stack_item *item = &self.stack[self.stack_size]
 *         self.stack_size += 1             # <<<<<<<<<<<<<<
 *         item.which = which
 *         item.split_dim = split_dim
 */
  __pyx_v_self->stack_size = (__pyx_v_self->stack_size + 1);

  /* "pyart/map/ckdtree.pyx":548
 *         cdef RR_stack_item *item = &self.stack[self.stack_size]
 *         self.stack_size += 1
 *         item.which = which             # <<<<<<<<<<<<<<
 *         item.split_dim = split_dim
 *         item.min_distance = self.min_distance
 */
  __pyx_v_item->which = __pyx_v_which;

  /* "pyart/map/ckdtree.pyx":549
 *         self.stack_size += 1
 *         item.which = which
 *         item.split_dim = split_dim             # <<<<<<<<<<<<<<
 *         item.min_distance = self.min_distance
 *         item.max_distance = self.max_distance
 */
  __pyx_v_item->split_dim = __pyx_v_split_dim;

  /* "pyart/map/ckdtree.pyx":550
 *         item.which = which
 *         item.split_dim = split_dim
 *         item.min_distance = self.min_distance             # <<<<<<<<<<<<<<
 *         item.max_distance = self.max_distance
 *         item.min_along_dim = rect.mins[split_dim]
 */
  __pyx_t_4 = __pyx_v_self->min_distance;
  __pyx_v_item->min_distance = __pyx_t_4;

  /* "pyart/map/ckdtree.pyx":551
 *         item.split_dim = split_dim
 *         item.min_distance = self.min_distance
 *         item.max_distance = self.max_distance             # <<<<<<<<<<<<<<
 *         item.min_along_dim = rect.mins[split_dim]
 *         item.max_along_dim = rect.maxes[split_dim]
 */
  __pyx_t_4 = __pyx_v_self->max_distance;
  __pyx_v_item->max_distance = __pyx_t_4;

  /* "pyart/map/ckdtree.pyx":552
 *         item.min_distance = self.min_distance
 *         item.max_distance = self.max_distance
 *         item.min_along_dim = rect.mins[split_dim]             # <<<<<<<<<<<<<<
 *         item.max_along_dim = rect.maxes[split_dim]
 * 
 */
  __pyx_v_item->min_along_dim = (__pyx_v_rect->mins[__pyx_v_split_dim]);

  /* "pyart/map/ckdtree.pyx":553
 *         item.max_distance = self.max_distance
 *         item.min_along_dim = rect.mins[split_dim]
 *         item.max_along_dim = rect.maxes[split_dim]             # <<<<<<<<<<<<<<
 * 
 *         # Update min/max distances
 */
  __pyx_v_item->max_along_dim = (__pyx_v_rect->maxes[__pyx_v_split_dim]);

  /* "pyart/map/ckdtree.pyx":556
 * 
 *         # Update min/max distances
 *         if self.p != infinity:             # <<<<<<<<<<<<<<
 *             self.min_distance -= min_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 *             self.max_distance -= max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 */
  __pyx_t_1 = (__pyx_v_self->p != __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":557
 *         # Update min/max distances
 *         if self.p != infinity:
 *             self.min_distance -= min_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)             # <<<<<<<<<<<<<<
 *             self.max_distance -= max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 * 
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect1);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = ((PyObject *)__pyx_v_self->rect2);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_v_self->min_distance = (__pyx_v_self->min_distance - __pyx_f_5pyart_3map_7ckdtree_min_dist_interval_interval_p(((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2), ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_5), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyart/map/ckdtree.pyx":558
 *         if self.p != infinity:
 *             self.min_distance -= min_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 *             self.max_distance -= max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)             # <<<<<<<<<<<<<<
 * 
 *         if direction == LESS:
 */
    __pyx_t_5 = ((PyObject *)__pyx_v_self->rect1);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_self->max_distance = (__pyx_v_self->max_distance - __pyx_f_5pyart_3map_7ckdtree_max_dist_interval_interval_p(((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_5), ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "pyart/map/ckdtree.pyx":560
 *             self.max_distance -= max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 * 
 *         if direction == LESS:             # <<<<<<<<<<<<<<
 *             rect.maxes[split_dim] = split_val
 *         else:
 */
  __pyx_t_1 = (__pyx_v_direction == __pyx_v_5pyart_3map_7ckdtree_LESS);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":561
 * 
 *         if direction == LESS:
 *             rect.maxes[split_dim] = split_val             # <<<<<<<<<<<<<<
 *         else:
 *             rect.mins[split_dim] = split_val
 */
    (__pyx_v_rect->maxes[__pyx_v_split_dim]) = __pyx_v_split_val;
    goto __pyx_L6;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":563
 *             rect.maxes[split_dim] = split_val
 *         else:
 *             rect.mins[split_dim] = split_val             # <<<<<<<<<<<<<<
 * 
 *         if self.p != infinity:
 */
    (__pyx_v_rect->mins[__pyx_v_split_dim]) = __pyx_v_split_val;
  }
  __pyx_L6:;

  /* "pyart/map/ckdtree.pyx":565
 *             rect.mins[split_dim] = split_val
 * 
 *         if self.p != infinity:             # <<<<<<<<<<<<<<
 *             self.min_distance += min_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 *             self.max_distance += max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 */
  __pyx_t_1 = (__pyx_v_self->p != __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":566
 * 
 *         if self.p != infinity:
 *             self.min_distance += min_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)             # <<<<<<<<<<<<<<
 *             self.max_distance += max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 *         else:
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect1);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = ((PyObject *)__pyx_v_self->rect2);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_v_self->min_distance = (__pyx_v_self->min_distance + __pyx_f_5pyart_3map_7ckdtree_min_dist_interval_interval_p(((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2), ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_5), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyart/map/ckdtree.pyx":567
 *         if self.p != infinity:
 *             self.min_distance += min_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 *             self.max_distance += max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)             # <<<<<<<<<<<<<<
 *         else:
 *             self.min_distance = min_dist_rect_rect_p_inf(self.rect1, self.rect2)
 */
    __pyx_t_5 = ((PyObject *)__pyx_v_self->rect1);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_self->max_distance = (__pyx_v_self->max_distance + __pyx_f_5pyart_3map_7ckdtree_max_dist_interval_interval_p(((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_5), ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L7;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":569
 *             self.max_distance += max_dist_interval_interval_p(self.rect1, self.rect2, split_dim, self.p)
 *         else:
 *             self.min_distance = min_dist_rect_rect_p_inf(self.rect1, self.rect2)             # <<<<<<<<<<<<<<
 *             self.max_distance = max_dist_rect_rect_p_inf(self.rect1, self.rect2)
 * 
 */
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect1);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_t_5 = ((PyObject *)__pyx_v_self->rect2);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_v_self->min_distance = __pyx_f_5pyart_3map_7ckdtree_min_dist_rect_rect_p_inf(((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2), ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_5));
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;

    /* "pyart/map/ckdtree.pyx":570
 *         else:
 *             self.min_distance = min_dist_rect_rect_p_inf(self.rect1, self.rect2)
 *             self.max_distance = max_dist_rect_rect_p_inf(self.rect1, self.rect2)             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_t_5 = ((PyObject *)__pyx_v_self->rect1);
    __Pyx_INCREF(__pyx_t_5);
    __pyx_t_2 = ((PyObject *)__pyx_v_self->rect2);
    __Pyx_INCREF(__pyx_t_2);
    __pyx_v_self->max_distance = __pyx_f_5pyart_3map_7ckdtree_max_dist_rect_rect_p_inf(((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_5), ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2));
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  }
  __pyx_L7:;

  /* "pyart/map/ckdtree.pyx":572
 *             self.max_distance = max_dist_rect_rect_p_inf(self.rect1, self.rect2)
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker.push", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_rect);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":575
 * 
 * 
 *     cdef inline int push_less_of(self, np.intp_t which,             # <<<<<<<<<<<<<<
 *                                  innernode *node) except -1:
 *         return self.push(which, LESS, node.split_dim, node.split)
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_which, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push_less_of", 0);

  /* "pyart/map/ckdtree.pyx":577
 *     cdef inline int push_less_of(self, np.intp_t which,
 *                                  innernode *node) except -1:
 *         return self.push(which, LESS, node.split_dim, node.split)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->push(__pyx_v_self, __pyx_v_which, __pyx_v_5pyart_3map_7ckdtree_LESS, __pyx_v_node->split_dim, __pyx_v_node->split); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 577; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker.push_less_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":580
 * 
 * 
 *     cdef inline int push_greater_of(self, np.intp_t which,             # <<<<<<<<<<<<<<
 *                                     innernode *node) except -1:
 *         return self.push(which, GREATER, node.split_dim, node.split)
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_which, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push_greater_of", 0);

  /* "pyart/map/ckdtree.pyx":582
 *     cdef inline int push_greater_of(self, np.intp_t which,
 *                                     innernode *node) except -1:
 *         return self.push(which, GREATER, node.split_dim, node.split)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->push(__pyx_v_self, __pyx_v_which, __pyx_v_5pyart_3map_7ckdtree_GREATER, __pyx_v_node->split_dim, __pyx_v_node->split); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 582; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker.push_greater_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":585
 * 
 * 
 *     cdef inline int pop(self) except -1:             # <<<<<<<<<<<<<<
 *         # Pop from stack
 *         self.stack_size -= 1
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_self) {
  struct __pyx_t_5pyart_3map_7ckdtree_RR_stack_item *__pyx_v_item;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_float64_t __pyx_t_1;
  int __pyx_t_2;
  double __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pop", 0);

  /* "pyart/map/ckdtree.pyx":587
 *     cdef inline int pop(self) except -1:
 *         # Pop from stack
 *         self.stack_size -= 1             # <<<<<<<<<<<<<<
 *         assert self.stack_size >= 0
 * 
 */
  __pyx_v_self->stack_size = (__pyx_v_self->stack_size - 1);

  /* "pyart/map/ckdtree.pyx":588
 *         # Pop from stack
 *         self.stack_size -= 1
 *         assert self.stack_size >= 0             # <<<<<<<<<<<<<<
 * 
 *         cdef RR_stack_item* item = &self.stack[self.stack_size]
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!(__pyx_v_self->stack_size >= 0))) {
    PyErr_SetNone(PyExc_AssertionError);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 588; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  #endif

  /* "pyart/map/ckdtree.pyx":590
 *         assert self.stack_size >= 0
 * 
 *         cdef RR_stack_item* item = &self.stack[self.stack_size]             # <<<<<<<<<<<<<<
 *         self.min_distance = item.min_distance
 *         self.max_distance = item.max_distance
 */
  __pyx_v_item = (&(__pyx_v_self->stack[__pyx_v_self->stack_size]));

  /* "pyart/map/ckdtree.pyx":591
 * 
 *         cdef RR_stack_item* item = &self.stack[self.stack_size]
 *         self.min_distance = item.min_distance             # <<<<<<<<<<<<<<
 *         self.max_distance = item.max_distance
 * 
 */
  __pyx_t_1 = __pyx_v_item->min_distance;
  __pyx_v_self->min_distance = __pyx_t_1;

  /* "pyart/map/ckdtree.pyx":592
 *         cdef RR_stack_item* item = &self.stack[self.stack_size]
 *         self.min_distance = item.min_distance
 *         self.max_distance = item.max_distance             # <<<<<<<<<<<<<<
 * 
 *         if item.which == 1:
 */
  __pyx_t_1 = __pyx_v_item->max_distance;
  __pyx_v_self->max_distance = __pyx_t_1;

  /* "pyart/map/ckdtree.pyx":594
 *         self.max_distance = item.max_distance
 * 
 *         if item.which == 1:             # <<<<<<<<<<<<<<
 *             self.rect1.mins[item.split_dim] = item.min_along_dim
 *             self.rect1.maxes[item.split_dim] = item.max_along_dim
 */
  __pyx_t_2 = (__pyx_v_item->which == 1);
  if (__pyx_t_2) {

    /* "pyart/map/ckdtree.pyx":595
 * 
 *         if item.which == 1:
 *             self.rect1.mins[item.split_dim] = item.min_along_dim             # <<<<<<<<<<<<<<
 *             self.rect1.maxes[item.split_dim] = item.max_along_dim
 *         else:
 */
    __pyx_t_3 = __pyx_v_item->min_along_dim;
    (__pyx_v_self->rect1->mins[__pyx_v_item->split_dim]) = __pyx_t_3;

    /* "pyart/map/ckdtree.pyx":596
 *         if item.which == 1:
 *             self.rect1.mins[item.split_dim] = item.min_along_dim
 *             self.rect1.maxes[item.split_dim] = item.max_along_dim             # <<<<<<<<<<<<<<
 *         else:
 *             self.rect2.mins[item.split_dim] = item.min_along_dim
 */
    __pyx_t_3 = __pyx_v_item->max_along_dim;
    (__pyx_v_self->rect1->maxes[__pyx_v_item->split_dim]) = __pyx_t_3;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":598
 *             self.rect1.maxes[item.split_dim] = item.max_along_dim
 *         else:
 *             self.rect2.mins[item.split_dim] = item.min_along_dim             # <<<<<<<<<<<<<<
 *             self.rect2.maxes[item.split_dim] = item.max_along_dim
 * 
 */
    __pyx_t_3 = __pyx_v_item->min_along_dim;
    (__pyx_v_self->rect2->mins[__pyx_v_item->split_dim]) = __pyx_t_3;

    /* "pyart/map/ckdtree.pyx":599
 *         else:
 *             self.rect2.mins[item.split_dim] = item.min_along_dim
 *             self.rect2.maxes[item.split_dim] = item.max_along_dim             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_t_3 = __pyx_v_item->max_along_dim;
    (__pyx_v_self->rect2->maxes[__pyx_v_item->split_dim]) = __pyx_t_3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":601
 *             self.rect2.maxes[item.split_dim] = item.max_along_dim
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * # Point-to-rectangle distance tracker
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.RectRectDistanceTracker.pop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":645
 * 
 *     # Stack handling
 *     cdef int _init_stack(self) except -1:             # <<<<<<<<<<<<<<
 *         cdef void *tmp
 *         self.stack_max_size = 10
 */

static int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker__init_stack(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self) {
  void *__pyx_v_tmp;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_init_stack", 0);

  /* "pyart/map/ckdtree.pyx":647
 *     cdef int _init_stack(self) except -1:
 *         cdef void *tmp
 *         self.stack_max_size = 10             # <<<<<<<<<<<<<<
 *         tmp = stdlib.malloc(sizeof(RP_stack_item) *
 *                             self.stack_max_size)
 */
  __pyx_v_self->stack_max_size = 10;

  /* "pyart/map/ckdtree.pyx":649
 *         self.stack_max_size = 10
 *         tmp = stdlib.malloc(sizeof(RP_stack_item) *
 *                             self.stack_max_size)             # <<<<<<<<<<<<<<
 *         if tmp == NULL:
 *             raise MemoryError
 */
  __pyx_v_tmp = malloc(((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item)) * __pyx_v_self->stack_max_size));

  /* "pyart/map/ckdtree.pyx":650
 *         tmp = stdlib.malloc(sizeof(RP_stack_item) *
 *                             self.stack_max_size)
 *         if tmp == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.stack = <RP_stack_item*> tmp
 */
  __pyx_t_1 = (__pyx_v_tmp == NULL);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":651
 *                             self.stack_max_size)
 *         if tmp == NULL:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.stack = <RP_stack_item*> tmp
 *         self.stack_size = 0
 */
    PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":652
 *         if tmp == NULL:
 *             raise MemoryError
 *         self.stack = <RP_stack_item*> tmp             # <<<<<<<<<<<<<<
 *         self.stack_size = 0
 *         return 0
 */
  __pyx_v_self->stack = ((struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item *)__pyx_v_tmp);

  /* "pyart/map/ckdtree.pyx":653
 *             raise MemoryError
 *         self.stack = <RP_stack_item*> tmp
 *         self.stack_size = 0             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  __pyx_v_self->stack_size = 0;

  /* "pyart/map/ckdtree.pyx":654
 *         self.stack = <RP_stack_item*> tmp
 *         self.stack_size = 0
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef int _resize_stack(self, np.intp_t new_max_size) except -1:
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker._init_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":656
 *         return 0
 * 
 *     cdef int _resize_stack(self, np.intp_t new_max_size) except -1:             # <<<<<<<<<<<<<<
 *         cdef void *tmp
 *         self.stack_max_size = new_max_size
 */

static int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker__resize_stack(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_new_max_size) {
  void *__pyx_v_tmp;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_resize_stack", 0);

  /* "pyart/map/ckdtree.pyx":658
 *     cdef int _resize_stack(self, np.intp_t new_max_size) except -1:
 *         cdef void *tmp
 *         self.stack_max_size = new_max_size             # <<<<<<<<<<<<<<
 *         tmp = stdlib.realloc(<RP_stack_item*> self.stack,
 *                               new_max_size * sizeof(RP_stack_item))
 */
  __pyx_v_self->stack_max_size = __pyx_v_new_max_size;

  /* "pyart/map/ckdtree.pyx":660
 *         self.stack_max_size = new_max_size
 *         tmp = stdlib.realloc(<RP_stack_item*> self.stack,
 *                               new_max_size * sizeof(RP_stack_item))             # <<<<<<<<<<<<<<
 *         if tmp == NULL:
 *             raise MemoryError
 */
  __pyx_v_tmp = realloc(((struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item *)__pyx_v_self->stack), (__pyx_v_new_max_size * (sizeof(struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item))));

  /* "pyart/map/ckdtree.pyx":661
 *         tmp = stdlib.realloc(<RP_stack_item*> self.stack,
 *                               new_max_size * sizeof(RP_stack_item))
 *         if tmp == NULL:             # <<<<<<<<<<<<<<
 *             raise MemoryError
 *         self.stack = <RP_stack_item*> tmp
 */
  __pyx_t_1 = (__pyx_v_tmp == NULL);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":662
 *                               new_max_size * sizeof(RP_stack_item))
 *         if tmp == NULL:
 *             raise MemoryError             # <<<<<<<<<<<<<<
 *         self.stack = <RP_stack_item*> tmp
 *         return 0
 */
    PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 662; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":663
 *         if tmp == NULL:
 *             raise MemoryError
 *         self.stack = <RP_stack_item*> tmp             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
  __pyx_v_self->stack = ((struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item *)__pyx_v_tmp);

  /* "pyart/map/ckdtree.pyx":664
 *             raise MemoryError
 *         self.stack = <RP_stack_item*> tmp
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef int _free_stack(self) except -1:
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker._resize_stack", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":666
 *         return 0
 * 
 *     cdef int _free_stack(self) except -1:             # <<<<<<<<<<<<<<
 *         if self.stack != <RP_stack_item*> NULL:
 *             stdlib.free(self.stack)
 */

static int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker__free_stack(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("_free_stack", 0);

  /* "pyart/map/ckdtree.pyx":667
 * 
 *     cdef int _free_stack(self) except -1:
 *         if self.stack != <RP_stack_item*> NULL:             # <<<<<<<<<<<<<<
 *             stdlib.free(self.stack)
 *         return 0
 */
  __pyx_t_1 = (__pyx_v_self->stack != ((struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item *)NULL));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":668
 *     cdef int _free_stack(self) except -1:
 *         if self.stack != <RP_stack_item*> NULL:
 *             stdlib.free(self.stack)             # <<<<<<<<<<<<<<
 *         return 0
 * 
 */
    free(__pyx_v_self->stack);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":669
 *         if self.stack != <RP_stack_item*> NULL:
 *             stdlib.free(self.stack)
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     cdef init(self, np.float64_t *pt, Rectangle rect,
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":671
 *         return 0
 * 
 *     cdef init(self, np.float64_t *pt, Rectangle rect,             # <<<<<<<<<<<<<<
 *               np.float64_t p, np.float64_t eps, np.float64_t upper_bound):
 * 
 */

static PyObject *__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_init(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self, __pyx_t_5numpy_float64_t *__pyx_v_pt, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *__pyx_v_rect, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps, __pyx_t_5numpy_float64_t __pyx_v_upper_bound) {
  __pyx_t_5numpy_intp_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  __pyx_t_5numpy_float64_t __pyx_t_4;
  int __pyx_t_5;
  __pyx_t_5numpy_intp_t __pyx_t_6;
  __pyx_t_5numpy_intp_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("init", 0);

  /* "pyart/map/ckdtree.pyx":674
 *               np.float64_t p, np.float64_t eps, np.float64_t upper_bound):
 * 
 *         self.pt = pt             # <<<<<<<<<<<<<<
 *         self.rect = rect
 *         self.p = p
 */
  __pyx_v_self->pt = __pyx_v_pt;

  /* "pyart/map/ckdtree.pyx":675
 * 
 *         self.pt = pt
 *         self.rect = rect             # <<<<<<<<<<<<<<
 *         self.p = p
 * 
 */
  __Pyx_INCREF(((PyObject *)__pyx_v_rect));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_rect));
  __Pyx_GOTREF(__pyx_v_self->rect);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->rect));
  __pyx_v_self->rect = __pyx_v_rect;

  /* "pyart/map/ckdtree.pyx":676
 *         self.pt = pt
 *         self.rect = rect
 *         self.p = p             # <<<<<<<<<<<<<<
 * 
 *         # internally we represent all distances as distance ** p
 */
  __pyx_v_self->p = __pyx_v_p;

  /* "pyart/map/ckdtree.pyx":679
 * 
 *         # internally we represent all distances as distance ** p
 *         if p != infinity and upper_bound != infinity:             # <<<<<<<<<<<<<<
 *             self.upper_bound = upper_bound ** p
 *         else:
 */
  __pyx_t_1 = (__pyx_v_p != __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {
    __pyx_t_2 = (__pyx_v_upper_bound != __pyx_v_5pyart_3map_7ckdtree_infinity);
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = __pyx_t_1;
  }
  if (__pyx_t_3) {

    /* "pyart/map/ckdtree.pyx":680
 *         # internally we represent all distances as distance ** p
 *         if p != infinity and upper_bound != infinity:
 *             self.upper_bound = upper_bound ** p             # <<<<<<<<<<<<<<
 *         else:
 *             self.upper_bound = upper_bound
 */
    __pyx_v_self->upper_bound = pow(__pyx_v_upper_bound, __pyx_v_p);
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":682
 *             self.upper_bound = upper_bound ** p
 *         else:
 *             self.upper_bound = upper_bound             # <<<<<<<<<<<<<<
 * 
 *         # fiddle approximation factor
 */
    __pyx_v_self->upper_bound = __pyx_v_upper_bound;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":685
 * 
 *         # fiddle approximation factor
 *         if eps == 0:             # <<<<<<<<<<<<<<
 *             self.epsfac = 1
 *         elif p == infinity:
 */
  __pyx_t_3 = (__pyx_v_eps == 0.0);
  if (__pyx_t_3) {

    /* "pyart/map/ckdtree.pyx":686
 *         # fiddle approximation factor
 *         if eps == 0:
 *             self.epsfac = 1             # <<<<<<<<<<<<<<
 *         elif p == infinity:
 *             self.epsfac = 1 / (1 + eps)
 */
    __pyx_v_self->epsfac = 1.0;
    goto __pyx_L4;
  }

  /* "pyart/map/ckdtree.pyx":687
 *         if eps == 0:
 *             self.epsfac = 1
 *         elif p == infinity:             # <<<<<<<<<<<<<<
 *             self.epsfac = 1 / (1 + eps)
 *         else:
 */
  __pyx_t_3 = (__pyx_v_p == __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_3) {

    /* "pyart/map/ckdtree.pyx":688
 *             self.epsfac = 1
 *         elif p == infinity:
 *             self.epsfac = 1 / (1 + eps)             # <<<<<<<<<<<<<<
 *         else:
 *             self.epsfac = 1 / (1 + eps) ** p
 */
    __pyx_t_4 = (1.0 + __pyx_v_eps);
    if (unlikely(__pyx_t_4 == 0)) {
      PyErr_Format(PyExc_ZeroDivisionError, "float division");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 688; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_v_self->epsfac = (1.0 / __pyx_t_4);
    goto __pyx_L4;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":690
 *             self.epsfac = 1 / (1 + eps)
 *         else:
 *             self.epsfac = 1 / (1 + eps) ** p             # <<<<<<<<<<<<<<
 * 
 *         self._init_stack()
 */
    __pyx_t_4 = pow((1.0 + __pyx_v_eps), __pyx_v_p);
    if (unlikely(__pyx_t_4 == 0)) {
      PyErr_Format(PyExc_ZeroDivisionError, "float division");
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 690; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_v_self->epsfac = (1.0 / __pyx_t_4);
  }
  __pyx_L4:;

  /* "pyart/map/ckdtree.pyx":692
 *             self.epsfac = 1 / (1 + eps) ** p
 * 
 *         self._init_stack()             # <<<<<<<<<<<<<<
 * 
 *         # Compute initial min and max distances
 */
  __pyx_t_5 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->_init_stack(__pyx_v_self); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 692; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":695
 * 
 *         # Compute initial min and max distances
 *         if self.p == infinity:             # <<<<<<<<<<<<<<
 *             self.min_distance = min_dist_point_rect_p_inf(pt, rect)
 *             self.max_distance = max_dist_point_rect_p_inf(pt, rect)
 */
  __pyx_t_3 = (__pyx_v_self->p == __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_3) {

    /* "pyart/map/ckdtree.pyx":696
 *         # Compute initial min and max distances
 *         if self.p == infinity:
 *             self.min_distance = min_dist_point_rect_p_inf(pt, rect)             # <<<<<<<<<<<<<<
 *             self.max_distance = max_dist_point_rect_p_inf(pt, rect)
 *         else:
 */
    __pyx_v_self->min_distance = __pyx_f_5pyart_3map_7ckdtree_min_dist_point_rect_p_inf(__pyx_v_pt, __pyx_v_rect);

    /* "pyart/map/ckdtree.pyx":697
 *         if self.p == infinity:
 *             self.min_distance = min_dist_point_rect_p_inf(pt, rect)
 *             self.max_distance = max_dist_point_rect_p_inf(pt, rect)             # <<<<<<<<<<<<<<
 *         else:
 *             self.min_distance = 0.
 */
    __pyx_v_self->max_distance = __pyx_f_5pyart_3map_7ckdtree_max_dist_point_rect_p_inf(__pyx_v_pt, __pyx_v_rect);
    goto __pyx_L5;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":699
 *             self.max_distance = max_dist_point_rect_p_inf(pt, rect)
 *         else:
 *             self.min_distance = 0.             # <<<<<<<<<<<<<<
 *             self.max_distance = 0.
 *             for i in range(rect.m):
 */
    __pyx_v_self->min_distance = 0.;

    /* "pyart/map/ckdtree.pyx":700
 *         else:
 *             self.min_distance = 0.
 *             self.max_distance = 0.             # <<<<<<<<<<<<<<
 *             for i in range(rect.m):
 *                 self.min_distance += min_dist_point_interval_p(pt, rect, i, p)
 */
    __pyx_v_self->max_distance = 0.;

    /* "pyart/map/ckdtree.pyx":701
 *             self.min_distance = 0.
 *             self.max_distance = 0.
 *             for i in range(rect.m):             # <<<<<<<<<<<<<<
 *                 self.min_distance += min_dist_point_interval_p(pt, rect, i, p)
 *                 self.max_distance += max_dist_point_interval_p(pt, rect, i, p)
 */
    __pyx_t_6 = __pyx_v_rect->m;
    for (__pyx_t_7 = 0; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
      __pyx_v_i = __pyx_t_7;

      /* "pyart/map/ckdtree.pyx":702
 *             self.max_distance = 0.
 *             for i in range(rect.m):
 *                 self.min_distance += min_dist_point_interval_p(pt, rect, i, p)             # <<<<<<<<<<<<<<
 *                 self.max_distance += max_dist_point_interval_p(pt, rect, i, p)
 * 
 */
      __pyx_v_self->min_distance = (__pyx_v_self->min_distance + __pyx_f_5pyart_3map_7ckdtree_min_dist_point_interval_p(__pyx_v_pt, __pyx_v_rect, __pyx_v_i, __pyx_v_p));

      /* "pyart/map/ckdtree.pyx":703
 *             for i in range(rect.m):
 *                 self.min_distance += min_dist_point_interval_p(pt, rect, i, p)
 *                 self.max_distance += max_dist_point_interval_p(pt, rect, i, p)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(self):
 */
      __pyx_v_self->max_distance = (__pyx_v_self->max_distance + __pyx_f_5pyart_3map_7ckdtree_max_dist_point_interval_p(__pyx_v_pt, __pyx_v_rect, __pyx_v_i, __pyx_v_p));
    }
  }
  __pyx_L5:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker.init", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static void __pyx_pw_5pyart_3map_7ckdtree_24PointRectDistanceTracker_1__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_3map_7ckdtree_24PointRectDistanceTracker_1__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_3map_7ckdtree_24PointRectDistanceTracker___dealloc__(((struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":705
 *                 self.max_distance += max_dist_point_interval_p(pt, rect, i, p)
 * 
 *     def __dealloc__(self):             # <<<<<<<<<<<<<<
 *         self._free_stack()
 * 
 */

static void __pyx_pf_5pyart_3map_7ckdtree_24PointRectDistanceTracker___dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/map/ckdtree.pyx":706
 * 
 *     def __dealloc__(self):
 *         self._free_stack()             # <<<<<<<<<<<<<<
 * 
 *     cdef int push(self, np.intp_t direction,
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->_free_stack(__pyx_v_self); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 706; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":708
 *         self._free_stack()
 * 
 *     cdef int push(self, np.intp_t direction,             # <<<<<<<<<<<<<<
 *                   np.intp_t split_dim,
 *                   np.float64_t split_val) except -1:
 */

static int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_direction, __pyx_t_5numpy_intp_t __pyx_v_split_dim, __pyx_t_5numpy_float64_t __pyx_v_split_val) {
  struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item *__pyx_v_item;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_float64_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push", 0);

  /* "pyart/map/ckdtree.pyx":713
 * 
 *         # Push onto stack
 *         if self.stack_size == self.stack_max_size:             # <<<<<<<<<<<<<<
 *             self._resize_stack(self.stack_max_size * 2)
 * 
 */
  __pyx_t_1 = (__pyx_v_self->stack_size == __pyx_v_self->stack_max_size);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":714
 *         # Push onto stack
 *         if self.stack_size == self.stack_max_size:
 *             self._resize_stack(self.stack_max_size * 2)             # <<<<<<<<<<<<<<
 * 
 *         cdef RP_stack_item *item = &self.stack[self.stack_size]
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->_resize_stack(__pyx_v_self, (__pyx_v_self->stack_max_size * 2)); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 714; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":716
 *             self._resize_stack(self.stack_max_size * 2)
 * 
 *         cdef RP_stack_item *item = &self.stack[self.stack_size]             # <<<<<<<<<<<<<<
 *         self.stack_size += 1
 * 
 */
  __pyx_v_item = (&(__pyx_v_self->stack[__pyx_v_self->stack_size]));

  /* "pyart/map/ckdtree.pyx":717
 * 
 *         cdef RP_stack_item *item = &self.stack[self.stack_size]
 *         self.stack_size += 1             # <<<<<<<<<<<<<<
 * 
 *         item.split_dim = split_dim
 */
  __pyx_v_self->stack_size = (__pyx_v_self->stack_size + 1);

  /* "pyart/map/ckdtree.pyx":719
 *         self.stack_size += 1
 * 
 *         item.split_dim = split_dim             # <<<<<<<<<<<<<<
 *         item.min_distance = self.min_distance
 *         item.max_distance = self.max_distance
 */
  __pyx_v_item->split_dim = __pyx_v_split_dim;

  /* "pyart/map/ckdtree.pyx":720
 * 
 *         item.split_dim = split_dim
 *         item.min_distance = self.min_distance             # <<<<<<<<<<<<<<
 *         item.max_distance = self.max_distance
 *         item.min_along_dim = self.rect.mins[split_dim]
 */
  __pyx_t_3 = __pyx_v_self->min_distance;
  __pyx_v_item->min_distance = __pyx_t_3;

  /* "pyart/map/ckdtree.pyx":721
 *         item.split_dim = split_dim
 *         item.min_distance = self.min_distance
 *         item.max_distance = self.max_distance             # <<<<<<<<<<<<<<
 *         item.min_along_dim = self.rect.mins[split_dim]
 *         item.max_along_dim = self.rect.maxes[split_dim]
 */
  __pyx_t_3 = __pyx_v_self->max_distance;
  __pyx_v_item->max_distance = __pyx_t_3;

  /* "pyart/map/ckdtree.pyx":722
 *         item.min_distance = self.min_distance
 *         item.max_distance = self.max_distance
 *         item.min_along_dim = self.rect.mins[split_dim]             # <<<<<<<<<<<<<<
 *         item.max_along_dim = self.rect.maxes[split_dim]
 * 
 */
  __pyx_v_item->min_along_dim = (__pyx_v_self->rect->mins[__pyx_v_split_dim]);

  /* "pyart/map/ckdtree.pyx":723
 *         item.max_distance = self.max_distance
 *         item.min_along_dim = self.rect.mins[split_dim]
 *         item.max_along_dim = self.rect.maxes[split_dim]             # <<<<<<<<<<<<<<
 * 
 *         if self.p != infinity:
 */
  __pyx_v_item->max_along_dim = (__pyx_v_self->rect->maxes[__pyx_v_split_dim]);

  /* "pyart/map/ckdtree.pyx":725
 *         item.max_along_dim = self.rect.maxes[split_dim]
 * 
 *         if self.p != infinity:             # <<<<<<<<<<<<<<
 *             self.min_distance -= min_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 *             self.max_distance -= max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 */
  __pyx_t_1 = (__pyx_v_self->p != __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":726
 * 
 *         if self.p != infinity:
 *             self.min_distance -= min_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)             # <<<<<<<<<<<<<<
 *             self.max_distance -= max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 * 
 */
    __pyx_t_4 = ((PyObject *)__pyx_v_self->rect);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_self->min_distance = (__pyx_v_self->min_distance - __pyx_f_5pyart_3map_7ckdtree_min_dist_point_interval_p(__pyx_v_self->pt, ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_4), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/map/ckdtree.pyx":727
 *         if self.p != infinity:
 *             self.min_distance -= min_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 *             self.max_distance -= max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)             # <<<<<<<<<<<<<<
 * 
 *         if direction == LESS:
 */
    __pyx_t_4 = ((PyObject *)__pyx_v_self->rect);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_self->max_distance = (__pyx_v_self->max_distance - __pyx_f_5pyart_3map_7ckdtree_max_dist_point_interval_p(__pyx_v_self->pt, ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_4), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "pyart/map/ckdtree.pyx":729
 *             self.max_distance -= max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 * 
 *         if direction == LESS:             # <<<<<<<<<<<<<<
 *             self.rect.maxes[split_dim] = split_val
 *         else:
 */
  __pyx_t_1 = (__pyx_v_direction == __pyx_v_5pyart_3map_7ckdtree_LESS);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":730
 * 
 *         if direction == LESS:
 *             self.rect.maxes[split_dim] = split_val             # <<<<<<<<<<<<<<
 *         else:
 *             self.rect.mins[split_dim] = split_val
 */
    (__pyx_v_self->rect->maxes[__pyx_v_split_dim]) = __pyx_v_split_val;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":732
 *             self.rect.maxes[split_dim] = split_val
 *         else:
 *             self.rect.mins[split_dim] = split_val             # <<<<<<<<<<<<<<
 * 
 *         if self.p != infinity:
 */
    (__pyx_v_self->rect->mins[__pyx_v_split_dim]) = __pyx_v_split_val;
  }
  __pyx_L5:;

  /* "pyart/map/ckdtree.pyx":734
 *             self.rect.mins[split_dim] = split_val
 * 
 *         if self.p != infinity:             # <<<<<<<<<<<<<<
 *             self.min_distance += min_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 *             self.max_distance += max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 */
  __pyx_t_1 = (__pyx_v_self->p != __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":735
 * 
 *         if self.p != infinity:
 *             self.min_distance += min_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)             # <<<<<<<<<<<<<<
 *             self.max_distance += max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 *         else:
 */
    __pyx_t_4 = ((PyObject *)__pyx_v_self->rect);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_self->min_distance = (__pyx_v_self->min_distance + __pyx_f_5pyart_3map_7ckdtree_min_dist_point_interval_p(__pyx_v_self->pt, ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_4), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/map/ckdtree.pyx":736
 *         if self.p != infinity:
 *             self.min_distance += min_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 *             self.max_distance += max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)             # <<<<<<<<<<<<<<
 *         else:
 *             self.min_distance = min_dist_point_rect_p_inf(self.pt, self.rect)
 */
    __pyx_t_4 = ((PyObject *)__pyx_v_self->rect);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_self->max_distance = (__pyx_v_self->max_distance + __pyx_f_5pyart_3map_7ckdtree_max_dist_point_interval_p(__pyx_v_self->pt, ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_4), __pyx_v_split_dim, __pyx_v_self->p));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    goto __pyx_L6;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":738
 *             self.max_distance += max_dist_point_interval_p(self.pt, self.rect, split_dim, self.p)
 *         else:
 *             self.min_distance = min_dist_point_rect_p_inf(self.pt, self.rect)             # <<<<<<<<<<<<<<
 *             self.max_distance = max_dist_point_rect_p_inf(self.pt, self.rect)
 * 
 */
    __pyx_t_4 = ((PyObject *)__pyx_v_self->rect);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_self->min_distance = __pyx_f_5pyart_3map_7ckdtree_min_dist_point_rect_p_inf(__pyx_v_self->pt, ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_4));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

    /* "pyart/map/ckdtree.pyx":739
 *         else:
 *             self.min_distance = min_dist_point_rect_p_inf(self.pt, self.rect)
 *             self.max_distance = max_dist_point_rect_p_inf(self.pt, self.rect)             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_t_4 = ((PyObject *)__pyx_v_self->rect);
    __Pyx_INCREF(__pyx_t_4);
    __pyx_v_self->max_distance = __pyx_f_5pyart_3map_7ckdtree_max_dist_point_rect_p_inf(__pyx_v_self->pt, ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_4));
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  }
  __pyx_L6:;

  /* "pyart/map/ckdtree.pyx":741
 *             self.max_distance = max_dist_point_rect_p_inf(self.pt, self.rect)
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker.push", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":744
 * 
 * 
 *     cdef inline int push_less_of(self, innernode* node) except -1:             # <<<<<<<<<<<<<<
 *         return self.push(LESS, node.split_dim, node.split)
 * 
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_less_of(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push_less_of", 0);

  /* "pyart/map/ckdtree.pyx":745
 * 
 *     cdef inline int push_less_of(self, innernode* node) except -1:
 *         return self.push(LESS, node.split_dim, node.split)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->push(__pyx_v_self, __pyx_v_5pyart_3map_7ckdtree_LESS, __pyx_v_node->split_dim, __pyx_v_node->split); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker.push_less_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":748
 * 
 * 
 *     cdef inline int push_greater_of(self, innernode* node) except -1:             # <<<<<<<<<<<<<<
 *         return self.push(GREATER, node.split_dim, node.split)
 * 
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_greater_of(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("push_greater_of", 0);

  /* "pyart/map/ckdtree.pyx":749
 * 
 *     cdef inline int push_greater_of(self, innernode* node) except -1:
 *         return self.push(GREATER, node.split_dim, node.split)             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_v_self->__pyx_vtab)->push(__pyx_v_self, __pyx_v_5pyart_3map_7ckdtree_GREATER, __pyx_v_node->split_dim, __pyx_v_node->split); if (unlikely(__pyx_t_1 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 749; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_t_1;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker.push_greater_of", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":752
 * 
 * 
 *     cdef inline int pop(self) except -1:             # <<<<<<<<<<<<<<
 *         self.stack_size -= 1
 *         assert self.stack_size >= 0
 */

static CYTHON_INLINE int __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_pop(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_self) {
  struct __pyx_t_5pyart_3map_7ckdtree_RP_stack_item *__pyx_v_item;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __pyx_t_5numpy_float64_t __pyx_t_1;
  double __pyx_t_2;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("pop", 0);

  /* "pyart/map/ckdtree.pyx":753
 * 
 *     cdef inline int pop(self) except -1:
 *         self.stack_size -= 1             # <<<<<<<<<<<<<<
 *         assert self.stack_size >= 0
 * 
 */
  __pyx_v_self->stack_size = (__pyx_v_self->stack_size - 1);

  /* "pyart/map/ckdtree.pyx":754
 *     cdef inline int pop(self) except -1:
 *         self.stack_size -= 1
 *         assert self.stack_size >= 0             # <<<<<<<<<<<<<<
 * 
 *         cdef RP_stack_item* item = &self.stack[self.stack_size]
 */
  #ifndef CYTHON_WITHOUT_ASSERTIONS
  if (unlikely(!(__pyx_v_self->stack_size >= 0))) {
    PyErr_SetNone(PyExc_AssertionError);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 754; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  #endif

  /* "pyart/map/ckdtree.pyx":756
 *         assert self.stack_size >= 0
 * 
 *         cdef RP_stack_item* item = &self.stack[self.stack_size]             # <<<<<<<<<<<<<<
 *         self.min_distance = item.min_distance
 *         self.max_distance = item.max_distance
 */
  __pyx_v_item = (&(__pyx_v_self->stack[__pyx_v_self->stack_size]));

  /* "pyart/map/ckdtree.pyx":757
 * 
 *         cdef RP_stack_item* item = &self.stack[self.stack_size]
 *         self.min_distance = item.min_distance             # <<<<<<<<<<<<<<
 *         self.max_distance = item.max_distance
 *         self.rect.mins[item.split_dim] = item.min_along_dim
 */
  __pyx_t_1 = __pyx_v_item->min_distance;
  __pyx_v_self->min_distance = __pyx_t_1;

  /* "pyart/map/ckdtree.pyx":758
 *         cdef RP_stack_item* item = &self.stack[self.stack_size]
 *         self.min_distance = item.min_distance
 *         self.max_distance = item.max_distance             # <<<<<<<<<<<<<<
 *         self.rect.mins[item.split_dim] = item.min_along_dim
 *         self.rect.maxes[item.split_dim] = item.max_along_dim
 */
  __pyx_t_1 = __pyx_v_item->max_distance;
  __pyx_v_self->max_distance = __pyx_t_1;

  /* "pyart/map/ckdtree.pyx":759
 *         self.min_distance = item.min_distance
 *         self.max_distance = item.max_distance
 *         self.rect.mins[item.split_dim] = item.min_along_dim             # <<<<<<<<<<<<<<
 *         self.rect.maxes[item.split_dim] = item.max_along_dim
 * 
 */
  __pyx_t_2 = __pyx_v_item->min_along_dim;
  (__pyx_v_self->rect->mins[__pyx_v_item->split_dim]) = __pyx_t_2;

  /* "pyart/map/ckdtree.pyx":760
 *         self.max_distance = item.max_distance
 *         self.rect.mins[item.split_dim] = item.min_along_dim
 *         self.rect.maxes[item.split_dim] = item.max_along_dim             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
  __pyx_t_2 = __pyx_v_item->max_along_dim;
  (__pyx_v_self->rect->maxes[__pyx_v_item->split_dim]) = __pyx_t_2;

  /* "pyart/map/ckdtree.pyx":762
 *         self.rect.maxes[item.split_dim] = item.max_along_dim
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * # Tree structure
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.PointRectDistanceTracker.pop", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static int __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static int __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_data = 0;
  __pyx_t_5numpy_intp_t __pyx_v_leafsize;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__data,&__pyx_n_s__leafsize,0};
    PyObject* values[2] = {0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__data)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__leafsize);
          if (value) { values[1] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_data = values[0];
    if (values[1]) {
      __pyx_v_leafsize = __Pyx_PyInt_from_py_Py_intptr_t(values[1]); if (unlikely((__pyx_v_leafsize == (npy_intp)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_leafsize = ((__pyx_t_5numpy_intp_t)10);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 0, 1, 2, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree___init__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self), __pyx_v_data, __pyx_v_leafsize);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":844
 *     cdef np.intp_t* raw_indices
 * 
 *     def __init__(cKDTree self, data, np.intp_t leafsize=10):             # <<<<<<<<<<<<<<
 *         self.data = np.ascontiguousarray(data,dtype=np.float64)
 *         self.n, self.m = np.shape(self.data)
 */

static int __pyx_pf_5pyart_3map_7ckdtree_7cKDTree___init__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_data, __pyx_t_5numpy_intp_t __pyx_v_leafsize) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  __pyx_t_5numpy_intp_t __pyx_t_7;
  __pyx_t_5numpy_intp_t __pyx_t_8;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_t_11;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "pyart/map/ckdtree.pyx":845
 * 
 *     def __init__(cKDTree self, data, np.intp_t leafsize=10):
 *         self.data = np.ascontiguousarray(data,dtype=np.float64)             # <<<<<<<<<<<<<<
 *         self.n, self.m = np.shape(self.data)
 *         self.leafsize = leafsize
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__ascontiguousarray); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_data);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_data);
  __Pyx_GIVEREF(__pyx_v_data);
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__float64); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__dtype), __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->data);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->data));
  __pyx_v_self->data = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":846
 *     def __init__(cKDTree self, data, np.intp_t leafsize=10):
 *         self.data = np.ascontiguousarray(data,dtype=np.float64)
 *         self.n, self.m = np.shape(self.data)             # <<<<<<<<<<<<<<
 *         self.leafsize = leafsize
 *         if self.leafsize<1:
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__shape); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_self->data));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->data));
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  if ((likely(PyTuple_CheckExact(__pyx_t_1))) || (PyList_CheckExact(__pyx_t_1))) {
    PyObject* sequence = __pyx_t_1;
    #if CYTHON_COMPILING_IN_CPYTHON
    Py_ssize_t size = Py_SIZE(sequence);
    #else
    Py_ssize_t size = PySequence_Size(sequence);
    #endif
    if (unlikely(size != 2)) {
      if (size > 2) __Pyx_RaiseTooManyValuesError(2);
      else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    #if CYTHON_COMPILING_IN_CPYTHON
    if (likely(PyTuple_CheckExact(sequence))) {
      __pyx_t_5 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 1); 
    } else {
      __pyx_t_5 = PyList_GET_ITEM(sequence, 0); 
      __pyx_t_3 = PyList_GET_ITEM(sequence, 1); 
    }
    __Pyx_INCREF(__pyx_t_5);
    __Pyx_INCREF(__pyx_t_3);
    #else
    __pyx_t_5 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_3 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  } else
  {
    Py_ssize_t index = -1;
    __pyx_t_2 = PyObject_GetIter(__pyx_t_1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = Py_TYPE(__pyx_t_2)->tp_iternext;
    index = 0; __pyx_t_5 = __pyx_t_6(__pyx_t_2); if (unlikely(!__pyx_t_5)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_5);
    index = 1; __pyx_t_3 = __pyx_t_6(__pyx_t_2); if (unlikely(!__pyx_t_3)) goto __pyx_L3_unpacking_failed;
    __Pyx_GOTREF(__pyx_t_3);
    if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_2), 2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_6 = NULL;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L4_unpacking_done;
    __pyx_L3_unpacking_failed:;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_6 = NULL;
    if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_L4_unpacking_done:;
  }
  __pyx_t_7 = __Pyx_PyInt_from_py_Py_intptr_t(__pyx_t_5); if (unlikely((__pyx_t_7 == (npy_intp)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_8 = __Pyx_PyInt_from_py_Py_intptr_t(__pyx_t_3); if (unlikely((__pyx_t_8 == (npy_intp)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_self->n = __pyx_t_7;
  __pyx_v_self->m = __pyx_t_8;

  /* "pyart/map/ckdtree.pyx":847
 *         self.data = np.ascontiguousarray(data,dtype=np.float64)
 *         self.n, self.m = np.shape(self.data)
 *         self.leafsize = leafsize             # <<<<<<<<<<<<<<
 *         if self.leafsize<1:
 *             raise ValueError("leafsize must be at least 1")
 */
  __pyx_v_self->leafsize = __pyx_v_leafsize;

  /* "pyart/map/ckdtree.pyx":848
 *         self.n, self.m = np.shape(self.data)
 *         self.leafsize = leafsize
 *         if self.leafsize<1:             # <<<<<<<<<<<<<<
 *             raise ValueError("leafsize must be at least 1")
 *         self.maxes = np.ascontiguousarray(np.amax(self.data,axis=0), dtype=np.float64)
 */
  __pyx_t_9 = (__pyx_v_self->leafsize < 1);
  if (__pyx_t_9) {

    /* "pyart/map/ckdtree.pyx":849
 *         self.leafsize = leafsize
 *         if self.leafsize<1:
 *             raise ValueError("leafsize must be at least 1")             # <<<<<<<<<<<<<<
 *         self.maxes = np.ascontiguousarray(np.amax(self.data,axis=0), dtype=np.float64)
 *         self.mins = np.ascontiguousarray(np.amin(self.data,axis=0), dtype=np.float64)
 */
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_5), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "pyart/map/ckdtree.pyx":850
 *         if self.leafsize<1:
 *             raise ValueError("leafsize must be at least 1")
 *         self.maxes = np.ascontiguousarray(np.amax(self.data,axis=0), dtype=np.float64)             # <<<<<<<<<<<<<<
 *         self.mins = np.ascontiguousarray(np.amin(self.data,axis=0), dtype=np.float64)
 *         self.indices = np.ascontiguousarray(np.arange(self.n,dtype=np.intp))
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__ascontiguousarray); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__amax); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->data));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->data));
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__axis), __pyx_int_0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_4 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = PyDict_New(); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_4));
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__float64); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (PyDict_SetItem(__pyx_t_4, ((PyObject *)__pyx_n_s__dtype), __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_4)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 850; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_5);
  __Pyx_GOTREF(__pyx_v_self->maxes);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_v_self->maxes = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":851
 *             raise ValueError("leafsize must be at least 1")
 *         self.maxes = np.ascontiguousarray(np.amax(self.data,axis=0), dtype=np.float64)
 *         self.mins = np.ascontiguousarray(np.amin(self.data,axis=0), dtype=np.float64)             # <<<<<<<<<<<<<<
 *         self.indices = np.ascontiguousarray(np.arange(self.n,dtype=np.intp))
 * 
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__ascontiguousarray); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__amin); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_self->data));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->data));
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__axis), __pyx_int_0) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_1 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__float64); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_GOTREF(__pyx_v_self->mins);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->mins));
  __pyx_v_self->mins = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":852
 *         self.maxes = np.ascontiguousarray(np.amax(self.data,axis=0), dtype=np.float64)
 *         self.mins = np.ascontiguousarray(np.amin(self.data,axis=0), dtype=np.float64)
 *         self.indices = np.ascontiguousarray(np.arange(self.n,dtype=np.intp))             # <<<<<<<<<<<<<<
 * 
 *         self.raw_data = <np.float64_t*>np.PyArray_DATA(self.data)
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__ascontiguousarray); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__arange); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_10 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__intp); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), __pyx_t_10) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
  __pyx_t_10 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_10);
  __Pyx_GIVEREF(__pyx_t_10);
  __pyx_t_10 = 0;
  __pyx_t_10 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_10)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_10);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  if (!(likely(((__pyx_t_10) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_10, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GIVEREF(__pyx_t_10);
  __Pyx_GOTREF(__pyx_v_self->indices);
  __Pyx_DECREF(((PyObject *)__pyx_v_self->indices));
  __pyx_v_self->indices = ((PyArrayObject *)__pyx_t_10);
  __pyx_t_10 = 0;

  /* "pyart/map/ckdtree.pyx":854
 *         self.indices = np.ascontiguousarray(np.arange(self.n,dtype=np.intp))
 * 
 *         self.raw_data = <np.float64_t*>np.PyArray_DATA(self.data)             # <<<<<<<<<<<<<<
 *         self.raw_maxes = <np.float64_t*>np.PyArray_DATA(self.maxes)
 *         self.raw_mins = <np.float64_t*>np.PyArray_DATA(self.mins)
 */
  __pyx_t_10 = ((PyObject *)__pyx_v_self->data);
  __Pyx_INCREF(__pyx_t_10);
  __pyx_v_self->raw_data = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_10)));
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "pyart/map/ckdtree.pyx":855
 * 
 *         self.raw_data = <np.float64_t*>np.PyArray_DATA(self.data)
 *         self.raw_maxes = <np.float64_t*>np.PyArray_DATA(self.maxes)             # <<<<<<<<<<<<<<
 *         self.raw_mins = <np.float64_t*>np.PyArray_DATA(self.mins)
 *         self.raw_indices = <np.intp_t*>np.PyArray_DATA(self.indices)
 */
  __pyx_t_10 = ((PyObject *)__pyx_v_self->maxes);
  __Pyx_INCREF(__pyx_t_10);
  __pyx_v_self->raw_maxes = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_10)));
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "pyart/map/ckdtree.pyx":856
 *         self.raw_data = <np.float64_t*>np.PyArray_DATA(self.data)
 *         self.raw_maxes = <np.float64_t*>np.PyArray_DATA(self.maxes)
 *         self.raw_mins = <np.float64_t*>np.PyArray_DATA(self.mins)             # <<<<<<<<<<<<<<
 *         self.raw_indices = <np.intp_t*>np.PyArray_DATA(self.indices)
 * 
 */
  __pyx_t_10 = ((PyObject *)__pyx_v_self->mins);
  __Pyx_INCREF(__pyx_t_10);
  __pyx_v_self->raw_mins = ((__pyx_t_5numpy_float64_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_10)));
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "pyart/map/ckdtree.pyx":857
 *         self.raw_maxes = <np.float64_t*>np.PyArray_DATA(self.maxes)
 *         self.raw_mins = <np.float64_t*>np.PyArray_DATA(self.mins)
 *         self.raw_indices = <np.intp_t*>np.PyArray_DATA(self.indices)             # <<<<<<<<<<<<<<
 * 
 *         self.tree = self.__build(0, self.n, self.raw_maxes, self.raw_mins)
 */
  __pyx_t_10 = ((PyObject *)__pyx_v_self->indices);
  __Pyx_INCREF(__pyx_t_10);
  __pyx_v_self->raw_indices = ((__pyx_t_5numpy_intp_t *)PyArray_DATA(((PyArrayObject *)__pyx_t_10)));
  __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;

  /* "pyart/map/ckdtree.pyx":859
 *         self.raw_indices = <np.intp_t*>np.PyArray_DATA(self.indices)
 * 
 *         self.tree = self.__build(0, self.n, self.raw_maxes, self.raw_mins)             # <<<<<<<<<<<<<<
 * 
 *     cdef innernode* __build(cKDTree self, np.intp_t start_idx, np.intp_t end_idx,
 */
  __pyx_t_11 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___build(__pyx_v_self, 0, __pyx_v_self->n, __pyx_v_self->raw_maxes, __pyx_v_self->raw_mins); if (unlikely(__pyx_t_11 == ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)NULL) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_v_self->tree = __pyx_t_11;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":861
 *         self.tree = self.__build(0, self.n, self.raw_maxes, self.raw_mins)
 * 
 *     cdef innernode* __build(cKDTree self, np.intp_t start_idx, np.intp_t end_idx,             # <<<<<<<<<<<<<<
 *                             np.float64_t* maxes, np.float64_t* mins) except? <innernode*> NULL:
 *         cdef leafnode* n
 */

static struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_f_5pyart_3map_7ckdtree_7cKDTree___build(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, __pyx_t_5numpy_intp_t __pyx_v_start_idx, __pyx_t_5numpy_intp_t __pyx_v_end_idx, __pyx_t_5numpy_float64_t *__pyx_v_maxes, __pyx_t_5numpy_float64_t *__pyx_v_mins) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_n;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_ni;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  __pyx_t_5numpy_intp_t __pyx_v_t;
  __pyx_t_5numpy_intp_t __pyx_v_p;
  __pyx_t_5numpy_intp_t __pyx_v_q;
  __pyx_t_5numpy_intp_t __pyx_v_d;
  __pyx_t_5numpy_float64_t __pyx_v_size;
  __pyx_t_5numpy_float64_t __pyx_v_split;
  __pyx_t_5numpy_float64_t __pyx_v_minval;
  __pyx_t_5numpy_float64_t __pyx_v_maxval;
  __pyx_t_5numpy_float64_t *__pyx_v_mids;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  long __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__build", 0);

  /* "pyart/map/ckdtree.pyx":868
 *         cdef np.float64_t size, split, minval, maxval
 *         cdef np.float64_t*mids
 *         if end_idx-start_idx<=self.leafsize:             # <<<<<<<<<<<<<<
 *             n = <leafnode*>stdlib.malloc(sizeof(leafnode))
 *             if n == <leafnode*> NULL:
 */
  __pyx_t_1 = ((__pyx_v_end_idx - __pyx_v_start_idx) <= __pyx_v_self->leafsize);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":869
 *         cdef np.float64_t*mids
 *         if end_idx-start_idx<=self.leafsize:
 *             n = <leafnode*>stdlib.malloc(sizeof(leafnode))             # <<<<<<<<<<<<<<
 *             if n == <leafnode*> NULL:
 *                 raise MemoryError
 */
    __pyx_v_n = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)malloc((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_leafnode))));

    /* "pyart/map/ckdtree.pyx":870
 *         if end_idx-start_idx<=self.leafsize:
 *             n = <leafnode*>stdlib.malloc(sizeof(leafnode))
 *             if n == <leafnode*> NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             n.split_dim = -1
 */
    __pyx_t_1 = (__pyx_v_n == ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)NULL));
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":871
 *             n = <leafnode*>stdlib.malloc(sizeof(leafnode))
 *             if n == <leafnode*> NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             n.split_dim = -1
 *             n.children = end_idx - start_idx
 */
      PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 871; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L4;
    }
    __pyx_L4:;

    /* "pyart/map/ckdtree.pyx":872
 *             if n == <leafnode*> NULL:
 *                 raise MemoryError
 *             n.split_dim = -1             # <<<<<<<<<<<<<<
 *             n.children = end_idx - start_idx
 *             n.start_idx = start_idx
 */
    __pyx_v_n->split_dim = -1;

    /* "pyart/map/ckdtree.pyx":873
 *                 raise MemoryError
 *             n.split_dim = -1
 *             n.children = end_idx - start_idx             # <<<<<<<<<<<<<<
 *             n.start_idx = start_idx
 *             n.end_idx = end_idx
 */
    __pyx_v_n->children = (__pyx_v_end_idx - __pyx_v_start_idx);

    /* "pyart/map/ckdtree.pyx":874
 *             n.split_dim = -1
 *             n.children = end_idx - start_idx
 *             n.start_idx = start_idx             # <<<<<<<<<<<<<<
 *             n.end_idx = end_idx
 *             return <innernode*>n
 */
    __pyx_v_n->start_idx = __pyx_v_start_idx;

    /* "pyart/map/ckdtree.pyx":875
 *             n.children = end_idx - start_idx
 *             n.start_idx = start_idx
 *             n.end_idx = end_idx             # <<<<<<<<<<<<<<
 *             return <innernode*>n
 *         else:
 */
    __pyx_v_n->end_idx = __pyx_v_end_idx;

    /* "pyart/map/ckdtree.pyx":876
 *             n.start_idx = start_idx
 *             n.end_idx = end_idx
 *             return <innernode*>n             # <<<<<<<<<<<<<<
 *         else:
 *             d = 0
 */
    __pyx_r = ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)__pyx_v_n);
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":878
 *             return <innernode*>n
 *         else:
 *             d = 0             # <<<<<<<<<<<<<<
 *             size = 0
 *             for i in range(self.m):
 */
    __pyx_v_d = 0;

    /* "pyart/map/ckdtree.pyx":879
 *         else:
 *             d = 0
 *             size = 0             # <<<<<<<<<<<<<<
 *             for i in range(self.m):
 *                 if maxes[i]-mins[i] > size:
 */
    __pyx_v_size = 0.0;

    /* "pyart/map/ckdtree.pyx":880
 *             d = 0
 *             size = 0
 *             for i in range(self.m):             # <<<<<<<<<<<<<<
 *                 if maxes[i]-mins[i] > size:
 *                     d = i
 */
    __pyx_t_2 = __pyx_v_self->m;
    for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "pyart/map/ckdtree.pyx":881
 *             size = 0
 *             for i in range(self.m):
 *                 if maxes[i]-mins[i] > size:             # <<<<<<<<<<<<<<
 *                     d = i
 *                     size =  maxes[i]-mins[i]
 */
      __pyx_t_1 = (((__pyx_v_maxes[__pyx_v_i]) - (__pyx_v_mins[__pyx_v_i])) > __pyx_v_size);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":882
 *             for i in range(self.m):
 *                 if maxes[i]-mins[i] > size:
 *                     d = i             # <<<<<<<<<<<<<<
 *                     size =  maxes[i]-mins[i]
 *             maxval = maxes[d]
 */
        __pyx_v_d = __pyx_v_i;

        /* "pyart/map/ckdtree.pyx":883
 *                 if maxes[i]-mins[i] > size:
 *                     d = i
 *                     size =  maxes[i]-mins[i]             # <<<<<<<<<<<<<<
 *             maxval = maxes[d]
 *             minval = mins[d]
 */
        __pyx_v_size = ((__pyx_v_maxes[__pyx_v_i]) - (__pyx_v_mins[__pyx_v_i]));
        goto __pyx_L7;
      }
      __pyx_L7:;
    }

    /* "pyart/map/ckdtree.pyx":884
 *                     d = i
 *                     size =  maxes[i]-mins[i]
 *             maxval = maxes[d]             # <<<<<<<<<<<<<<
 *             minval = mins[d]
 *             if maxval==minval:
 */
    __pyx_v_maxval = (__pyx_v_maxes[__pyx_v_d]);

    /* "pyart/map/ckdtree.pyx":885
 *                     size =  maxes[i]-mins[i]
 *             maxval = maxes[d]
 *             minval = mins[d]             # <<<<<<<<<<<<<<
 *             if maxval==minval:
 *                 # all points are identical; warn user?
 */
    __pyx_v_minval = (__pyx_v_mins[__pyx_v_d]);

    /* "pyart/map/ckdtree.pyx":886
 *             maxval = maxes[d]
 *             minval = mins[d]
 *             if maxval==minval:             # <<<<<<<<<<<<<<
 *                 # all points are identical; warn user?
 *                 n = <leafnode*>stdlib.malloc(sizeof(leafnode))
 */
    __pyx_t_1 = (__pyx_v_maxval == __pyx_v_minval);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":888
 *             if maxval==minval:
 *                 # all points are identical; warn user?
 *                 n = <leafnode*>stdlib.malloc(sizeof(leafnode))             # <<<<<<<<<<<<<<
 *                 if n == <leafnode*> NULL:
 *                     raise MemoryError
 */
      __pyx_v_n = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)malloc((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_leafnode))));

      /* "pyart/map/ckdtree.pyx":889
 *                 # all points are identical; warn user?
 *                 n = <leafnode*>stdlib.malloc(sizeof(leafnode))
 *                 if n == <leafnode*> NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 *                 n.split_dim = -1
 */
      __pyx_t_1 = (__pyx_v_n == ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)NULL));
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":890
 *                 n = <leafnode*>stdlib.malloc(sizeof(leafnode))
 *                 if n == <leafnode*> NULL:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 *                 n.split_dim = -1
 *                 n.children = end_idx - start_idx
 */
        PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 890; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L9;
      }
      __pyx_L9:;

      /* "pyart/map/ckdtree.pyx":891
 *                 if n == <leafnode*> NULL:
 *                     raise MemoryError
 *                 n.split_dim = -1             # <<<<<<<<<<<<<<
 *                 n.children = end_idx - start_idx
 *                 n.start_idx = start_idx
 */
      __pyx_v_n->split_dim = -1;

      /* "pyart/map/ckdtree.pyx":892
 *                     raise MemoryError
 *                 n.split_dim = -1
 *                 n.children = end_idx - start_idx             # <<<<<<<<<<<<<<
 *                 n.start_idx = start_idx
 *                 n.end_idx = end_idx
 */
      __pyx_v_n->children = (__pyx_v_end_idx - __pyx_v_start_idx);

      /* "pyart/map/ckdtree.pyx":893
 *                 n.split_dim = -1
 *                 n.children = end_idx - start_idx
 *                 n.start_idx = start_idx             # <<<<<<<<<<<<<<
 *                 n.end_idx = end_idx
 *                 return <innernode*>n
 */
      __pyx_v_n->start_idx = __pyx_v_start_idx;

      /* "pyart/map/ckdtree.pyx":894
 *                 n.children = end_idx - start_idx
 *                 n.start_idx = start_idx
 *                 n.end_idx = end_idx             # <<<<<<<<<<<<<<
 *                 return <innernode*>n
 * 
 */
      __pyx_v_n->end_idx = __pyx_v_end_idx;

      /* "pyart/map/ckdtree.pyx":895
 *                 n.start_idx = start_idx
 *                 n.end_idx = end_idx
 *                 return <innernode*>n             # <<<<<<<<<<<<<<
 * 
 *             split = (maxval+minval)/2
 */
      __pyx_r = ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)__pyx_v_n);
      goto __pyx_L0;
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "pyart/map/ckdtree.pyx":897
 *                 return <innernode*>n
 * 
 *             split = (maxval+minval)/2             # <<<<<<<<<<<<<<
 * 
 *             p = start_idx
 */
    __pyx_v_split = ((__pyx_v_maxval + __pyx_v_minval) / 2.0);

    /* "pyart/map/ckdtree.pyx":899
 *             split = (maxval+minval)/2
 * 
 *             p = start_idx             # <<<<<<<<<<<<<<
 *             q = end_idx-1
 *             while p<=q:
 */
    __pyx_v_p = __pyx_v_start_idx;

    /* "pyart/map/ckdtree.pyx":900
 * 
 *             p = start_idx
 *             q = end_idx-1             # <<<<<<<<<<<<<<
 *             while p<=q:
 *                 if self.raw_data[self.raw_indices[p]*self.m+d]<split:
 */
    __pyx_v_q = (__pyx_v_end_idx - 1);

    /* "pyart/map/ckdtree.pyx":901
 *             p = start_idx
 *             q = end_idx-1
 *             while p<=q:             # <<<<<<<<<<<<<<
 *                 if self.raw_data[self.raw_indices[p]*self.m+d]<split:
 *                     p+=1
 */
    while (1) {
      __pyx_t_1 = (__pyx_v_p <= __pyx_v_q);
      if (!__pyx_t_1) break;

      /* "pyart/map/ckdtree.pyx":902
 *             q = end_idx-1
 *             while p<=q:
 *                 if self.raw_data[self.raw_indices[p]*self.m+d]<split:             # <<<<<<<<<<<<<<
 *                     p+=1
 *                 elif self.raw_data[self.raw_indices[q]*self.m+d]>=split:
 */
      __pyx_t_1 = ((__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_p]) * __pyx_v_self->m) + __pyx_v_d)]) < __pyx_v_split);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":903
 *             while p<=q:
 *                 if self.raw_data[self.raw_indices[p]*self.m+d]<split:
 *                     p+=1             # <<<<<<<<<<<<<<
 *                 elif self.raw_data[self.raw_indices[q]*self.m+d]>=split:
 *                     q-=1
 */
        __pyx_v_p = (__pyx_v_p + 1);
        goto __pyx_L12;
      }

      /* "pyart/map/ckdtree.pyx":904
 *                 if self.raw_data[self.raw_indices[p]*self.m+d]<split:
 *                     p+=1
 *                 elif self.raw_data[self.raw_indices[q]*self.m+d]>=split:             # <<<<<<<<<<<<<<
 *                     q-=1
 *                 else:
 */
      __pyx_t_1 = ((__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_q]) * __pyx_v_self->m) + __pyx_v_d)]) >= __pyx_v_split);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":905
 *                     p+=1
 *                 elif self.raw_data[self.raw_indices[q]*self.m+d]>=split:
 *                     q-=1             # <<<<<<<<<<<<<<
 *                 else:
 *                     t = self.raw_indices[p]
 */
        __pyx_v_q = (__pyx_v_q - 1);
        goto __pyx_L12;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":907
 *                     q-=1
 *                 else:
 *                     t = self.raw_indices[p]             # <<<<<<<<<<<<<<
 *                     self.raw_indices[p] = self.raw_indices[q]
 *                     self.raw_indices[q] = t
 */
        __pyx_v_t = (__pyx_v_self->raw_indices[__pyx_v_p]);

        /* "pyart/map/ckdtree.pyx":908
 *                 else:
 *                     t = self.raw_indices[p]
 *                     self.raw_indices[p] = self.raw_indices[q]             # <<<<<<<<<<<<<<
 *                     self.raw_indices[q] = t
 *                     p+=1
 */
        (__pyx_v_self->raw_indices[__pyx_v_p]) = (__pyx_v_self->raw_indices[__pyx_v_q]);

        /* "pyart/map/ckdtree.pyx":909
 *                     t = self.raw_indices[p]
 *                     self.raw_indices[p] = self.raw_indices[q]
 *                     self.raw_indices[q] = t             # <<<<<<<<<<<<<<
 *                     p+=1
 *                     q-=1
 */
        (__pyx_v_self->raw_indices[__pyx_v_q]) = __pyx_v_t;

        /* "pyart/map/ckdtree.pyx":910
 *                     self.raw_indices[p] = self.raw_indices[q]
 *                     self.raw_indices[q] = t
 *                     p+=1             # <<<<<<<<<<<<<<
 *                     q-=1
 * 
 */
        __pyx_v_p = (__pyx_v_p + 1);

        /* "pyart/map/ckdtree.pyx":911
 *                     self.raw_indices[q] = t
 *                     p+=1
 *                     q-=1             # <<<<<<<<<<<<<<
 * 
 *             # slide midpoint if necessary
 */
        __pyx_v_q = (__pyx_v_q - 1);
      }
      __pyx_L12:;
    }

    /* "pyart/map/ckdtree.pyx":914
 * 
 *             # slide midpoint if necessary
 *             if p==start_idx:             # <<<<<<<<<<<<<<
 *                 # no points less than split
 *                 j = start_idx
 */
    __pyx_t_1 = (__pyx_v_p == __pyx_v_start_idx);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":916
 *             if p==start_idx:
 *                 # no points less than split
 *                 j = start_idx             # <<<<<<<<<<<<<<
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 for i in range(start_idx+1, end_idx):
 */
      __pyx_v_j = __pyx_v_start_idx;

      /* "pyart/map/ckdtree.pyx":917
 *                 # no points less than split
 *                 j = start_idx
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]             # <<<<<<<<<<<<<<
 *                 for i in range(start_idx+1, end_idx):
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]<split:
 */
      __pyx_v_split = (__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_j]) * __pyx_v_self->m) + __pyx_v_d)]);

      /* "pyart/map/ckdtree.pyx":918
 *                 j = start_idx
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 for i in range(start_idx+1, end_idx):             # <<<<<<<<<<<<<<
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]<split:
 *                         j = i
 */
      __pyx_t_2 = __pyx_v_end_idx;
      for (__pyx_t_3 = (__pyx_v_start_idx + 1); __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
        __pyx_v_i = __pyx_t_3;

        /* "pyart/map/ckdtree.pyx":919
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 for i in range(start_idx+1, end_idx):
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]<split:             # <<<<<<<<<<<<<<
 *                         j = i
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 */
        __pyx_t_1 = ((__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m) + __pyx_v_d)]) < __pyx_v_split);
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":920
 *                 for i in range(start_idx+1, end_idx):
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]<split:
 *                         j = i             # <<<<<<<<<<<<<<
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 t = self.raw_indices[start_idx]
 */
          __pyx_v_j = __pyx_v_i;

          /* "pyart/map/ckdtree.pyx":921
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]<split:
 *                         j = i
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]             # <<<<<<<<<<<<<<
 *                 t = self.raw_indices[start_idx]
 *                 self.raw_indices[start_idx] = self.raw_indices[j]
 */
          __pyx_v_split = (__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_j]) * __pyx_v_self->m) + __pyx_v_d)]);
          goto __pyx_L16;
        }
        __pyx_L16:;
      }

      /* "pyart/map/ckdtree.pyx":922
 *                         j = i
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 t = self.raw_indices[start_idx]             # <<<<<<<<<<<<<<
 *                 self.raw_indices[start_idx] = self.raw_indices[j]
 *                 self.raw_indices[j] = t
 */
      __pyx_v_t = (__pyx_v_self->raw_indices[__pyx_v_start_idx]);

      /* "pyart/map/ckdtree.pyx":923
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 t = self.raw_indices[start_idx]
 *                 self.raw_indices[start_idx] = self.raw_indices[j]             # <<<<<<<<<<<<<<
 *                 self.raw_indices[j] = t
 *                 p = start_idx+1
 */
      (__pyx_v_self->raw_indices[__pyx_v_start_idx]) = (__pyx_v_self->raw_indices[__pyx_v_j]);

      /* "pyart/map/ckdtree.pyx":924
 *                 t = self.raw_indices[start_idx]
 *                 self.raw_indices[start_idx] = self.raw_indices[j]
 *                 self.raw_indices[j] = t             # <<<<<<<<<<<<<<
 *                 p = start_idx+1
 *                 q = start_idx
 */
      (__pyx_v_self->raw_indices[__pyx_v_j]) = __pyx_v_t;

      /* "pyart/map/ckdtree.pyx":925
 *                 self.raw_indices[start_idx] = self.raw_indices[j]
 *                 self.raw_indices[j] = t
 *                 p = start_idx+1             # <<<<<<<<<<<<<<
 *                 q = start_idx
 *             elif p==end_idx:
 */
      __pyx_v_p = (__pyx_v_start_idx + 1);

      /* "pyart/map/ckdtree.pyx":926
 *                 self.raw_indices[j] = t
 *                 p = start_idx+1
 *                 q = start_idx             # <<<<<<<<<<<<<<
 *             elif p==end_idx:
 *                 # no points greater than split
 */
      __pyx_v_q = __pyx_v_start_idx;
      goto __pyx_L13;
    }

    /* "pyart/map/ckdtree.pyx":927
 *                 p = start_idx+1
 *                 q = start_idx
 *             elif p==end_idx:             # <<<<<<<<<<<<<<
 *                 # no points greater than split
 *                 j = end_idx-1
 */
    __pyx_t_1 = (__pyx_v_p == __pyx_v_end_idx);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":929
 *             elif p==end_idx:
 *                 # no points greater than split
 *                 j = end_idx-1             # <<<<<<<<<<<<<<
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 for i in range(start_idx, end_idx-1):
 */
      __pyx_v_j = (__pyx_v_end_idx - 1);

      /* "pyart/map/ckdtree.pyx":930
 *                 # no points greater than split
 *                 j = end_idx-1
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]             # <<<<<<<<<<<<<<
 *                 for i in range(start_idx, end_idx-1):
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]>split:
 */
      __pyx_v_split = (__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_j]) * __pyx_v_self->m) + __pyx_v_d)]);

      /* "pyart/map/ckdtree.pyx":931
 *                 j = end_idx-1
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 for i in range(start_idx, end_idx-1):             # <<<<<<<<<<<<<<
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]>split:
 *                         j = i
 */
      __pyx_t_4 = (__pyx_v_end_idx - 1);
      for (__pyx_t_2 = __pyx_v_start_idx; __pyx_t_2 < __pyx_t_4; __pyx_t_2+=1) {
        __pyx_v_i = __pyx_t_2;

        /* "pyart/map/ckdtree.pyx":932
 *                 split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 for i in range(start_idx, end_idx-1):
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]>split:             # <<<<<<<<<<<<<<
 *                         j = i
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 */
        __pyx_t_1 = ((__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m) + __pyx_v_d)]) > __pyx_v_split);
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":933
 *                 for i in range(start_idx, end_idx-1):
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]>split:
 *                         j = i             # <<<<<<<<<<<<<<
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 t = self.raw_indices[end_idx-1]
 */
          __pyx_v_j = __pyx_v_i;

          /* "pyart/map/ckdtree.pyx":934
 *                     if self.raw_data[self.raw_indices[i]*self.m+d]>split:
 *                         j = i
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]             # <<<<<<<<<<<<<<
 *                 t = self.raw_indices[end_idx-1]
 *                 self.raw_indices[end_idx-1] = self.raw_indices[j]
 */
          __pyx_v_split = (__pyx_v_self->raw_data[(((__pyx_v_self->raw_indices[__pyx_v_j]) * __pyx_v_self->m) + __pyx_v_d)]);
          goto __pyx_L19;
        }
        __pyx_L19:;
      }

      /* "pyart/map/ckdtree.pyx":935
 *                         j = i
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 t = self.raw_indices[end_idx-1]             # <<<<<<<<<<<<<<
 *                 self.raw_indices[end_idx-1] = self.raw_indices[j]
 *                 self.raw_indices[j] = t
 */
      __pyx_v_t = (__pyx_v_self->raw_indices[(__pyx_v_end_idx - 1)]);

      /* "pyart/map/ckdtree.pyx":936
 *                         split = self.raw_data[self.raw_indices[j]*self.m+d]
 *                 t = self.raw_indices[end_idx-1]
 *                 self.raw_indices[end_idx-1] = self.raw_indices[j]             # <<<<<<<<<<<<<<
 *                 self.raw_indices[j] = t
 *                 p = end_idx-1
 */
      (__pyx_v_self->raw_indices[(__pyx_v_end_idx - 1)]) = (__pyx_v_self->raw_indices[__pyx_v_j]);

      /* "pyart/map/ckdtree.pyx":937
 *                 t = self.raw_indices[end_idx-1]
 *                 self.raw_indices[end_idx-1] = self.raw_indices[j]
 *                 self.raw_indices[j] = t             # <<<<<<<<<<<<<<
 *                 p = end_idx-1
 *                 q = end_idx-2
 */
      (__pyx_v_self->raw_indices[__pyx_v_j]) = __pyx_v_t;

      /* "pyart/map/ckdtree.pyx":938
 *                 self.raw_indices[end_idx-1] = self.raw_indices[j]
 *                 self.raw_indices[j] = t
 *                 p = end_idx-1             # <<<<<<<<<<<<<<
 *                 q = end_idx-2
 * 
 */
      __pyx_v_p = (__pyx_v_end_idx - 1);

      /* "pyart/map/ckdtree.pyx":939
 *                 self.raw_indices[j] = t
 *                 p = end_idx-1
 *                 q = end_idx-2             # <<<<<<<<<<<<<<
 * 
 *             # construct new node representation
 */
      __pyx_v_q = (__pyx_v_end_idx - 2);
      goto __pyx_L13;
    }
    __pyx_L13:;

    /* "pyart/map/ckdtree.pyx":942
 * 
 *             # construct new node representation
 *             ni = <innernode*>stdlib.malloc(sizeof(innernode))             # <<<<<<<<<<<<<<
 *             if ni ==  <innernode*> NULL:
 *                 raise MemoryError
 */
    __pyx_v_ni = ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)malloc((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_innernode))));

    /* "pyart/map/ckdtree.pyx":943
 *             # construct new node representation
 *             ni = <innernode*>stdlib.malloc(sizeof(innernode))
 *             if ni ==  <innernode*> NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 * 
 */
    __pyx_t_1 = (__pyx_v_ni == ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)NULL));
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":944
 *             ni = <innernode*>stdlib.malloc(sizeof(innernode))
 *             if ni ==  <innernode*> NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 * 
 *             try:
 */
      PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L20;
    }
    __pyx_L20:;

    /* "pyart/map/ckdtree.pyx":946
 *                 raise MemoryError
 * 
 *             try:             # <<<<<<<<<<<<<<
 *                 mids = <np.float64_t*>stdlib.malloc(sizeof(np.float64_t)*self.m)
 *                 if mids == <np.float64_t*> NULL:
 */
    {
      __Pyx_ExceptionSave(&__pyx_t_5, &__pyx_t_6, &__pyx_t_7);
      __Pyx_XGOTREF(__pyx_t_5);
      __Pyx_XGOTREF(__pyx_t_6);
      __Pyx_XGOTREF(__pyx_t_7);
      /*try:*/ {

        /* "pyart/map/ckdtree.pyx":947
 * 
 *             try:
 *                 mids = <np.float64_t*>stdlib.malloc(sizeof(np.float64_t)*self.m)             # <<<<<<<<<<<<<<
 *                 if mids == <np.float64_t*> NULL:
 *                     raise MemoryError
 */
        __pyx_v_mids = ((__pyx_t_5numpy_float64_t *)malloc(((sizeof(__pyx_t_5numpy_float64_t)) * __pyx_v_self->m)));

        /* "pyart/map/ckdtree.pyx":948
 *             try:
 *                 mids = <np.float64_t*>stdlib.malloc(sizeof(np.float64_t)*self.m)
 *                 if mids == <np.float64_t*> NULL:             # <<<<<<<<<<<<<<
 *                     raise MemoryError
 * 
 */
        __pyx_t_1 = (__pyx_v_mids == ((__pyx_t_5numpy_float64_t *)NULL));
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":949
 *                 mids = <np.float64_t*>stdlib.malloc(sizeof(np.float64_t)*self.m)
 *                 if mids == <np.float64_t*> NULL:
 *                     raise MemoryError             # <<<<<<<<<<<<<<
 * 
 *                 for i in range(self.m):
 */
          PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 949; __pyx_clineno = __LINE__; goto __pyx_L21_error;}
          goto __pyx_L29;
        }
        __pyx_L29:;

        /* "pyart/map/ckdtree.pyx":951
 *                     raise MemoryError
 * 
 *                 for i in range(self.m):             # <<<<<<<<<<<<<<
 *                     mids[i] = maxes[i]
 *                 mids[d] = split
 */
        __pyx_t_2 = __pyx_v_self->m;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pyart/map/ckdtree.pyx":952
 * 
 *                 for i in range(self.m):
 *                     mids[i] = maxes[i]             # <<<<<<<<<<<<<<
 *                 mids[d] = split
 *                 ni.less = self.__build(start_idx,p,mids,mins)
 */
          (__pyx_v_mids[__pyx_v_i]) = (__pyx_v_maxes[__pyx_v_i]);
        }

        /* "pyart/map/ckdtree.pyx":953
 *                 for i in range(self.m):
 *                     mids[i] = maxes[i]
 *                 mids[d] = split             # <<<<<<<<<<<<<<
 *                 ni.less = self.__build(start_idx,p,mids,mins)
 * 
 */
        (__pyx_v_mids[__pyx_v_d]) = __pyx_v_split;

        /* "pyart/map/ckdtree.pyx":954
 *                     mids[i] = maxes[i]
 *                 mids[d] = split
 *                 ni.less = self.__build(start_idx,p,mids,mins)             # <<<<<<<<<<<<<<
 * 
 *                 for i in range(self.m):
 */
        __pyx_t_8 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___build(__pyx_v_self, __pyx_v_start_idx, __pyx_v_p, __pyx_v_mids, __pyx_v_mins); if (unlikely(__pyx_t_8 == ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)NULL) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 954; __pyx_clineno = __LINE__; goto __pyx_L21_error;}
        __pyx_v_ni->less = __pyx_t_8;

        /* "pyart/map/ckdtree.pyx":956
 *                 ni.less = self.__build(start_idx,p,mids,mins)
 * 
 *                 for i in range(self.m):             # <<<<<<<<<<<<<<
 *                     mids[i] = mins[i]
 *                 mids[d] = split
 */
        __pyx_t_2 = __pyx_v_self->m;
        for (__pyx_t_3 = 0; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
          __pyx_v_i = __pyx_t_3;

          /* "pyart/map/ckdtree.pyx":957
 * 
 *                 for i in range(self.m):
 *                     mids[i] = mins[i]             # <<<<<<<<<<<<<<
 *                 mids[d] = split
 *                 ni.greater = self.__build(p,end_idx,maxes,mids)
 */
          (__pyx_v_mids[__pyx_v_i]) = (__pyx_v_mins[__pyx_v_i]);
        }

        /* "pyart/map/ckdtree.pyx":958
 *                 for i in range(self.m):
 *                     mids[i] = mins[i]
 *                 mids[d] = split             # <<<<<<<<<<<<<<
 *                 ni.greater = self.__build(p,end_idx,maxes,mids)
 * 
 */
        (__pyx_v_mids[__pyx_v_d]) = __pyx_v_split;

        /* "pyart/map/ckdtree.pyx":959
 *                     mids[i] = mins[i]
 *                 mids[d] = split
 *                 ni.greater = self.__build(p,end_idx,maxes,mids)             # <<<<<<<<<<<<<<
 * 
 *                 ni.children = ni.less.children + ni.greater.children
 */
        __pyx_t_8 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___build(__pyx_v_self, __pyx_v_p, __pyx_v_end_idx, __pyx_v_maxes, __pyx_v_mids); if (unlikely(__pyx_t_8 == ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)NULL) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 959; __pyx_clineno = __LINE__; goto __pyx_L21_error;}
        __pyx_v_ni->greater = __pyx_t_8;

        /* "pyart/map/ckdtree.pyx":961
 *                 ni.greater = self.__build(p,end_idx,maxes,mids)
 * 
 *                 ni.children = ni.less.children + ni.greater.children             # <<<<<<<<<<<<<<
 * 
 *             except:
 */
        __pyx_v_ni->children = (__pyx_v_ni->less->children + __pyx_v_ni->greater->children);
      }
      /*else:*/ {

        /* "pyart/map/ckdtree.pyx":971
 *                 raise
 *             else:
 *                 if mids != <np.float64_t*> NULL:             # <<<<<<<<<<<<<<
 *                     stdlib.free(mids)
 * 
 */
        __pyx_t_1 = (__pyx_v_mids != ((__pyx_t_5numpy_float64_t *)NULL));
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":972
 *             else:
 *                 if mids != <np.float64_t*> NULL:
 *                     stdlib.free(mids)             # <<<<<<<<<<<<<<
 * 
 *             ni.split_dim = d
 */
          free(__pyx_v_mids);
          goto __pyx_L34;
        }
        __pyx_L34:;
      }
      __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
      __Pyx_XDECREF(__pyx_t_6); __pyx_t_6 = 0;
      __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
      goto __pyx_L28_try_end;
      __pyx_L21_error:;

      /* "pyart/map/ckdtree.pyx":963
 *                 ni.children = ni.less.children + ni.greater.children
 * 
 *             except:             # <<<<<<<<<<<<<<
 *                 # free ni if it cannot be returned
 *                 if ni !=  <innernode*> NULL:
 */
      /*except:*/ {
        __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__build", __pyx_clineno, __pyx_lineno, __pyx_filename);
        if (__Pyx_GetException(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 963; __pyx_clineno = __LINE__; goto __pyx_L23_except_error;}
        __Pyx_GOTREF(__pyx_t_9);
        __Pyx_GOTREF(__pyx_t_10);
        __Pyx_GOTREF(__pyx_t_11);

        /* "pyart/map/ckdtree.pyx":965
 *             except:
 *                 # free ni if it cannot be returned
 *                 if ni !=  <innernode*> NULL:             # <<<<<<<<<<<<<<
 *                     stdlib.free(mids)
 *                 if mids != <np.float64_t*> NULL:
 */
        __pyx_t_1 = (__pyx_v_ni != ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)NULL));
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":966
 *                 # free ni if it cannot be returned
 *                 if ni !=  <innernode*> NULL:
 *                     stdlib.free(mids)             # <<<<<<<<<<<<<<
 *                 if mids != <np.float64_t*> NULL:
 *                     stdlib.free(mids)
 */
          free(__pyx_v_mids);
          goto __pyx_L37;
        }
        __pyx_L37:;

        /* "pyart/map/ckdtree.pyx":967
 *                 if ni !=  <innernode*> NULL:
 *                     stdlib.free(mids)
 *                 if mids != <np.float64_t*> NULL:             # <<<<<<<<<<<<<<
 *                     stdlib.free(mids)
 *                 raise
 */
        __pyx_t_1 = (__pyx_v_mids != ((__pyx_t_5numpy_float64_t *)NULL));
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":968
 *                     stdlib.free(mids)
 *                 if mids != <np.float64_t*> NULL:
 *                     stdlib.free(mids)             # <<<<<<<<<<<<<<
 *                 raise
 *             else:
 */
          free(__pyx_v_mids);
          goto __pyx_L38;
        }
        __pyx_L38:;

        /* "pyart/map/ckdtree.pyx":969
 *                 if mids != <np.float64_t*> NULL:
 *                     stdlib.free(mids)
 *                 raise             # <<<<<<<<<<<<<<
 *             else:
 *                 if mids != <np.float64_t*> NULL:
 */
        __Pyx_GIVEREF(__pyx_t_9);
        __Pyx_GIVEREF(__pyx_t_10);
        __Pyx_GIVEREF(__pyx_t_11);
        __Pyx_ErrRestore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        __pyx_t_9 = 0; __pyx_t_10 = 0; __pyx_t_11 = 0; 
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 969; __pyx_clineno = __LINE__; goto __pyx_L23_except_error;}
        __Pyx_DECREF(__pyx_t_9); __pyx_t_9 = 0;
        __Pyx_DECREF(__pyx_t_10); __pyx_t_10 = 0;
        __Pyx_DECREF(__pyx_t_11); __pyx_t_11 = 0;
        goto __pyx_L22_exception_handled;
      }
      __pyx_L23_except_error:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      goto __pyx_L1_error;
      __pyx_L22_exception_handled:;
      __Pyx_XGIVEREF(__pyx_t_5);
      __Pyx_XGIVEREF(__pyx_t_6);
      __Pyx_XGIVEREF(__pyx_t_7);
      __Pyx_ExceptionReset(__pyx_t_5, __pyx_t_6, __pyx_t_7);
      __pyx_L28_try_end:;
    }

    /* "pyart/map/ckdtree.pyx":974
 *                     stdlib.free(mids)
 * 
 *             ni.split_dim = d             # <<<<<<<<<<<<<<
 *             ni.split = split
 *             return ni
 */
    __pyx_v_ni->split_dim = __pyx_v_d;

    /* "pyart/map/ckdtree.pyx":975
 * 
 *             ni.split_dim = d
 *             ni.split = split             # <<<<<<<<<<<<<<
 *             return ni
 * 
 */
    __pyx_v_ni->split = __pyx_v_split;

    /* "pyart/map/ckdtree.pyx":976
 *             ni.split_dim = d
 *             ni.split = split
 *             return ni             # <<<<<<<<<<<<<<
 * 
 *     cdef __free_tree(cKDTree self, innernode* node):
 */
    __pyx_r = __pyx_v_ni;
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_9);
  __Pyx_XDECREF(__pyx_t_10);
  __Pyx_XDECREF(__pyx_t_11);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__build", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)NULL);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":978
 *             return ni
 * 
 *     cdef __free_tree(cKDTree self, innernode* node):             # <<<<<<<<<<<<<<
 *         if node.split_dim!=-1:
 *             self.__free_tree(node.less)
 */

static PyObject *__pyx_f_5pyart_3map_7ckdtree_7cKDTree___free_tree(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__free_tree", 0);

  /* "pyart/map/ckdtree.pyx":979
 * 
 *     cdef __free_tree(cKDTree self, innernode* node):
 *         if node.split_dim!=-1:             # <<<<<<<<<<<<<<
 *             self.__free_tree(node.less)
 *             self.__free_tree(node.greater)
 */
  __pyx_t_1 = (__pyx_v_node->split_dim != -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":980
 *     cdef __free_tree(cKDTree self, innernode* node):
 *         if node.split_dim!=-1:
 *             self.__free_tree(node.less)             # <<<<<<<<<<<<<<
 *             self.__free_tree(node.greater)
 *         stdlib.free(node)
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___free_tree(__pyx_v_self, __pyx_v_node->less); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 980; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "pyart/map/ckdtree.pyx":981
 *         if node.split_dim!=-1:
 *             self.__free_tree(node.less)
 *             self.__free_tree(node.greater)             # <<<<<<<<<<<<<<
 *         stdlib.free(node)
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___free_tree(__pyx_v_self, __pyx_v_node->greater); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 981; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":982
 *             self.__free_tree(node.less)
 *             self.__free_tree(node.greater)
 *         stdlib.free(node)             # <<<<<<<<<<<<<<
 * 
 *     def __dealloc__(cKDTree self):
 */
  free(__pyx_v_node);

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__free_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static void __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_3__dealloc__(PyObject *__pyx_v_self); /*proto*/
static void __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_3__dealloc__(PyObject *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__dealloc__ (wrapper)", 0);
  __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_2__dealloc__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":984
 *         stdlib.free(node)
 * 
 *     def __dealloc__(cKDTree self):             # <<<<<<<<<<<<<<
 *         if <np.intp_t>(self.tree) == 0:
 *             # should happen only if __init__ was never called
 */

static void __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_2__dealloc__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__dealloc__", 0);

  /* "pyart/map/ckdtree.pyx":985
 * 
 *     def __dealloc__(cKDTree self):
 *         if <np.intp_t>(self.tree) == 0:             # <<<<<<<<<<<<<<
 *             # should happen only if __init__ was never called
 *             return
 */
  __pyx_t_1 = (((__pyx_t_5numpy_intp_t)__pyx_v_self->tree) == 0);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":987
 *         if <np.intp_t>(self.tree) == 0:
 *             # should happen only if __init__ was never called
 *             return             # <<<<<<<<<<<<<<
 *         self.__free_tree(self.tree)
 * 
 */
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":988
 *             # should happen only if __init__ was never called
 *             return
 *         self.__free_tree(self.tree)             # <<<<<<<<<<<<<<
 * 
 *     # -----
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___free_tree(__pyx_v_self, __pyx_v_self->tree); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 988; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__dealloc__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
}

/* "pyart/map/ckdtree.pyx":994
 *     # -----
 * 
 *     cdef int __query(cKDTree self,             # <<<<<<<<<<<<<<
 *             np.float64_t*result_distances,
 *             np.intp_t*result_indices,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___query(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, __pyx_t_5numpy_float64_t *__pyx_v_result_distances, __pyx_t_5numpy_intp_t *__pyx_v_result_indices, __pyx_t_5numpy_float64_t *__pyx_v_x, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_eps, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_distance_upper_bound) {
  struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_q = 0;
  struct __pyx_obj_5pyart_3map_7ckdtree_heap *__pyx_v_neighbors = 0;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_float64_t __pyx_v_t;
  struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *__pyx_v_inf;
  struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *__pyx_v_inf2;
  __pyx_t_5numpy_float64_t __pyx_v_d;
  __pyx_t_5numpy_float64_t __pyx_v_epsfac;
  __pyx_t_5numpy_float64_t __pyx_v_min_distance;
  __pyx_t_5numpy_float64_t __pyx_v_far_min_distance;
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_v_it;
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_v_it2;
  struct __pyx_t_5pyart_3map_7ckdtree_heapitem __pyx_v_neighbor;
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_node;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_inode;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_near;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_far;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_t_4;
  __pyx_t_5numpy_intp_t __pyx_t_5;
  __pyx_t_5numpy_intp_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  __pyx_t_5numpy_float64_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query", 0);

  /* "pyart/map/ckdtree.pyx":1027
 *         #  distances between the nearest side of the cell and the target
 *         #  the head node of the cell
 *         q = heap(12)             # <<<<<<<<<<<<<<
 * 
 *         # priority queue for the nearest neighbors
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_heap)), ((PyObject *)__pyx_k_tuple_6), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1027; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_q = ((struct __pyx_obj_5pyart_3map_7ckdtree_heap *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1032
 *         # furthest known neighbor first
 *         # entries are (-distance**p, i)
 *         neighbors = heap(k)             # <<<<<<<<<<<<<<
 * 
 *         inf = inf2 = <nodeinfo*> NULL
 */
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_heap)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1032; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_v_neighbors = ((struct __pyx_obj_5pyart_3map_7ckdtree_heap *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1034
 *         neighbors = heap(k)
 * 
 *         inf = inf2 = <nodeinfo*> NULL             # <<<<<<<<<<<<<<
 * 
 *         try:
 */
  __pyx_v_inf = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL);
  __pyx_v_inf2 = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL);

  /* "pyart/map/ckdtree.pyx":1036
 *         inf = inf2 = <nodeinfo*> NULL
 * 
 *         try:             # <<<<<<<<<<<<<<
 *             # set up first nodeinfo
 *             inf = <nodeinfo*>stdlib.malloc(sizeof(nodeinfo)+self.m*sizeof(np.float64_t))
 */
  /*try:*/ {

    /* "pyart/map/ckdtree.pyx":1038
 *         try:
 *             # set up first nodeinfo
 *             inf = <nodeinfo*>stdlib.malloc(sizeof(nodeinfo)+self.m*sizeof(np.float64_t))             # <<<<<<<<<<<<<<
 *             if inf == <nodeinfo*> NULL:
 *                 raise MemoryError
 */
    __pyx_v_inf = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)malloc(((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo)) + (__pyx_v_self->m * (sizeof(__pyx_t_5numpy_float64_t))))));

    /* "pyart/map/ckdtree.pyx":1039
 *             # set up first nodeinfo
 *             inf = <nodeinfo*>stdlib.malloc(sizeof(nodeinfo)+self.m*sizeof(np.float64_t))
 *             if inf == <nodeinfo*> NULL:             # <<<<<<<<<<<<<<
 *                 raise MemoryError
 *             inf.node = self.tree
 */
    __pyx_t_3 = (__pyx_v_inf == ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL));
    if (__pyx_t_3) {

      /* "pyart/map/ckdtree.pyx":1040
 *             inf = <nodeinfo*>stdlib.malloc(sizeof(nodeinfo)+self.m*sizeof(np.float64_t))
 *             if inf == <nodeinfo*> NULL:
 *                 raise MemoryError             # <<<<<<<<<<<<<<
 *             inf.node = self.tree
 *             for i in range(self.m):
 */
      PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1040; __pyx_clineno = __LINE__; goto __pyx_L4;}
      goto __pyx_L6;
    }
    __pyx_L6:;

    /* "pyart/map/ckdtree.pyx":1041
 *             if inf == <nodeinfo*> NULL:
 *                 raise MemoryError
 *             inf.node = self.tree             # <<<<<<<<<<<<<<
 *             for i in range(self.m):
 *                 inf.side_distances[i] = 0
 */
    __pyx_t_4 = __pyx_v_self->tree;
    __pyx_v_inf->node = __pyx_t_4;

    /* "pyart/map/ckdtree.pyx":1042
 *                 raise MemoryError
 *             inf.node = self.tree
 *             for i in range(self.m):             # <<<<<<<<<<<<<<
 *                 inf.side_distances[i] = 0
 *                 t = x[i]-self.raw_maxes[i]
 */
    __pyx_t_5 = __pyx_v_self->m;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "pyart/map/ckdtree.pyx":1043
 *             inf.node = self.tree
 *             for i in range(self.m):
 *                 inf.side_distances[i] = 0             # <<<<<<<<<<<<<<
 *                 t = x[i]-self.raw_maxes[i]
 *                 if t>inf.side_distances[i]:
 */
      (__pyx_v_inf->side_distances[__pyx_v_i]) = 0.0;

      /* "pyart/map/ckdtree.pyx":1044
 *             for i in range(self.m):
 *                 inf.side_distances[i] = 0
 *                 t = x[i]-self.raw_maxes[i]             # <<<<<<<<<<<<<<
 *                 if t>inf.side_distances[i]:
 *                     inf.side_distances[i] = t
 */
      __pyx_v_t = ((__pyx_v_x[__pyx_v_i]) - (__pyx_v_self->raw_maxes[__pyx_v_i]));

      /* "pyart/map/ckdtree.pyx":1045
 *                 inf.side_distances[i] = 0
 *                 t = x[i]-self.raw_maxes[i]
 *                 if t>inf.side_distances[i]:             # <<<<<<<<<<<<<<
 *                     inf.side_distances[i] = t
 *                 else:
 */
      __pyx_t_3 = (__pyx_v_t > (__pyx_v_inf->side_distances[__pyx_v_i]));
      if (__pyx_t_3) {

        /* "pyart/map/ckdtree.pyx":1046
 *                 t = x[i]-self.raw_maxes[i]
 *                 if t>inf.side_distances[i]:
 *                     inf.side_distances[i] = t             # <<<<<<<<<<<<<<
 *                 else:
 *                     t = self.raw_mins[i]-x[i]
 */
        (__pyx_v_inf->side_distances[__pyx_v_i]) = __pyx_v_t;
        goto __pyx_L9;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1048
 *                     inf.side_distances[i] = t
 *                 else:
 *                     t = self.raw_mins[i]-x[i]             # <<<<<<<<<<<<<<
 *                     if t>inf.side_distances[i]:
 *                         inf.side_distances[i] = t
 */
        __pyx_v_t = ((__pyx_v_self->raw_mins[__pyx_v_i]) - (__pyx_v_x[__pyx_v_i]));

        /* "pyart/map/ckdtree.pyx":1049
 *                 else:
 *                     t = self.raw_mins[i]-x[i]
 *                     if t>inf.side_distances[i]:             # <<<<<<<<<<<<<<
 *                         inf.side_distances[i] = t
 *                 if p!=1 and p!=infinity:
 */
        __pyx_t_3 = (__pyx_v_t > (__pyx_v_inf->side_distances[__pyx_v_i]));
        if (__pyx_t_3) {

          /* "pyart/map/ckdtree.pyx":1050
 *                     t = self.raw_mins[i]-x[i]
 *                     if t>inf.side_distances[i]:
 *                         inf.side_distances[i] = t             # <<<<<<<<<<<<<<
 *                 if p!=1 and p!=infinity:
 *                     inf.side_distances[i]=inf.side_distances[i]**p
 */
          (__pyx_v_inf->side_distances[__pyx_v_i]) = __pyx_v_t;
          goto __pyx_L10;
        }
        __pyx_L10:;
      }
      __pyx_L9:;

      /* "pyart/map/ckdtree.pyx":1051
 *                     if t>inf.side_distances[i]:
 *                         inf.side_distances[i] = t
 *                 if p!=1 and p!=infinity:             # <<<<<<<<<<<<<<
 *                     inf.side_distances[i]=inf.side_distances[i]**p
 * 
 */
      __pyx_t_3 = (__pyx_v_p != 1.0);
      if (__pyx_t_3) {
        __pyx_t_7 = (__pyx_v_p != __pyx_v_5pyart_3map_7ckdtree_infinity);
        __pyx_t_8 = __pyx_t_7;
      } else {
        __pyx_t_8 = __pyx_t_3;
      }
      if (__pyx_t_8) {

        /* "pyart/map/ckdtree.pyx":1052
 *                         inf.side_distances[i] = t
 *                 if p!=1 and p!=infinity:
 *                     inf.side_distances[i]=inf.side_distances[i]**p             # <<<<<<<<<<<<<<
 * 
 *             # compute first distance
 */
        (__pyx_v_inf->side_distances[__pyx_v_i]) = pow((__pyx_v_inf->side_distances[__pyx_v_i]), __pyx_v_p);
        goto __pyx_L11;
      }
      __pyx_L11:;
    }

    /* "pyart/map/ckdtree.pyx":1055
 * 
 *             # compute first distance
 *             min_distance = 0.             # <<<<<<<<<<<<<<
 *             for i in range(self.m):
 *                 if p==infinity:
 */
    __pyx_v_min_distance = 0.;

    /* "pyart/map/ckdtree.pyx":1056
 *             # compute first distance
 *             min_distance = 0.
 *             for i in range(self.m):             # <<<<<<<<<<<<<<
 *                 if p==infinity:
 *                     min_distance = dmax(min_distance,inf.side_distances[i])
 */
    __pyx_t_5 = __pyx_v_self->m;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "pyart/map/ckdtree.pyx":1057
 *             min_distance = 0.
 *             for i in range(self.m):
 *                 if p==infinity:             # <<<<<<<<<<<<<<
 *                     min_distance = dmax(min_distance,inf.side_distances[i])
 *                 else:
 */
      __pyx_t_8 = (__pyx_v_p == __pyx_v_5pyart_3map_7ckdtree_infinity);
      if (__pyx_t_8) {

        /* "pyart/map/ckdtree.pyx":1058
 *             for i in range(self.m):
 *                 if p==infinity:
 *                     min_distance = dmax(min_distance,inf.side_distances[i])             # <<<<<<<<<<<<<<
 *                 else:
 *                     min_distance += inf.side_distances[i]
 */
        __pyx_v_min_distance = __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_v_min_distance, (__pyx_v_inf->side_distances[__pyx_v_i]));
        goto __pyx_L14;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1060
 *                     min_distance = dmax(min_distance,inf.side_distances[i])
 *                 else:
 *                     min_distance += inf.side_distances[i]             # <<<<<<<<<<<<<<
 * 
 *             # fiddle approximation factor
 */
        __pyx_v_min_distance = (__pyx_v_min_distance + (__pyx_v_inf->side_distances[__pyx_v_i]));
      }
      __pyx_L14:;
    }

    /* "pyart/map/ckdtree.pyx":1063
 * 
 *             # fiddle approximation factor
 *             if eps==0:             # <<<<<<<<<<<<<<
 *                 epsfac=1
 *             elif p==infinity:
 */
    __pyx_t_8 = (__pyx_v_eps == 0.0);
    if (__pyx_t_8) {

      /* "pyart/map/ckdtree.pyx":1064
 *             # fiddle approximation factor
 *             if eps==0:
 *                 epsfac=1             # <<<<<<<<<<<<<<
 *             elif p==infinity:
 *                 epsfac = 1/(1+eps)
 */
      __pyx_v_epsfac = 1.0;
      goto __pyx_L15;
    }

    /* "pyart/map/ckdtree.pyx":1065
 *             if eps==0:
 *                 epsfac=1
 *             elif p==infinity:             # <<<<<<<<<<<<<<
 *                 epsfac = 1/(1+eps)
 *             else:
 */
    __pyx_t_8 = (__pyx_v_p == __pyx_v_5pyart_3map_7ckdtree_infinity);
    if (__pyx_t_8) {

      /* "pyart/map/ckdtree.pyx":1066
 *                 epsfac=1
 *             elif p==infinity:
 *                 epsfac = 1/(1+eps)             # <<<<<<<<<<<<<<
 *             else:
 *                 epsfac = 1/(1+eps)**p
 */
      __pyx_t_9 = (1.0 + __pyx_v_eps);
      if (unlikely(__pyx_t_9 == 0)) {
        PyErr_Format(PyExc_ZeroDivisionError, "float division");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1066; __pyx_clineno = __LINE__; goto __pyx_L4;}
      }
      __pyx_v_epsfac = (1.0 / __pyx_t_9);
      goto __pyx_L15;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1068
 *                 epsfac = 1/(1+eps)
 *             else:
 *                 epsfac = 1/(1+eps)**p             # <<<<<<<<<<<<<<
 * 
 *             # internally we represent all distances as distance**p
 */
      __pyx_t_9 = pow((1.0 + __pyx_v_eps), __pyx_v_p);
      if (unlikely(__pyx_t_9 == 0)) {
        PyErr_Format(PyExc_ZeroDivisionError, "float division");
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1068; __pyx_clineno = __LINE__; goto __pyx_L4;}
      }
      __pyx_v_epsfac = (1.0 / __pyx_t_9);
    }
    __pyx_L15:;

    /* "pyart/map/ckdtree.pyx":1071
 * 
 *             # internally we represent all distances as distance**p
 *             if p!=infinity and distance_upper_bound!=infinity:             # <<<<<<<<<<<<<<
 *                 distance_upper_bound = distance_upper_bound**p
 * 
 */
    __pyx_t_8 = (__pyx_v_p != __pyx_v_5pyart_3map_7ckdtree_infinity);
    if (__pyx_t_8) {
      __pyx_t_3 = (__pyx_v_distance_upper_bound != __pyx_v_5pyart_3map_7ckdtree_infinity);
      __pyx_t_7 = __pyx_t_3;
    } else {
      __pyx_t_7 = __pyx_t_8;
    }
    if (__pyx_t_7) {

      /* "pyart/map/ckdtree.pyx":1072
 *             # internally we represent all distances as distance**p
 *             if p!=infinity and distance_upper_bound!=infinity:
 *                 distance_upper_bound = distance_upper_bound**p             # <<<<<<<<<<<<<<
 * 
 *             while True:
 */
      __pyx_v_distance_upper_bound = pow(__pyx_v_distance_upper_bound, __pyx_v_p);
      goto __pyx_L16;
    }
    __pyx_L16:;

    /* "pyart/map/ckdtree.pyx":1074
 *                 distance_upper_bound = distance_upper_bound**p
 * 
 *             while True:             # <<<<<<<<<<<<<<
 *                 if inf.node.split_dim==-1:
 *                     node = <leafnode*>inf.node
 */
    while (1) {
      if (!1) break;

      /* "pyart/map/ckdtree.pyx":1075
 * 
 *             while True:
 *                 if inf.node.split_dim==-1:             # <<<<<<<<<<<<<<
 *                     node = <leafnode*>inf.node
 * 
 */
      __pyx_t_7 = (__pyx_v_inf->node->split_dim == -1);
      if (__pyx_t_7) {

        /* "pyart/map/ckdtree.pyx":1076
 *             while True:
 *                 if inf.node.split_dim==-1:
 *                     node = <leafnode*>inf.node             # <<<<<<<<<<<<<<
 * 
 *                     # brute-force
 */
        __pyx_v_node = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_inf->node);

        /* "pyart/map/ckdtree.pyx":1079
 * 
 *                     # brute-force
 *                     for i in range(node.start_idx,node.end_idx):             # <<<<<<<<<<<<<<
 *                         d = _distance_p(
 *                                 self.raw_data+self.raw_indices[i]*self.m,
 */
        __pyx_t_5 = __pyx_v_node->end_idx;
        for (__pyx_t_6 = __pyx_v_node->start_idx; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
          __pyx_v_i = __pyx_t_6;

          /* "pyart/map/ckdtree.pyx":1082
 *                         d = _distance_p(
 *                                 self.raw_data+self.raw_indices[i]*self.m,
 *                                 x,p,self.m,distance_upper_bound)             # <<<<<<<<<<<<<<
 * 
 *                         if d<distance_upper_bound:
 */
          __pyx_v_d = __pyx_f_5pyart_3map_7ckdtree__distance_p((__pyx_v_self->raw_data + ((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m)), __pyx_v_x, __pyx_v_p, __pyx_v_self->m, __pyx_v_distance_upper_bound);

          /* "pyart/map/ckdtree.pyx":1084
 *                                 x,p,self.m,distance_upper_bound)
 * 
 *                         if d<distance_upper_bound:             # <<<<<<<<<<<<<<
 *                             # replace furthest neighbor
 *                             if neighbors.n==k:
 */
          __pyx_t_7 = (__pyx_v_d < __pyx_v_distance_upper_bound);
          if (__pyx_t_7) {

            /* "pyart/map/ckdtree.pyx":1086
 *                         if d<distance_upper_bound:
 *                             # replace furthest neighbor
 *                             if neighbors.n==k:             # <<<<<<<<<<<<<<
 *                                 neighbors.remove()
 *                             neighbor.priority = -d
 */
            __pyx_t_7 = (__pyx_v_neighbors->n == __pyx_v_k);
            if (__pyx_t_7) {

              /* "pyart/map/ckdtree.pyx":1087
 *                             # replace furthest neighbor
 *                             if neighbors.n==k:
 *                                 neighbors.remove()             # <<<<<<<<<<<<<<
 *                             neighbor.priority = -d
 *                             neighbor.contents.intdata = self.raw_indices[i]
 */
              __pyx_t_10 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *)__pyx_v_neighbors->__pyx_vtab)->remove(__pyx_v_neighbors); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1087; __pyx_clineno = __LINE__; goto __pyx_L4;}
              goto __pyx_L23;
            }
            __pyx_L23:;

            /* "pyart/map/ckdtree.pyx":1088
 *                             if neighbors.n==k:
 *                                 neighbors.remove()
 *                             neighbor.priority = -d             # <<<<<<<<<<<<<<
 *                             neighbor.contents.intdata = self.raw_indices[i]
 *                             neighbors.push(neighbor)
 */
            __pyx_v_neighbor.priority = (-__pyx_v_d);

            /* "pyart/map/ckdtree.pyx":1089
 *                                 neighbors.remove()
 *                             neighbor.priority = -d
 *                             neighbor.contents.intdata = self.raw_indices[i]             # <<<<<<<<<<<<<<
 *                             neighbors.push(neighbor)
 * 
 */
            __pyx_v_neighbor.contents.intdata = (__pyx_v_self->raw_indices[__pyx_v_i]);

            /* "pyart/map/ckdtree.pyx":1090
 *                             neighbor.priority = -d
 *                             neighbor.contents.intdata = self.raw_indices[i]
 *                             neighbors.push(neighbor)             # <<<<<<<<<<<<<<
 * 
 *                             # adjust upper bound for efficiency
 */
            __pyx_t_10 = __pyx_f_5pyart_3map_7ckdtree_4heap_push(__pyx_v_neighbors, __pyx_v_neighbor); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1090; __pyx_clineno = __LINE__; goto __pyx_L4;}

            /* "pyart/map/ckdtree.pyx":1093
 * 
 *                             # adjust upper bound for efficiency
 *                             if neighbors.n==k:             # <<<<<<<<<<<<<<
 *                                 distance_upper_bound = -neighbors.peek().priority
 * 
 */
            __pyx_t_7 = (__pyx_v_neighbors->n == __pyx_v_k);
            if (__pyx_t_7) {

              /* "pyart/map/ckdtree.pyx":1094
 *                             # adjust upper bound for efficiency
 *                             if neighbors.n==k:
 *                                 distance_upper_bound = -neighbors.peek().priority             # <<<<<<<<<<<<<<
 * 
 *                     # done with this node, get another
 */
              __pyx_v_distance_upper_bound = (-((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *)__pyx_v_neighbors->__pyx_vtab)->peek(__pyx_v_neighbors).priority);
              goto __pyx_L24;
            }
            __pyx_L24:;
            goto __pyx_L22;
          }
          __pyx_L22:;
        }

        /* "pyart/map/ckdtree.pyx":1097
 * 
 *                     # done with this node, get another
 *                     stdlib.free(inf)             # <<<<<<<<<<<<<<
 *                     inf = <nodeinfo*> NULL
 * 
 */
        free(__pyx_v_inf);

        /* "pyart/map/ckdtree.pyx":1098
 *                     # done with this node, get another
 *                     stdlib.free(inf)
 *                     inf = <nodeinfo*> NULL             # <<<<<<<<<<<<<<
 * 
 *                     if q.n==0:
 */
        __pyx_v_inf = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL);

        /* "pyart/map/ckdtree.pyx":1100
 *                     inf = <nodeinfo*> NULL
 * 
 *                     if q.n==0:             # <<<<<<<<<<<<<<
 *                         # no more nodes to visit
 *                         break
 */
        __pyx_t_7 = (__pyx_v_q->n == 0);
        if (__pyx_t_7) {

          /* "pyart/map/ckdtree.pyx":1102
 *                     if q.n==0:
 *                         # no more nodes to visit
 *                         break             # <<<<<<<<<<<<<<
 *                     else:
 *                         q.pop(&it)
 */
          goto __pyx_L18_break;
          goto __pyx_L25;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":1104
 *                         break
 *                     else:
 *                         q.pop(&it)             # <<<<<<<<<<<<<<
 *                         inf = <nodeinfo*>it.contents.ptrdata
 *                         min_distance = it.priority
 */
          __pyx_t_10 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *)__pyx_v_q->__pyx_vtab)->pop(__pyx_v_q, (&__pyx_v_it)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1104; __pyx_clineno = __LINE__; goto __pyx_L4;}

          /* "pyart/map/ckdtree.pyx":1105
 *                     else:
 *                         q.pop(&it)
 *                         inf = <nodeinfo*>it.contents.ptrdata             # <<<<<<<<<<<<<<
 *                         min_distance = it.priority
 *                 else:
 */
          __pyx_v_inf = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)__pyx_v_it.contents.ptrdata);

          /* "pyart/map/ckdtree.pyx":1106
 *                         q.pop(&it)
 *                         inf = <nodeinfo*>it.contents.ptrdata
 *                         min_distance = it.priority             # <<<<<<<<<<<<<<
 *                 else:
 *                     inode = <innernode*>inf.node
 */
          __pyx_t_9 = __pyx_v_it.priority;
          __pyx_v_min_distance = __pyx_t_9;
        }
        __pyx_L25:;
        goto __pyx_L19;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1108
 *                         min_distance = it.priority
 *                 else:
 *                     inode = <innernode*>inf.node             # <<<<<<<<<<<<<<
 * 
 *                     # we don't push cells that are too far onto the queue at all,
 */
        __pyx_v_inode = ((struct __pyx_t_5pyart_3map_7ckdtree_innernode *)__pyx_v_inf->node);

        /* "pyart/map/ckdtree.pyx":1113
 *                     # but since the distance_upper_bound decreases, we might get
 *                     # here even if the cell's too far
 *                     if min_distance>distance_upper_bound*epsfac:             # <<<<<<<<<<<<<<
 * 
 *                         # since this is the nearest cell, we're done, bail out
 */
        __pyx_t_7 = (__pyx_v_min_distance > (__pyx_v_distance_upper_bound * __pyx_v_epsfac));
        if (__pyx_t_7) {

          /* "pyart/map/ckdtree.pyx":1116
 * 
 *                         # since this is the nearest cell, we're done, bail out
 *                         stdlib.free(inf)             # <<<<<<<<<<<<<<
 *                         inf = <nodeinfo*> NULL
 * 
 */
          free(__pyx_v_inf);

          /* "pyart/map/ckdtree.pyx":1117
 *                         # since this is the nearest cell, we're done, bail out
 *                         stdlib.free(inf)
 *                         inf = <nodeinfo*> NULL             # <<<<<<<<<<<<<<
 * 
 *                         # free all the nodes still on the heap
 */
          __pyx_v_inf = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL);

          /* "pyart/map/ckdtree.pyx":1120
 * 
 *                         # free all the nodes still on the heap
 *                         for i in range(q.n):             # <<<<<<<<<<<<<<
 *                             stdlib.free(q.heap[i].contents.ptrdata)
 *                             q.heap[i].contents.ptrdata = <char*> NULL
 */
          __pyx_t_5 = __pyx_v_q->n;
          for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
            __pyx_v_i = __pyx_t_6;

            /* "pyart/map/ckdtree.pyx":1121
 *                         # free all the nodes still on the heap
 *                         for i in range(q.n):
 *                             stdlib.free(q.heap[i].contents.ptrdata)             # <<<<<<<<<<<<<<
 *                             q.heap[i].contents.ptrdata = <char*> NULL
 *                         break
 */
            free((__pyx_v_q->heap[__pyx_v_i]).contents.ptrdata);

            /* "pyart/map/ckdtree.pyx":1122
 *                         for i in range(q.n):
 *                             stdlib.free(q.heap[i].contents.ptrdata)
 *                             q.heap[i].contents.ptrdata = <char*> NULL             # <<<<<<<<<<<<<<
 *                         break
 * 
 */
            (__pyx_v_q->heap[__pyx_v_i]).contents.ptrdata = ((char *)NULL);
          }

          /* "pyart/map/ckdtree.pyx":1123
 *                             stdlib.free(q.heap[i].contents.ptrdata)
 *                             q.heap[i].contents.ptrdata = <char*> NULL
 *                         break             # <<<<<<<<<<<<<<
 * 
 *                     # set up children for searching
 */
          goto __pyx_L18_break;
          goto __pyx_L26;
        }
        __pyx_L26:;

        /* "pyart/map/ckdtree.pyx":1126
 * 
 *                     # set up children for searching
 *                     if x[inode.split_dim]<inode.split:             # <<<<<<<<<<<<<<
 *                         near = inode.less
 *                         far = inode.greater
 */
        __pyx_t_7 = ((__pyx_v_x[__pyx_v_inode->split_dim]) < __pyx_v_inode->split);
        if (__pyx_t_7) {

          /* "pyart/map/ckdtree.pyx":1127
 *                     # set up children for searching
 *                     if x[inode.split_dim]<inode.split:
 *                         near = inode.less             # <<<<<<<<<<<<<<
 *                         far = inode.greater
 *                     else:
 */
          __pyx_t_4 = __pyx_v_inode->less;
          __pyx_v_near = __pyx_t_4;

          /* "pyart/map/ckdtree.pyx":1128
 *                     if x[inode.split_dim]<inode.split:
 *                         near = inode.less
 *                         far = inode.greater             # <<<<<<<<<<<<<<
 *                     else:
 *                         near = inode.greater
 */
          __pyx_t_4 = __pyx_v_inode->greater;
          __pyx_v_far = __pyx_t_4;
          goto __pyx_L29;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":1130
 *                         far = inode.greater
 *                     else:
 *                         near = inode.greater             # <<<<<<<<<<<<<<
 *                         far = inode.less
 * 
 */
          __pyx_t_4 = __pyx_v_inode->greater;
          __pyx_v_near = __pyx_t_4;

          /* "pyart/map/ckdtree.pyx":1131
 *                     else:
 *                         near = inode.greater
 *                         far = inode.less             # <<<<<<<<<<<<<<
 * 
 *                     # near child is at the same distance as the current node
 */
          __pyx_t_4 = __pyx_v_inode->less;
          __pyx_v_far = __pyx_t_4;
        }
        __pyx_L29:;

        /* "pyart/map/ckdtree.pyx":1136
 *                     # we're going here next, so no point pushing it on the queue
 *                     # no need to recompute the distance or the side_distances
 *                     inf.node = near             # <<<<<<<<<<<<<<
 * 
 *                     # far child is further by an amount depending only
 */
        __pyx_v_inf->node = __pyx_v_near;

        /* "pyart/map/ckdtree.pyx":1141
 *                     # on the split value; compute its distance and side_distances
 *                     # and push it on the queue if it's near enough
 *                     inf2 = <nodeinfo*>stdlib.malloc(sizeof(nodeinfo)+self.m*sizeof(np.float64_t))             # <<<<<<<<<<<<<<
 *                     if inf2 == <nodeinfo*> NULL:
 *                         raise MemoryError
 */
        __pyx_v_inf2 = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)malloc(((sizeof(struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo)) + (__pyx_v_self->m * (sizeof(__pyx_t_5numpy_float64_t))))));

        /* "pyart/map/ckdtree.pyx":1142
 *                     # and push it on the queue if it's near enough
 *                     inf2 = <nodeinfo*>stdlib.malloc(sizeof(nodeinfo)+self.m*sizeof(np.float64_t))
 *                     if inf2 == <nodeinfo*> NULL:             # <<<<<<<<<<<<<<
 *                         raise MemoryError
 * 
 */
        __pyx_t_7 = (__pyx_v_inf2 == ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL));
        if (__pyx_t_7) {

          /* "pyart/map/ckdtree.pyx":1143
 *                     inf2 = <nodeinfo*>stdlib.malloc(sizeof(nodeinfo)+self.m*sizeof(np.float64_t))
 *                     if inf2 == <nodeinfo*> NULL:
 *                         raise MemoryError             # <<<<<<<<<<<<<<
 * 
 *                     it2.contents.ptrdata = <char*> inf2
 */
          PyErr_NoMemory(); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1143; __pyx_clineno = __LINE__; goto __pyx_L4;}
          goto __pyx_L30;
        }
        __pyx_L30:;

        /* "pyart/map/ckdtree.pyx":1145
 *                         raise MemoryError
 * 
 *                     it2.contents.ptrdata = <char*> inf2             # <<<<<<<<<<<<<<
 *                     inf2.node = far
 *                     # most side distances unchanged
 */
        __pyx_v_it2.contents.ptrdata = ((char *)__pyx_v_inf2);

        /* "pyart/map/ckdtree.pyx":1146
 * 
 *                     it2.contents.ptrdata = <char*> inf2
 *                     inf2.node = far             # <<<<<<<<<<<<<<
 *                     # most side distances unchanged
 *                     for i in range(self.m):
 */
        __pyx_v_inf2->node = __pyx_v_far;

        /* "pyart/map/ckdtree.pyx":1148
 *                     inf2.node = far
 *                     # most side distances unchanged
 *                     for i in range(self.m):             # <<<<<<<<<<<<<<
 *                         inf2.side_distances[i] = inf.side_distances[i]
 * 
 */
        __pyx_t_5 = __pyx_v_self->m;
        for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
          __pyx_v_i = __pyx_t_6;

          /* "pyart/map/ckdtree.pyx":1149
 *                     # most side distances unchanged
 *                     for i in range(self.m):
 *                         inf2.side_distances[i] = inf.side_distances[i]             # <<<<<<<<<<<<<<
 * 
 *                     # one side distance changes
 */
          (__pyx_v_inf2->side_distances[__pyx_v_i]) = (__pyx_v_inf->side_distances[__pyx_v_i]);
        }

        /* "pyart/map/ckdtree.pyx":1153
 *                     # one side distance changes
 *                     # we can adjust the minimum distance without recomputing
 *                     if p == infinity:             # <<<<<<<<<<<<<<
 *                         # we never use side_distances in the l_infinity case
 *                         # inf2.side_distances[inode.split_dim] = dabs(inode.split-x[inode.split_dim])
 */
        __pyx_t_7 = (__pyx_v_p == __pyx_v_5pyart_3map_7ckdtree_infinity);
        if (__pyx_t_7) {

          /* "pyart/map/ckdtree.pyx":1156
 *                         # we never use side_distances in the l_infinity case
 *                         # inf2.side_distances[inode.split_dim] = dabs(inode.split-x[inode.split_dim])
 *                         far_min_distance = dmax(min_distance, dabs(inode.split-x[inode.split_dim]))             # <<<<<<<<<<<<<<
 *                     elif p == 1:
 *                         inf2.side_distances[inode.split_dim] = dabs(inode.split-x[inode.split_dim])
 */
          __pyx_v_far_min_distance = __pyx_f_5pyart_3map_7ckdtree_dmax(__pyx_v_min_distance, __pyx_f_5pyart_3map_7ckdtree_dabs((__pyx_v_inode->split - (__pyx_v_x[__pyx_v_inode->split_dim]))));
          goto __pyx_L33;
        }

        /* "pyart/map/ckdtree.pyx":1157
 *                         # inf2.side_distances[inode.split_dim] = dabs(inode.split-x[inode.split_dim])
 *                         far_min_distance = dmax(min_distance, dabs(inode.split-x[inode.split_dim]))
 *                     elif p == 1:             # <<<<<<<<<<<<<<
 *                         inf2.side_distances[inode.split_dim] = dabs(inode.split-x[inode.split_dim])
 *                         far_min_distance = min_distance - \
 */
        __pyx_t_7 = (__pyx_v_p == 1.0);
        if (__pyx_t_7) {

          /* "pyart/map/ckdtree.pyx":1158
 *                         far_min_distance = dmax(min_distance, dabs(inode.split-x[inode.split_dim]))
 *                     elif p == 1:
 *                         inf2.side_distances[inode.split_dim] = dabs(inode.split-x[inode.split_dim])             # <<<<<<<<<<<<<<
 *                         far_min_distance = min_distance - \
 *                             inf.side_distances[inode.split_dim] + \
 */
          (__pyx_v_inf2->side_distances[__pyx_v_inode->split_dim]) = __pyx_f_5pyart_3map_7ckdtree_dabs((__pyx_v_inode->split - (__pyx_v_x[__pyx_v_inode->split_dim])));

          /* "pyart/map/ckdtree.pyx":1161
 *                         far_min_distance = min_distance - \
 *                             inf.side_distances[inode.split_dim] + \
 *                             inf2.side_distances[inode.split_dim]             # <<<<<<<<<<<<<<
 *                     else:
 *                         inf2.side_distances[inode.split_dim] = dabs(inode.split -
 */
          __pyx_v_far_min_distance = ((__pyx_v_min_distance - (__pyx_v_inf->side_distances[__pyx_v_inode->split_dim])) + (__pyx_v_inf2->side_distances[__pyx_v_inode->split_dim]));
          goto __pyx_L33;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":1163
 *                             inf2.side_distances[inode.split_dim]
 *                     else:
 *                         inf2.side_distances[inode.split_dim] = dabs(inode.split -             # <<<<<<<<<<<<<<
 *                                                                     x[inode.split_dim])**p
 *                         far_min_distance = min_distance - \
 */
          (__pyx_v_inf2->side_distances[__pyx_v_inode->split_dim]) = pow(__pyx_f_5pyart_3map_7ckdtree_dabs((__pyx_v_inode->split - (__pyx_v_x[__pyx_v_inode->split_dim]))), __pyx_v_p);

          /* "pyart/map/ckdtree.pyx":1167
 *                         far_min_distance = min_distance - \
 *                             inf.side_distances[inode.split_dim] + \
 *                             inf2.side_distances[inode.split_dim]             # <<<<<<<<<<<<<<
 * 
 *                     it2.priority = far_min_distance
 */
          __pyx_v_far_min_distance = ((__pyx_v_min_distance - (__pyx_v_inf->side_distances[__pyx_v_inode->split_dim])) + (__pyx_v_inf2->side_distances[__pyx_v_inode->split_dim]));
        }
        __pyx_L33:;

        /* "pyart/map/ckdtree.pyx":1169
 *                             inf2.side_distances[inode.split_dim]
 * 
 *                     it2.priority = far_min_distance             # <<<<<<<<<<<<<<
 * 
 * 
 */
        __pyx_v_it2.priority = __pyx_v_far_min_distance;

        /* "pyart/map/ckdtree.pyx":1173
 * 
 *                     # far child might be too far, if so, don't bother pushing it
 *                     if far_min_distance<=distance_upper_bound*epsfac:             # <<<<<<<<<<<<<<
 *                         q.push(it2)
 *                     else:
 */
        __pyx_t_7 = (__pyx_v_far_min_distance <= (__pyx_v_distance_upper_bound * __pyx_v_epsfac));
        if (__pyx_t_7) {

          /* "pyart/map/ckdtree.pyx":1174
 *                     # far child might be too far, if so, don't bother pushing it
 *                     if far_min_distance<=distance_upper_bound*epsfac:
 *                         q.push(it2)             # <<<<<<<<<<<<<<
 *                     else:
 *                         stdlib.free(inf2)
 */
          __pyx_t_10 = __pyx_f_5pyart_3map_7ckdtree_4heap_push(__pyx_v_q, __pyx_v_it2); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1174; __pyx_clineno = __LINE__; goto __pyx_L4;}
          goto __pyx_L34;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":1176
 *                         q.push(it2)
 *                     else:
 *                         stdlib.free(inf2)             # <<<<<<<<<<<<<<
 *                         inf2 = <nodeinfo*> NULL
 *                         # just in case
 */
          free(__pyx_v_inf2);

          /* "pyart/map/ckdtree.pyx":1177
 *                     else:
 *                         stdlib.free(inf2)
 *                         inf2 = <nodeinfo*> NULL             # <<<<<<<<<<<<<<
 *                         # just in case
 *                         it2.contents.ptrdata = <char*> NULL
 */
          __pyx_v_inf2 = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL);

          /* "pyart/map/ckdtree.pyx":1179
 *                         inf2 = <nodeinfo*> NULL
 *                         # just in case
 *                         it2.contents.ptrdata = <char*> NULL             # <<<<<<<<<<<<<<
 * 
 *             # fill output arrays with sorted neighbors
 */
          __pyx_v_it2.contents.ptrdata = ((char *)NULL);
        }
        __pyx_L34:;
      }
      __pyx_L19:;
    }
    __pyx_L18_break:;

    /* "pyart/map/ckdtree.pyx":1182
 * 
 *             # fill output arrays with sorted neighbors
 *             for i in range(neighbors.n-1,-1,-1):             # <<<<<<<<<<<<<<
 *                 neighbors.pop(&neighbor)
 *                 result_indices[i] = neighbor.contents.intdata
 */
    for (__pyx_t_5 = (__pyx_v_neighbors->n - 1); __pyx_t_5 > -1; __pyx_t_5-=1) {
      __pyx_v_i = __pyx_t_5;

      /* "pyart/map/ckdtree.pyx":1183
 *             # fill output arrays with sorted neighbors
 *             for i in range(neighbors.n-1,-1,-1):
 *                 neighbors.pop(&neighbor)             # <<<<<<<<<<<<<<
 *                 result_indices[i] = neighbor.contents.intdata
 *                 if p==1 or p==infinity:
 */
      __pyx_t_10 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap *)__pyx_v_neighbors->__pyx_vtab)->pop(__pyx_v_neighbors, (&__pyx_v_neighbor)); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1183; __pyx_clineno = __LINE__; goto __pyx_L4;}

      /* "pyart/map/ckdtree.pyx":1184
 *             for i in range(neighbors.n-1,-1,-1):
 *                 neighbors.pop(&neighbor)
 *                 result_indices[i] = neighbor.contents.intdata             # <<<<<<<<<<<<<<
 *                 if p==1 or p==infinity:
 *                     result_distances[i] = -neighbor.priority
 */
      __pyx_t_6 = __pyx_v_neighbor.contents.intdata;
      (__pyx_v_result_indices[__pyx_v_i]) = __pyx_t_6;

      /* "pyart/map/ckdtree.pyx":1185
 *                 neighbors.pop(&neighbor)
 *                 result_indices[i] = neighbor.contents.intdata
 *                 if p==1 or p==infinity:             # <<<<<<<<<<<<<<
 *                     result_distances[i] = -neighbor.priority
 *                 else:
 */
      __pyx_t_7 = (__pyx_v_p == 1.0);
      if (!__pyx_t_7) {
        __pyx_t_8 = (__pyx_v_p == __pyx_v_5pyart_3map_7ckdtree_infinity);
        __pyx_t_3 = __pyx_t_8;
      } else {
        __pyx_t_3 = __pyx_t_7;
      }
      if (__pyx_t_3) {

        /* "pyart/map/ckdtree.pyx":1186
 *                 result_indices[i] = neighbor.contents.intdata
 *                 if p==1 or p==infinity:
 *                     result_distances[i] = -neighbor.priority             # <<<<<<<<<<<<<<
 *                 else:
 *                     result_distances[i] = (-neighbor.priority)**(1./p)
 */
        (__pyx_v_result_distances[__pyx_v_i]) = (-__pyx_v_neighbor.priority);
        goto __pyx_L37;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1188
 *                     result_distances[i] = -neighbor.priority
 *                 else:
 *                     result_distances[i] = (-neighbor.priority)**(1./p)             # <<<<<<<<<<<<<<
 * 
 *             inf = inf2 = <nodeinfo*> NULL
 */
        if (unlikely(__pyx_v_p == 0)) {
          PyErr_Format(PyExc_ZeroDivisionError, "float division");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1188; __pyx_clineno = __LINE__; goto __pyx_L4;}
        }
        (__pyx_v_result_distances[__pyx_v_i]) = pow((-__pyx_v_neighbor.priority), (1. / __pyx_v_p));
      }
      __pyx_L37:;
    }

    /* "pyart/map/ckdtree.pyx":1190
 *                     result_distances[i] = (-neighbor.priority)**(1./p)
 * 
 *             inf = inf2 = <nodeinfo*> NULL             # <<<<<<<<<<<<<<
 * 
 *         finally:
 */
    __pyx_v_inf = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL);
    __pyx_v_inf2 = ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL);
  }

  /* "pyart/map/ckdtree.pyx":1193
 * 
 *         finally:
 *             if inf2 != <nodeinfo*> NULL:             # <<<<<<<<<<<<<<
 *                 stdlib.free(inf2)
 * 
 */
  /*finally:*/ {
    int __pyx_why;
    PyObject *__pyx_exc_type, *__pyx_exc_value, *__pyx_exc_tb;
    int __pyx_exc_lineno;
    __pyx_exc_type = 0; __pyx_exc_value = 0; __pyx_exc_tb = 0; __pyx_exc_lineno = 0;
    __pyx_why = 0; goto __pyx_L5;
    __pyx_L4: {
      __pyx_why = 4;
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_ErrFetch(&__pyx_exc_type, &__pyx_exc_value, &__pyx_exc_tb);
      __pyx_exc_lineno = __pyx_lineno;
      goto __pyx_L5;
    }
    __pyx_L5:;
    __pyx_t_3 = (__pyx_v_inf2 != ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL));
    if (__pyx_t_3) {

      /* "pyart/map/ckdtree.pyx":1194
 *         finally:
 *             if inf2 != <nodeinfo*> NULL:
 *                 stdlib.free(inf2)             # <<<<<<<<<<<<<<
 * 
 *             if inf != <nodeinfo*> NULL:
 */
      free(__pyx_v_inf2);
      goto __pyx_L39;
    }
    __pyx_L39:;

    /* "pyart/map/ckdtree.pyx":1196
 *                 stdlib.free(inf2)
 * 
 *             if inf != <nodeinfo*> NULL:             # <<<<<<<<<<<<<<
 *                 stdlib.free(inf)
 * 
 */
    __pyx_t_3 = (__pyx_v_inf != ((struct __pyx_t_5pyart_3map_7ckdtree_nodeinfo *)NULL));
    if (__pyx_t_3) {

      /* "pyart/map/ckdtree.pyx":1197
 * 
 *             if inf != <nodeinfo*> NULL:
 *                 stdlib.free(inf)             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
      free(__pyx_v_inf);
      goto __pyx_L40;
    }
    __pyx_L40:;
    switch (__pyx_why) {
      case 4: {
        __Pyx_ErrRestore(__pyx_exc_type, __pyx_exc_value, __pyx_exc_tb);
        __pyx_lineno = __pyx_exc_lineno;
        __pyx_exc_type = 0;
        __pyx_exc_value = 0;
        __pyx_exc_tb = 0;
        goto __pyx_L1_error;
      }
    }
  }

  /* "pyart/map/ckdtree.pyx":1199
 *                 stdlib.free(inf)
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_q);
  __Pyx_XDECREF((PyObject *)__pyx_v_neighbors);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_5query(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_3map_7ckdtree_7cKDTree_4query[] = "query(self, x, k=1, eps=0, p=2, distance_upper_bound=np.inf)\n        \n        Query the kd-tree for nearest neighbors\n\n        Parameters\n        ----------\n        x : array_like, last dimension self.m\n            An array of points to query.\n        k : integer\n            The number of nearest neighbors to return.\n        eps : non-negative float\n            Return approximate nearest neighbors; the kth returned value \n            is guaranteed to be no further than (1+eps) times the \n            distance to the real k-th nearest neighbor.\n        p : float, 1<=p<=infinity\n            Which Minkowski p-norm to use. \n            1 is the sum-of-absolute-values \"Manhattan\" distance\n            2 is the usual Euclidean distance\n            infinity is the maximum-coordinate-difference distance\n        distance_upper_bound : nonnegative float\n            Return only neighbors within this distance.  This is used to prune\n            tree searches, so if you are doing a series of nearest-neighbor\n            queries, it may help to supply the distance to the nearest neighbor\n            of the most recent point.\n\n        Returns\n        -------\n        d : array of floats\n            The distances to the nearest neighbors. \n            If x has shape tuple+(self.m,), then d has shape tuple+(k,).\n            Missing neighbors are indicated with infinite distances.\n        i : ndarray of ints\n            The locations of the neighbors in self.data.\n            If `x` has shape tuple+(self.m,), then `i` has shape tuple+(k,).\n            Missing neighbors are indicated with self.n.\n\n        ";
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_5query(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_x = 0;
  __pyx_t_5numpy_intp_t __pyx_v_k;
  __pyx_t_5numpy_float64_t __pyx_v_eps;
  __pyx_t_5numpy_float64_t __pyx_v_p;
  __pyx_t_5numpy_float64_t __pyx_v_distance_upper_bound;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__x,&__pyx_n_s__k,&__pyx_n_s__eps,&__pyx_n_s__p,&__pyx_n_s_7,0};
    PyObject* values[5] = {0,0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__x)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__k);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__eps);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__p);
          if (value) { values[3] = value; kw_args--; }
        }
        case  4:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s_7);
          if (value) { values[4] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "query") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  5: values[4] = PyTuple_GET_ITEM(__pyx_args, 4);
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_x = values[0];
    if (values[1]) {
      __pyx_v_k = __Pyx_PyInt_from_py_Py_intptr_t(values[1]); if (unlikely((__pyx_v_k == (npy_intp)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_k = ((__pyx_t_5numpy_intp_t)1);
    }
    if (values[2]) {
      __pyx_v_eps = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_eps == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":1204
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def query(cKDTree self, object x, np.intp_t k=1, np.float64_t eps=0,             # <<<<<<<<<<<<<<
 *               np.float64_t p=2, np.float64_t distance_upper_bound=infinity):
 *         """query(self, x, k=1, eps=0, p=2, distance_upper_bound=np.inf)
 */
      __pyx_v_eps = ((__pyx_t_5numpy_float64_t)0.0);
    }
    if (values[3]) {
      __pyx_v_p = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_p == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":1205
 *     @cython.wraparound(False)
 *     def query(cKDTree self, object x, np.intp_t k=1, np.float64_t eps=0,
 *               np.float64_t p=2, np.float64_t distance_upper_bound=infinity):             # <<<<<<<<<<<<<<
 *         """query(self, x, k=1, eps=0, p=2, distance_upper_bound=np.inf)
 * 
 */
      __pyx_v_p = ((__pyx_t_5numpy_float64_t)2.0);
    }
    if (values[4]) {
      __pyx_v_distance_upper_bound = __pyx_PyFloat_AsDouble(values[4]); if (unlikely((__pyx_v_distance_upper_bound == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1205; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_distance_upper_bound = __pyx_k_8;
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("query", 0, 1, 5, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1204; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4query(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self), __pyx_v_x, __pyx_v_k, __pyx_v_eps, __pyx_v_p, __pyx_v_distance_upper_bound);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1204
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def query(cKDTree self, object x, np.intp_t k=1, np.float64_t eps=0,             # <<<<<<<<<<<<<<
 *               np.float64_t p=2, np.float64_t distance_upper_bound=infinity):
 *         """query(self, x, k=1, eps=0, p=2, distance_upper_bound=np.inf)
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4query(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_x, __pyx_t_5numpy_intp_t __pyx_v_k, __pyx_t_5numpy_float64_t __pyx_v_eps, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_distance_upper_bound) {
  PyArrayObject *__pyx_v_ii = 0;
  PyArrayObject *__pyx_v_dd = 0;
  PyArrayObject *__pyx_v_xx = 0;
  __pyx_t_5numpy_intp_t __pyx_v_c;
  __pyx_t_5numpy_intp_t __pyx_v_n;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  int __pyx_v_single;
  PyObject *__pyx_v_retshape = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_dd;
  __Pyx_Buffer __pyx_pybuffer_dd;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_ii;
  __Pyx_Buffer __pyx_pybuffer_ii;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_xx;
  __Pyx_Buffer __pyx_pybuffer_xx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  Py_ssize_t __pyx_t_6;
  __pyx_t_5numpy_intp_t __pyx_t_7;
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  PyObject *__pyx_t_13 = NULL;
  PyArrayObject *__pyx_t_14 = NULL;
  PyArrayObject *__pyx_t_15 = NULL;
  __pyx_t_5numpy_intp_t __pyx_t_16;
  __pyx_t_5numpy_intp_t __pyx_t_17;
  long __pyx_t_18;
  __pyx_t_5numpy_intp_t __pyx_t_19;
  long __pyx_t_20;
  __pyx_t_5numpy_intp_t __pyx_t_21;
  long __pyx_t_22;
  long __pyx_t_23;
  long __pyx_t_24;
  long __pyx_t_25;
  long __pyx_t_26;
  long __pyx_t_27;
  long __pyx_t_28;
  long __pyx_t_29;
  long __pyx_t_30;
  long __pyx_t_31;
  long __pyx_t_32;
  long __pyx_t_33;
  long __pyx_t_34;
  long __pyx_t_35;
  long __pyx_t_36;
  __pyx_t_5numpy_intp_t __pyx_t_37;
  __pyx_t_5numpy_intp_t __pyx_t_38;
  __pyx_t_5numpy_intp_t __pyx_t_39;
  __pyx_t_5numpy_intp_t __pyx_t_40;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query", 0);
  __Pyx_INCREF(__pyx_v_x);
  __pyx_pybuffer_ii.pybuffer.buf = NULL;
  __pyx_pybuffer_ii.refcount = 0;
  __pyx_pybuffernd_ii.data = NULL;
  __pyx_pybuffernd_ii.rcbuffer = &__pyx_pybuffer_ii;
  __pyx_pybuffer_dd.pybuffer.buf = NULL;
  __pyx_pybuffer_dd.refcount = 0;
  __pyx_pybuffernd_dd.data = NULL;
  __pyx_pybuffernd_dd.rcbuffer = &__pyx_pybuffer_dd;
  __pyx_pybuffer_xx.pybuffer.buf = NULL;
  __pyx_pybuffer_xx.refcount = 0;
  __pyx_pybuffernd_xx.data = NULL;
  __pyx_pybuffernd_xx.rcbuffer = &__pyx_pybuffer_xx;

  /* "pyart/map/ckdtree.pyx":1247
 *         cdef np.ndarray[np.float64_t, ndim=2] xx
 *         cdef np.intp_t c, n, i, j
 *         x = np.asarray(x).astype(np.float64)             # <<<<<<<<<<<<<<
 *         if np.shape(x)[-1] != self.m:
 *             raise ValueError("x must consist of vectors of length %d but has"
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__asarray); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_x);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_x);
  __Pyx_GIVEREF(__pyx_v_x);
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__astype); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__float64); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1247; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_v_x);
  __pyx_v_x = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1248
 *         cdef np.intp_t c, n, i, j
 *         x = np.asarray(x).astype(np.float64)
 *         if np.shape(x)[-1] != self.m:             # <<<<<<<<<<<<<<
 *             raise ValueError("x must consist of vectors of length %d but has"
 *                              "shape %s" % (int(self.m), np.shape(x)))
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_x);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_x);
  __Pyx_GIVEREF(__pyx_v_x);
  __pyx_t_1 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, -1, sizeof(long), PyInt_FromLong); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->m); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_RichCompare(__pyx_t_2, __pyx_t_1, Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1248; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":1250
 *         if np.shape(x)[-1] != self.m:
 *             raise ValueError("x must consist of vectors of length %d but has"
 *                              "shape %s" % (int(self.m), np.shape(x)))             # <<<<<<<<<<<<<<
 *         if p < 1:
 *             raise ValueError("Only p-norms with 1<=p<=infinity permitted")
 */
    __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->m); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__shape); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_x);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_x);
    __Pyx_GIVEREF(__pyx_v_x);
    __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
    __Pyx_GIVEREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
    __Pyx_GIVEREF(__pyx_t_5);
    __pyx_t_3 = 0;
    __pyx_t_5 = 0;
    __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_9), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1250; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_5));
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_5));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
    __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1249; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1251
 *             raise ValueError("x must consist of vectors of length %d but has"
 *                              "shape %s" % (int(self.m), np.shape(x)))
 *         if p < 1:             # <<<<<<<<<<<<<<
 *             raise ValueError("Only p-norms with 1<=p<=infinity permitted")
 *         if len(x.shape)==1:
 */
  __pyx_t_4 = (__pyx_v_p < 1.0);
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":1252
 *                              "shape %s" % (int(self.m), np.shape(x)))
 *         if p < 1:
 *             raise ValueError("Only p-norms with 1<=p<=infinity permitted")             # <<<<<<<<<<<<<<
 *         if len(x.shape)==1:
 *             single = True
 */
    __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_11), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1252; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_Raise(__pyx_t_5, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1252; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L4;
  }
  __pyx_L4:;

  /* "pyart/map/ckdtree.pyx":1253
 *         if p < 1:
 *             raise ValueError("Only p-norms with 1<=p<=infinity permitted")
 *         if len(x.shape)==1:             # <<<<<<<<<<<<<<
 *             single = True
 *             x = x[np.newaxis,:]
 */
  __pyx_t_5 = PyObject_GetAttr(__pyx_v_x, __pyx_n_s__shape); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyObject_Length(__pyx_t_5); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1253; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_4 = (__pyx_t_6 == 1);
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":1254
 *             raise ValueError("Only p-norms with 1<=p<=infinity permitted")
 *         if len(x.shape)==1:
 *             single = True             # <<<<<<<<<<<<<<
 *             x = x[np.newaxis,:]
 *         else:
 */
    __pyx_v_single = 1;

    /* "pyart/map/ckdtree.pyx":1255
 *         if len(x.shape)==1:
 *             single = True
 *             x = x[np.newaxis,:]             # <<<<<<<<<<<<<<
 *         else:
 *             single = False
 */
    __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_1 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__newaxis); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_k_slice_12);
    PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_k_slice_12);
    __Pyx_GIVEREF(__pyx_k_slice_12);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_GetItem(__pyx_v_x, ((PyObject *)__pyx_t_5)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
    __Pyx_DECREF(__pyx_v_x);
    __pyx_v_x = __pyx_t_1;
    __pyx_t_1 = 0;
    goto __pyx_L5;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1257
 *             x = x[np.newaxis,:]
 *         else:
 *             single = False             # <<<<<<<<<<<<<<
 *         retshape = np.shape(x)[:-1]
 *         n = <np.intp_t> np.prod(retshape)
 */
    __pyx_v_single = 0;
  }
  __pyx_L5:;

  /* "pyart/map/ckdtree.pyx":1258
 *         else:
 *             single = False
 *         retshape = np.shape(x)[:-1]             # <<<<<<<<<<<<<<
 *         n = <np.intp_t> np.prod(retshape)
 *         xx = np.reshape(x,(n,self.m))
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__shape); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_x);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_x);
  __Pyx_GIVEREF(__pyx_v_x);
  __pyx_t_3 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PySequence_GetSlice(__pyx_t_3, 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1258; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_v_retshape = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1259
 *             single = False
 *         retshape = np.shape(x)[:-1]
 *         n = <np.intp_t> np.prod(retshape)             # <<<<<<<<<<<<<<
 *         xx = np.reshape(x,(n,self.m))
 *         xx = np.ascontiguousarray(xx,dtype=np.float64)
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__prod); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_retshape);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_retshape);
  __Pyx_GIVEREF(__pyx_v_retshape);
  __pyx_t_5 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_7 = __Pyx_PyInt_from_py_Py_intptr_t(__pyx_t_5); if (unlikely((__pyx_t_7 == (npy_intp)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1259; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_v_n = ((__pyx_t_5numpy_intp_t)__pyx_t_7);

  /* "pyart/map/ckdtree.pyx":1260
 *         retshape = np.shape(x)[:-1]
 *         n = <np.intp_t> np.prod(retshape)
 *         xx = np.reshape(x,(n,self.m))             # <<<<<<<<<<<<<<
 *         xx = np.ascontiguousarray(xx,dtype=np.float64)
 *         dd = np.empty((n,k),dtype=np.float64)
 */
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__reshape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_n); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->m); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_5 = 0;
  __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_INCREF(__pyx_v_x);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_x);
  __Pyx_GIVEREF(__pyx_v_x);
  PyTuple_SET_ITEM(__pyx_t_3, 1, ((PyObject *)__pyx_t_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_2);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_v_xx, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
    }
    __pyx_pybuffernd_xx.diminfo[0].strides = __pyx_pybuffernd_xx.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_xx.diminfo[0].shape = __pyx_pybuffernd_xx.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_xx.diminfo[1].strides = __pyx_pybuffernd_xx.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_xx.diminfo[1].shape = __pyx_pybuffernd_xx.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1260; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_8 = 0;
  __pyx_v_xx = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1261
 *         n = <np.intp_t> np.prod(retshape)
 *         xx = np.reshape(x,(n,self.m))
 *         xx = np.ascontiguousarray(xx,dtype=np.float64)             # <<<<<<<<<<<<<<
 *         dd = np.empty((n,k),dtype=np.float64)
 *         dd.fill(infinity)
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__ascontiguousarray); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_xx));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_xx));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_xx));
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_13 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__float64); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_13) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_13) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_13, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_8 = ((PyArrayObject *)__pyx_t_13);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_v_xx, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
    }
    __pyx_pybuffernd_xx.diminfo[0].strides = __pyx_pybuffernd_xx.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_xx.diminfo[0].shape = __pyx_pybuffernd_xx.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_xx.diminfo[1].strides = __pyx_pybuffernd_xx.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_xx.diminfo[1].shape = __pyx_pybuffernd_xx.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1261; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_8 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_v_xx));
  __pyx_v_xx = ((PyArrayObject *)__pyx_t_13);
  __pyx_t_13 = 0;

  /* "pyart/map/ckdtree.pyx":1262
 *         xx = np.reshape(x,(n,self.m))
 *         xx = np.ascontiguousarray(xx,dtype=np.float64)
 *         dd = np.empty((n,k),dtype=np.float64)             # <<<<<<<<<<<<<<
 *         dd.fill(infinity)
 *         ii = np.empty((n,k),dtype=np.intp)
 */
  __pyx_t_13 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_13, __pyx_n_s__empty); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_n); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_13);
  __Pyx_GIVEREF(__pyx_t_13);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_13 = 0;
  __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_t_3));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_t_3 = 0;
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __pyx_t_13 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_13, __pyx_n_s__float64); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__dtype), __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_14 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_dd.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_dd.rcbuffer->pybuffer, (PyObject*)__pyx_t_14, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_dd.rcbuffer->pybuffer, (PyObject*)__pyx_v_dd, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
      }
    }
    __pyx_pybuffernd_dd.diminfo[0].strides = __pyx_pybuffernd_dd.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_dd.diminfo[0].shape = __pyx_pybuffernd_dd.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_dd.diminfo[1].strides = __pyx_pybuffernd_dd.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_dd.diminfo[1].shape = __pyx_pybuffernd_dd.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1262; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_14 = 0;
  __pyx_v_dd = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":1263
 *         xx = np.ascontiguousarray(xx,dtype=np.float64)
 *         dd = np.empty((n,k),dtype=np.float64)
 *         dd.fill(infinity)             # <<<<<<<<<<<<<<
 *         ii = np.empty((n,k),dtype=np.intp)
 *         ii.fill(self.n)
 */
  __pyx_t_5 = PyObject_GetAttr(((PyObject *)__pyx_v_dd), __pyx_n_s__fill); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_3 = PyFloat_FromDouble(__pyx_v_5pyart_3map_7ckdtree_infinity); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1263; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "pyart/map/ckdtree.pyx":1264
 *         dd = np.empty((n,k),dtype=np.float64)
 *         dd.fill(infinity)
 *         ii = np.empty((n,k),dtype=np.intp)             # <<<<<<<<<<<<<<
 *         ii.fill(self.n)
 *         for c in range(n):
 */
  __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_n); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_3 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_t_1));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
  __pyx_t_1 = 0;
  __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_1));
  __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_13 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__intp); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_13) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __pyx_t_13 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_5), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  if (!(likely(((__pyx_t_13) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_13, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_15 = ((PyArrayObject *)__pyx_t_13);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_ii.rcbuffer->pybuffer);
    __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_ii.rcbuffer->pybuffer, (PyObject*)__pyx_t_15, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack);
    if (unlikely(__pyx_t_9 < 0)) {
      PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_ii.rcbuffer->pybuffer, (PyObject*)__pyx_v_ii, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 2, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
      }
    }
    __pyx_pybuffernd_ii.diminfo[0].strides = __pyx_pybuffernd_ii.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_ii.diminfo[0].shape = __pyx_pybuffernd_ii.rcbuffer->pybuffer.shape[0]; __pyx_pybuffernd_ii.diminfo[1].strides = __pyx_pybuffernd_ii.rcbuffer->pybuffer.strides[1]; __pyx_pybuffernd_ii.diminfo[1].shape = __pyx_pybuffernd_ii.rcbuffer->pybuffer.shape[1];
    if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1264; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_15 = 0;
  __pyx_v_ii = ((PyArrayObject *)__pyx_t_13);
  __pyx_t_13 = 0;

  /* "pyart/map/ckdtree.pyx":1265
 *         dd.fill(infinity)
 *         ii = np.empty((n,k),dtype=np.intp)
 *         ii.fill(self.n)             # <<<<<<<<<<<<<<
 *         for c in range(n):
 *             self.__query(&dd[c, 0], &ii[c, 0], &xx[c, 0],
 */
  __pyx_t_13 = PyObject_GetAttr(((PyObject *)__pyx_v_ii), __pyx_n_s__fill); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_13);
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_Call(__pyx_t_13, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1265; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1266
 *         ii = np.empty((n,k),dtype=np.intp)
 *         ii.fill(self.n)
 *         for c in range(n):             # <<<<<<<<<<<<<<
 *             self.__query(&dd[c, 0], &ii[c, 0], &xx[c, 0],
 *                          k, eps, p, distance_upper_bound)
 */
  __pyx_t_7 = __pyx_v_n;
  for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_7; __pyx_t_16+=1) {
    __pyx_v_c = __pyx_t_16;

    /* "pyart/map/ckdtree.pyx":1267
 *         ii.fill(self.n)
 *         for c in range(n):
 *             self.__query(&dd[c, 0], &ii[c, 0], &xx[c, 0],             # <<<<<<<<<<<<<<
 *                          k, eps, p, distance_upper_bound)
 * 
 */
    __pyx_t_17 = __pyx_v_c;
    __pyx_t_18 = 0;
    __pyx_t_19 = __pyx_v_c;
    __pyx_t_20 = 0;
    __pyx_t_21 = __pyx_v_c;
    __pyx_t_22 = 0;

    /* "pyart/map/ckdtree.pyx":1268
 *         for c in range(n):
 *             self.__query(&dd[c, 0], &ii[c, 0], &xx[c, 0],
 *                          k, eps, p, distance_upper_bound)             # <<<<<<<<<<<<<<
 * 
 *         if single:
 */
    __pyx_t_9 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query(__pyx_v_self, (&(*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_dd.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_dd.diminfo[0].strides, __pyx_t_18, __pyx_pybuffernd_dd.diminfo[1].strides))), (&(*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_ii.rcbuffer->pybuffer.buf, __pyx_t_19, __pyx_pybuffernd_ii.diminfo[0].strides, __pyx_t_20, __pyx_pybuffernd_ii.diminfo[1].strides))), (&(*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_xx.rcbuffer->pybuffer.buf, __pyx_t_21, __pyx_pybuffernd_xx.diminfo[0].strides, __pyx_t_22, __pyx_pybuffernd_xx.diminfo[1].strides))), __pyx_v_k, __pyx_v_eps, __pyx_v_p, __pyx_v_distance_upper_bound); if (unlikely(__pyx_t_9 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1267; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }

  /* "pyart/map/ckdtree.pyx":1270
 *                          k, eps, p, distance_upper_bound)
 * 
 *         if single:             # <<<<<<<<<<<<<<
 *             if k==1:
 *                 if sizeof(long) < sizeof(np.intp_t):
 */
  if (__pyx_v_single) {

    /* "pyart/map/ckdtree.pyx":1271
 * 
 *         if single:
 *             if k==1:             # <<<<<<<<<<<<<<
 *                 if sizeof(long) < sizeof(np.intp_t):
 *                     # ... e.g. Windows 64
 */
    __pyx_t_4 = (__pyx_v_k == 1);
    if (__pyx_t_4) {

      /* "pyart/map/ckdtree.pyx":1272
 *         if single:
 *             if k==1:
 *                 if sizeof(long) < sizeof(np.intp_t):             # <<<<<<<<<<<<<<
 *                     # ... e.g. Windows 64
 *                     if ii[0,0] <= <np.intp_t>LONG_MAX:
 */
      __pyx_t_4 = ((sizeof(long)) < (sizeof(__pyx_t_5numpy_intp_t)));
      if (__pyx_t_4) {

        /* "pyart/map/ckdtree.pyx":1274
 *                 if sizeof(long) < sizeof(np.intp_t):
 *                     # ... e.g. Windows 64
 *                     if ii[0,0] <= <np.intp_t>LONG_MAX:             # <<<<<<<<<<<<<<
 *                         return dd[0,0], int(ii[0,0])
 *                     else:
 */
        __pyx_t_23 = 0;
        __pyx_t_24 = 0;
        __pyx_t_4 = ((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_ii.rcbuffer->pybuffer.buf, __pyx_t_23, __pyx_pybuffernd_ii.diminfo[0].strides, __pyx_t_24, __pyx_pybuffernd_ii.diminfo[1].strides)) <= ((__pyx_t_5numpy_intp_t)LONG_MAX));
        if (__pyx_t_4) {

          /* "pyart/map/ckdtree.pyx":1275
 *                     # ... e.g. Windows 64
 *                     if ii[0,0] <= <np.intp_t>LONG_MAX:
 *                         return dd[0,0], int(ii[0,0])             # <<<<<<<<<<<<<<
 *                     else:
 *                         return dd[0,0], ii[0,0]
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_25 = 0;
          __pyx_t_26 = 0;
          __pyx_t_1 = PyFloat_FromDouble((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_dd.rcbuffer->pybuffer.buf, __pyx_t_25, __pyx_pybuffernd_dd.diminfo[0].strides, __pyx_t_26, __pyx_pybuffernd_dd.diminfo[1].strides))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          __pyx_t_27 = 0;
          __pyx_t_28 = 0;
          __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_ii.rcbuffer->pybuffer.buf, __pyx_t_27, __pyx_pybuffernd_ii.diminfo[0].strides, __pyx_t_28, __pyx_pybuffernd_ii.diminfo[1].strides))); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_5);
          __pyx_t_5 = 0;
          __pyx_t_5 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_13), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __Pyx_DECREF(((PyObject *)__pyx_t_13)); __pyx_t_13 = 0;
          __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1275; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_1);
          __Pyx_GIVEREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_5);
          __pyx_t_1 = 0;
          __pyx_t_5 = 0;
          __pyx_r = ((PyObject *)__pyx_t_13);
          __pyx_t_13 = 0;
          goto __pyx_L0;
          goto __pyx_L11;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":1277
 *                         return dd[0,0], int(ii[0,0])
 *                     else:
 *                         return dd[0,0], ii[0,0]             # <<<<<<<<<<<<<<
 *                 else:
 *                     # ... most other platforms
 */
          __Pyx_XDECREF(__pyx_r);
          __pyx_t_29 = 0;
          __pyx_t_30 = 0;
          __pyx_t_13 = PyFloat_FromDouble((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_dd.rcbuffer->pybuffer.buf, __pyx_t_29, __pyx_pybuffernd_dd.diminfo[0].strides, __pyx_t_30, __pyx_pybuffernd_dd.diminfo[1].strides))); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_13);
          __pyx_t_31 = 0;
          __pyx_t_32 = 0;
          __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_ii.rcbuffer->pybuffer.buf, __pyx_t_31, __pyx_pybuffernd_ii.diminfo[0].strides, __pyx_t_32, __pyx_pybuffernd_ii.diminfo[1].strides))); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_5);
          __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1277; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          __Pyx_GOTREF(__pyx_t_1);
          PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_13);
          __Pyx_GIVEREF(__pyx_t_13);
          PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
          __Pyx_GIVEREF(__pyx_t_5);
          __pyx_t_13 = 0;
          __pyx_t_5 = 0;
          __pyx_r = ((PyObject *)__pyx_t_1);
          __pyx_t_1 = 0;
          goto __pyx_L0;
        }
        __pyx_L11:;
        goto __pyx_L10;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1280
 *                 else:
 *                     # ... most other platforms
 *                     return dd[0,0], ii[0,0]             # <<<<<<<<<<<<<<
 *             else:
 *                 return dd[0], ii[0]
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_33 = 0;
        __pyx_t_34 = 0;
        __pyx_t_1 = PyFloat_FromDouble((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_dd.rcbuffer->pybuffer.buf, __pyx_t_33, __pyx_pybuffernd_dd.diminfo[0].strides, __pyx_t_34, __pyx_pybuffernd_dd.diminfo[1].strides))); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __pyx_t_35 = 0;
        __pyx_t_36 = 0;
        __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_ii.rcbuffer->pybuffer.buf, __pyx_t_35, __pyx_pybuffernd_ii.diminfo[0].strides, __pyx_t_36, __pyx_pybuffernd_ii.diminfo[1].strides))); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1280; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_1 = 0;
        __pyx_t_5 = 0;
        __pyx_r = ((PyObject *)__pyx_t_13);
        __pyx_t_13 = 0;
        goto __pyx_L0;
      }
      __pyx_L10:;
      goto __pyx_L9;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1282
 *                     return dd[0,0], ii[0,0]
 *             else:
 *                 return dd[0], ii[0]             # <<<<<<<<<<<<<<
 *         else:
 *             if sizeof(long) < sizeof(np.intp_t):
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_13 = __Pyx_GetItemInt(((PyObject *)__pyx_v_dd), 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_13) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_13);
      __pyx_t_5 = __Pyx_GetItemInt(((PyObject *)__pyx_v_ii), 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1282; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_13);
      __Pyx_GIVEREF(__pyx_t_13);
      PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
      __Pyx_GIVEREF(__pyx_t_5);
      __pyx_t_13 = 0;
      __pyx_t_5 = 0;
      __pyx_r = ((PyObject *)__pyx_t_1);
      __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    __pyx_L9:;
    goto __pyx_L8;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1284
 *                 return dd[0], ii[0]
 *         else:
 *             if sizeof(long) < sizeof(np.intp_t):             # <<<<<<<<<<<<<<
 *                 # ... e.g. Windows 64
 *                 for i in range(n):
 */
    __pyx_t_4 = ((sizeof(long)) < (sizeof(__pyx_t_5numpy_intp_t)));
    if (__pyx_t_4) {

      /* "pyart/map/ckdtree.pyx":1286
 *             if sizeof(long) < sizeof(np.intp_t):
 *                 # ... e.g. Windows 64
 *                 for i in range(n):             # <<<<<<<<<<<<<<
 *                     for j in range(k):
 *                         if ii[i,j] > <np.intp_t>LONG_MAX:
 */
      __pyx_t_7 = __pyx_v_n;
      for (__pyx_t_16 = 0; __pyx_t_16 < __pyx_t_7; __pyx_t_16+=1) {
        __pyx_v_i = __pyx_t_16;

        /* "pyart/map/ckdtree.pyx":1287
 *                 # ... e.g. Windows 64
 *                 for i in range(n):
 *                     for j in range(k):             # <<<<<<<<<<<<<<
 *                         if ii[i,j] > <np.intp_t>LONG_MAX:
 *                             # C long overlow, return array of dtype=np.int_p
 */
        __pyx_t_37 = __pyx_v_k;
        for (__pyx_t_38 = 0; __pyx_t_38 < __pyx_t_37; __pyx_t_38+=1) {
          __pyx_v_j = __pyx_t_38;

          /* "pyart/map/ckdtree.pyx":1288
 *                 for i in range(n):
 *                     for j in range(k):
 *                         if ii[i,j] > <np.intp_t>LONG_MAX:             # <<<<<<<<<<<<<<
 *                             # C long overlow, return array of dtype=np.int_p
 *                             if k==1:
 */
          __pyx_t_39 = __pyx_v_i;
          __pyx_t_40 = __pyx_v_j;
          __pyx_t_4 = ((*__Pyx_BufPtrStrided2d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_ii.rcbuffer->pybuffer.buf, __pyx_t_39, __pyx_pybuffernd_ii.diminfo[0].strides, __pyx_t_40, __pyx_pybuffernd_ii.diminfo[1].strides)) > ((__pyx_t_5numpy_intp_t)LONG_MAX));
          if (__pyx_t_4) {

            /* "pyart/map/ckdtree.pyx":1290
 *                         if ii[i,j] > <np.intp_t>LONG_MAX:
 *                             # C long overlow, return array of dtype=np.int_p
 *                             if k==1:             # <<<<<<<<<<<<<<
 *                                 return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)
 *                             else:
 */
            __pyx_t_4 = (__pyx_v_k == 1);
            if (__pyx_t_4) {

              /* "pyart/map/ckdtree.pyx":1291
 *                             # C long overlow, return array of dtype=np.int_p
 *                             if k==1:
 *                                 return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)             # <<<<<<<<<<<<<<
 *                             else:
 *                                 return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,))
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_5 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__reshape); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_t_1 = PyObject_GetItem(((PyObject *)__pyx_v_dd), ((PyObject *)__pyx_k_tuple_13)); if (!__pyx_t_1) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_13);
              PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_1);
              __Pyx_GIVEREF(__pyx_t_1);
              __Pyx_INCREF(__pyx_v_retshape);
              PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_v_retshape);
              __Pyx_GIVEREF(__pyx_v_retshape);
              __pyx_t_1 = 0;
              __pyx_t_1 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_13), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(((PyObject *)__pyx_t_13)); __pyx_t_13 = 0;
              __pyx_t_13 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_5 = PyObject_GetAttr(__pyx_t_13, __pyx_n_s__reshape); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __pyx_t_13 = PyObject_GetItem(((PyObject *)__pyx_v_ii), ((PyObject *)__pyx_k_tuple_14)); if (!__pyx_t_13) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_13);
              __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_2);
              PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_13);
              __Pyx_GIVEREF(__pyx_t_13);
              __Pyx_INCREF(__pyx_v_retshape);
              PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_retshape);
              __Pyx_GIVEREF(__pyx_v_retshape);
              __pyx_t_13 = 0;
              __pyx_t_13 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
              __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
              __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_2);
              PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
              __Pyx_GIVEREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_13);
              __Pyx_GIVEREF(__pyx_t_13);
              __pyx_t_1 = 0;
              __pyx_t_13 = 0;
              __pyx_r = ((PyObject *)__pyx_t_2);
              __pyx_t_2 = 0;
              goto __pyx_L0;
              goto __pyx_L18;
            }
            /*else*/ {

              /* "pyart/map/ckdtree.pyx":1293
 *                                 return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)
 *                             else:
 *                                 return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,))             # <<<<<<<<<<<<<<
 * 
 *                 # no C long overlow, return array of dtype=int
 */
              __Pyx_XDECREF(__pyx_r);
              __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_13 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__reshape); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
              __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_2);
              __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
              __Pyx_GIVEREF(__pyx_t_2);
              __pyx_t_2 = 0;
              __pyx_t_2 = PyNumber_Add(__pyx_v_retshape, ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
              __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_INCREF(((PyObject *)__pyx_v_dd));
              PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_dd));
              __Pyx_GIVEREF(((PyObject *)__pyx_v_dd));
              PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_2);
              __Pyx_GIVEREF(__pyx_t_2);
              __pyx_t_2 = 0;
              __pyx_t_2 = PyObject_Call(__pyx_t_13, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_2);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
              __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_13 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__reshape); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_13);
              __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
              __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_5);
              PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_1);
              __Pyx_GIVEREF(__pyx_t_1);
              __pyx_t_1 = 0;
              __pyx_t_1 = PyNumber_Add(__pyx_v_retshape, ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
              __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_5);
              __Pyx_INCREF(((PyObject *)__pyx_v_ii));
              PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_ii));
              __Pyx_GIVEREF(((PyObject *)__pyx_v_ii));
              PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
              __Pyx_GIVEREF(__pyx_t_1);
              __pyx_t_1 = 0;
              __pyx_t_1 = PyObject_Call(__pyx_t_13, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_1);
              __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
              __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
              __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1293; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
              __Pyx_GOTREF(__pyx_t_5);
              PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
              __Pyx_GIVEREF(__pyx_t_2);
              PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
              __Pyx_GIVEREF(__pyx_t_1);
              __pyx_t_2 = 0;
              __pyx_t_1 = 0;
              __pyx_r = ((PyObject *)__pyx_t_5);
              __pyx_t_5 = 0;
              goto __pyx_L0;
            }
            __pyx_L18:;
            goto __pyx_L17;
          }
          __pyx_L17:;
        }
      }

      /* "pyart/map/ckdtree.pyx":1296
 * 
 *                 # no C long overlow, return array of dtype=int
 *                 if k==1:             # <<<<<<<<<<<<<<
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape).astype(int)
 *                 else:
 */
      __pyx_t_4 = (__pyx_v_k == 1);
      if (__pyx_t_4) {

        /* "pyart/map/ckdtree.pyx":1297
 *                 # no C long overlow, return array of dtype=int
 *                 if k==1:
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape).astype(int)             # <<<<<<<<<<<<<<
 *                 else:
 *                     return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,)).astype(int)
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__reshape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_GetItem(((PyObject *)__pyx_v_dd), ((PyObject *)__pyx_k_tuple_15)); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_retshape);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_retshape);
        __Pyx_GIVEREF(__pyx_v_retshape);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__reshape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = PyObject_GetItem(((PyObject *)__pyx_v_ii), ((PyObject *)__pyx_k_tuple_16)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_v_retshape);
        PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_v_retshape);
        __Pyx_GIVEREF(__pyx_v_retshape);
        __pyx_t_2 = 0;
        __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_13), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_13)); __pyx_t_13 = 0;
        __pyx_t_13 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__astype); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_INCREF(((PyObject *)((PyObject*)(&PyInt_Type))));
        PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)((PyObject*)(&PyInt_Type))));
        __Pyx_GIVEREF(((PyObject *)((PyObject*)(&PyInt_Type))));
        __pyx_t_1 = PyObject_Call(__pyx_t_13, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_5 = 0;
        __pyx_t_1 = 0;
        __pyx_r = ((PyObject *)__pyx_t_2);
        __pyx_t_2 = 0;
        goto __pyx_L0;
        goto __pyx_L19;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1299
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape).astype(int)
 *                 else:
 *                     return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,)).astype(int)             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__reshape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_2 = PyNumber_Add(__pyx_v_retshape, ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(((PyObject *)__pyx_v_dd));
        PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_dd));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_dd));
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        __pyx_t_2 = 0;
        __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__reshape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_13 = PyTuple_New(1); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_Add(__pyx_v_retshape, ((PyObject *)__pyx_t_13)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_13)); __pyx_t_13 = 0;
        __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_INCREF(((PyObject *)__pyx_v_ii));
        PyTuple_SET_ITEM(__pyx_t_13, 0, ((PyObject *)__pyx_v_ii));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_ii));
        PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_13), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_13)); __pyx_t_13 = 0;
        __pyx_t_13 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__astype); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(((PyObject *)((PyObject*)(&PyInt_Type))));
        PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)((PyObject*)(&PyInt_Type))));
        __Pyx_GIVEREF(((PyObject *)((PyObject*)(&PyInt_Type))));
        __pyx_t_1 = PyObject_Call(__pyx_t_13, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
        __Pyx_GIVEREF(__pyx_t_1);
        __pyx_t_2 = 0;
        __pyx_t_1 = 0;
        __pyx_r = ((PyObject *)__pyx_t_5);
        __pyx_t_5 = 0;
        goto __pyx_L0;
      }
      __pyx_L19:;
      goto __pyx_L12;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1303
 *             else:
 *                 # ... most other platforms
 *                 if k==1:             # <<<<<<<<<<<<<<
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)
 *                 else:
 */
      __pyx_t_4 = (__pyx_v_k == 1);
      if (__pyx_t_4) {

        /* "pyart/map/ckdtree.pyx":1304
 *                 # ... most other platforms
 *                 if k==1:
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)             # <<<<<<<<<<<<<<
 *                 else:
 *                     return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,))
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__reshape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_GetItem(((PyObject *)__pyx_v_dd), ((PyObject *)__pyx_k_tuple_17)); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __Pyx_INCREF(__pyx_v_retshape);
        PyTuple_SET_ITEM(__pyx_t_2, 1, __pyx_v_retshape);
        __Pyx_GIVEREF(__pyx_v_retshape);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
        __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__reshape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_t_2 = PyObject_GetItem(((PyObject *)__pyx_v_ii), ((PyObject *)__pyx_k_tuple_18)); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        __Pyx_INCREF(__pyx_v_retshape);
        PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_v_retshape);
        __Pyx_GIVEREF(__pyx_v_retshape);
        __pyx_t_2 = 0;
        __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_13), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_13)); __pyx_t_13 = 0;
        __pyx_t_13 = PyTuple_New(2); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_13, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_13, 1, __pyx_t_2);
        __Pyx_GIVEREF(__pyx_t_2);
        __pyx_t_5 = 0;
        __pyx_t_2 = 0;
        __pyx_r = ((PyObject *)__pyx_t_13);
        __pyx_t_13 = 0;
        goto __pyx_L0;
        goto __pyx_L20;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1306
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)
 *                 else:
 *                     return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,))             # <<<<<<<<<<<<<<
 * 
 *     # ----------------
 */
        __Pyx_XDECREF(__pyx_r);
        __pyx_t_13 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_2 = PyObject_GetAttr(__pyx_t_13, __pyx_n_s__reshape); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_13); __pyx_t_13 = 0;
        __pyx_t_13 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __pyx_t_5 = PyTuple_New(1); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_13);
        __pyx_t_13 = 0;
        __pyx_t_13 = PyNumber_Add(__pyx_v_retshape, ((PyObject *)__pyx_t_5)); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
        __pyx_t_5 = PyTuple_New(2); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_INCREF(((PyObject *)__pyx_v_dd));
        PyTuple_SET_ITEM(__pyx_t_5, 0, ((PyObject *)__pyx_v_dd));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_dd));
        PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_13);
        __pyx_t_13 = 0;
        __pyx_t_13 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_5), NULL); if (unlikely(!__pyx_t_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_13);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_5)); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_2 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__reshape); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        __pyx_t_5 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_k); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyNumber_Add(__pyx_v_retshape, ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        __Pyx_INCREF(((PyObject *)__pyx_v_ii));
        PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_ii));
        __Pyx_GIVEREF(((PyObject *)__pyx_v_ii));
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
        __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1306; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_1);
        PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_13);
        __Pyx_GIVEREF(__pyx_t_13);
        PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_t_5);
        __Pyx_GIVEREF(__pyx_t_5);
        __pyx_t_13 = 0;
        __pyx_t_5 = 0;
        __pyx_r = ((PyObject *)__pyx_t_1);
        __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      __pyx_L20:;
    }
    __pyx_L12:;
  }
  __pyx_L8:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_13);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_dd.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_ii.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_dd.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_ii.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_ii);
  __Pyx_XDECREF((PyObject *)__pyx_v_dd);
  __Pyx_XDECREF((PyObject *)__pyx_v_xx);
  __Pyx_XDECREF(__pyx_v_retshape);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1311
 *     # query_ball_point
 *     # ----------------
 *     cdef int __query_ball_point_traverse_no_checking(cKDTree self,             # <<<<<<<<<<<<<<
 *                                                      list results,
 *                                                      innernode* node) except -1:
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_point_traverse_no_checking(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_results, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  int __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query_ball_point_traverse_no_checking", 0);

  /* "pyart/map/ckdtree.pyx":1317
 *         cdef np.intp_t i
 * 
 *         if node.split_dim == -1:  # leaf node             # <<<<<<<<<<<<<<
 *             lnode = <leafnode*> node
 *             for i in range(lnode.start_idx, lnode.end_idx):
 */
  __pyx_t_1 = (__pyx_v_node->split_dim == -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1318
 * 
 *         if node.split_dim == -1:  # leaf node
 *             lnode = <leafnode*> node             # <<<<<<<<<<<<<<
 *             for i in range(lnode.start_idx, lnode.end_idx):
 *                 list_append(results, self.raw_indices[i])
 */
    __pyx_v_lnode = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node);

    /* "pyart/map/ckdtree.pyx":1319
 *         if node.split_dim == -1:  # leaf node
 *             lnode = <leafnode*> node
 *             for i in range(lnode.start_idx, lnode.end_idx):             # <<<<<<<<<<<<<<
 *                 list_append(results, self.raw_indices[i])
 *         else:
 */
    __pyx_t_2 = __pyx_v_lnode->end_idx;
    for (__pyx_t_3 = __pyx_v_lnode->start_idx; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
      __pyx_v_i = __pyx_t_3;

      /* "pyart/map/ckdtree.pyx":1320
 *             lnode = <leafnode*> node
 *             for i in range(lnode.start_idx, lnode.end_idx):
 *                 list_append(results, self.raw_indices[i])             # <<<<<<<<<<<<<<
 *         else:
 *             self.__query_ball_point_traverse_no_checking(results, node.less)
 */
      __pyx_t_4 = __pyx_f_5pyart_3map_7ckdtree_list_append(__pyx_v_results, (__pyx_v_self->raw_indices[__pyx_v_i])); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1320; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1322
 *                 list_append(results, self.raw_indices[i])
 *         else:
 *             self.__query_ball_point_traverse_no_checking(results, node.less)             # <<<<<<<<<<<<<<
 *             self.__query_ball_point_traverse_no_checking(results, node.greater)
 * 
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node->less); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1322; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/map/ckdtree.pyx":1323
 *         else:
 *             self.__query_ball_point_traverse_no_checking(results, node.less)
 *             self.__query_ball_point_traverse_no_checking(results, node.greater)             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_t_4 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node->greater); if (unlikely(__pyx_t_4 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1323; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1325
 *             self.__query_ball_point_traverse_no_checking(results, node.greater)
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query_ball_point_traverse_no_checking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1329
 * 
 *     @cython.cdivision(True)
 *     cdef int __query_ball_point_traverse_checking(cKDTree self,             # <<<<<<<<<<<<<<
 *                                                   list results,
 *                                                   innernode* node,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_point_traverse_checking(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_results, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node, struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_tracker) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode;
  __pyx_t_5numpy_float64_t __pyx_v_d;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  __pyx_t_5numpy_intp_t __pyx_t_4;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query_ball_point_traverse_checking", 0);

  /* "pyart/map/ckdtree.pyx":1337
 *         cdef np.intp_t i
 * 
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:             # <<<<<<<<<<<<<<
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 */
  __pyx_t_1 = (__pyx_v_tracker->min_distance > (__pyx_v_tracker->upper_bound * __pyx_v_tracker->epsfac));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1338
 * 
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:
 *             return 0             # <<<<<<<<<<<<<<
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_ball_point_traverse_no_checking(results, node)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":1339
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:             # <<<<<<<<<<<<<<
 *             self.__query_ball_point_traverse_no_checking(results, node)
 *         elif node.split_dim == -1:  # leaf node
 */
  __pyx_t_1 = (__pyx_v_tracker->max_distance < (__pyx_v_tracker->upper_bound / __pyx_v_tracker->epsfac));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1340
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_ball_point_traverse_no_checking(results, node)             # <<<<<<<<<<<<<<
 *         elif node.split_dim == -1:  # leaf node
 *             lnode = <leafnode*>node
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1340; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":1341
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_ball_point_traverse_no_checking(results, node)
 *         elif node.split_dim == -1:  # leaf node             # <<<<<<<<<<<<<<
 *             lnode = <leafnode*>node
 *             # brute-force
 */
  __pyx_t_1 = (__pyx_v_node->split_dim == -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1342
 *             self.__query_ball_point_traverse_no_checking(results, node)
 *         elif node.split_dim == -1:  # leaf node
 *             lnode = <leafnode*>node             # <<<<<<<<<<<<<<
 *             # brute-force
 *             for i in range(lnode.start_idx, lnode.end_idx):
 */
    __pyx_v_lnode = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node);

    /* "pyart/map/ckdtree.pyx":1344
 *             lnode = <leafnode*>node
 *             # brute-force
 *             for i in range(lnode.start_idx, lnode.end_idx):             # <<<<<<<<<<<<<<
 *                 d = _distance_p(
 *                     self.raw_data + self.raw_indices[i] * self.m,
 */
    __pyx_t_3 = __pyx_v_lnode->end_idx;
    for (__pyx_t_4 = __pyx_v_lnode->start_idx; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
      __pyx_v_i = __pyx_t_4;

      /* "pyart/map/ckdtree.pyx":1347
 *                 d = _distance_p(
 *                     self.raw_data + self.raw_indices[i] * self.m,
 *                     tracker.pt, tracker.p, self.m, tracker.upper_bound)             # <<<<<<<<<<<<<<
 *                 if d <= tracker.upper_bound:
 *                     list_append(results, self.raw_indices[i])
 */
      __pyx_v_d = __pyx_f_5pyart_3map_7ckdtree__distance_p((__pyx_v_self->raw_data + ((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m)), __pyx_v_tracker->pt, __pyx_v_tracker->p, __pyx_v_self->m, __pyx_v_tracker->upper_bound);

      /* "pyart/map/ckdtree.pyx":1348
 *                     self.raw_data + self.raw_indices[i] * self.m,
 *                     tracker.pt, tracker.p, self.m, tracker.upper_bound)
 *                 if d <= tracker.upper_bound:             # <<<<<<<<<<<<<<
 *                     list_append(results, self.raw_indices[i])
 *         else:
 */
      __pyx_t_1 = (__pyx_v_d <= __pyx_v_tracker->upper_bound);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":1349
 *                     tracker.pt, tracker.p, self.m, tracker.upper_bound)
 *                 if d <= tracker.upper_bound:
 *                     list_append(results, self.raw_indices[i])             # <<<<<<<<<<<<<<
 *         else:
 *             tracker.push_less_of(node)
 */
        __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_list_append(__pyx_v_results, (__pyx_v_self->raw_indices[__pyx_v_i])); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1349; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L6;
      }
      __pyx_L6:;
    }
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1351
 *                     list_append(results, self.raw_indices[i])
 *         else:
 *             tracker.push_less_of(node)             # <<<<<<<<<<<<<<
 *             self.__query_ball_point_traverse_checking(
 *                 results, node.less, tracker)
 */
    __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_less_of(__pyx_v_tracker, __pyx_v_node); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1351; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/map/ckdtree.pyx":1353
 *             tracker.push_less_of(node)
 *             self.__query_ball_point_traverse_checking(
 *                 results, node.less, tracker)             # <<<<<<<<<<<<<<
 *             tracker.pop()
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node->less, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1352; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/map/ckdtree.pyx":1354
 *             self.__query_ball_point_traverse_checking(
 *                 results, node.less, tracker)
 *             tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *             tracker.push_greater_of(node)
 */
    __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1354; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/map/ckdtree.pyx":1356
 *             tracker.pop()
 * 
 *             tracker.push_greater_of(node)             # <<<<<<<<<<<<<<
 *             self.__query_ball_point_traverse_checking(
 *                 results, node.greater, tracker)
 */
    __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_greater_of(__pyx_v_tracker, __pyx_v_node); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1356; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/map/ckdtree.pyx":1358
 *             tracker.push_greater_of(node)
 *             self.__query_ball_point_traverse_checking(
 *                 results, node.greater, tracker)             # <<<<<<<<<<<<<<
 *             tracker.pop()
 * 
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node->greater, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1357; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/map/ckdtree.pyx":1359
 *             self.__query_ball_point_traverse_checking(
 *                 results, node.greater, tracker)
 *             tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1359; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1361
 *             tracker.pop()
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query_ball_point_traverse_checking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1364
 * 
 * 
 *     cdef list __query_ball_point(cKDTree self,             # <<<<<<<<<<<<<<
 *                                  np.float64_t* x,
 *                                  np.float64_t r,
 */

static PyObject *__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_point(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, __pyx_t_5numpy_float64_t *__pyx_v_x, __pyx_t_5numpy_float64_t __pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps) {
  struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *__pyx_v_tracker = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  int __pyx_t_3;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query_ball_point", 0);

  /* "pyart/map/ckdtree.pyx":1370
 *                                  np.float64_t eps):
 * 
 *         tracker = PointRectDistanceTracker()             # <<<<<<<<<<<<<<
 *         tracker.init(x, Rectangle(self.mins, self.maxes),
 *                      p, eps, r)
 */
  __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_PointRectDistanceTracker)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1370; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_tracker = ((struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1371
 * 
 *         tracker = PointRectDistanceTracker()
 *         tracker.init(x, Rectangle(self.mins, self.maxes),             # <<<<<<<<<<<<<<
 *                      p, eps, r)
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1371; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mins));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->maxes));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1371; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1372
 *         tracker = PointRectDistanceTracker()
 *         tracker.init(x, Rectangle(self.mins, self.maxes),
 *                      p, eps, r)             # <<<<<<<<<<<<<<
 * 
 *         results = []
 */
  __pyx_t_1 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker *)__pyx_v_tracker->__pyx_vtab)->init(__pyx_v_tracker, __pyx_v_x, ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)__pyx_t_2), __pyx_v_p, __pyx_v_eps, __pyx_v_r); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1371; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1374
 *                      p, eps, r)
 * 
 *         results = []             # <<<<<<<<<<<<<<
 *         self.__query_ball_point_traverse_checking(
 *             results, self.tree, tracker)
 */
  __pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1374; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_v_results = __pyx_t_1;
  __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1376
 *         results = []
 *         self.__query_ball_point_traverse_checking(
 *             results, self.tree, tracker)             # <<<<<<<<<<<<<<
 *         return results
 * 
 */
  __pyx_t_3 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_self->tree, __pyx_v_tracker); if (unlikely(__pyx_t_3 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1375; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":1377
 *         self.__query_ball_point_traverse_checking(
 *             results, self.tree, tracker)
 *         return results             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  __Pyx_INCREF(((PyObject *)__pyx_v_results));
  __pyx_r = __pyx_v_results;
  goto __pyx_L0;

  __pyx_r = ((PyObject*)Py_None); __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query_ball_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tracker);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_7query_ball_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_3map_7ckdtree_7cKDTree_6query_ball_point[] = "query_ball_point(self, x, r, p, eps)\n        \n        Find all points within distance r of point(s) x.\n\n        Parameters\n        ----------\n        x : array_like, shape tuple + (self.m,)\n            The point or points to search for neighbors of.\n        r : positive float\n            The radius of points to return.\n        p : float, optional\n            Which Minkowski p-norm to use.  Should be in the range [1, inf].\n        eps : nonnegative float, optional\n            Approximate search. Branches of the tree are not explored if their\n            nearest points are further than ``r / (1 + eps)``, and branches are\n            added in bulk if their furthest points are nearer than\n            ``r * (1 + eps)``.\n\n        Returns\n        -------\n        results : list or array of lists\n            If `x` is a single point, returns a list of the indices of the\n            neighbors of `x`. If `x` is an array of points, returns an object\n            array of shape tuple containing lists of neighbors.\n\n        Notes\n        -----\n        If you have many points whose neighbors you want to find, you may save\n        substantial amounts of time by putting them in a cKDTree and using\n        query_ball_tree.\n\n        Examples\n        --------\n        >>> from scipy import spatial\n        >>> x, y = np.mgrid[0:4, 0:4]\n        >>> points = zip(x.ravel(), y.ravel())\n        >>> tree = spatial.cKDTree(points)\n        >>> tree.query_ball_point([2, 0], 1)\n        [4, 8, 9, 12]\n\n        ";
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_7query_ball_point(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_x = 0;
  __pyx_t_5numpy_float64_t __pyx_v_r;
  __pyx_t_5numpy_float64_t __pyx_v_p;
  __pyx_t_5numpy_float64_t __pyx_v_eps;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_ball_point (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__x,&__pyx_n_s__r,&__pyx_n_s__p,&__pyx_n_s__eps,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__x)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__r)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("query_ball_point", 0, 2, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1380; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__p);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__eps);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "query_ball_point") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1380; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_x = values[0];
    __pyx_v_r = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_r == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1380; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    if (values[2]) {
      __pyx_v_p = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_p == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1381; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":1381
 * 
 *     def query_ball_point(cKDTree self, object x, np.float64_t r,
 *                          np.float64_t p=2., np.float64_t eps=0):             # <<<<<<<<<<<<<<
 *         """query_ball_point(self, x, r, p, eps)
 * 
 */
      __pyx_v_p = ((__pyx_t_5numpy_float64_t)2.);
    }
    if (values[3]) {
      __pyx_v_eps = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_eps == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1381; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_eps = ((__pyx_t_5numpy_float64_t)0.0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("query_ball_point", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1380; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query_ball_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_6query_ball_point(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self), __pyx_v_x, __pyx_v_r, __pyx_v_p, __pyx_v_eps);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1380
 * 
 * 
 *     def query_ball_point(cKDTree self, object x, np.float64_t r,             # <<<<<<<<<<<<<<
 *                          np.float64_t p=2., np.float64_t eps=0):
 *         """query_ball_point(self, x, r, p, eps)
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_6query_ball_point(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_x, __pyx_t_5numpy_float64_t __pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps) {
  PyArrayObject *__pyx_v_xx = 0;
  PyObject *__pyx_v_retshape = NULL;
  PyObject *__pyx_v_result = NULL;
  PyObject *__pyx_v_c = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_xx;
  __Pyx_Buffer __pyx_pybuffer_xx;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  int __pyx_t_4;
  Py_ssize_t __pyx_t_5;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  PyArrayObject *__pyx_t_8 = NULL;
  int __pyx_t_9;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  PyObject *__pyx_t_12 = NULL;
  long __pyx_t_13;
  PyObject *(*__pyx_t_14)(PyObject *);
  PyObject *__pyx_t_15 = NULL;
  long __pyx_t_16;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_ball_point", 0);
  __Pyx_INCREF(__pyx_v_x);
  __pyx_pybuffer_xx.pybuffer.buf = NULL;
  __pyx_pybuffer_xx.refcount = 0;
  __pyx_pybuffernd_xx.data = NULL;
  __pyx_pybuffernd_xx.rcbuffer = &__pyx_pybuffer_xx;

  /* "pyart/map/ckdtree.pyx":1425
 *         cdef np.ndarray[np.float64_t, ndim=1, mode="c"] xx
 * 
 *         x = np.asarray(x).astype(np.float64)             # <<<<<<<<<<<<<<
 *         if x.shape[-1] != self.m:
 *             raise ValueError("Searching for a %d-dimensional point in a " \
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__asarray); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v_x);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_x);
  __Pyx_GIVEREF(__pyx_v_x);
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __pyx_t_1 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__astype); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__float64); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1425; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_v_x);
  __pyx_v_x = __pyx_t_2;
  __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1426
 * 
 *         x = np.asarray(x).astype(np.float64)
 *         if x.shape[-1] != self.m:             # <<<<<<<<<<<<<<
 *             raise ValueError("Searching for a %d-dimensional point in a " \
 *                              "%d-dimensional KDTree" % (int(x.shape[-1]), int(self.m)))
 */
  __pyx_t_2 = PyObject_GetAttr(__pyx_v_x, __pyx_n_s__shape); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1426; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_GetItemInt(__pyx_t_2, -1, sizeof(long), PyInt_FromLong); if (!__pyx_t_3) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1426; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->m); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1426; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_1 = PyObject_RichCompare(__pyx_t_3, __pyx_t_2, Py_NE); __Pyx_XGOTREF(__pyx_t_1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1426; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_4 = __Pyx_PyObject_IsTrue(__pyx_t_1); if (unlikely(__pyx_t_4 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1426; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":1428
 *         if x.shape[-1] != self.m:
 *             raise ValueError("Searching for a %d-dimensional point in a " \
 *                              "%d-dimensional KDTree" % (int(x.shape[-1]), int(self.m)))             # <<<<<<<<<<<<<<
 *         if len(x.shape) == 1:
 *             xx = np.ascontiguousarray(x, dtype=np.float64)
 */
    __pyx_t_1 = PyObject_GetAttr(__pyx_v_x, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_1, -1, sizeof(long), PyInt_FromLong); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    __pyx_t_2 = 0;
    __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->m); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_2);
    PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_1);
    __Pyx_GIVEREF(__pyx_t_1);
    __pyx_t_2 = 0;
    __pyx_t_1 = 0;
    __pyx_t_1 = PyNumber_Remainder(((PyObject *)__pyx_kp_s_19), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1428; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_1));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_1));
    __pyx_t_1 = 0;
    __pyx_t_1 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_Raise(__pyx_t_1, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1427; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1429
 *             raise ValueError("Searching for a %d-dimensional point in a " \
 *                              "%d-dimensional KDTree" % (int(x.shape[-1]), int(self.m)))
 *         if len(x.shape) == 1:             # <<<<<<<<<<<<<<
 *             xx = np.ascontiguousarray(x, dtype=np.float64)
 *             return self.__query_ball_point(&xx[0], r, p, eps)
 */
  __pyx_t_1 = PyObject_GetAttr(__pyx_v_x, __pyx_n_s__shape); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1429; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyObject_Length(__pyx_t_1); if (unlikely(__pyx_t_5 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1429; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_4 = (__pyx_t_5 == 1);
  if (__pyx_t_4) {

    /* "pyart/map/ckdtree.pyx":1430
 *                              "%d-dimensional KDTree" % (int(x.shape[-1]), int(self.m)))
 *         if len(x.shape) == 1:
 *             xx = np.ascontiguousarray(x, dtype=np.float64)             # <<<<<<<<<<<<<<
 *             return self.__query_ball_point(&xx[0], r, p, eps)
 *         else:
 */
    __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__ascontiguousarray); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_INCREF(__pyx_v_x);
    PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_x);
    __Pyx_GIVEREF(__pyx_v_x);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __pyx_t_6 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_7 = PyObject_GetAttr(__pyx_t_6, __pyx_n_s__float64); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), __pyx_t_7) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_7) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_7, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_8 = ((PyArrayObject *)__pyx_t_7);
    {
      __Pyx_BufFmt_StackElem __pyx_stack[1];
      __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
      __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
      if (unlikely(__pyx_t_9 < 0)) {
        PyErr_Fetch(&__pyx_t_10, &__pyx_t_11, &__pyx_t_12);
        if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_v_xx, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
          Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_12);
          __Pyx_RaiseBufferFallbackError();
        } else {
          PyErr_Restore(__pyx_t_10, __pyx_t_11, __pyx_t_12);
        }
      }
      __pyx_pybuffernd_xx.diminfo[0].strides = __pyx_pybuffernd_xx.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_xx.diminfo[0].shape = __pyx_pybuffernd_xx.rcbuffer->pybuffer.shape[0];
      if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1430; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_8 = 0;
    __pyx_v_xx = ((PyArrayObject *)__pyx_t_7);
    __pyx_t_7 = 0;

    /* "pyart/map/ckdtree.pyx":1431
 *         if len(x.shape) == 1:
 *             xx = np.ascontiguousarray(x, dtype=np.float64)
 *             return self.__query_ball_point(&xx[0], r, p, eps)             # <<<<<<<<<<<<<<
 *         else:
 *             retshape = x.shape[:-1]
 */
    __Pyx_XDECREF(__pyx_r);
    __pyx_t_13 = 0;
    __pyx_t_9 = -1;
    if (__pyx_t_13 < 0) {
      __pyx_t_13 += __pyx_pybuffernd_xx.diminfo[0].shape;
      if (unlikely(__pyx_t_13 < 0)) __pyx_t_9 = 0;
    } else if (unlikely(__pyx_t_13 >= __pyx_pybuffernd_xx.diminfo[0].shape)) __pyx_t_9 = 0;
    if (unlikely(__pyx_t_9 != -1)) {
      __Pyx_RaiseBufferIndexError(__pyx_t_9);
      {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1431; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_7 = ((PyObject *)((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point(__pyx_v_self, (&(*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_xx.rcbuffer->pybuffer.buf, __pyx_t_13, __pyx_pybuffernd_xx.diminfo[0].strides))), __pyx_v_r, __pyx_v_p, __pyx_v_eps)); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1431; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_r = __pyx_t_7;
    __pyx_t_7 = 0;
    goto __pyx_L0;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1433
 *             return self.__query_ball_point(&xx[0], r, p, eps)
 *         else:
 *             retshape = x.shape[:-1]             # <<<<<<<<<<<<<<
 *             result = np.empty(retshape, dtype=np.object)
 *             for c in np.ndindex(retshape):
 */
    __pyx_t_7 = PyObject_GetAttr(__pyx_v_x, __pyx_n_s__shape); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = __Pyx_PySequence_GetSlice(__pyx_t_7, 0, -1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1433; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_v_retshape = __pyx_t_2;
    __pyx_t_2 = 0;

    /* "pyart/map/ckdtree.pyx":1434
 *         else:
 *             retshape = x.shape[:-1]
 *             result = np.empty(retshape, dtype=np.object)             # <<<<<<<<<<<<<<
 *             for c in np.ndindex(retshape):
 *                 xx = np.ascontiguousarray(x[c], dtype=np.float64)
 */
    __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__empty); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_retshape);
    PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_retshape);
    __Pyx_GIVEREF(__pyx_v_retshape);
    __pyx_t_1 = PyDict_New(); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_1));
    __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__object); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (PyDict_SetItem(__pyx_t_1, ((PyObject *)__pyx_n_s__dtype), __pyx_t_6) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyObject_Call(__pyx_t_7, ((PyObject *)__pyx_t_2), ((PyObject *)__pyx_t_1)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1434; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
    __pyx_v_result = __pyx_t_6;
    __pyx_t_6 = 0;

    /* "pyart/map/ckdtree.pyx":1435
 *             retshape = x.shape[:-1]
 *             result = np.empty(retshape, dtype=np.object)
 *             for c in np.ndindex(retshape):             # <<<<<<<<<<<<<<
 *                 xx = np.ascontiguousarray(x[c], dtype=np.float64)
 *                 result[c] = self.__query_ball_point(&xx[0], r, p, eps)
 */
    __pyx_t_6 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __pyx_t_1 = PyObject_GetAttr(__pyx_t_6, __pyx_n_s__ndindex); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_INCREF(__pyx_v_retshape);
    PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_retshape);
    __Pyx_GIVEREF(__pyx_v_retshape);
    __pyx_t_2 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
    if (PyList_CheckExact(__pyx_t_2) || PyTuple_CheckExact(__pyx_t_2)) {
      __pyx_t_6 = __pyx_t_2; __Pyx_INCREF(__pyx_t_6); __pyx_t_5 = 0;
      __pyx_t_14 = NULL;
    } else {
      __pyx_t_5 = -1; __pyx_t_6 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_6);
      __pyx_t_14 = Py_TYPE(__pyx_t_6)->tp_iternext;
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    for (;;) {
      if (!__pyx_t_14 && PyList_CheckExact(__pyx_t_6)) {
        if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_2 = PyList_GET_ITEM(__pyx_t_6, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_6, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else if (!__pyx_t_14 && PyTuple_CheckExact(__pyx_t_6)) {
        if (__pyx_t_5 >= PyTuple_GET_SIZE(__pyx_t_6)) break;
        #if CYTHON_COMPILING_IN_CPYTHON
        __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_6, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #else
        __pyx_t_2 = PySequence_ITEM(__pyx_t_6, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        #endif
      } else {
        __pyx_t_2 = __pyx_t_14(__pyx_t_6);
        if (unlikely(!__pyx_t_2)) {
          if (PyErr_Occurred()) {
            if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) PyErr_Clear();
            else {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1435; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
          }
          break;
        }
        __Pyx_GOTREF(__pyx_t_2);
      }
      __Pyx_XDECREF(__pyx_v_c);
      __pyx_v_c = __pyx_t_2;
      __pyx_t_2 = 0;

      /* "pyart/map/ckdtree.pyx":1436
 *             result = np.empty(retshape, dtype=np.object)
 *             for c in np.ndindex(retshape):
 *                 xx = np.ascontiguousarray(x[c], dtype=np.float64)             # <<<<<<<<<<<<<<
 *                 result[c] = self.__query_ball_point(&xx[0], r, p, eps)
 *             return result
 */
      __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__ascontiguousarray); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = PyObject_GetItem(__pyx_v_x, __pyx_v_c); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = PyTuple_New(1); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_7);
      PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_2));
      __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_15 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__float64); if (unlikely(!__pyx_t_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), __pyx_t_15) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
      __pyx_t_15 = PyObject_Call(__pyx_t_1, ((PyObject *)__pyx_t_7), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_15);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
      __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
      if (!(likely(((__pyx_t_15) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_15, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_8 = ((PyArrayObject *)__pyx_t_15);
      {
        __Pyx_BufFmt_StackElem __pyx_stack[1];
        __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
        __pyx_t_9 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_t_8, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
        if (unlikely(__pyx_t_9 < 0)) {
          PyErr_Fetch(&__pyx_t_12, &__pyx_t_11, &__pyx_t_10);
          if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_xx.rcbuffer->pybuffer, (PyObject*)__pyx_v_xx, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
            Py_XDECREF(__pyx_t_12); Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10);
            __Pyx_RaiseBufferFallbackError();
          } else {
            PyErr_Restore(__pyx_t_12, __pyx_t_11, __pyx_t_10);
          }
        }
        __pyx_pybuffernd_xx.diminfo[0].strides = __pyx_pybuffernd_xx.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_xx.diminfo[0].shape = __pyx_pybuffernd_xx.rcbuffer->pybuffer.shape[0];
        if (unlikely(__pyx_t_9 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1436; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_8 = 0;
      __Pyx_XDECREF(((PyObject *)__pyx_v_xx));
      __pyx_v_xx = ((PyArrayObject *)__pyx_t_15);
      __pyx_t_15 = 0;

      /* "pyart/map/ckdtree.pyx":1437
 *             for c in np.ndindex(retshape):
 *                 xx = np.ascontiguousarray(x[c], dtype=np.float64)
 *                 result[c] = self.__query_ball_point(&xx[0], r, p, eps)             # <<<<<<<<<<<<<<
 *             return result
 * 
 */
      __pyx_t_16 = 0;
      __pyx_t_9 = -1;
      if (__pyx_t_16 < 0) {
        __pyx_t_16 += __pyx_pybuffernd_xx.diminfo[0].shape;
        if (unlikely(__pyx_t_16 < 0)) __pyx_t_9 = 0;
      } else if (unlikely(__pyx_t_16 >= __pyx_pybuffernd_xx.diminfo[0].shape)) __pyx_t_9 = 0;
      if (unlikely(__pyx_t_9 != -1)) {
        __Pyx_RaiseBufferIndexError(__pyx_t_9);
        {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_t_15 = ((PyObject *)((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_point(__pyx_v_self, (&(*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_xx.rcbuffer->pybuffer.buf, __pyx_t_16, __pyx_pybuffernd_xx.diminfo[0].strides))), __pyx_v_r, __pyx_v_p, __pyx_v_eps)); if (unlikely(!__pyx_t_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_15);
      if (PyObject_SetItem(__pyx_v_result, __pyx_v_c, __pyx_t_15) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1437; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_15); __pyx_t_15 = 0;
    }
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;

    /* "pyart/map/ckdtree.pyx":1438
 *                 xx = np.ascontiguousarray(x[c], dtype=np.float64)
 *                 result[c] = self.__query_ball_point(&xx[0], r, p, eps)
 *             return result             # <<<<<<<<<<<<<<
 * 
 *     # ---------------
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(__pyx_v_result);
    __pyx_r = __pyx_v_result;
    goto __pyx_L0;
  }
  __pyx_L4:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_15);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query_ball_point", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_xx.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_xx);
  __Pyx_XDECREF(__pyx_v_retshape);
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_c);
  __Pyx_XDECREF(__pyx_v_x);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1443
 *     # query_ball_tree
 *     # ---------------
 *     cdef int __query_ball_tree_traverse_no_checking(cKDTree self,             # <<<<<<<<<<<<<<
 *                                                     cKDTree other,
 *                                                     list results,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_tree_traverse_no_checking(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, PyObject *__pyx_v_results, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node1, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node2) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode1;
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode2;
  PyObject *__pyx_v_results_i = 0;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  __pyx_t_5numpy_intp_t __pyx_t_5;
  __pyx_t_5numpy_intp_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query_ball_tree_traverse_no_checking", 0);

  /* "pyart/map/ckdtree.pyx":1452
 *         cdef np.intp_t i, j
 * 
 *         if node1.split_dim == -1:  # leaf node             # <<<<<<<<<<<<<<
 *             lnode1 = <leafnode*>node1
 * 
 */
  __pyx_t_1 = (__pyx_v_node1->split_dim == -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1453
 * 
 *         if node1.split_dim == -1:  # leaf node
 *             lnode1 = <leafnode*>node1             # <<<<<<<<<<<<<<
 * 
 *             if node2.split_dim == -1:  # leaf node
 */
    __pyx_v_lnode1 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node1);

    /* "pyart/map/ckdtree.pyx":1455
 *             lnode1 = <leafnode*>node1
 * 
 *             if node2.split_dim == -1:  # leaf node             # <<<<<<<<<<<<<<
 *                 lnode2 = <leafnode*>node2
 * 
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1456
 * 
 *             if node2.split_dim == -1:  # leaf node
 *                 lnode2 = <leafnode*>node2             # <<<<<<<<<<<<<<
 * 
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 */
      __pyx_v_lnode2 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node2);

      /* "pyart/map/ckdtree.pyx":1458
 *                 lnode2 = <leafnode*>node2
 * 
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):             # <<<<<<<<<<<<<<
 *                     results_i = results[self.raw_indices[i]]
 *                     for j in range(lnode2.start_idx, lnode2.end_idx):
 */
      __pyx_t_2 = __pyx_v_lnode1->end_idx;
      for (__pyx_t_3 = __pyx_v_lnode1->start_idx; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
        __pyx_v_i = __pyx_t_3;

        /* "pyart/map/ckdtree.pyx":1459
 * 
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 *                     results_i = results[self.raw_indices[i]]             # <<<<<<<<<<<<<<
 *                     for j in range(lnode2.start_idx, lnode2.end_idx):
 *                         list_append(results_i, other.raw_indices[j])
 */
        if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_4 = __Pyx_GetItemInt_List(((PyObject *)__pyx_v_results), (__pyx_v_self->raw_indices[__pyx_v_i]), sizeof(__pyx_t_5numpy_intp_t), __Pyx_PyInt_to_py_Py_intptr_t); if (!__pyx_t_4) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_4);
        if (!(likely(PyList_CheckExact(__pyx_t_4))||((__pyx_t_4) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_t_4)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1459; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_XDECREF(((PyObject *)__pyx_v_results_i));
        __pyx_v_results_i = ((PyObject*)__pyx_t_4);
        __pyx_t_4 = 0;

        /* "pyart/map/ckdtree.pyx":1460
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 *                     results_i = results[self.raw_indices[i]]
 *                     for j in range(lnode2.start_idx, lnode2.end_idx):             # <<<<<<<<<<<<<<
 *                         list_append(results_i, other.raw_indices[j])
 *             else:
 */
        __pyx_t_5 = __pyx_v_lnode2->end_idx;
        for (__pyx_t_6 = __pyx_v_lnode2->start_idx; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
          __pyx_v_j = __pyx_t_6;

          /* "pyart/map/ckdtree.pyx":1461
 *                     results_i = results[self.raw_indices[i]]
 *                     for j in range(lnode2.start_idx, lnode2.end_idx):
 *                         list_append(results_i, other.raw_indices[j])             # <<<<<<<<<<<<<<
 *             else:
 * 
 */
          __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_list_append(__pyx_v_results_i, (__pyx_v_other->raw_indices[__pyx_v_j])); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1461; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
      }
      goto __pyx_L4;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1464
 *             else:
 * 
 *                 self.__query_ball_tree_traverse_no_checking(other, results, node1, node2.less)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_no_checking(other, results, node1, node2.greater)
 *         else:
 */
      __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_no_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->less); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1464; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1465
 * 
 *                 self.__query_ball_tree_traverse_no_checking(other, results, node1, node2.less)
 *                 self.__query_ball_tree_traverse_no_checking(other, results, node1, node2.greater)             # <<<<<<<<<<<<<<
 *         else:
 * 
 */
      __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_no_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->greater); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1465; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1468
 *         else:
 * 
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1.less, node2)             # <<<<<<<<<<<<<<
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1.greater, node2)
 * 
 */
    __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_no_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1468; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

    /* "pyart/map/ckdtree.pyx":1469
 * 
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1.less, node2)
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1.greater, node2)             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
    __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_no_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1469; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1471
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1.greater, node2)
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query_ball_tree_traverse_no_checking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_results_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1475
 * 
 *     @cython.cdivision(True)
 *     cdef int __query_ball_tree_traverse_checking(cKDTree self,             # <<<<<<<<<<<<<<
 *                                                  cKDTree other,
 *                                                  list results,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_tree_traverse_checking(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, PyObject *__pyx_v_results, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node1, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node2, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode1;
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode2;
  PyObject *__pyx_v_results_i = 0;
  __pyx_t_5numpy_float64_t __pyx_v_d;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  __pyx_t_5numpy_intp_t __pyx_t_4;
  PyObject *__pyx_t_5 = NULL;
  __pyx_t_5numpy_intp_t __pyx_t_6;
  __pyx_t_5numpy_intp_t __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query_ball_tree_traverse_checking", 0);

  /* "pyart/map/ckdtree.pyx":1486
 *         cdef np.intp_t i, j
 * 
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:             # <<<<<<<<<<<<<<
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 */
  __pyx_t_1 = (__pyx_v_tracker->min_distance > (__pyx_v_tracker->upper_bound * __pyx_v_tracker->epsfac));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1487
 * 
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:
 *             return 0             # <<<<<<<<<<<<<<
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1, node2)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":1488
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:             # <<<<<<<<<<<<<<
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1, node2)
 *         elif node1.split_dim == -1:  # 1 is leaf node
 */
  __pyx_t_1 = (__pyx_v_tracker->max_distance < (__pyx_v_tracker->upper_bound / __pyx_v_tracker->epsfac));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1489
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1, node2)             # <<<<<<<<<<<<<<
 *         elif node1.split_dim == -1:  # 1 is leaf node
 *             lnode1 = <leafnode*>node1
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_no_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1489; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":1490
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1, node2)
 *         elif node1.split_dim == -1:  # 1 is leaf node             # <<<<<<<<<<<<<<
 *             lnode1 = <leafnode*>node1
 * 
 */
  __pyx_t_1 = (__pyx_v_node1->split_dim == -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1491
 *             self.__query_ball_tree_traverse_no_checking(other, results, node1, node2)
 *         elif node1.split_dim == -1:  # 1 is leaf node
 *             lnode1 = <leafnode*>node1             # <<<<<<<<<<<<<<
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves
 */
    __pyx_v_lnode1 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node1);

    /* "pyart/map/ckdtree.pyx":1493
 *             lnode1 = <leafnode*>node1
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves             # <<<<<<<<<<<<<<
 *                 lnode2 = <leafnode*>node2
 * 
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1494
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves
 *                 lnode2 = <leafnode*>node2             # <<<<<<<<<<<<<<
 * 
 *                 # brute-force
 */
      __pyx_v_lnode2 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node2);

      /* "pyart/map/ckdtree.pyx":1497
 * 
 *                 # brute-force
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):             # <<<<<<<<<<<<<<
 *                     results_i = results[self.raw_indices[i]]
 *                     for j in range(lnode2.start_idx, lnode2.end_idx):
 */
      __pyx_t_3 = __pyx_v_lnode1->end_idx;
      for (__pyx_t_4 = __pyx_v_lnode1->start_idx; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
        __pyx_v_i = __pyx_t_4;

        /* "pyart/map/ckdtree.pyx":1498
 *                 # brute-force
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 *                     results_i = results[self.raw_indices[i]]             # <<<<<<<<<<<<<<
 *                     for j in range(lnode2.start_idx, lnode2.end_idx):
 *                         d = _distance_p(
 */
        if (unlikely(((PyObject *)__pyx_v_results) == Py_None)) {
          PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
          {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
        __pyx_t_5 = __Pyx_GetItemInt_List(((PyObject *)__pyx_v_results), (__pyx_v_self->raw_indices[__pyx_v_i]), sizeof(__pyx_t_5numpy_intp_t), __Pyx_PyInt_to_py_Py_intptr_t); if (!__pyx_t_5) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        if (!(likely(PyList_CheckExact(__pyx_t_5))||((__pyx_t_5) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected list, got %.200s", Py_TYPE(__pyx_t_5)->tp_name), 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1498; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_XDECREF(((PyObject *)__pyx_v_results_i));
        __pyx_v_results_i = ((PyObject*)__pyx_t_5);
        __pyx_t_5 = 0;

        /* "pyart/map/ckdtree.pyx":1499
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 *                     results_i = results[self.raw_indices[i]]
 *                     for j in range(lnode2.start_idx, lnode2.end_idx):             # <<<<<<<<<<<<<<
 *                         d = _distance_p(
 *                             self.raw_data + self.raw_indices[i] * self.m,
 */
        __pyx_t_6 = __pyx_v_lnode2->end_idx;
        for (__pyx_t_7 = __pyx_v_lnode2->start_idx; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
          __pyx_v_j = __pyx_t_7;

          /* "pyart/map/ckdtree.pyx":1503
 *                             self.raw_data + self.raw_indices[i] * self.m,
 *                             other.raw_data + other.raw_indices[j] * other.m,
 *                             tracker.p, self.m, tracker.upper_bound)             # <<<<<<<<<<<<<<
 *                         if d <= tracker.upper_bound:
 *                             list_append(results_i, other.raw_indices[j])
 */
          __pyx_v_d = __pyx_f_5pyart_3map_7ckdtree__distance_p((__pyx_v_self->raw_data + ((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m)), (__pyx_v_other->raw_data + ((__pyx_v_other->raw_indices[__pyx_v_j]) * __pyx_v_other->m)), __pyx_v_tracker->p, __pyx_v_self->m, __pyx_v_tracker->upper_bound);

          /* "pyart/map/ckdtree.pyx":1504
 *                             other.raw_data + other.raw_indices[j] * other.m,
 *                             tracker.p, self.m, tracker.upper_bound)
 *                         if d <= tracker.upper_bound:             # <<<<<<<<<<<<<<
 *                             list_append(results_i, other.raw_indices[j])
 * 
 */
          __pyx_t_1 = (__pyx_v_d <= __pyx_v_tracker->upper_bound);
          if (__pyx_t_1) {

            /* "pyart/map/ckdtree.pyx":1505
 *                             tracker.p, self.m, tracker.upper_bound)
 *                         if d <= tracker.upper_bound:
 *                             list_append(results_i, other.raw_indices[j])             # <<<<<<<<<<<<<<
 * 
 *             else:  # 1 is a leaf node, 2 is inner node
 */
            __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_list_append(__pyx_v_results_i, (__pyx_v_other->raw_indices[__pyx_v_j])); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1505; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            goto __pyx_L9;
          }
          __pyx_L9:;
        }
      }
      goto __pyx_L4;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1509
 *             else:  # 1 is a leaf node, 2 is inner node
 * 
 *                 tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1, node2.less, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1509; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1511
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1510; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1512
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1, node2.less, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1512; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1514
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1, node2.greater, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1514; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1516
 *                 tracker.push_greater_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1515; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1517
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1517; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1521
 * 
 *         else:  # 1 is an inner node
 *             if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node             # <<<<<<<<<<<<<<
 *                 tracker.push_less_of(1, node1)
 *                 self.__query_ball_tree_traverse_checking(
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1522
 *         else:  # 1 is an inner node
 *             if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node
 *                 tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1522; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1524
 *                 tracker.push_less_of(1, node1)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1523; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1525
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(1, node1)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1525; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1527
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1527; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1529
 *                 tracker.push_greater_of(1, node1)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1528; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1530
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *             else: # 1 & 2 are inner nodes
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1530; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L10;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1534
 *             else: # 1 & 2 are inner nodes
 * 
 *                 tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1534; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1535
 * 
 *                 tracker.push_less_of(1, node1)
 *                 tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2.less, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1535; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1537
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1536; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1538
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2.less, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1538; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1540
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2.greater, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1540; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1542
 *                 tracker.push_greater_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 *                 tracker.pop()
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1541; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1543
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.less, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1543; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1544
 *                     other, results, node1.less, node2.greater, tracker)
 *                 tracker.pop()
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 * 
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1544; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1547
 * 
 * 
 *                 tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1547; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1548
 * 
 *                 tracker.push_greater_of(1, node1)
 *                 tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2.less, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1548; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1550
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1549; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1551
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2.less, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1551; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1553
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2.greater, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1553; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1555
 *                 tracker.push_greater_of(2, node2)
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 *                 tracker.pop()
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1554; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1556
 *                 self.__query_ball_tree_traverse_checking(
 *                     other, results, node1.greater, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1556; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1557
 *                     other, results, node1.greater, node2.greater, tracker)
 *                 tracker.pop()
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1557; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L10:;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1559
 *                 tracker.pop()
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query_ball_tree_traverse_checking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_results_i);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_9query_ball_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_3map_7ckdtree_7cKDTree_8query_ball_tree[] = "query_ball_tree(self, other, r, p, eps)\n\n        Find all pairs of points whose distance is at most r\n\n        Parameters\n        ----------\n        other : KDTree instance\n            The tree containing points to search against.\n        r : float\n            The maximum distance, has to be positive.\n        p : float, optional\n            Which Minkowski norm to use.  `p` has to meet the condition\n            ``1 <= p <= infinity``.\n        eps : float, optional\n            Approximate search.  Branches of the tree are not explored\n            if their nearest points are further than ``r/(1+eps)``, and\n            branches are added in bulk if their furthest points are nearer\n            than ``r * (1+eps)``.  `eps` has to be non-negative.\n\n        Returns\n        -------\n        results : list of lists\n            For each element ``self.data[i]`` of this tree, ``results[i]`` is a\n            list of the indices of its neighbors in ``other.data``.\n\n        ";
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_9query_ball_tree(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other = 0;
  __pyx_t_5numpy_float64_t __pyx_v_r;
  __pyx_t_5numpy_float64_t __pyx_v_p;
  __pyx_t_5numpy_float64_t __pyx_v_eps;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_ball_tree (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__other,&__pyx_n_s__r,&__pyx_n_s__p,&__pyx_n_s__eps,0};
    PyObject* values[4] = {0,0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__other)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__r)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("query_ball_tree", 0, 2, 4, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1562; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__p);
          if (value) { values[2] = value; kw_args--; }
        }
        case  3:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__eps);
          if (value) { values[3] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "query_ball_tree") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1562; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  4: values[3] = PyTuple_GET_ITEM(__pyx_args, 3);
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_other = ((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)values[0]);
    __pyx_v_r = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_r == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1563; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    if (values[2]) {
      __pyx_v_p = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_p == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1563; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":1563
 * 
 *     def query_ball_tree(cKDTree self, cKDTree other,
 *                         np.float64_t r, np.float64_t p=2., np.float64_t eps=0):             # <<<<<<<<<<<<<<
 *         """query_ball_tree(self, other, r, p, eps)
 * 
 */
      __pyx_v_p = ((__pyx_t_5numpy_float64_t)2.);
    }
    if (values[3]) {
      __pyx_v_eps = __pyx_PyFloat_AsDouble(values[3]); if (unlikely((__pyx_v_eps == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1563; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {
      __pyx_v_eps = ((__pyx_t_5numpy_float64_t)0.0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("query_ball_tree", 0, 2, 4, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1562; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query_ball_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_5pyart_3map_7ckdtree_cKDTree, 1, "other", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1562; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_8query_ball_tree(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self), __pyx_v_other, __pyx_v_r, __pyx_v_p, __pyx_v_eps);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1562
 * 
 * 
 *     def query_ball_tree(cKDTree self, cKDTree other,             # <<<<<<<<<<<<<<
 *                         np.float64_t r, np.float64_t p=2., np.float64_t eps=0):
 *         """query_ball_tree(self, other, r, p, eps)
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_8query_ball_tree(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, __pyx_t_5numpy_float64_t __pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps) {
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker = NULL;
  PyObject *__pyx_v_results = NULL;
  CYTHON_UNUSED __pyx_t_5numpy_intp_t __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyObject *__pyx_t_7 = NULL;
  __pyx_t_5numpy_intp_t __pyx_t_8;
  __pyx_t_5numpy_intp_t __pyx_t_9;
  int __pyx_t_10;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_ball_tree", 0);

  /* "pyart/map/ckdtree.pyx":1592
 * 
 *         # Make sure trees are compatible
 *         if self.m != other.m:             # <<<<<<<<<<<<<<
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->m != __pyx_v_other->m);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1593
 *         # Make sure trees are compatible
 *         if self.m != other.m:
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")             # <<<<<<<<<<<<<<
 * 
 *         # Track node-to-node min/max distances
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_21), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1593; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1593; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1597
 *         # Track node-to-node min/max distances
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),             # <<<<<<<<<<<<<<
 *             Rectangle(other.mins, other.maxes),
 *             p, eps, r)
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1597; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mins));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->maxes));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1597; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1598
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(other.mins, other.maxes),             # <<<<<<<<<<<<<<
 *             p, eps, r)
 * 
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1598; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_other->mins));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_other->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_other->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_other->maxes));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_other->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_other->maxes));
  __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1598; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1599
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(other.mins, other.maxes),
 *             p, eps, r)             # <<<<<<<<<<<<<<
 * 
 *         results = [[] for i in range(self.n)]
 */
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_p); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1599; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_eps); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1599; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyFloat_FromDouble(__pyx_v_r); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1599; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = PyTuple_New(5); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1596; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_7);
  PyTuple_SET_ITEM(__pyx_t_7, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_7, 1, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_7, 2, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_7, 3, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_7, 4, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_2 = 0;
  __pyx_t_5 = 0;
  __pyx_t_6 = 0;
  __pyx_t_6 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_RectRectDistanceTracker)), ((PyObject *)__pyx_t_7), NULL); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1596; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
  __pyx_v_tracker = ((struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_t_6);
  __pyx_t_6 = 0;

  /* "pyart/map/ckdtree.pyx":1601
 *             p, eps, r)
 * 
 *         results = [[] for i in range(self.n)]             # <<<<<<<<<<<<<<
 *         self.__query_ball_tree_traverse_checking(
 *             other, results, self.tree, other.tree, tracker)
 */
  __pyx_t_6 = PyList_New(0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1601; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = __pyx_v_self->n;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;
    __pyx_t_7 = PyList_New(0); if (unlikely(!__pyx_t_7)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1601; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_7);
    if (unlikely(__Pyx_PyList_Append(__pyx_t_6, (PyObject*)__pyx_t_7))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1601; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(((PyObject *)__pyx_t_7)); __pyx_t_7 = 0;
  }
  __pyx_t_7 = ((PyObject *)__pyx_t_6);
  __Pyx_INCREF(__pyx_t_7);
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_results = ((PyObject*)__pyx_t_7);
  __pyx_t_7 = 0;

  /* "pyart/map/ckdtree.pyx":1603
 *         results = [[] for i in range(self.n)]
 *         self.__query_ball_tree_traverse_checking(
 *             other, results, self.tree, other.tree, tracker)             # <<<<<<<<<<<<<<
 * 
 *         return results
 */
  __pyx_t_10 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_ball_tree_traverse_checking(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_self->tree, __pyx_v_other->tree, __pyx_v_tracker); if (unlikely(__pyx_t_10 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1602; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":1605
 *             other, results, self.tree, other.tree, tracker)
 * 
 *         return results             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_results));
  __pyx_r = ((PyObject *)__pyx_v_results);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_7);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query_ball_tree", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tracker);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1611
 *     # query_pairs
 *     # -----------
 *     cdef int __query_pairs_traverse_no_checking(cKDTree self,             # <<<<<<<<<<<<<<
 *                                                 set results,
 *                                                 innernode* node1,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_pairs_traverse_no_checking(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_results, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node1, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node2) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode1;
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode2;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  __pyx_t_5numpy_intp_t __pyx_v_min_j;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  __pyx_t_5numpy_intp_t __pyx_t_4;
  __pyx_t_5numpy_intp_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query_pairs_traverse_no_checking", 0);

  /* "pyart/map/ckdtree.pyx":1619
 *         cdef np.intp_t i, j, min_j
 * 
 *         if node1.split_dim == -1:  # leaf node             # <<<<<<<<<<<<<<
 *             lnode1 = <leafnode*>node1
 * 
 */
  __pyx_t_1 = (__pyx_v_node1->split_dim == -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1620
 * 
 *         if node1.split_dim == -1:  # leaf node
 *             lnode1 = <leafnode*>node1             # <<<<<<<<<<<<<<
 * 
 *             if node2.split_dim == -1:  # leaf node
 */
    __pyx_v_lnode1 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node1);

    /* "pyart/map/ckdtree.pyx":1622
 *             lnode1 = <leafnode*>node1
 * 
 *             if node2.split_dim == -1:  # leaf node             # <<<<<<<<<<<<<<
 *                 lnode2 = <leafnode*>node2
 * 
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1623
 * 
 *             if node2.split_dim == -1:  # leaf node
 *                 lnode2 = <leafnode*>node2             # <<<<<<<<<<<<<<
 * 
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 */
      __pyx_v_lnode2 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node2);

      /* "pyart/map/ckdtree.pyx":1625
 *                 lnode2 = <leafnode*>node2
 * 
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):             # <<<<<<<<<<<<<<
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:
 */
      __pyx_t_2 = __pyx_v_lnode1->end_idx;
      for (__pyx_t_3 = __pyx_v_lnode1->start_idx; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
        __pyx_v_i = __pyx_t_3;

        /* "pyart/map/ckdtree.pyx":1627
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:             # <<<<<<<<<<<<<<
 *                         min_j = i + 1
 *                     else:
 */
        __pyx_t_1 = (__pyx_v_node1 == __pyx_v_node2);
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":1628
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:
 *                         min_j = i + 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         min_j = lnode2.start_idx
 */
          __pyx_v_min_j = (__pyx_v_i + 1);
          goto __pyx_L7;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":1630
 *                         min_j = i + 1
 *                     else:
 *                         min_j = lnode2.start_idx             # <<<<<<<<<<<<<<
 * 
 *                     for j in range(min_j, lnode2.end_idx):
 */
          __pyx_t_4 = __pyx_v_lnode2->start_idx;
          __pyx_v_min_j = __pyx_t_4;
        }
        __pyx_L7:;

        /* "pyart/map/ckdtree.pyx":1632
 *                         min_j = lnode2.start_idx
 * 
 *                     for j in range(min_j, lnode2.end_idx):             # <<<<<<<<<<<<<<
 *                         set_add_ordered_pair(results,
 *                                              self.raw_indices[i],
 */
        __pyx_t_4 = __pyx_v_lnode2->end_idx;
        for (__pyx_t_5 = __pyx_v_min_j; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
          __pyx_v_j = __pyx_t_5;

          /* "pyart/map/ckdtree.pyx":1635
 *                         set_add_ordered_pair(results,
 *                                              self.raw_indices[i],
 *                                              self.raw_indices[j])             # <<<<<<<<<<<<<<
 * 
 *             else:
 */
          __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_set_add_ordered_pair(__pyx_v_results, (__pyx_v_self->raw_indices[__pyx_v_i]), (__pyx_v_self->raw_indices[__pyx_v_j])); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1633; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        }
      }
      goto __pyx_L4;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1638
 * 
 *             else:
 *                 self.__query_pairs_traverse_no_checking(results, node1, node2.less)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_no_checking(results, node1, node2.greater)
 *         else:
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->less); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1638; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1639
 *             else:
 *                 self.__query_pairs_traverse_no_checking(results, node1, node2.less)
 *                 self.__query_pairs_traverse_no_checking(results, node1, node2.greater)             # <<<<<<<<<<<<<<
 *         else:
 *             if node1 == node2:
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->greater); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1639; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1641
 *                 self.__query_pairs_traverse_no_checking(results, node1, node2.greater)
 *         else:
 *             if node1 == node2:             # <<<<<<<<<<<<<<
 *                 # Avoid traversing (node1.less, node2.greater) and
 *                 # (node1.greater, node2.less) (it's the same node pair twice
 */
    __pyx_t_1 = (__pyx_v_node1 == __pyx_v_node2);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1646
 *                 # over, which is the source of the complication in the
 *                 # original KDTree.query_pairs)
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2.less)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2.greater)
 *                 self.__query_pairs_traverse_no_checking(results, node1.greater, node2.greater)
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->less); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1646; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1647
 *                 # original KDTree.query_pairs)
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2.less)
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2.greater)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_no_checking(results, node1.greater, node2.greater)
 *             else:
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->greater); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1647; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1648
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2.less)
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2.greater)
 *                 self.__query_pairs_traverse_no_checking(results, node1.greater, node2.greater)             # <<<<<<<<<<<<<<
 *             else:
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2)
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2->greater); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1648; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L10;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1650
 *                 self.__query_pairs_traverse_no_checking(results, node1.greater, node2.greater)
 *             else:
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_no_checking(results, node1.greater, node2)
 * 
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1650; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1651
 *             else:
 *                 self.__query_pairs_traverse_no_checking(results, node1.less, node2)
 *                 self.__query_pairs_traverse_no_checking(results, node1.greater, node2)             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1651; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L10:;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1653
 *                 self.__query_pairs_traverse_no_checking(results, node1.greater, node2)
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     @cython.cdivision(True)
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query_pairs_traverse_no_checking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1656
 * 
 *     @cython.cdivision(True)
 *     cdef int __query_pairs_traverse_checking(cKDTree self,             # <<<<<<<<<<<<<<
 *                                              set results,
 *                                              innernode* node1,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_pairs_traverse_checking(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, PyObject *__pyx_v_results, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node1, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node2, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode1;
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode2;
  __pyx_t_5numpy_float64_t __pyx_v_d;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  __pyx_t_5numpy_intp_t __pyx_v_min_j;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  __pyx_t_5numpy_intp_t __pyx_t_4;
  __pyx_t_5numpy_intp_t __pyx_t_5;
  __pyx_t_5numpy_intp_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__query_pairs_traverse_checking", 0);

  /* "pyart/map/ckdtree.pyx":1666
 *         cdef np.intp_t i, j, min_j
 * 
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:             # <<<<<<<<<<<<<<
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 */
  __pyx_t_1 = (__pyx_v_tracker->min_distance > (__pyx_v_tracker->upper_bound * __pyx_v_tracker->epsfac));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1667
 * 
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:
 *             return 0             # <<<<<<<<<<<<<<
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_pairs_traverse_no_checking(results, node1, node2)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":1668
 *         if tracker.min_distance > tracker.upper_bound * tracker.epsfac:
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:             # <<<<<<<<<<<<<<
 *             self.__query_pairs_traverse_no_checking(results, node1, node2)
 *         elif node1.split_dim == -1:  # 1 is leaf node
 */
  __pyx_t_1 = (__pyx_v_tracker->max_distance < (__pyx_v_tracker->upper_bound / __pyx_v_tracker->epsfac));
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1669
 *             return 0
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_pairs_traverse_no_checking(results, node1, node2)             # <<<<<<<<<<<<<<
 *         elif node1.split_dim == -1:  # 1 is leaf node
 *             lnode1 = <leafnode*>node1
 */
    __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_no_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1669; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":1670
 *         elif tracker.max_distance < tracker.upper_bound / tracker.epsfac:
 *             self.__query_pairs_traverse_no_checking(results, node1, node2)
 *         elif node1.split_dim == -1:  # 1 is leaf node             # <<<<<<<<<<<<<<
 *             lnode1 = <leafnode*>node1
 * 
 */
  __pyx_t_1 = (__pyx_v_node1->split_dim == -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1671
 *             self.__query_pairs_traverse_no_checking(results, node1, node2)
 *         elif node1.split_dim == -1:  # 1 is leaf node
 *             lnode1 = <leafnode*>node1             # <<<<<<<<<<<<<<
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves
 */
    __pyx_v_lnode1 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node1);

    /* "pyart/map/ckdtree.pyx":1673
 *             lnode1 = <leafnode*>node1
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves             # <<<<<<<<<<<<<<
 *                 lnode2 = <leafnode*>node2
 * 
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1674
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves
 *                 lnode2 = <leafnode*>node2             # <<<<<<<<<<<<<<
 * 
 *                 # brute-force
 */
      __pyx_v_lnode2 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node2);

      /* "pyart/map/ckdtree.pyx":1677
 * 
 *                 # brute-force
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):             # <<<<<<<<<<<<<<
 * 
 *                     # Special care here to avoid duplicate pairs
 */
      __pyx_t_3 = __pyx_v_lnode1->end_idx;
      for (__pyx_t_4 = __pyx_v_lnode1->start_idx; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
        __pyx_v_i = __pyx_t_4;

        /* "pyart/map/ckdtree.pyx":1680
 * 
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:             # <<<<<<<<<<<<<<
 *                         min_j = i + 1
 *                     else:
 */
        __pyx_t_1 = (__pyx_v_node1 == __pyx_v_node2);
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":1681
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:
 *                         min_j = i + 1             # <<<<<<<<<<<<<<
 *                     else:
 *                         min_j = lnode2.start_idx
 */
          __pyx_v_min_j = (__pyx_v_i + 1);
          goto __pyx_L7;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":1683
 *                         min_j = i + 1
 *                     else:
 *                         min_j = lnode2.start_idx             # <<<<<<<<<<<<<<
 * 
 *                     for j in range(min_j, lnode2.end_idx):
 */
          __pyx_t_5 = __pyx_v_lnode2->start_idx;
          __pyx_v_min_j = __pyx_t_5;
        }
        __pyx_L7:;

        /* "pyart/map/ckdtree.pyx":1685
 *                         min_j = lnode2.start_idx
 * 
 *                     for j in range(min_j, lnode2.end_idx):             # <<<<<<<<<<<<<<
 *                         d = _distance_p(
 *                             self.raw_data + self.raw_indices[i] * self.m,
 */
        __pyx_t_5 = __pyx_v_lnode2->end_idx;
        for (__pyx_t_6 = __pyx_v_min_j; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
          __pyx_v_j = __pyx_t_6;

          /* "pyart/map/ckdtree.pyx":1689
 *                             self.raw_data + self.raw_indices[i] * self.m,
 *                             self.raw_data + self.raw_indices[j] * self.m,
 *                             tracker.p, self.m, tracker.upper_bound)             # <<<<<<<<<<<<<<
 *                         if d <= tracker.upper_bound:
 *                             set_add_ordered_pair(results,
 */
          __pyx_v_d = __pyx_f_5pyart_3map_7ckdtree__distance_p((__pyx_v_self->raw_data + ((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m)), (__pyx_v_self->raw_data + ((__pyx_v_self->raw_indices[__pyx_v_j]) * __pyx_v_self->m)), __pyx_v_tracker->p, __pyx_v_self->m, __pyx_v_tracker->upper_bound);

          /* "pyart/map/ckdtree.pyx":1690
 *                             self.raw_data + self.raw_indices[j] * self.m,
 *                             tracker.p, self.m, tracker.upper_bound)
 *                         if d <= tracker.upper_bound:             # <<<<<<<<<<<<<<
 *                             set_add_ordered_pair(results,
 *                                                  self.raw_indices[i],
 */
          __pyx_t_1 = (__pyx_v_d <= __pyx_v_tracker->upper_bound);
          if (__pyx_t_1) {

            /* "pyart/map/ckdtree.pyx":1693
 *                             set_add_ordered_pair(results,
 *                                                  self.raw_indices[i],
 *                                                  self.raw_indices[j])             # <<<<<<<<<<<<<<
 * 
 *             else:  # 1 is a leaf node, 2 is inner node
 */
            __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_set_add_ordered_pair(__pyx_v_results, (__pyx_v_self->raw_indices[__pyx_v_i]), (__pyx_v_self->raw_indices[__pyx_v_j])); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1691; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
      }
      goto __pyx_L4;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1696
 * 
 *             else:  # 1 is a leaf node, 2 is inner node
 *                 tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1, node2.less, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1696; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1698
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1697; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1699
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1, node2.less, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1699; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1701
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1, node2.greater, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1701; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1703
 *                 tracker.push_greater_of(2, node2)
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1702; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1704
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *         else:  # 1 is an inner node
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1704; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1707
 * 
 *         else:  # 1 is an inner node
 *             if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node             # <<<<<<<<<<<<<<
 *                 tracker.push_less_of(1, node1)
 *                 self.__query_pairs_traverse_checking(
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1708
 *         else:  # 1 is an inner node
 *             if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node
 *                 tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1708; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1710
 *                 tracker.push_less_of(1, node1)
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1709; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1711
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(1, node1)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1711; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1713
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.greater, node2, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1713; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1715
 *                 tracker.push_greater_of(1, node1)
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.greater, node2, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1714; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1716
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.greater, node2, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *             else: # 1 and 2 are inner nodes
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1716; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L11;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1719
 * 
 *             else: # 1 and 2 are inner nodes
 *                 tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_pairs_traverse_checking(
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1719; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1720
 *             else: # 1 and 2 are inner nodes
 *                 tracker.push_less_of(1, node1)
 *                 tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2.less, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1720; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1722
 *                 tracker.push_less_of(2, node2)
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1721; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1723
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2.less, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1723; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1725
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2.greater, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1725; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1727
 *                 tracker.push_greater_of(2, node2)
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 *                 tracker.pop()
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1726; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1728
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.less, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1728; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1729
 *                     results, node1.less, node2.greater, tracker)
 *                 tracker.pop()
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(1, node1)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1729; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1731
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                 if node1 != node2:
 *                     # Avoid traversing (node1.less, node2.greater) and
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1731; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1732
 * 
 *                 tracker.push_greater_of(1, node1)
 *                 if node1 != node2:             # <<<<<<<<<<<<<<
 *                     # Avoid traversing (node1.less, node2.greater) and
 *                     # (node1.greater, node2.less) (it's the same node pair
 */
      __pyx_t_1 = (__pyx_v_node1 != __pyx_v_node2);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":1737
 *                     # twice over, which is the source of the complication in
 *                     # the original KDTree.query_pairs)
 *                     tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__query_pairs_traverse_checking(
 *                         results, node1.greater, node2.less, tracker)
 */
        __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1737; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1739
 *                     tracker.push_less_of(2, node2)
 *                     self.__query_pairs_traverse_checking(
 *                         results, node1.greater, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1738; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1740
 *                     self.__query_pairs_traverse_checking(
 *                         results, node1.greater, node2.less, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
        __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1740; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L12;
      }
      __pyx_L12:;

      /* "pyart/map/ckdtree.pyx":1742
 *                     tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.greater, node2.greater, tracker)
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1742; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1744
 *                 tracker.push_greater_of(2, node2)
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.greater, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 *                 tracker.pop()
 */
      __pyx_t_2 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1743; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1745
 *                 self.__query_pairs_traverse_checking(
 *                     results, node1.greater, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1745; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":1746
 *                     results, node1.greater, node2.greater, tracker)
 *                 tracker.pop()
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
      __pyx_t_2 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_2 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1746; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L11:;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1748
 *                 tracker.pop()
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__query_pairs_traverse_checking", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_11query_pairs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_3map_7ckdtree_7cKDTree_10query_pairs[] = "query_pairs(self, r, p, eps)\n\n        Find all pairs of points whose distance is at most r.\n\n        Parameters\n        ----------\n        r : positive float\n            The maximum distance.\n        p : float, optional\n            Which Minkowski norm to use.  `p` has to meet the condition\n            ``1 <= p <= infinity``.\n        eps : float, optional\n            Approximate search.  Branches of the tree are not explored\n            if their nearest points are further than ``r/(1+eps)``, and\n            branches are added in bulk if their furthest points are nearer\n            than ``r * (1+eps)``.  `eps` has to be non-negative.\n\n        Returns\n        -------\n        results : set\n            Set of pairs ``(i,j)``, with ``i < j`, for which the corresponding\n            positions are close.\n\n        ";
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_11query_pairs(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  __pyx_t_5numpy_float64_t __pyx_v_r;
  __pyx_t_5numpy_float64_t __pyx_v_p;
  __pyx_t_5numpy_float64_t __pyx_v_eps;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("query_pairs (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__r,&__pyx_n_s__p,&__pyx_n_s__eps,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__r)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__p);
          if (value) { values[1] = value; kw_args--; }
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__eps);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "query_pairs") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1751; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_r = __pyx_PyFloat_AsDouble(values[0]); if (unlikely((__pyx_v_r == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1751; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    if (values[1]) {
      __pyx_v_p = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_p == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1751; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":1751
 * 
 * 
 *     def query_pairs(cKDTree self, np.float64_t r, np.float64_t p=2.,             # <<<<<<<<<<<<<<
 *                     np.float64_t eps=0):
 *         """query_pairs(self, r, p, eps)
 */
      __pyx_v_p = ((__pyx_t_5numpy_float64_t)2.);
    }
    if (values[2]) {
      __pyx_v_eps = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_eps == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1752; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":1752
 * 
 *     def query_pairs(cKDTree self, np.float64_t r, np.float64_t p=2.,
 *                     np.float64_t eps=0):             # <<<<<<<<<<<<<<
 *         """query_pairs(self, r, p, eps)
 * 
 */
      __pyx_v_eps = ((__pyx_t_5numpy_float64_t)0.0);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("query_pairs", 0, 1, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1751; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query_pairs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_10query_pairs(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self), __pyx_v_r, __pyx_v_p, __pyx_v_eps);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1751
 * 
 * 
 *     def query_pairs(cKDTree self, np.float64_t r, np.float64_t p=2.,             # <<<<<<<<<<<<<<
 *                     np.float64_t eps=0):
 *         """query_pairs(self, r, p, eps)
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_10query_pairs(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, __pyx_t_5numpy_float64_t __pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p, __pyx_t_5numpy_float64_t __pyx_v_eps) {
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker = NULL;
  PyObject *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("query_pairs", 0);

  /* "pyart/map/ckdtree.pyx":1779
 * 
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),             # <<<<<<<<<<<<<<
 *             Rectangle(self.mins, self.maxes),
 *             p, eps, r)
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mins));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->maxes));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1779; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1780
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(self.mins, self.maxes),             # <<<<<<<<<<<<<<
 *             p, eps, r)
 * 
 */
  __pyx_t_1 = PyTuple_New(2); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mins));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_v_self->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->maxes));
  PyTuple_SET_ITEM(__pyx_t_1, 1, ((PyObject *)__pyx_v_self->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_1), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1780; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":1781
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(self.mins, self.maxes),
 *             p, eps, r)             # <<<<<<<<<<<<<<
 * 
 *         results = set()
 */
  __pyx_t_1 = PyFloat_FromDouble(__pyx_v_p); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_4 = PyFloat_FromDouble(__pyx_v_eps); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_r); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1778; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 4, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_2 = 0;
  __pyx_t_3 = 0;
  __pyx_t_1 = 0;
  __pyx_t_4 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_RectRectDistanceTracker)), ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1778; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_tracker = ((struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":1783
 *             p, eps, r)
 * 
 *         results = set()             # <<<<<<<<<<<<<<
 *         self.__query_pairs_traverse_checking(
 *             results, self.tree, self.tree, tracker)
 */
  __pyx_t_5 = PySet_New(0); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1783; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_5));
  __pyx_v_results = __pyx_t_5;
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":1785
 *         results = set()
 *         self.__query_pairs_traverse_checking(
 *             results, self.tree, self.tree, tracker)             # <<<<<<<<<<<<<<
 * 
 *         return results
 */
  __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___query_pairs_traverse_checking(__pyx_v_self, __pyx_v_results, __pyx_v_self->tree, __pyx_v_self->tree, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1784; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":1787
 *             results, self.tree, self.tree, tracker)
 * 
 *         return results             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_results));
  __pyx_r = ((PyObject *)__pyx_v_results);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.query_pairs", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tracker);
  __Pyx_XDECREF(__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1793
 *     # count_neighbors
 *     # ---------------
 *     cdef int __count_neighbors_traverse(cKDTree self,             # <<<<<<<<<<<<<<
 *                                         cKDTree other,
 *                                         np.intp_t n_queries,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___count_neighbors_traverse(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, __pyx_t_5numpy_intp_t __pyx_v_n_queries, __pyx_t_5numpy_float64_t *__pyx_v_r, __pyx_t_5numpy_intp_t *__pyx_v_results, __pyx_t_5numpy_intp_t *__pyx_v_idx, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node1, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node2, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode1;
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode2;
  __pyx_t_5numpy_float64_t __pyx_v_d;
  __pyx_t_5numpy_intp_t *__pyx_v_old_idx;
  __pyx_t_5numpy_intp_t __pyx_v_old_n_queries;
  __pyx_t_5numpy_intp_t __pyx_v_l;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  PyArrayObject *__pyx_v_inner_idx = 0;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_inner_idx;
  __Pyx_Buffer __pyx_pybuffer_inner_idx;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyArrayObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  long __pyx_t_11;
  __pyx_t_5numpy_intp_t __pyx_t_12;
  __pyx_t_5numpy_intp_t __pyx_t_13;
  int __pyx_t_14;
  __pyx_t_5numpy_intp_t __pyx_t_15;
  __pyx_t_5numpy_intp_t __pyx_t_16;
  __pyx_t_5numpy_intp_t __pyx_t_17;
  __pyx_t_5numpy_intp_t __pyx_t_18;
  __pyx_t_5numpy_intp_t __pyx_t_19;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__count_neighbors_traverse", 0);
  __pyx_pybuffer_inner_idx.pybuffer.buf = NULL;
  __pyx_pybuffer_inner_idx.refcount = 0;
  __pyx_pybuffernd_inner_idx.data = NULL;
  __pyx_pybuffernd_inner_idx.rcbuffer = &__pyx_pybuffer_inner_idx;

  /* "pyart/map/ckdtree.pyx":1809
 *         # Speed through pairs of nodes all of whose children are close
 *         # and see if any work remains to be done
 *         old_idx = idx             # <<<<<<<<<<<<<<
 *         cdef np.ndarray[np.intp_t, ndim=1] inner_idx
 *         inner_idx = np.empty((n_queries,), dtype=np.intp)
 */
  __pyx_v_old_idx = __pyx_v_idx;

  /* "pyart/map/ckdtree.pyx":1811
 *         old_idx = idx
 *         cdef np.ndarray[np.intp_t, ndim=1] inner_idx
 *         inner_idx = np.empty((n_queries,), dtype=np.intp)             # <<<<<<<<<<<<<<
 *         idx = &inner_idx[0]
 * 
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__empty); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_n_queries); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_1);
  __Pyx_GIVEREF(__pyx_t_1);
  __pyx_t_1 = 0;
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)__pyx_t_3));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_3));
  __pyx_t_3 = 0;
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_5 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__intp); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__dtype), __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_1), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_1)); __pyx_t_1 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_6 = ((PyArrayObject *)__pyx_t_5);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_inner_idx.rcbuffer->pybuffer);
    __pyx_t_7 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_inner_idx.rcbuffer->pybuffer, (PyObject*)__pyx_t_6, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_7 < 0)) {
      PyErr_Fetch(&__pyx_t_8, &__pyx_t_9, &__pyx_t_10);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_inner_idx.rcbuffer->pybuffer, (PyObject*)__pyx_v_inner_idx, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_STRIDES, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_8); Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_8, __pyx_t_9, __pyx_t_10);
      }
    }
    __pyx_pybuffernd_inner_idx.diminfo[0].strides = __pyx_pybuffernd_inner_idx.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_inner_idx.diminfo[0].shape = __pyx_pybuffernd_inner_idx.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1811; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_6 = 0;
  __pyx_v_inner_idx = ((PyArrayObject *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":1812
 *         cdef np.ndarray[np.intp_t, ndim=1] inner_idx
 *         inner_idx = np.empty((n_queries,), dtype=np.intp)
 *         idx = &inner_idx[0]             # <<<<<<<<<<<<<<
 * 
 *         old_n_queries = n_queries
 */
  __pyx_t_11 = 0;
  __pyx_t_7 = -1;
  if (__pyx_t_11 < 0) {
    __pyx_t_11 += __pyx_pybuffernd_inner_idx.diminfo[0].shape;
    if (unlikely(__pyx_t_11 < 0)) __pyx_t_7 = 0;
  } else if (unlikely(__pyx_t_11 >= __pyx_pybuffernd_inner_idx.diminfo[0].shape)) __pyx_t_7 = 0;
  if (unlikely(__pyx_t_7 != -1)) {
    __Pyx_RaiseBufferIndexError(__pyx_t_7);
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1812; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_v_idx = (&(*__Pyx_BufPtrStrided1d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_inner_idx.rcbuffer->pybuffer.buf, __pyx_t_11, __pyx_pybuffernd_inner_idx.diminfo[0].strides)));

  /* "pyart/map/ckdtree.pyx":1814
 *         idx = &inner_idx[0]
 * 
 *         old_n_queries = n_queries             # <<<<<<<<<<<<<<
 *         n_queries = 0
 *         for i in range(old_n_queries):
 */
  __pyx_v_old_n_queries = __pyx_v_n_queries;

  /* "pyart/map/ckdtree.pyx":1815
 * 
 *         old_n_queries = n_queries
 *         n_queries = 0             # <<<<<<<<<<<<<<
 *         for i in range(old_n_queries):
 *             if tracker.max_distance < r[old_idx[i]]:
 */
  __pyx_v_n_queries = 0;

  /* "pyart/map/ckdtree.pyx":1816
 *         old_n_queries = n_queries
 *         n_queries = 0
 *         for i in range(old_n_queries):             # <<<<<<<<<<<<<<
 *             if tracker.max_distance < r[old_idx[i]]:
 *                 results[old_idx[i]] += node1.children * node2.children
 */
  __pyx_t_12 = __pyx_v_old_n_queries;
  for (__pyx_t_13 = 0; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
    __pyx_v_i = __pyx_t_13;

    /* "pyart/map/ckdtree.pyx":1817
 *         n_queries = 0
 *         for i in range(old_n_queries):
 *             if tracker.max_distance < r[old_idx[i]]:             # <<<<<<<<<<<<<<
 *                 results[old_idx[i]] += node1.children * node2.children
 *             elif tracker.min_distance <= r[old_idx[i]]:
 */
    __pyx_t_14 = (__pyx_v_tracker->max_distance < (__pyx_v_r[(__pyx_v_old_idx[__pyx_v_i])]));
    if (__pyx_t_14) {

      /* "pyart/map/ckdtree.pyx":1818
 *         for i in range(old_n_queries):
 *             if tracker.max_distance < r[old_idx[i]]:
 *                 results[old_idx[i]] += node1.children * node2.children             # <<<<<<<<<<<<<<
 *             elif tracker.min_distance <= r[old_idx[i]]:
 *                 idx[n_queries] = old_idx[i]
 */
      __pyx_t_15 = (__pyx_v_old_idx[__pyx_v_i]);
      (__pyx_v_results[__pyx_t_15]) = ((__pyx_v_results[__pyx_t_15]) + (__pyx_v_node1->children * __pyx_v_node2->children));
      goto __pyx_L5;
    }

    /* "pyart/map/ckdtree.pyx":1819
 *             if tracker.max_distance < r[old_idx[i]]:
 *                 results[old_idx[i]] += node1.children * node2.children
 *             elif tracker.min_distance <= r[old_idx[i]]:             # <<<<<<<<<<<<<<
 *                 idx[n_queries] = old_idx[i]
 *                 n_queries += 1
 */
    __pyx_t_14 = (__pyx_v_tracker->min_distance <= (__pyx_v_r[(__pyx_v_old_idx[__pyx_v_i])]));
    if (__pyx_t_14) {

      /* "pyart/map/ckdtree.pyx":1820
 *                 results[old_idx[i]] += node1.children * node2.children
 *             elif tracker.min_distance <= r[old_idx[i]]:
 *                 idx[n_queries] = old_idx[i]             # <<<<<<<<<<<<<<
 *                 n_queries += 1
 * 
 */
      (__pyx_v_idx[__pyx_v_n_queries]) = (__pyx_v_old_idx[__pyx_v_i]);

      /* "pyart/map/ckdtree.pyx":1821
 *             elif tracker.min_distance <= r[old_idx[i]]:
 *                 idx[n_queries] = old_idx[i]
 *                 n_queries += 1             # <<<<<<<<<<<<<<
 * 
 *         if n_queries > 0:
 */
      __pyx_v_n_queries = (__pyx_v_n_queries + 1);
      goto __pyx_L5;
    }
    __pyx_L5:;
  }

  /* "pyart/map/ckdtree.pyx":1823
 *                 n_queries += 1
 * 
 *         if n_queries > 0:             # <<<<<<<<<<<<<<
 *             # OK, need to probe a bit deeper
 *             if node1.split_dim == -1:  # 1 is leaf node
 */
  __pyx_t_14 = (__pyx_v_n_queries > 0);
  if (__pyx_t_14) {

    /* "pyart/map/ckdtree.pyx":1825
 *         if n_queries > 0:
 *             # OK, need to probe a bit deeper
 *             if node1.split_dim == -1:  # 1 is leaf node             # <<<<<<<<<<<<<<
 *                 lnode1 = <leafnode*>node1
 *                 if node2.split_dim == -1:  # 1 & 2 are leaves
 */
    __pyx_t_14 = (__pyx_v_node1->split_dim == -1);
    if (__pyx_t_14) {

      /* "pyart/map/ckdtree.pyx":1826
 *             # OK, need to probe a bit deeper
 *             if node1.split_dim == -1:  # 1 is leaf node
 *                 lnode1 = <leafnode*>node1             # <<<<<<<<<<<<<<
 *                 if node2.split_dim == -1:  # 1 & 2 are leaves
 *                     lnode2 = <leafnode*>node2
 */
      __pyx_v_lnode1 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node1);

      /* "pyart/map/ckdtree.pyx":1827
 *             if node1.split_dim == -1:  # 1 is leaf node
 *                 lnode1 = <leafnode*>node1
 *                 if node2.split_dim == -1:  # 1 & 2 are leaves             # <<<<<<<<<<<<<<
 *                     lnode2 = <leafnode*>node2
 * 
 */
      __pyx_t_14 = (__pyx_v_node2->split_dim == -1);
      if (__pyx_t_14) {

        /* "pyart/map/ckdtree.pyx":1828
 *                 lnode1 = <leafnode*>node1
 *                 if node2.split_dim == -1:  # 1 & 2 are leaves
 *                     lnode2 = <leafnode*>node2             # <<<<<<<<<<<<<<
 * 
 *                     # brute-force
 */
        __pyx_v_lnode2 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node2);

        /* "pyart/map/ckdtree.pyx":1831
 * 
 *                     # brute-force
 *                     for i in range(lnode1.start_idx, lnode1.end_idx):             # <<<<<<<<<<<<<<
 *                         for j in range(lnode2.start_idx, lnode2.end_idx):
 *                             d = _distance_p(
 */
        __pyx_t_12 = __pyx_v_lnode1->end_idx;
        for (__pyx_t_13 = __pyx_v_lnode1->start_idx; __pyx_t_13 < __pyx_t_12; __pyx_t_13+=1) {
          __pyx_v_i = __pyx_t_13;

          /* "pyart/map/ckdtree.pyx":1832
 *                     # brute-force
 *                     for i in range(lnode1.start_idx, lnode1.end_idx):
 *                         for j in range(lnode2.start_idx, lnode2.end_idx):             # <<<<<<<<<<<<<<
 *                             d = _distance_p(
 *                                 self.raw_data + self.raw_indices[i] * self.m,
 */
          __pyx_t_15 = __pyx_v_lnode2->end_idx;
          for (__pyx_t_16 = __pyx_v_lnode2->start_idx; __pyx_t_16 < __pyx_t_15; __pyx_t_16+=1) {
            __pyx_v_j = __pyx_t_16;

            /* "pyart/map/ckdtree.pyx":1836
 *                                 self.raw_data + self.raw_indices[i] * self.m,
 *                                 other.raw_data + other.raw_indices[j] * other.m,
 *                                 tracker.p, self.m, tracker.max_distance)             # <<<<<<<<<<<<<<
 *                             # I think it's usually cheaper to test d against all r's
 *                             # than to generate a distance array, sort it, then
 */
            __pyx_v_d = __pyx_f_5pyart_3map_7ckdtree__distance_p((__pyx_v_self->raw_data + ((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m)), (__pyx_v_other->raw_data + ((__pyx_v_other->raw_indices[__pyx_v_j]) * __pyx_v_other->m)), __pyx_v_tracker->p, __pyx_v_self->m, __pyx_v_tracker->max_distance);

            /* "pyart/map/ckdtree.pyx":1840
 *                             # than to generate a distance array, sort it, then
 *                             # search for all r's via binary search
 *                             for l in range(n_queries):             # <<<<<<<<<<<<<<
 *                                 if d <= r[idx[l]]:
 *                                     results[idx[l]] += 1
 */
            __pyx_t_17 = __pyx_v_n_queries;
            for (__pyx_t_18 = 0; __pyx_t_18 < __pyx_t_17; __pyx_t_18+=1) {
              __pyx_v_l = __pyx_t_18;

              /* "pyart/map/ckdtree.pyx":1841
 *                             # search for all r's via binary search
 *                             for l in range(n_queries):
 *                                 if d <= r[idx[l]]:             # <<<<<<<<<<<<<<
 *                                     results[idx[l]] += 1
 * 
 */
              __pyx_t_14 = (__pyx_v_d <= (__pyx_v_r[(__pyx_v_idx[__pyx_v_l])]));
              if (__pyx_t_14) {

                /* "pyart/map/ckdtree.pyx":1842
 *                             for l in range(n_queries):
 *                                 if d <= r[idx[l]]:
 *                                     results[idx[l]] += 1             # <<<<<<<<<<<<<<
 * 
 *                 else:  # 1 is a leaf node, 2 is inner node
 */
                __pyx_t_19 = (__pyx_v_idx[__pyx_v_l]);
                (__pyx_v_results[__pyx_t_19]) = ((__pyx_v_results[__pyx_t_19]) + 1);
                goto __pyx_L15;
              }
              __pyx_L15:;
            }
          }
        }
        goto __pyx_L8;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1845
 * 
 *                 else:  # 1 is a leaf node, 2 is inner node
 *                     tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1845; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1848
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1846; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1849
 *                         other, n_queries, r, results, idx,
 *                         node1, node2.less, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                     tracker.push_greater_of(2, node2)
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1851
 *                     tracker.pop()
 * 
 *                     tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1851; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1854
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1852; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1855
 *                         other, n_queries, r, results, idx,
 *                         node1, node2.greater, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *             else:  # 1 is an inner node
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1855; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L8:;
      goto __pyx_L7;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1858
 * 
 *             else:  # 1 is an inner node
 *                 if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node             # <<<<<<<<<<<<<<
 *                     tracker.push_less_of(1, node1)
 *                     self.__count_neighbors_traverse(
 */
      __pyx_t_14 = (__pyx_v_node2->split_dim == -1);
      if (__pyx_t_14) {

        /* "pyart/map/ckdtree.pyx":1859
 *             else:  # 1 is an inner node
 *                 if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node
 *                     tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1859; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1862
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1.less, node2, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1->less, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1860; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1863
 *                         other, n_queries, r, results, idx,
 *                         node1.less, node2, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                     tracker.push_greater_of(1, node1)
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1863; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1865
 *                     tracker.pop()
 * 
 *                     tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1865; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1868
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1.greater, node2, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1->greater, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1866; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1869
 *                         other, n_queries, r, results, idx,
 *                         node1.greater, node2, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 else: # 1 and 2 are inner nodes
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1869; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L16;
      }
      /*else*/ {

        /* "pyart/map/ckdtree.pyx":1872
 * 
 *                 else: # 1 and 2 are inner nodes
 *                     tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                     tracker.push_less_of(2, node2)
 *                     self.__count_neighbors_traverse(
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1872; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1873
 *                 else: # 1 and 2 are inner nodes
 *                     tracker.push_less_of(1, node1)
 *                     tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1873; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1876
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1.less, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1->less, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1874; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1877
 *                         other, n_queries, r, results, idx,
 *                         node1.less, node2.less, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                     tracker.push_greater_of(2, node2)
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1877; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1879
 *                     tracker.pop()
 * 
 *                     tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1879; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1882
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1.less, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 *                     tracker.pop()
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1->less, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1880; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1883
 *                         other, n_queries, r, results, idx,
 *                         node1.less, node2.greater, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1883; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1884
 *                         node1.less, node2.greater, tracker)
 *                     tracker.pop()
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                     tracker.push_greater_of(1, node1)
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1884; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1886
 *                     tracker.pop()
 * 
 *                     tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                     tracker.push_less_of(2, node2)
 *                     self.__count_neighbors_traverse(
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1886; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1887
 * 
 *                     tracker.push_greater_of(1, node1)
 *                     tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1887; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1890
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1.greater, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1->greater, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1888; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1891
 *                         other, n_queries, r, results, idx,
 *                         node1.greater, node2.less, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                     tracker.push_greater_of(2, node2)
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1891; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1893
 *                     tracker.pop()
 * 
 *                     tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1893; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1896
 *                     self.__count_neighbors_traverse(
 *                         other, n_queries, r, results, idx,
 *                         node1.greater, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 *                     tracker.pop()
 */
        __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, __pyx_v_r, __pyx_v_results, __pyx_v_idx, __pyx_v_node1->greater, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1894; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1897
 *                         other, n_queries, r, results, idx,
 *                         node1.greater, node2.greater, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1897; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":1898
 *                         node1.greater, node2.greater, tracker)
 *                     tracker.pop()
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
        __pyx_t_7 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1898; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L16:;
    }
    __pyx_L7:;
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "pyart/map/ckdtree.pyx":1900
 *                     tracker.pop()
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     @cython.boundscheck(False)
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_inner_idx.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__count_neighbors_traverse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_inner_idx.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_inner_idx);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_13count_neighbors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_3map_7ckdtree_7cKDTree_12count_neighbors[] = "count_neighbors(self, other, r, p)\n\n        Count how many nearby pairs can be formed.\n\n        Count the number of pairs (x1,x2) can be formed, with x1 drawn\n        from self and x2 drawn from `other`, and where\n        ``distance(x1, x2, p) <= r``.\n        This is the \"two-point correlation\" described in Gray and Moore 2000,\n        \"N-body problems in statistical learning\", and the code here is based\n        on their algorithm.\n\n        Parameters\n        ----------\n        other : KDTree instance\n            The other tree to draw points from.\n        r : float or one-dimensional array of floats\n            The radius to produce a count for. Multiple radii are searched with\n            a single tree traversal.\n        p : float, 1<=p<=infinity\n            Which Minkowski p-norm to use\n\n        Returns\n        -------\n        result : int or 1-D array of ints\n            The number of pairs. Note that this is internally stored in a numpy int,\n            and so may overflow if very large (2e9).\n\n        ";
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_13count_neighbors(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other = 0;
  PyObject *__pyx_v_r = 0;
  __pyx_t_5numpy_float64_t __pyx_v_p;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("count_neighbors (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__other,&__pyx_n_s__r,&__pyx_n_s__p,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__other)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__r)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("count_neighbors", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1904; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__p);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "count_neighbors") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1904; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_other = ((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)values[0]);
    __pyx_v_r = values[1];
    if (values[2]) {
      __pyx_v_p = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_p == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1904; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":1904
 *     @cython.boundscheck(False)
 *     @cython.wraparound(False)
 *     def count_neighbors(cKDTree self, cKDTree other, object r, np.float64_t p=2.):             # <<<<<<<<<<<<<<
 *         """count_neighbors(self, other, r, p)
 * 
 */
      __pyx_v_p = ((__pyx_t_5numpy_float64_t)2.);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("count_neighbors", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1904; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.count_neighbors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_5pyart_3map_7ckdtree_cKDTree, 1, "other", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1904; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_12count_neighbors(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self), __pyx_v_other, __pyx_v_r, __pyx_v_p);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_12count_neighbors(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, PyObject *__pyx_v_r, __pyx_t_5numpy_float64_t __pyx_v_p) {
  __pyx_t_5numpy_intp_t __pyx_v_n_queries;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  PyArrayObject *__pyx_v_real_r = 0;
  PyArrayObject *__pyx_v_results = 0;
  PyArrayObject *__pyx_v_idx = 0;
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker = NULL;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_idx;
  __Pyx_Buffer __pyx_pybuffer_idx;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_real_r;
  __Pyx_Buffer __pyx_pybuffer_real_r;
  __Pyx_LocalBuf_ND __pyx_pybuffernd_results;
  __Pyx_Buffer __pyx_pybuffer_results;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  PyArrayObject *__pyx_t_7 = NULL;
  int __pyx_t_8;
  PyObject *__pyx_t_9 = NULL;
  PyObject *__pyx_t_10 = NULL;
  PyObject *__pyx_t_11 = NULL;
  Py_ssize_t __pyx_t_12;
  __pyx_t_5numpy_intp_t __pyx_t_13;
  __pyx_t_5numpy_intp_t __pyx_t_14;
  __pyx_t_5numpy_intp_t __pyx_t_15;
  __pyx_t_5numpy_intp_t __pyx_t_16;
  __pyx_t_5numpy_intp_t __pyx_t_17;
  PyObject *__pyx_t_18 = NULL;
  PyArrayObject *__pyx_t_19 = NULL;
  long __pyx_t_20;
  long __pyx_t_21;
  long __pyx_t_22;
  long __pyx_t_23;
  long __pyx_t_24;
  long __pyx_t_25;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("count_neighbors", 0);
  __pyx_pybuffer_real_r.pybuffer.buf = NULL;
  __pyx_pybuffer_real_r.refcount = 0;
  __pyx_pybuffernd_real_r.data = NULL;
  __pyx_pybuffernd_real_r.rcbuffer = &__pyx_pybuffer_real_r;
  __pyx_pybuffer_results.pybuffer.buf = NULL;
  __pyx_pybuffer_results.refcount = 0;
  __pyx_pybuffernd_results.data = NULL;
  __pyx_pybuffernd_results.rcbuffer = &__pyx_pybuffer_results;
  __pyx_pybuffer_idx.pybuffer.buf = NULL;
  __pyx_pybuffer_idx.refcount = 0;
  __pyx_pybuffernd_idx.data = NULL;
  __pyx_pybuffernd_idx.rcbuffer = &__pyx_pybuffer_idx;

  /* "pyart/map/ckdtree.pyx":1938
 * 
 *         # Make sure trees are compatible
 *         if self.m != other.m:             # <<<<<<<<<<<<<<
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->m != __pyx_v_other->m);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1939
 *         # Make sure trees are compatible
 *         if self.m != other.m:
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")             # <<<<<<<<<<<<<<
 * 
 *         # Make a copy of r array to ensure it's contiguous and to modify it
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_22), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1939; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1939; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":1943
 *         # Make a copy of r array to ensure it's contiguous and to modify it
 *         # below
 *         if np.shape(r) == ():             # <<<<<<<<<<<<<<
 *             real_r = np.array([r], dtype=np.float64)
 *             n_queries = 1
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_r);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_r);
  __Pyx_GIVEREF(__pyx_v_r);
  __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_4, ((PyObject *)__pyx_empty_tuple), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1943; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1944
 *         # below
 *         if np.shape(r) == ():
 *             real_r = np.array([r], dtype=np.float64)             # <<<<<<<<<<<<<<
 *             n_queries = 1
 *         elif len(np.shape(r))==1:
 */
    __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_4 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__array); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_INCREF(__pyx_v_r);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_v_r);
    __Pyx_GIVEREF(__pyx_v_r);
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_2));
    __Pyx_GIVEREF(((PyObject *)__pyx_t_2));
    __pyx_t_2 = 0;
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __pyx_t_5 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = PyObject_GetAttr(__pyx_t_5, __pyx_n_s__float64); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), __pyx_t_6) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_6 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_6) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_6, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = ((PyArrayObject *)__pyx_t_6);
    {
      __Pyx_BufFmt_StackElem __pyx_stack[1];
      __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer);
      __pyx_t_8 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS| PyBUF_WRITABLE, 1, 0, __pyx_stack);
      if (unlikely(__pyx_t_8 < 0)) {
        PyErr_Fetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
        if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer, (PyObject*)__pyx_v_real_r, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
          Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11);
          __Pyx_RaiseBufferFallbackError();
        } else {
          PyErr_Restore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
        }
      }
      __pyx_pybuffernd_real_r.diminfo[0].strides = __pyx_pybuffernd_real_r.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_real_r.diminfo[0].shape = __pyx_pybuffernd_real_r.rcbuffer->pybuffer.shape[0];
      if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1944; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_7 = 0;
    __pyx_v_real_r = ((PyArrayObject *)__pyx_t_6);
    __pyx_t_6 = 0;

    /* "pyart/map/ckdtree.pyx":1945
 *         if np.shape(r) == ():
 *             real_r = np.array([r], dtype=np.float64)
 *             n_queries = 1             # <<<<<<<<<<<<<<
 *         elif len(np.shape(r))==1:
 *             real_r = np.array(r, dtype=np.float64)
 */
    __pyx_v_n_queries = 1;
    goto __pyx_L4;
  }

  /* "pyart/map/ckdtree.pyx":1946
 *             real_r = np.array([r], dtype=np.float64)
 *             n_queries = 1
 *         elif len(np.shape(r))==1:             # <<<<<<<<<<<<<<
 *             real_r = np.array(r, dtype=np.float64)
 *             n_queries = r.shape[0]
 */
  __pyx_t_6 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1946; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_6, __pyx_n_s__shape); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1946; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1946; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_INCREF(__pyx_v_r);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_v_r);
  __Pyx_GIVEREF(__pyx_v_r);
  __pyx_t_3 = PyObject_Call(__pyx_t_2, ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1946; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_t_12 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_12 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1946; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_12 == 1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1947
 *             n_queries = 1
 *         elif len(np.shape(r))==1:
 *             real_r = np.array(r, dtype=np.float64)             # <<<<<<<<<<<<<<
 *             n_queries = r.shape[0]
 *         else:
 */
    __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_6 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__array); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_INCREF(__pyx_v_r);
    PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_v_r);
    __Pyx_GIVEREF(__pyx_v_r);
    __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(((PyObject *)__pyx_t_2));
    __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_5 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__float64); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_n_s__dtype), __pyx_t_5) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_3), ((PyObject *)__pyx_t_2)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
    __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
    if (!(likely(((__pyx_t_5) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_5, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_t_7 = ((PyArrayObject *)__pyx_t_5);
    {
      __Pyx_BufFmt_StackElem __pyx_stack[1];
      __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer);
      __pyx_t_8 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer, (PyObject*)__pyx_t_7, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS| PyBUF_WRITABLE, 1, 0, __pyx_stack);
      if (unlikely(__pyx_t_8 < 0)) {
        PyErr_Fetch(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9);
        if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer, (PyObject*)__pyx_v_real_r, &__Pyx_TypeInfo_nn___pyx_t_5numpy_float64_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS| PyBUF_WRITABLE, 1, 0, __pyx_stack) == -1)) {
          Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_9);
          __Pyx_RaiseBufferFallbackError();
        } else {
          PyErr_Restore(__pyx_t_11, __pyx_t_10, __pyx_t_9);
        }
      }
      __pyx_pybuffernd_real_r.diminfo[0].strides = __pyx_pybuffernd_real_r.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_real_r.diminfo[0].shape = __pyx_pybuffernd_real_r.rcbuffer->pybuffer.shape[0];
      if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1947; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_t_7 = 0;
    __pyx_v_real_r = ((PyArrayObject *)__pyx_t_5);
    __pyx_t_5 = 0;

    /* "pyart/map/ckdtree.pyx":1948
 *         elif len(np.shape(r))==1:
 *             real_r = np.array(r, dtype=np.float64)
 *             n_queries = r.shape[0]             # <<<<<<<<<<<<<<
 *         else:
 *             raise ValueError("r must be either a single value or a one-dimensional array of values")
 */
    __pyx_t_5 = PyObject_GetAttr(__pyx_v_r, __pyx_n_s__shape); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1948; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_2 = __Pyx_GetItemInt(__pyx_t_5, 0, sizeof(long), PyInt_FromLong); if (!__pyx_t_2) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1948; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_13 = __Pyx_PyInt_from_py_Py_intptr_t(__pyx_t_2); if (unlikely((__pyx_t_13 == (npy_intp)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1948; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_n_queries = __pyx_t_13;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":1950
 *             n_queries = r.shape[0]
 *         else:
 *             raise ValueError("r must be either a single value or a one-dimensional array of values")             # <<<<<<<<<<<<<<
 * 
 *         # Internally, we represent all distances as distance ** p
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_24), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_L4:;

  /* "pyart/map/ckdtree.pyx":1953
 * 
 *         # Internally, we represent all distances as distance ** p
 *         if p != infinity:             # <<<<<<<<<<<<<<
 *             for i in range(n_queries):
 *                 if real_r[i] != infinity:
 */
  __pyx_t_1 = (__pyx_v_p != __pyx_v_5pyart_3map_7ckdtree_infinity);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1954
 *         # Internally, we represent all distances as distance ** p
 *         if p != infinity:
 *             for i in range(n_queries):             # <<<<<<<<<<<<<<
 *                 if real_r[i] != infinity:
 *                     real_r[i] = real_r[i] ** p
 */
    __pyx_t_13 = __pyx_v_n_queries;
    for (__pyx_t_14 = 0; __pyx_t_14 < __pyx_t_13; __pyx_t_14+=1) {
      __pyx_v_i = __pyx_t_14;

      /* "pyart/map/ckdtree.pyx":1955
 *         if p != infinity:
 *             for i in range(n_queries):
 *                 if real_r[i] != infinity:             # <<<<<<<<<<<<<<
 *                     real_r[i] = real_r[i] ** p
 * 
 */
      __pyx_t_15 = __pyx_v_i;
      __pyx_t_1 = ((*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_real_r.rcbuffer->pybuffer.buf, __pyx_t_15, __pyx_pybuffernd_real_r.diminfo[0].strides)) != __pyx_v_5pyart_3map_7ckdtree_infinity);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":1956
 *             for i in range(n_queries):
 *                 if real_r[i] != infinity:
 *                     real_r[i] = real_r[i] ** p             # <<<<<<<<<<<<<<
 * 
 *         # Track node-to-node min/max distances
 */
        __pyx_t_16 = __pyx_v_i;
        __pyx_t_17 = __pyx_v_i;
        *__Pyx_BufPtrCContig1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_real_r.rcbuffer->pybuffer.buf, __pyx_t_17, __pyx_pybuffernd_real_r.diminfo[0].strides) = pow((*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_real_r.rcbuffer->pybuffer.buf, __pyx_t_16, __pyx_pybuffernd_real_r.diminfo[0].strides)), __pyx_v_p);
        goto __pyx_L8;
      }
      __pyx_L8:;
    }
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "pyart/map/ckdtree.pyx":1960
 *         # Track node-to-node min/max distances
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),             # <<<<<<<<<<<<<<
 *             Rectangle(other.mins, other.maxes),
 *             p, 0.0, 0.0)
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1960; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mins));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->maxes));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_t_5 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1960; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1961
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(other.mins, other.maxes),             # <<<<<<<<<<<<<<
 *             p, 0.0, 0.0)
 * 
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1961; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_other->mins));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_other->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_other->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_other->maxes));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_other->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_other->maxes));
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1961; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1962
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(other.mins, other.maxes),
 *             p, 0.0, 0.0)             # <<<<<<<<<<<<<<
 * 
 *         # Go!
 */
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_p); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_6 = PyFloat_FromDouble(0.0); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_4 = PyFloat_FromDouble(0.0); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1962; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_18 = PyTuple_New(5); if (unlikely(!__pyx_t_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1959; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_18);
  PyTuple_SET_ITEM(__pyx_t_18, 0, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_18, 1, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_18, 2, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_18, 3, __pyx_t_6);
  __Pyx_GIVEREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_18, 4, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_5 = 0;
  __pyx_t_3 = 0;
  __pyx_t_2 = 0;
  __pyx_t_6 = 0;
  __pyx_t_4 = 0;
  __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_RectRectDistanceTracker)), ((PyObject *)__pyx_t_18), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1959; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(((PyObject *)__pyx_t_18)); __pyx_t_18 = 0;
  __pyx_v_tracker = ((struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "pyart/map/ckdtree.pyx":1965
 * 
 *         # Go!
 *         results = np.zeros((n_queries,), dtype=np.intp)             # <<<<<<<<<<<<<<
 *         idx = np.arange(n_queries, dtype=np.intp)
 *         self.__count_neighbors_traverse(other, n_queries,
 */
  __pyx_t_4 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_18 = PyObject_GetAttr(__pyx_t_4, __pyx_n_s__zeros); if (unlikely(!__pyx_t_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_18);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_n_queries); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_6 = PyTuple_New(1); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_4 = 0;
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_6));
  __Pyx_GIVEREF(((PyObject *)__pyx_t_6));
  __pyx_t_6 = 0;
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__intp); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__dtype), __pyx_t_3) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_18, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_19 = ((PyArrayObject *)__pyx_t_3);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_results.rcbuffer->pybuffer);
    __pyx_t_8 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_results.rcbuffer->pybuffer, (PyObject*)__pyx_t_19, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_8 < 0)) {
      PyErr_Fetch(&__pyx_t_9, &__pyx_t_10, &__pyx_t_11);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_results.rcbuffer->pybuffer, (PyObject*)__pyx_v_results, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_9); Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_11);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_9, __pyx_t_10, __pyx_t_11);
      }
    }
    __pyx_pybuffernd_results.diminfo[0].strides = __pyx_pybuffernd_results.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_results.diminfo[0].shape = __pyx_pybuffernd_results.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1965; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_19 = 0;
  __pyx_v_results = ((PyArrayObject *)__pyx_t_3);
  __pyx_t_3 = 0;

  /* "pyart/map/ckdtree.pyx":1966
 *         # Go!
 *         results = np.zeros((n_queries,), dtype=np.intp)
 *         idx = np.arange(n_queries, dtype=np.intp)             # <<<<<<<<<<<<<<
 *         self.__count_neighbors_traverse(other, n_queries,
 *                                         &real_r[0], &results[0], &idx[0],
 */
  __pyx_t_3 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__arange); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_n_queries); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  __pyx_t_3 = 0;
  __pyx_t_3 = PyDict_New(); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_3));
  __pyx_t_18 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_18);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_18, __pyx_n_s__intp); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_18); __pyx_t_18 = 0;
  if (PyDict_SetItem(__pyx_t_3, ((PyObject *)__pyx_n_s__dtype), __pyx_t_2) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_t_4), ((PyObject *)__pyx_t_3)); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_5numpy_ndarray))))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_t_19 = ((PyArrayObject *)__pyx_t_2);
  {
    __Pyx_BufFmt_StackElem __pyx_stack[1];
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_idx.rcbuffer->pybuffer);
    __pyx_t_8 = __Pyx_GetBufferAndValidate(&__pyx_pybuffernd_idx.rcbuffer->pybuffer, (PyObject*)__pyx_t_19, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack);
    if (unlikely(__pyx_t_8 < 0)) {
      PyErr_Fetch(&__pyx_t_11, &__pyx_t_10, &__pyx_t_9);
      if (unlikely(__Pyx_GetBufferAndValidate(&__pyx_pybuffernd_idx.rcbuffer->pybuffer, (PyObject*)__pyx_v_idx, &__Pyx_TypeInfo_nn___pyx_t_5numpy_intp_t, PyBUF_FORMAT| PyBUF_C_CONTIGUOUS, 1, 0, __pyx_stack) == -1)) {
        Py_XDECREF(__pyx_t_11); Py_XDECREF(__pyx_t_10); Py_XDECREF(__pyx_t_9);
        __Pyx_RaiseBufferFallbackError();
      } else {
        PyErr_Restore(__pyx_t_11, __pyx_t_10, __pyx_t_9);
      }
    }
    __pyx_pybuffernd_idx.diminfo[0].strides = __pyx_pybuffernd_idx.rcbuffer->pybuffer.strides[0]; __pyx_pybuffernd_idx.diminfo[0].shape = __pyx_pybuffernd_idx.rcbuffer->pybuffer.shape[0];
    if (unlikely(__pyx_t_8 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1966; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_19 = 0;
  __pyx_v_idx = ((PyArrayObject *)__pyx_t_2);
  __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":1968
 *         idx = np.arange(n_queries, dtype=np.intp)
 *         self.__count_neighbors_traverse(other, n_queries,
 *                                         &real_r[0], &results[0], &idx[0],             # <<<<<<<<<<<<<<
 *                                         self.tree, other.tree,
 *                                         tracker)
 */
  __pyx_t_20 = 0;
  __pyx_t_21 = 0;
  __pyx_t_22 = 0;

  /* "pyart/map/ckdtree.pyx":1970
 *                                         &real_r[0], &results[0], &idx[0],
 *                                         self.tree, other.tree,
 *                                         tracker)             # <<<<<<<<<<<<<<
 * 
 *         if np.shape(r) == ():
 */
  __pyx_t_8 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___count_neighbors_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_n_queries, (&(*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_float64_t *, __pyx_pybuffernd_real_r.rcbuffer->pybuffer.buf, __pyx_t_20, __pyx_pybuffernd_real_r.diminfo[0].strides))), (&(*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_results.rcbuffer->pybuffer.buf, __pyx_t_21, __pyx_pybuffernd_results.diminfo[0].strides))), (&(*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_idx.rcbuffer->pybuffer.buf, __pyx_t_22, __pyx_pybuffernd_idx.diminfo[0].strides))), __pyx_v_self->tree, __pyx_v_other->tree, __pyx_v_tracker); if (unlikely(__pyx_t_8 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1967; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":1972
 *                                         tracker)
 * 
 *         if np.shape(r) == ():             # <<<<<<<<<<<<<<
 *             if results[0] <= <np.intp_t> LONG_MAX:
 *                 return int(results[0])
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_r);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_r);
  __Pyx_GIVEREF(__pyx_v_r);
  __pyx_t_4 = PyObject_Call(__pyx_t_3, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_2 = PyObject_RichCompare(__pyx_t_4, ((PyObject *)__pyx_empty_tuple), Py_EQ); __Pyx_XGOTREF(__pyx_t_2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_1 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely(__pyx_t_1 < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1972; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1973
 * 
 *         if np.shape(r) == ():
 *             if results[0] <= <np.intp_t> LONG_MAX:             # <<<<<<<<<<<<<<
 *                 return int(results[0])
 *             else:
 */
    __pyx_t_23 = 0;
    __pyx_t_1 = ((*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_results.rcbuffer->pybuffer.buf, __pyx_t_23, __pyx_pybuffernd_results.diminfo[0].strides)) <= ((__pyx_t_5numpy_intp_t)LONG_MAX));
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1974
 *         if np.shape(r) == ():
 *             if results[0] <= <np.intp_t> LONG_MAX:
 *                 return int(results[0])             # <<<<<<<<<<<<<<
 *             else:
 *                 return results[0]
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_24 = 0;
      __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t((*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_results.rcbuffer->pybuffer.buf, __pyx_t_24, __pyx_pybuffernd_results.diminfo[0].strides))); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_2);
      __pyx_t_2 = 0;
      __pyx_t_2 = PyObject_Call(((PyObject *)((PyObject*)(&PyInt_Type))), ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1974; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;
      goto __pyx_L10;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":1976
 *                 return int(results[0])
 *             else:
 *                 return results[0]             # <<<<<<<<<<<<<<
 *         elif len(np.shape(r))==1:
 *             return results
 */
      __Pyx_XDECREF(__pyx_r);
      __pyx_t_25 = 0;
      __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t((*__Pyx_BufPtrCContig1d(__pyx_t_5numpy_intp_t *, __pyx_pybuffernd_results.rcbuffer->pybuffer.buf, __pyx_t_25, __pyx_pybuffernd_results.diminfo[0].strides))); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1976; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      goto __pyx_L0;
    }
    __pyx_L10:;
    goto __pyx_L9;
  }

  /* "pyart/map/ckdtree.pyx":1977
 *             else:
 *                 return results[0]
 *         elif len(np.shape(r))==1:             # <<<<<<<<<<<<<<
 *             return results
 * 
 */
  __pyx_t_2 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = PyObject_GetAttr(__pyx_t_2, __pyx_n_s__shape); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = PyTuple_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_v_r);
  PyTuple_SET_ITEM(__pyx_t_2, 0, __pyx_v_r);
  __Pyx_GIVEREF(__pyx_v_r);
  __pyx_t_3 = PyObject_Call(__pyx_t_4, ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;
  __pyx_t_12 = PyObject_Length(__pyx_t_3); if (unlikely(__pyx_t_12 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1977; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_1 = (__pyx_t_12 == 1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1978
 *                 return results[0]
 *         elif len(np.shape(r))==1:
 *             return results             # <<<<<<<<<<<<<<
 * 
 *     # ----------------------
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_results));
    __pyx_r = ((PyObject *)__pyx_v_results);
    goto __pyx_L0;
    goto __pyx_L9;
  }
  __pyx_L9:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_18);
  { PyObject *__pyx_type, *__pyx_value, *__pyx_tb;
    __Pyx_ErrFetch(&__pyx_type, &__pyx_value, &__pyx_tb);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_idx.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer);
    __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_results.rcbuffer->pybuffer);
  __Pyx_ErrRestore(__pyx_type, __pyx_value, __pyx_tb);}
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.count_neighbors", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  goto __pyx_L2;
  __pyx_L0:;
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_idx.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_real_r.rcbuffer->pybuffer);
  __Pyx_SafeReleaseBuffer(&__pyx_pybuffernd_results.rcbuffer->pybuffer);
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_real_r);
  __Pyx_XDECREF((PyObject *)__pyx_v_results);
  __Pyx_XDECREF((PyObject *)__pyx_v_idx);
  __Pyx_XDECREF((PyObject *)__pyx_v_tracker);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":1983
 *     # sparse_distance_matrix
 *     # ----------------------
 *     cdef int __sparse_distance_matrix_traverse(cKDTree self, cKDTree other,             # <<<<<<<<<<<<<<
 *                                                coo_entries results,
 *                                                innernode* node1, innernode* node2,
 */

static int __pyx_f_5pyart_3map_7ckdtree_7cKDTree___sparse_distance_matrix_traverse(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *__pyx_v_results, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node1, struct __pyx_t_5pyart_3map_7ckdtree_innernode *__pyx_v_node2, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker) {
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode1;
  struct __pyx_t_5pyart_3map_7ckdtree_leafnode *__pyx_v_lnode2;
  __pyx_t_5numpy_float64_t __pyx_v_d;
  __pyx_t_5numpy_intp_t __pyx_v_i;
  __pyx_t_5numpy_intp_t __pyx_v_j;
  __pyx_t_5numpy_intp_t __pyx_v_min_j;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __pyx_t_5numpy_intp_t __pyx_t_2;
  __pyx_t_5numpy_intp_t __pyx_t_3;
  __pyx_t_5numpy_intp_t __pyx_t_4;
  __pyx_t_5numpy_intp_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__sparse_distance_matrix_traverse", 0);

  /* "pyart/map/ckdtree.pyx":1992
 *         cdef np.intp_t i, j, min_j
 * 
 *         if tracker.min_distance > tracker.upper_bound:             # <<<<<<<<<<<<<<
 *             return 0
 *         elif node1.split_dim == -1:  # 1 is leaf node
 */
  __pyx_t_1 = (__pyx_v_tracker->min_distance > __pyx_v_tracker->upper_bound);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1993
 * 
 *         if tracker.min_distance > tracker.upper_bound:
 *             return 0             # <<<<<<<<<<<<<<
 *         elif node1.split_dim == -1:  # 1 is leaf node
 *             lnode1 = <leafnode*>node1
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }

  /* "pyart/map/ckdtree.pyx":1994
 *         if tracker.min_distance > tracker.upper_bound:
 *             return 0
 *         elif node1.split_dim == -1:  # 1 is leaf node             # <<<<<<<<<<<<<<
 *             lnode1 = <leafnode*>node1
 * 
 */
  __pyx_t_1 = (__pyx_v_node1->split_dim == -1);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":1995
 *             return 0
 *         elif node1.split_dim == -1:  # 1 is leaf node
 *             lnode1 = <leafnode*>node1             # <<<<<<<<<<<<<<
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves
 */
    __pyx_v_lnode1 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node1);

    /* "pyart/map/ckdtree.pyx":1997
 *             lnode1 = <leafnode*>node1
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves             # <<<<<<<<<<<<<<
 *                 lnode2 = <leafnode*>node2
 * 
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":1998
 * 
 *             if node2.split_dim == -1:  # 1 & 2 are leaves
 *                 lnode2 = <leafnode*>node2             # <<<<<<<<<<<<<<
 * 
 *                 # brute-force
 */
      __pyx_v_lnode2 = ((struct __pyx_t_5pyart_3map_7ckdtree_leafnode *)__pyx_v_node2);

      /* "pyart/map/ckdtree.pyx":2001
 * 
 *                 # brute-force
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):             # <<<<<<<<<<<<<<
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:
 */
      __pyx_t_2 = __pyx_v_lnode1->end_idx;
      for (__pyx_t_3 = __pyx_v_lnode1->start_idx; __pyx_t_3 < __pyx_t_2; __pyx_t_3+=1) {
        __pyx_v_i = __pyx_t_3;

        /* "pyart/map/ckdtree.pyx":2003
 *                 for i in range(lnode1.start_idx, lnode1.end_idx):
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:             # <<<<<<<<<<<<<<
 *                         min_j = i+1
 *                     else:
 */
        __pyx_t_1 = (__pyx_v_node1 == __pyx_v_node2);
        if (__pyx_t_1) {

          /* "pyart/map/ckdtree.pyx":2004
 *                     # Special care here to avoid duplicate pairs
 *                     if node1 == node2:
 *                         min_j = i+1             # <<<<<<<<<<<<<<
 *                     else:
 *                         min_j = lnode2.end_idx
 */
          __pyx_v_min_j = (__pyx_v_i + 1);
          goto __pyx_L7;
        }
        /*else*/ {

          /* "pyart/map/ckdtree.pyx":2006
 *                         min_j = i+1
 *                     else:
 *                         min_j = lnode2.end_idx             # <<<<<<<<<<<<<<
 * 
 *                     for j in range(min_j, lnode2.end_idx):
 */
          __pyx_t_4 = __pyx_v_lnode2->end_idx;
          __pyx_v_min_j = __pyx_t_4;
        }
        __pyx_L7:;

        /* "pyart/map/ckdtree.pyx":2008
 *                         min_j = lnode2.end_idx
 * 
 *                     for j in range(min_j, lnode2.end_idx):             # <<<<<<<<<<<<<<
 *                         d = _distance_p(
 *                             self.raw_data + self.raw_indices[i] * self.m,
 */
        __pyx_t_4 = __pyx_v_lnode2->end_idx;
        for (__pyx_t_5 = __pyx_v_min_j; __pyx_t_5 < __pyx_t_4; __pyx_t_5+=1) {
          __pyx_v_j = __pyx_t_5;

          /* "pyart/map/ckdtree.pyx":2012
 *                             self.raw_data + self.raw_indices[i] * self.m,
 *                             other.raw_data + other.raw_indices[j] * self.m,
 *                             tracker.p, self.m, tracker.upper_bound)             # <<<<<<<<<<<<<<
 *                         if d <= tracker.upper_bound:
 *                             results.add(self.raw_indices[i],
 */
          __pyx_v_d = __pyx_f_5pyart_3map_7ckdtree__distance_p((__pyx_v_self->raw_data + ((__pyx_v_self->raw_indices[__pyx_v_i]) * __pyx_v_self->m)), (__pyx_v_other->raw_data + ((__pyx_v_other->raw_indices[__pyx_v_j]) * __pyx_v_self->m)), __pyx_v_tracker->p, __pyx_v_self->m, __pyx_v_tracker->upper_bound);

          /* "pyart/map/ckdtree.pyx":2013
 *                             other.raw_data + other.raw_indices[j] * self.m,
 *                             tracker.p, self.m, tracker.upper_bound)
 *                         if d <= tracker.upper_bound:             # <<<<<<<<<<<<<<
 *                             results.add(self.raw_indices[i],
 *                                         self.raw_indices[j], d)
 */
          __pyx_t_1 = (__pyx_v_d <= __pyx_v_tracker->upper_bound);
          if (__pyx_t_1) {

            /* "pyart/map/ckdtree.pyx":2015
 *                         if d <= tracker.upper_bound:
 *                             results.add(self.raw_indices[i],
 *                                         self.raw_indices[j], d)             # <<<<<<<<<<<<<<
 *                             if node1 == node2:
 *                                 results.add(self.raw_indices[j],
 */
            ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_coo_entries *)__pyx_v_results->__pyx_vtab)->add(__pyx_v_results, (__pyx_v_self->raw_indices[__pyx_v_i]), (__pyx_v_self->raw_indices[__pyx_v_j]), __pyx_v_d);

            /* "pyart/map/ckdtree.pyx":2016
 *                             results.add(self.raw_indices[i],
 *                                         self.raw_indices[j], d)
 *                             if node1 == node2:             # <<<<<<<<<<<<<<
 *                                 results.add(self.raw_indices[j],
 *                                             self.raw_indices[i], d)
 */
            __pyx_t_1 = (__pyx_v_node1 == __pyx_v_node2);
            if (__pyx_t_1) {

              /* "pyart/map/ckdtree.pyx":2018
 *                             if node1 == node2:
 *                                 results.add(self.raw_indices[j],
 *                                             self.raw_indices[i], d)             # <<<<<<<<<<<<<<
 * 
 *             else:  # 1 is a leaf node, 2 is inner node
 */
              ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_coo_entries *)__pyx_v_results->__pyx_vtab)->add(__pyx_v_results, (__pyx_v_self->raw_indices[__pyx_v_j]), (__pyx_v_self->raw_indices[__pyx_v_i]), __pyx_v_d);
              goto __pyx_L11;
            }
            __pyx_L11:;
            goto __pyx_L10;
          }
          __pyx_L10:;
        }
      }
      goto __pyx_L4;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":2021
 * 
 *             else:  # 1 is a leaf node, 2 is inner node
 *                 tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1, node2.less, tracker)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2021; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2023
 *                 tracker.push_less_of(2, node2)
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2022; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2024
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1, node2.less, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2024; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2026
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1, node2.greater, tracker)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2026; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2028
 *                 tracker.push_greater_of(2, node2)
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2027; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2029
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *         else:  # 1 is an inner node
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2029; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L4:;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "pyart/map/ckdtree.pyx":2032
 * 
 *         else:  # 1 is an inner node
 *             if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node             # <<<<<<<<<<<<<<
 *                 tracker.push_less_of(1, node1)
 *                 self.__sparse_distance_matrix_traverse(
 */
    __pyx_t_1 = (__pyx_v_node2->split_dim == -1);
    if (__pyx_t_1) {

      /* "pyart/map/ckdtree.pyx":2033
 *         else:  # 1 is an inner node
 *             if node2.split_dim == -1:  # 1 is an inner node, 2 is a leaf node
 *                 tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2, tracker)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2033; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2035
 *                 tracker.push_less_of(1, node1)
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2034; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2036
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(1, node1)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2036; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2038
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.greater, node2, tracker)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2038; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2040
 *                 tracker.push_greater_of(1, node1)
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.greater, node2, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2039; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2041
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.greater, node2, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *             else: # 1 and 2 are inner nodes
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2041; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L12;
    }
    /*else*/ {

      /* "pyart/map/ckdtree.pyx":2044
 * 
 *             else: # 1 and 2 are inner nodes
 *                 tracker.push_less_of(1, node1)             # <<<<<<<<<<<<<<
 *                 tracker.push_less_of(2, node2)
 *                 self.__sparse_distance_matrix_traverse(
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2044; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2045
 *             else: # 1 and 2 are inner nodes
 *                 tracker.push_less_of(1, node1)
 *                 tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2.less, tracker)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2045; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2047
 *                 tracker.push_less_of(2, node2)
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2046; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2048
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2.less, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2048; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2050
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2.greater, tracker)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2050; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2052
 *                 tracker.push_greater_of(2, node2)
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 *                 tracker.pop()
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->less, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2051; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2053
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.less, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2053; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2054
 *                     other, results, node1.less, node2.greater, tracker)
 *                 tracker.pop()
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(1, node1)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2054; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2056
 *                 tracker.pop()
 * 
 *                 tracker.push_greater_of(1, node1)             # <<<<<<<<<<<<<<
 *                 if node1 != node2:
 *                     # Avoid traversing (node1.less, node2.greater) and
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 1, __pyx_v_node1); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2056; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2057
 * 
 *                 tracker.push_greater_of(1, node1)
 *                 if node1 != node2:             # <<<<<<<<<<<<<<
 *                     # Avoid traversing (node1.less, node2.greater) and
 *                     # (node1.greater, node2.less) (it's the same node pair
 */
      __pyx_t_1 = (__pyx_v_node1 != __pyx_v_node2);
      if (__pyx_t_1) {

        /* "pyart/map/ckdtree.pyx":2062
 *                     # twice over, which is the source of the complication in
 *                     # the original KDTree.sparse_distance_matrix)
 *                     tracker.push_less_of(2, node2)             # <<<<<<<<<<<<<<
 *                     self.__sparse_distance_matrix_traverse(
 *                         other, results, node1.greater, node2.less, tracker)
 */
        __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2062; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":2064
 *                     tracker.push_less_of(2, node2)
 *                     self.__sparse_distance_matrix_traverse(
 *                         other, results, node1.greater, node2.less, tracker)             # <<<<<<<<<<<<<<
 *                     tracker.pop()
 * 
 */
        __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2->less, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2063; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

        /* "pyart/map/ckdtree.pyx":2065
 *                     self.__sparse_distance_matrix_traverse(
 *                         other, results, node1.greater, node2.less, tracker)
 *                     tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *                 tracker.push_greater_of(2, node2)
 */
        __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2065; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L13;
      }
      __pyx_L13:;

      /* "pyart/map/ckdtree.pyx":2067
 *                     tracker.pop()
 * 
 *                 tracker.push_greater_of(2, node2)             # <<<<<<<<<<<<<<
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.greater, node2.greater, tracker)
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of(__pyx_v_tracker, 2, __pyx_v_node2); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2067; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2069
 *                 tracker.push_greater_of(2, node2)
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.greater, node2.greater, tracker)             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 *                 tracker.pop()
 */
      __pyx_t_6 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_node1->greater, __pyx_v_node2->greater, __pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2068; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2070
 *                 self.__sparse_distance_matrix_traverse(
 *                     other, results, node1.greater, node2.greater, tracker)
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 *                 tracker.pop()
 * 
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2070; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

      /* "pyart/map/ckdtree.pyx":2071
 *                     other, results, node1.greater, node2.greater, tracker)
 *                 tracker.pop()
 *                 tracker.pop()             # <<<<<<<<<<<<<<
 * 
 *         return 0
 */
      __pyx_t_6 = __pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop(__pyx_v_tracker); if (unlikely(__pyx_t_6 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2071; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L12:;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":2073
 *                 tracker.pop()
 * 
 *         return 0             # <<<<<<<<<<<<<<
 * 
 *     def sparse_distance_matrix(cKDTree self, cKDTree other,
 */
  __pyx_r = 0;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.__sparse_distance_matrix_traverse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_15sparse_distance_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_5pyart_3map_7ckdtree_7cKDTree_14sparse_distance_matrix[] = "sparse_distance_matrix(self, max_distance, p)\n\n        Compute a sparse distance matrix\n\n        Computes a distance matrix between two KDTrees, leaving as zero\n        any distance greater than max_distance.\n\n        Parameters\n        ----------\n        other : cKDTree\n\n        max_distance : positive float\n\n        Returns\n        -------\n        result : dok_matrix\n            Sparse matrix representing the results in \"dictionary of keys\" format.\n            FIXME: Internally, built as a COO matrix, it would be more\n            efficient to return this COO matrix.\n\n        ";
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_15sparse_distance_matrix(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other = 0;
  __pyx_t_5numpy_float64_t __pyx_v_max_distance;
  __pyx_t_5numpy_float64_t __pyx_v_p;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("sparse_distance_matrix (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s__other,&__pyx_n_s__max_distance,&__pyx_n_s__p,0};
    PyObject* values[3] = {0,0,0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__other)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
        case  1:
        if (likely((values[1] = PyDict_GetItem(__pyx_kwds, __pyx_n_s__max_distance)) != 0)) kw_args--;
        else {
          __Pyx_RaiseArgtupleInvalid("sparse_distance_matrix", 0, 2, 3, 1); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2075; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
        }
        case  2:
        if (kw_args > 0) {
          PyObject* value = PyDict_GetItem(__pyx_kwds, __pyx_n_s__p);
          if (value) { values[2] = value; kw_args--; }
        }
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "sparse_distance_matrix") < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2075; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
      }
    } else {
      switch (PyTuple_GET_SIZE(__pyx_args)) {
        case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
        case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
        values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        break;
        default: goto __pyx_L5_argtuple_error;
      }
    }
    __pyx_v_other = ((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)values[0]);
    __pyx_v_max_distance = __pyx_PyFloat_AsDouble(values[1]); if (unlikely((__pyx_v_max_distance == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2076; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    if (values[2]) {
      __pyx_v_p = __pyx_PyFloat_AsDouble(values[2]); if (unlikely((__pyx_v_p == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2077; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
    } else {

      /* "pyart/map/ckdtree.pyx":2077
 *     def sparse_distance_matrix(cKDTree self, cKDTree other,
 *                                np.float64_t max_distance,
 *                                np.float64_t p=2.):             # <<<<<<<<<<<<<<
 *         """sparse_distance_matrix(self, max_distance, p)
 * 
 */
      __pyx_v_p = ((__pyx_t_5numpy_float64_t)2.);
    }
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("sparse_distance_matrix", 0, 2, 3, PyTuple_GET_SIZE(__pyx_args)); {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2075; __pyx_clineno = __LINE__; goto __pyx_L3_error;}
  __pyx_L3_error:;
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.sparse_distance_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_other), __pyx_ptype_5pyart_3map_7ckdtree_cKDTree, 1, "other", 0))) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2075; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_14sparse_distance_matrix(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self), __pyx_v_other, __pyx_v_max_distance, __pyx_v_p);
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":2075
 *         return 0
 * 
 *     def sparse_distance_matrix(cKDTree self, cKDTree other,             # <<<<<<<<<<<<<<
 *                                np.float64_t max_distance,
 *                                np.float64_t p=2.):
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_14sparse_distance_matrix(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_other, __pyx_t_5numpy_float64_t __pyx_v_max_distance, __pyx_t_5numpy_float64_t __pyx_v_p) {
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *__pyx_v_tracker = NULL;
  struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *__pyx_v_results = NULL;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  int __pyx_t_7;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("sparse_distance_matrix", 0);

  /* "pyart/map/ckdtree.pyx":2101
 * 
 *         # Make sure trees are compatible
 *         if self.m != other.m:             # <<<<<<<<<<<<<<
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")
 * 
 */
  __pyx_t_1 = (__pyx_v_self->m != __pyx_v_other->m);
  if (__pyx_t_1) {

    /* "pyart/map/ckdtree.pyx":2102
 *         # Make sure trees are compatible
 *         if self.m != other.m:
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")             # <<<<<<<<<<<<<<
 * 
 *         # Calculate mins and maxes to outer box
 */
    __pyx_t_2 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_25), NULL); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_Raise(__pyx_t_2, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "pyart/map/ckdtree.pyx":2106
 *         # Calculate mins and maxes to outer box
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),             # <<<<<<<<<<<<<<
 *             Rectangle(other.mins, other.maxes),
 *             p, 0, max_distance)
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mins));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_self->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_self->maxes));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_self->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_t_3 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2106; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":2107
 *         tracker = RectRectDistanceTracker(
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(other.mins, other.maxes),             # <<<<<<<<<<<<<<
 *             p, 0, max_distance)
 * 
 */
  __pyx_t_2 = PyTuple_New(2); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_v_other->mins));
  PyTuple_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_v_other->mins));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_other->mins));
  __Pyx_INCREF(((PyObject *)__pyx_v_other->maxes));
  PyTuple_SET_ITEM(__pyx_t_2, 1, ((PyObject *)__pyx_v_other->maxes));
  __Pyx_GIVEREF(((PyObject *)__pyx_v_other->maxes));
  __pyx_t_4 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_Rectangle)), ((PyObject *)__pyx_t_2), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2107; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":2108
 *             Rectangle(self.mins, self.maxes),
 *             Rectangle(other.mins, other.maxes),
 *             p, 0, max_distance)             # <<<<<<<<<<<<<<
 * 
 *         results = coo_entries()
 */
  __pyx_t_2 = PyFloat_FromDouble(__pyx_v_p); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_5 = PyFloat_FromDouble(__pyx_v_max_distance); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2108; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyTuple_New(5); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  PyTuple_SET_ITEM(__pyx_t_6, 0, __pyx_t_3);
  __Pyx_GIVEREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_6, 1, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_6, 2, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_6, 3, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_t_6, 4, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_5);
  __pyx_t_3 = 0;
  __pyx_t_4 = 0;
  __pyx_t_2 = 0;
  __pyx_t_5 = 0;
  __pyx_t_5 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_RectRectDistanceTracker)), ((PyObject *)__pyx_t_6), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2105; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_v_tracker = ((struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":2110
 *             p, 0, max_distance)
 * 
 *         results = coo_entries()             # <<<<<<<<<<<<<<
 *         self.__sparse_distance_matrix_traverse(other, results,
 *                                                self.tree, other.tree,
 */
  __pyx_t_5 = PyObject_Call(((PyObject *)((PyObject*)__pyx_ptype_5pyart_3map_7ckdtree_coo_entries)), ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2110; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_v_results = ((struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *)__pyx_t_5);
  __pyx_t_5 = 0;

  /* "pyart/map/ckdtree.pyx":2113
 *         self.__sparse_distance_matrix_traverse(other, results,
 *                                                self.tree, other.tree,
 *                                                tracker)             # <<<<<<<<<<<<<<
 * 
 *         return results.to_matrix(shape=(self.n, other.n)).todok()
 */
  __pyx_t_7 = ((struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self->__pyx_vtab)->__pyx___sparse_distance_matrix_traverse(__pyx_v_self, __pyx_v_other, __pyx_v_results, __pyx_v_self->tree, __pyx_v_other->tree, __pyx_v_tracker); if (unlikely(__pyx_t_7 == -1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2111; __pyx_clineno = __LINE__; goto __pyx_L1_error;}

  /* "pyart/map/ckdtree.pyx":2115
 *                                                tracker)
 * 
 *         return results.to_matrix(shape=(self.n, other.n)).todok()             # <<<<<<<<<<<<<<
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_5 = PyObject_GetAttr(((PyObject *)__pyx_v_results), __pyx_n_s__to_matrix); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_6 = PyDict_New(); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_6));
  __pyx_t_2 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_other->n); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_3 = PyTuple_New(2); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  PyTuple_SET_ITEM(__pyx_t_3, 0, __pyx_t_2);
  __Pyx_GIVEREF(__pyx_t_2);
  PyTuple_SET_ITEM(__pyx_t_3, 1, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_4);
  __pyx_t_2 = 0;
  __pyx_t_4 = 0;
  if (PyDict_SetItem(__pyx_t_6, ((PyObject *)__pyx_n_s__shape), ((PyObject *)__pyx_t_3)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_5, ((PyObject *)__pyx_empty_tuple), ((PyObject *)__pyx_t_6)); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(((PyObject *)__pyx_t_6)); __pyx_t_6 = 0;
  __pyx_t_6 = PyObject_GetAttr(__pyx_t_3, __pyx_n_s__todok); if (unlikely(!__pyx_t_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_6);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = PyObject_Call(__pyx_t_6, ((PyObject *)__pyx_empty_tuple), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2115; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  __pyx_r = __pyx_t_3;
  __pyx_t_3 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.sparse_distance_matrix", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_tracker);
  __Pyx_XDECREF((PyObject *)__pyx_v_results);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_4data_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_4data_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4data___get__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":833
 * 
 *     cdef innernode* tree
 *     cdef readonly np.ndarray data             # <<<<<<<<<<<<<<
 *     cdef np.float64_t* raw_data
 *     cdef readonly np.intp_t n, m
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4data___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->data));
  __pyx_r = ((PyObject *)__pyx_v_self->data);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1n_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1n_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_1n___get__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":835
 *     cdef readonly np.ndarray data
 *     cdef np.float64_t* raw_data
 *     cdef readonly np.intp_t n, m             # <<<<<<<<<<<<<<
 *     cdef readonly np.intp_t leafsize
 *     cdef readonly np.ndarray maxes
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_1n___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->n); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.n.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1m_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1m_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_1m___get__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_1m___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->m); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.m.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_8leafsize_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_8leafsize_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_8leafsize___get__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":836
 *     cdef np.float64_t* raw_data
 *     cdef readonly np.intp_t n, m
 *     cdef readonly np.intp_t leafsize             # <<<<<<<<<<<<<<
 *     cdef readonly np.ndarray maxes
 *     cdef np.float64_t* raw_maxes
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_8leafsize___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_to_py_Py_intptr_t(__pyx_v_self->leafsize); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("pyart.map.ckdtree.cKDTree.leafsize.__get__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_5maxes_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_5maxes_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_5maxes___get__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":837
 *     cdef readonly np.intp_t n, m
 *     cdef readonly np.intp_t leafsize
 *     cdef readonly np.ndarray maxes             # <<<<<<<<<<<<<<
 *     cdef np.float64_t* raw_maxes
 *     cdef readonly np.ndarray mins
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_5maxes___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->maxes));
  __pyx_r = ((PyObject *)__pyx_v_self->maxes);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_4mins_1__get__(PyObject *__pyx_v_self); /*proto*/
static PyObject *__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_4mins_1__get__(PyObject *__pyx_v_self) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4mins___get__(((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)__pyx_v_self));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "pyart/map/ckdtree.pyx":839
 *     cdef readonly np.ndarray maxes
 *     cdef np.float64_t* raw_maxes
 *     cdef readonly np.ndarray mins             # <<<<<<<<<<<<<<
 *     cdef np.float64_t* raw_mins
 *     cdef np.ndarray indices
 */

static PyObject *__pyx_pf_5pyart_3map_7ckdtree_7cKDTree_4mins___get__(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__get__", 0);
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(((PyObject *)__pyx_v_self->mins));
  __pyx_r = ((PyObject *)__pyx_v_self->mins);
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags); /*proto*/
static CYTHON_UNUSED int __pyx_pw_5numpy_7ndarray_1__getbuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__getbuffer__ (wrapper)", 0);
  __pyx_r = __pyx_pf_5numpy_7ndarray___getbuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info), ((int)__pyx_v_flags));
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":194
 *         # experimental exception made for __getbuffer__ and __releasebuffer__
 *         # -- the details of this may change.
 *         def __getbuffer__(ndarray self, Py_buffer* info, int flags):             # <<<<<<<<<<<<<<
 *             # This implementation of getbuffer is geared towards Cython
 *             # requirements, and does not yet fullfill the PEP.
 */

static int __pyx_pf_5numpy_7ndarray___getbuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info, int __pyx_v_flags) {
  int __pyx_v_copy_shape;
  int __pyx_v_i;
  int __pyx_v_ndim;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  int __pyx_v_t;
  char *__pyx_v_f;
  PyArray_Descr *__pyx_v_descr = 0;
  int __pyx_v_offset;
  int __pyx_v_hasfields;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  int __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_t_6;
  int __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  char *__pyx_t_9;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__getbuffer__", 0);
  if (__pyx_v_info != NULL) {
    __pyx_v_info->obj = Py_None; __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(__pyx_v_info->obj);
  }

  /* "numpy.pxd":200
 *             # of flags
 * 
 *             if info == NULL: return             # <<<<<<<<<<<<<<
 * 
 *             cdef int copy_shape, i, ndim
 */
  __pyx_t_1 = (__pyx_v_info == NULL);
  if (__pyx_t_1) {
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "numpy.pxd":203
 * 
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 */
  __pyx_v_endian_detector = 1;

  /* "numpy.pxd":204
 *             cdef int copy_shape, i, ndim
 *             cdef int endian_detector = 1
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 * 
 *             ndim = PyArray_NDIM(self)
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "numpy.pxd":206
 *             cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 * 
 *             ndim = PyArray_NDIM(self)             # <<<<<<<<<<<<<<
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_v_ndim = PyArray_NDIM(__pyx_v_self);

  /* "numpy.pxd":208
 *             ndim = PyArray_NDIM(self)
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 copy_shape = 1
 *             else:
 */
  __pyx_t_1 = ((sizeof(npy_intp)) != (sizeof(Py_ssize_t)));
  if (__pyx_t_1) {

    /* "numpy.pxd":209
 * 
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 copy_shape = 1             # <<<<<<<<<<<<<<
 *             else:
 *                 copy_shape = 0
 */
    __pyx_v_copy_shape = 1;
    goto __pyx_L4;
  }
  /*else*/ {

    /* "numpy.pxd":211
 *                 copy_shape = 1
 *             else:
 *                 copy_shape = 0             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 */
    __pyx_v_copy_shape = 0;
  }
  __pyx_L4:;

  /* "numpy.pxd":213
 *                 copy_shape = 0
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")
 */
  __pyx_t_1 = ((__pyx_v_flags & PyBUF_C_CONTIGUOUS) == PyBUF_C_CONTIGUOUS);
  if (__pyx_t_1) {

    /* "numpy.pxd":214
 * 
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 */
    __pyx_t_2 = (!PyArray_CHKFLAGS(__pyx_v_self, NPY_C_CONTIGUOUS));
    __pyx_t_3 = __pyx_t_2;
  } else {
    __pyx_t_3 = __pyx_t_1;
  }
  if (__pyx_t_3) {

    /* "numpy.pxd":215
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_27), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L5;
  }
  __pyx_L5:;

  /* "numpy.pxd":217
 *                 raise ValueError(u"ndarray is not C contiguous")
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)             # <<<<<<<<<<<<<<
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 */
  __pyx_t_3 = ((__pyx_v_flags & PyBUF_F_CONTIGUOUS) == PyBUF_F_CONTIGUOUS);
  if (__pyx_t_3) {

    /* "numpy.pxd":218
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):             # <<<<<<<<<<<<<<
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 */
    __pyx_t_1 = (!PyArray_CHKFLAGS(__pyx_v_self, NPY_F_CONTIGUOUS));
    __pyx_t_2 = __pyx_t_1;
  } else {
    __pyx_t_2 = __pyx_t_3;
  }
  if (__pyx_t_2) {

    /* "numpy.pxd":219
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
    __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_29), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_Raise(__pyx_t_4, 0, 0, 0);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    goto __pyx_L6;
  }
  __pyx_L6:;

  /* "numpy.pxd":221
 *                 raise ValueError(u"ndarray is not Fortran contiguous")
 * 
 *             info.buf = PyArray_DATA(self)             # <<<<<<<<<<<<<<
 *             info.ndim = ndim
 *             if copy_shape:
 */
  __pyx_v_info->buf = PyArray_DATA(__pyx_v_self);

  /* "numpy.pxd":222
 * 
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim             # <<<<<<<<<<<<<<
 *             if copy_shape:
 *                 # Allocate new buffer for strides and shape info.
 */
  __pyx_v_info->ndim = __pyx_v_ndim;

  /* "numpy.pxd":223
 *             info.buf = PyArray_DATA(self)
 *             info.ndim = ndim
 *             if copy_shape:             # <<<<<<<<<<<<<<
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 */
  if (__pyx_v_copy_shape) {

    /* "numpy.pxd":226
 *                 # Allocate new buffer for strides and shape info.
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)             # <<<<<<<<<<<<<<
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 */
    __pyx_v_info->strides = ((Py_ssize_t *)malloc((((sizeof(Py_ssize_t)) * ((size_t)__pyx_v_ndim)) * 2)));

    /* "numpy.pxd":227
 *                 # This is allocated as one block, strides first.
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim             # <<<<<<<<<<<<<<
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 */
    __pyx_v_info->shape = (__pyx_v_info->strides + __pyx_v_ndim);

    /* "numpy.pxd":228
 *                 info.strides = <Py_ssize_t*>stdlib.malloc(sizeof(Py_ssize_t) * <size_t>ndim * 2)
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):             # <<<<<<<<<<<<<<
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 */
    __pyx_t_5 = __pyx_v_ndim;
    for (__pyx_t_6 = 0; __pyx_t_6 < __pyx_t_5; __pyx_t_6+=1) {
      __pyx_v_i = __pyx_t_6;

      /* "numpy.pxd":229
 *                 info.shape = info.strides + ndim
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]             # <<<<<<<<<<<<<<
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 */
      (__pyx_v_info->strides[__pyx_v_i]) = (PyArray_STRIDES(__pyx_v_self)[__pyx_v_i]);

      /* "numpy.pxd":230
 *                 for i in range(ndim):
 *                     info.strides[i] = PyArray_STRIDES(self)[i]
 *                     info.shape[i] = PyArray_DIMS(self)[i]             # <<<<<<<<<<<<<<
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 */
      (__pyx_v_info->shape[__pyx_v_i]) = (PyArray_DIMS(__pyx_v_self)[__pyx_v_i]);
    }
    goto __pyx_L7;
  }
  /*else*/ {

    /* "numpy.pxd":232
 *                     info.shape[i] = PyArray_DIMS(self)[i]
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)             # <<<<<<<<<<<<<<
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 */
    __pyx_v_info->strides = ((Py_ssize_t *)PyArray_STRIDES(__pyx_v_self));

    /* "numpy.pxd":233
 *             else:
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)             # <<<<<<<<<<<<<<
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 */
    __pyx_v_info->shape = ((Py_ssize_t *)PyArray_DIMS(__pyx_v_self));
  }
  __pyx_L7:;

  /* "numpy.pxd":234
 *                 info.strides = <Py_ssize_t*>PyArray_STRIDES(self)
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL             # <<<<<<<<<<<<<<
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 */
  __pyx_v_info->suboffsets = NULL;

  /* "numpy.pxd":235
 *                 info.shape = <Py_ssize_t*>PyArray_DIMS(self)
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)             # <<<<<<<<<<<<<<
 *             info.readonly = not PyArray_ISWRITEABLE(self)
 * 
 */
  __pyx_v_info->itemsize = PyArray_ITEMSIZE(__pyx_v_self);

  /* "numpy.pxd":236
 *             info.suboffsets = NULL
 *             info.itemsize = PyArray_ITEMSIZE(self)
 *             info.readonly = not PyArray_ISWRITEABLE(self)             # <<<<<<<<<<<<<<
 * 
 *             cdef int t
 */
  __pyx_v_info->readonly = (!PyArray_ISWRITEABLE(__pyx_v_self));

  /* "numpy.pxd":239
 * 
 *             cdef int t
 *             cdef char* f = NULL             # <<<<<<<<<<<<<<
 *             cdef dtype descr = self.descr
 *             cdef list stack
 */
  __pyx_v_f = NULL;

  /* "numpy.pxd":240
 *             cdef int t
 *             cdef char* f = NULL
 *             cdef dtype descr = self.descr             # <<<<<<<<<<<<<<
 *             cdef list stack
 *             cdef int offset
 */
  __pyx_t_4 = ((PyObject *)__pyx_v_self->descr);
  __Pyx_INCREF(__pyx_t_4);
  __pyx_v_descr = ((PyArray_Descr *)__pyx_t_4);
  __pyx_t_4 = 0;

  /* "numpy.pxd":244
 *             cdef int offset
 * 
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields and not copy_shape:
 */
  __pyx_v_hasfields = PyDataType_HASFIELDS(__pyx_v_descr);

  /* "numpy.pxd":246
 *             cdef bint hasfields = PyDataType_HASFIELDS(descr)
 * 
 *             if not hasfields and not copy_shape:             # <<<<<<<<<<<<<<
 *                 # do not call releasebuffer
 *                 info.obj = None
 */
  __pyx_t_2 = (!__pyx_v_hasfields);
  if (__pyx_t_2) {
    __pyx_t_3 = (!__pyx_v_copy_shape);
    __pyx_t_1 = __pyx_t_3;
  } else {
    __pyx_t_1 = __pyx_t_2;
  }
  if (__pyx_t_1) {

    /* "numpy.pxd":248
 *             if not hasfields and not copy_shape:
 *                 # do not call releasebuffer
 *                 info.obj = None             # <<<<<<<<<<<<<<
 *             else:
 *                 # need to call releasebuffer
 */
    __Pyx_INCREF(Py_None);
    __Pyx_GIVEREF(Py_None);
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = Py_None;
    goto __pyx_L10;
  }
  /*else*/ {

    /* "numpy.pxd":251
 *             else:
 *                 # need to call releasebuffer
 *                 info.obj = self             # <<<<<<<<<<<<<<
 * 
 *             if not hasfields:
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_self));
    __Pyx_GIVEREF(((PyObject *)__pyx_v_self));
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj);
    __pyx_v_info->obj = ((PyObject *)__pyx_v_self);
  }
  __pyx_L10:;

  /* "numpy.pxd":253
 *                 info.obj = self
 * 
 *             if not hasfields:             # <<<<<<<<<<<<<<
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 */
  __pyx_t_1 = (!__pyx_v_hasfields);
  if (__pyx_t_1) {

    /* "numpy.pxd":254
 * 
 *             if not hasfields:
 *                 t = descr.type_num             # <<<<<<<<<<<<<<
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 */
    __pyx_t_5 = __pyx_v_descr->type_num;
    __pyx_v_t = __pyx_t_5;

    /* "numpy.pxd":255
 *             if not hasfields:
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_1 = (__pyx_v_descr->byteorder == '>');
    if (__pyx_t_1) {
      __pyx_t_2 = __pyx_v_little_endian;
    } else {
      __pyx_t_2 = __pyx_t_1;
    }
    if (!__pyx_t_2) {

      /* "numpy.pxd":256
 *                 t = descr.type_num
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 */
      __pyx_t_1 = (__pyx_v_descr->byteorder == '<');
      if (__pyx_t_1) {
        __pyx_t_3 = (!__pyx_v_little_endian);
        __pyx_t_7 = __pyx_t_3;
      } else {
        __pyx_t_7 = __pyx_t_1;
      }
      __pyx_t_1 = __pyx_t_7;
    } else {
      __pyx_t_1 = __pyx_t_2;
    }
    if (__pyx_t_1) {

      /* "numpy.pxd":257
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
      __pyx_t_4 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_31), NULL); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_Raise(__pyx_t_4, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L12;
    }
    __pyx_L12:;

    /* "numpy.pxd":258
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_BYTE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__b;
      goto __pyx_L13;
    }

    /* "numpy.pxd":259
 *                     raise ValueError(u"Non-native byte order not supported")
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_UBYTE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__B;
      goto __pyx_L13;
    }

    /* "numpy.pxd":260
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_SHORT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__h;
      goto __pyx_L13;
    }

    /* "numpy.pxd":261
 *                 elif t == NPY_UBYTE:       f = "B"
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_USHORT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__H;
      goto __pyx_L13;
    }

    /* "numpy.pxd":262
 *                 elif t == NPY_SHORT:       f = "h"
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_INT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__i;
      goto __pyx_L13;
    }

    /* "numpy.pxd":263
 *                 elif t == NPY_USHORT:      f = "H"
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_UINT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__I;
      goto __pyx_L13;
    }

    /* "numpy.pxd":264
 *                 elif t == NPY_INT:         f = "i"
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__l;
      goto __pyx_L13;
    }

    /* "numpy.pxd":265
 *                 elif t == NPY_UINT:        f = "I"
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_ULONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__L;
      goto __pyx_L13;
    }

    /* "numpy.pxd":266
 *                 elif t == NPY_LONG:        f = "l"
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONGLONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__q;
      goto __pyx_L13;
    }

    /* "numpy.pxd":267
 *                 elif t == NPY_ULONG:       f = "L"
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_ULONGLONG);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Q;
      goto __pyx_L13;
    }

    /* "numpy.pxd":268
 *                 elif t == NPY_LONGLONG:    f = "q"
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_FLOAT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__f;
      goto __pyx_L13;
    }

    /* "numpy.pxd":269
 *                 elif t == NPY_ULONGLONG:   f = "Q"
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_DOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__d;
      goto __pyx_L13;
    }

    /* "numpy.pxd":270
 *                 elif t == NPY_FLOAT:       f = "f"
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_LONGDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__g;
      goto __pyx_L13;
    }

    /* "numpy.pxd":271
 *                 elif t == NPY_DOUBLE:      f = "d"
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CFLOAT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zf;
      goto __pyx_L13;
    }

    /* "numpy.pxd":272
 *                 elif t == NPY_LONGDOUBLE:  f = "g"
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zd;
      goto __pyx_L13;
    }

    /* "numpy.pxd":273
 *                 elif t == NPY_CFLOAT:      f = "Zf"
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"             # <<<<<<<<<<<<<<
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 */
    __pyx_t_1 = (__pyx_v_t == NPY_CLONGDOUBLE);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__Zg;
      goto __pyx_L13;
    }

    /* "numpy.pxd":274
 *                 elif t == NPY_CDOUBLE:     f = "Zd"
 *                 elif t == NPY_CLONGDOUBLE: f = "Zg"
 *                 elif t == NPY_OBJECT:      f = "O"             # <<<<<<<<<<<<<<
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
    __pyx_t_1 = (__pyx_v_t == NPY_OBJECT);
    if (__pyx_t_1) {
      __pyx_v_f = __pyx_k__O;
      goto __pyx_L13;
    }
    /*else*/ {

      /* "numpy.pxd":276
 *                 elif t == NPY_OBJECT:      f = "O"
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *                 info.format = f
 *                 return
 */
      __pyx_t_4 = PyInt_FromLong(__pyx_v_t); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_32), __pyx_t_4); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(((PyObject *)__pyx_t_8));
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = PyTuple_New(1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_4);
      PyTuple_SET_ITEM(__pyx_t_4, 0, ((PyObject *)__pyx_t_8));
      __Pyx_GIVEREF(((PyObject *)__pyx_t_8));
      __pyx_t_8 = 0;
      __pyx_t_8 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_4), NULL); if (unlikely(!__pyx_t_8)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(((PyObject *)__pyx_t_4)); __pyx_t_4 = 0;
      __Pyx_Raise(__pyx_t_8, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 276; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
    __pyx_L13:;

    /* "numpy.pxd":277
 *                 else:
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f             # <<<<<<<<<<<<<<
 *                 return
 *             else:
 */
    __pyx_v_info->format = __pyx_v_f;

    /* "numpy.pxd":278
 *                     raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *                 info.format = f
 *                 return             # <<<<<<<<<<<<<<
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 */
    __pyx_r = 0;
    goto __pyx_L0;
    goto __pyx_L11;
  }
  /*else*/ {

    /* "numpy.pxd":280
 *                 return
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)             # <<<<<<<<<<<<<<
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0
 */
    __pyx_v_info->format = ((char *)malloc(255));

    /* "numpy.pxd":281
 *             else:
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment             # <<<<<<<<<<<<<<
 *                 offset = 0
 *                 f = _util_dtypestring(descr, info.format + 1,
 */
    (__pyx_v_info->format[0]) = '^';

    /* "numpy.pxd":282
 *                 info.format = <char*>stdlib.malloc(_buffer_format_string_len)
 *                 info.format[0] = c'^' # Native data types, manual alignment
 *                 offset = 0             # <<<<<<<<<<<<<<
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 */
    __pyx_v_offset = 0;

    /* "numpy.pxd":285
 *                 f = _util_dtypestring(descr, info.format + 1,
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)             # <<<<<<<<<<<<<<
 *                 f[0] = c'\0' # Terminate format string
 * 
 */
    __pyx_t_9 = __pyx_f_5numpy__util_dtypestring(__pyx_v_descr, (__pyx_v_info->format + 1), (__pyx_v_info->format + 255), (&__pyx_v_offset)); if (unlikely(__pyx_t_9 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 283; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __pyx_v_f = __pyx_t_9;

    /* "numpy.pxd":286
 *                                       info.format + _buffer_format_string_len,
 *                                       &offset)
 *                 f[0] = c'\0' # Terminate format string             # <<<<<<<<<<<<<<
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 */
    (__pyx_v_f[0]) = '\x00';
  }
  __pyx_L11:;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("numpy.ndarray.__getbuffer__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  if (__pyx_v_info != NULL && __pyx_v_info->obj != NULL) {
    __Pyx_GOTREF(__pyx_v_info->obj);
    __Pyx_DECREF(__pyx_v_info->obj); __pyx_v_info->obj = NULL;
  }
  goto __pyx_L2;
  __pyx_L0:;
  if (__pyx_v_info != NULL && __pyx_v_info->obj == Py_None) {
    __Pyx_GOTREF(Py_None);
    __Pyx_DECREF(Py_None); __pyx_v_info->obj = NULL;
  }
  __pyx_L2:;
  __Pyx_XDECREF((PyObject *)__pyx_v_descr);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info); /*proto*/
static CYTHON_UNUSED void __pyx_pw_5numpy_7ndarray_3__releasebuffer__(PyObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__releasebuffer__ (wrapper)", 0);
  __pyx_pf_5numpy_7ndarray_2__releasebuffer__(((PyArrayObject *)__pyx_v_self), ((Py_buffer *)__pyx_v_info));
  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":288
 *                 f[0] = c'\0' # Terminate format string
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):             # <<<<<<<<<<<<<<
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 */

static void __pyx_pf_5numpy_7ndarray_2__releasebuffer__(PyArrayObject *__pyx_v_self, Py_buffer *__pyx_v_info) {
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("__releasebuffer__", 0);

  /* "numpy.pxd":289
 * 
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 */
  __pyx_t_1 = PyArray_HASFIELDS(__pyx_v_self);
  if (__pyx_t_1) {

    /* "numpy.pxd":290
 *         def __releasebuffer__(ndarray self, Py_buffer* info):
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)             # <<<<<<<<<<<<<<
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)
 */
    free(__pyx_v_info->format);
    goto __pyx_L3;
  }
  __pyx_L3:;

  /* "numpy.pxd":291
 *             if PyArray_HASFIELDS(self):
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):             # <<<<<<<<<<<<<<
 *                 stdlib.free(info.strides)
 *                 # info.shape was stored after info.strides in the same block
 */
  __pyx_t_1 = ((sizeof(npy_intp)) != (sizeof(Py_ssize_t)));
  if (__pyx_t_1) {

    /* "numpy.pxd":292
 *                 stdlib.free(info.format)
 *             if sizeof(npy_intp) != sizeof(Py_ssize_t):
 *                 stdlib.free(info.strides)             # <<<<<<<<<<<<<<
 *                 # info.shape was stored after info.strides in the same block
 * 
 */
    free(__pyx_v_info->strides);
    goto __pyx_L4;
  }
  __pyx_L4:;

  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":768
 * ctypedef npy_cdouble     complex_t
 * 
 * cdef inline object PyArray_MultiIterNew1(a):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew1(PyObject *__pyx_v_a) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew1", 0);

  /* "numpy.pxd":769
 * 
 * cdef inline object PyArray_MultiIterNew1(a):
 *     return PyArray_MultiIterNew(1, <void*>a)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(1, ((void *)__pyx_v_a)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 769; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew1", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":771
 *     return PyArray_MultiIterNew(1, <void*>a)
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew2(PyObject *__pyx_v_a, PyObject *__pyx_v_b) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew2", 0);

  /* "numpy.pxd":772
 * 
 * cdef inline object PyArray_MultiIterNew2(a, b):
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(2, ((void *)__pyx_v_a), ((void *)__pyx_v_b)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 772; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew2", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":774
 *     return PyArray_MultiIterNew(2, <void*>a, <void*>b)
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew3(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew3", 0);

  /* "numpy.pxd":775
 * 
 * cdef inline object PyArray_MultiIterNew3(a, b, c):
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(3, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 775; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew3", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":777
 *     return PyArray_MultiIterNew(3, <void*>a, <void*>b, <void*> c)
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew4(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew4", 0);

  /* "numpy.pxd":778
 * 
 * cdef inline object PyArray_MultiIterNew4(a, b, c, d):
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)             # <<<<<<<<<<<<<<
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(4, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 778; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew4", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":780
 *     return PyArray_MultiIterNew(4, <void*>a, <void*>b, <void*>c, <void*> d)
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):             # <<<<<<<<<<<<<<
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_PyArray_MultiIterNew5(PyObject *__pyx_v_a, PyObject *__pyx_v_b, PyObject *__pyx_v_c, PyObject *__pyx_v_d, PyObject *__pyx_v_e) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("PyArray_MultiIterNew5", 0);

  /* "numpy.pxd":781
 * 
 * cdef inline object PyArray_MultiIterNew5(a, b, c, d, e):
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)             # <<<<<<<<<<<<<<
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:
 */
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = PyArray_MultiIterNew(5, ((void *)__pyx_v_a), ((void *)__pyx_v_b), ((void *)__pyx_v_c), ((void *)__pyx_v_d), ((void *)__pyx_v_e)); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 781; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("numpy.PyArray_MultiIterNew5", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":783
 *     return PyArray_MultiIterNew(5, <void*>a, <void*>b, <void*>c, <void*> d, <void*> e)
 * 
 * cdef inline char* _util_dtypestring(dtype descr, char* f, char* end, int* offset) except NULL:             # <<<<<<<<<<<<<<
 *     # Recursive utility function used in __getbuffer__ to get format
 *     # string. The new location in the format string is returned.
 */

static CYTHON_INLINE char *__pyx_f_5numpy__util_dtypestring(PyArray_Descr *__pyx_v_descr, char *__pyx_v_f, char *__pyx_v_end, int *__pyx_v_offset) {
  PyArray_Descr *__pyx_v_child = 0;
  int __pyx_v_endian_detector;
  int __pyx_v_little_endian;
  PyObject *__pyx_v_fields = 0;
  PyObject *__pyx_v_childname = NULL;
  PyObject *__pyx_v_new_offset = NULL;
  PyObject *__pyx_v_t = NULL;
  char *__pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  Py_ssize_t __pyx_t_2;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *(*__pyx_t_6)(PyObject *);
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_t_9;
  int __pyx_t_10;
  long __pyx_t_11;
  char *__pyx_t_12;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("_util_dtypestring", 0);

  /* "numpy.pxd":790
 *     cdef int delta_offset
 *     cdef tuple i
 *     cdef int endian_detector = 1             # <<<<<<<<<<<<<<
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)
 *     cdef tuple fields
 */
  __pyx_v_endian_detector = 1;

  /* "numpy.pxd":791
 *     cdef tuple i
 *     cdef int endian_detector = 1
 *     cdef bint little_endian = ((<char*>&endian_detector)[0] != 0)             # <<<<<<<<<<<<<<
 *     cdef tuple fields
 * 
 */
  __pyx_v_little_endian = ((((char *)(&__pyx_v_endian_detector))[0]) != 0);

  /* "numpy.pxd":794
 *     cdef tuple fields
 * 
 *     for childname in descr.names:             # <<<<<<<<<<<<<<
 *         fields = descr.fields[childname]
 *         child, new_offset = fields
 */
  if (unlikely(((PyObject *)__pyx_v_descr->names) == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
    {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  }
  __pyx_t_1 = ((PyObject *)__pyx_v_descr->names); __Pyx_INCREF(__pyx_t_1); __pyx_t_2 = 0;
  for (;;) {
    if (__pyx_t_2 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
    #if CYTHON_COMPILING_IN_CPYTHON
    __pyx_t_3 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_2); __Pyx_INCREF(__pyx_t_3); __pyx_t_2++; if (unlikely(0 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #else
    __pyx_t_3 = PySequence_ITEM(__pyx_t_1, __pyx_t_2); __pyx_t_2++; if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 794; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    #endif
    __Pyx_XDECREF(__pyx_v_childname);
    __pyx_v_childname = __pyx_t_3;
    __pyx_t_3 = 0;

    /* "numpy.pxd":795
 * 
 *     for childname in descr.names:
 *         fields = descr.fields[childname]             # <<<<<<<<<<<<<<
 *         child, new_offset = fields
 * 
 */
    __pyx_t_3 = PyObject_GetItem(__pyx_v_descr->fields, __pyx_v_childname); if (!__pyx_t_3) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    if (!(likely(PyTuple_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected tuple, got %.200s", Py_TYPE(__pyx_t_3)->tp_name), 0))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 795; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(((PyObject *)__pyx_v_fields));
    __pyx_v_fields = ((PyObject*)__pyx_t_3);
    __pyx_t_3 = 0;

    /* "numpy.pxd":796
 *     for childname in descr.names:
 *         fields = descr.fields[childname]
 *         child, new_offset = fields             # <<<<<<<<<<<<<<
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 */
    if (likely(PyTuple_CheckExact(((PyObject *)__pyx_v_fields)))) {
      PyObject* sequence = ((PyObject *)__pyx_v_fields);
      #if CYTHON_COMPILING_IN_CPYTHON
      Py_ssize_t size = Py_SIZE(sequence);
      #else
      Py_ssize_t size = PySequence_Size(sequence);
      #endif
      if (unlikely(size != 2)) {
        if (size > 2) __Pyx_RaiseTooManyValuesError(2);
        else if (size >= 0) __Pyx_RaiseNeedMoreValuesError(size);
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      #if CYTHON_COMPILING_IN_CPYTHON
      __pyx_t_3 = PyTuple_GET_ITEM(sequence, 0); 
      __pyx_t_4 = PyTuple_GET_ITEM(sequence, 1); 
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_4);
      #else
      __pyx_t_3 = PySequence_ITEM(sequence, 0); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_4 = PySequence_ITEM(sequence, 1); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      #endif
    } else if (1) {
      __Pyx_RaiseNoneNotIterableError(); {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    } else
    {
      Py_ssize_t index = -1;
      __pyx_t_5 = PyObject_GetIter(((PyObject *)__pyx_v_fields)); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_6 = Py_TYPE(__pyx_t_5)->tp_iternext;
      index = 0; __pyx_t_3 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_3)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_3);
      index = 1; __pyx_t_4 = __pyx_t_6(__pyx_t_5); if (unlikely(!__pyx_t_4)) goto __pyx_L5_unpacking_failed;
      __Pyx_GOTREF(__pyx_t_4);
      if (__Pyx_IternextUnpackEndCheck(__pyx_t_6(__pyx_t_5), 2) < 0) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_t_6 = NULL;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      goto __pyx_L6_unpacking_done;
      __pyx_L5_unpacking_failed:;
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_6 = NULL;
      if (__Pyx_IterFinish() == 0) __Pyx_RaiseNeedMoreValuesError(index);
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_L6_unpacking_done:;
    }
    if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_5numpy_dtype))))) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 796; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_XDECREF(((PyObject *)__pyx_v_child));
    __pyx_v_child = ((PyArray_Descr *)__pyx_t_3);
    __pyx_t_3 = 0;
    __Pyx_XDECREF(__pyx_v_new_offset);
    __pyx_v_new_offset = __pyx_t_4;
    __pyx_t_4 = 0;

    /* "numpy.pxd":798
 *         child, new_offset = fields
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:             # <<<<<<<<<<<<<<
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 */
    __pyx_t_4 = PyInt_FromLong((__pyx_v_end - __pyx_v_f)); if (unlikely(!__pyx_t_4)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_3 = PyInt_FromLong((__pyx_v_offset[0])); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_5 = PyNumber_Subtract(__pyx_v_new_offset, __pyx_t_3); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_5);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyNumber_Subtract(__pyx_t_4, __pyx_t_5); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = PyObject_RichCompare(__pyx_t_3, __pyx_int_15, Py_LT); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 798; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (__pyx_t_7) {

      /* "numpy.pxd":799
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
      __pyx_t_5 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_k_tuple_34), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L7;
    }
    __pyx_L7:;

    /* "numpy.pxd":801
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")
 * 
 *         if ((child.byteorder == c'>' and little_endian) or             # <<<<<<<<<<<<<<
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")
 */
    __pyx_t_7 = (__pyx_v_child->byteorder == '>');
    if (__pyx_t_7) {
      __pyx_t_8 = __pyx_v_little_endian;
    } else {
      __pyx_t_8 = __pyx_t_7;
    }
    if (!__pyx_t_8) {

      /* "numpy.pxd":802
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):             # <<<<<<<<<<<<<<
 *             raise ValueError(u"Non-native byte order not supported")
 *             # One could encode it in the format string and have Cython
 */
      __pyx_t_7 = (__pyx_v_child->byteorder == '<');
      if (__pyx_t_7) {
        __pyx_t_9 = (!__pyx_v_little_endian);
        __pyx_t_10 = __pyx_t_9;
      } else {
        __pyx_t_10 = __pyx_t_7;
      }
      __pyx_t_7 = __pyx_t_10;
    } else {
      __pyx_t_7 = __pyx_t_8;
    }
    if (__pyx_t_7) {

      /* "numpy.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
      __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_k_tuple_35), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __Pyx_Raise(__pyx_t_5, 0, 0, 0);
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      goto __pyx_L8;
    }
    __pyx_L8:;

    /* "numpy.pxd":813
 * 
 *         # Output padding bytes
 *         while offset[0] < new_offset:             # <<<<<<<<<<<<<<
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 */
    while (1) {
      __pyx_t_5 = PyInt_FromLong((__pyx_v_offset[0])); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_t_5, __pyx_v_new_offset, Py_LT); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 813; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!__pyx_t_7) break;

      /* "numpy.pxd":814
 *         # Output padding bytes
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte             # <<<<<<<<<<<<<<
 *             f += 1
 *             offset[0] += 1
 */
      (__pyx_v_f[0]) = 120;

      /* "numpy.pxd":815
 *         while offset[0] < new_offset:
 *             f[0] = 120 # "x"; pad byte
 *             f += 1             # <<<<<<<<<<<<<<
 *             offset[0] += 1
 * 
 */
      __pyx_v_f = (__pyx_v_f + 1);

      /* "numpy.pxd":816
 *             f[0] = 120 # "x"; pad byte
 *             f += 1
 *             offset[0] += 1             # <<<<<<<<<<<<<<
 * 
 *         offset[0] += child.itemsize
 */
      __pyx_t_11 = 0;
      (__pyx_v_offset[__pyx_t_11]) = ((__pyx_v_offset[__pyx_t_11]) + 1);
    }

    /* "numpy.pxd":818
 *             offset[0] += 1
 * 
 *         offset[0] += child.itemsize             # <<<<<<<<<<<<<<
 * 
 *         if not PyDataType_HASFIELDS(child):
 */
    __pyx_t_11 = 0;
    (__pyx_v_offset[__pyx_t_11]) = ((__pyx_v_offset[__pyx_t_11]) + __pyx_v_child->elsize);

    /* "numpy.pxd":820
 *         offset[0] += child.itemsize
 * 
 *         if not PyDataType_HASFIELDS(child):             # <<<<<<<<<<<<<<
 *             t = child.type_num
 *             if end - f < 5:
 */
    __pyx_t_7 = (!PyDataType_HASFIELDS(__pyx_v_child));
    if (__pyx_t_7) {

      /* "numpy.pxd":821
 * 
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num             # <<<<<<<<<<<<<<
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")
 */
      __pyx_t_3 = PyInt_FromLong(__pyx_v_child->type_num); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 821; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_XDECREF(__pyx_v_t);
      __pyx_v_t = __pyx_t_3;
      __pyx_t_3 = 0;

      /* "numpy.pxd":822
 *         if not PyDataType_HASFIELDS(child):
 *             t = child.type_num
 *             if end - f < 5:             # <<<<<<<<<<<<<<
 *                 raise RuntimeError(u"Format string allocated too short.")
 * 
 */
      __pyx_t_7 = ((__pyx_v_end - __pyx_v_f) < 5);
      if (__pyx_t_7) {

        /* "numpy.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
        __pyx_t_3 = PyObject_Call(__pyx_builtin_RuntimeError, ((PyObject *)__pyx_k_tuple_37), NULL); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_Raise(__pyx_t_3, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        goto __pyx_L12;
      }
      __pyx_L12:;

      /* "numpy.pxd":826
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_BYTE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 826; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 98;
        goto __pyx_L13;
      }

      /* "numpy.pxd":827
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"             # <<<<<<<<<<<<<<
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_UBYTE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 827; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 66;
        goto __pyx_L13;
      }

      /* "numpy.pxd":828
 *             if   t == NPY_BYTE:        f[0] =  98 #"b"
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"             # <<<<<<<<<<<<<<
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_SHORT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 828; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 104;
        goto __pyx_L13;
      }

      /* "numpy.pxd":829
 *             elif t == NPY_UBYTE:       f[0] =  66 #"B"
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"             # <<<<<<<<<<<<<<
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_USHORT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 829; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 72;
        goto __pyx_L13;
      }

      /* "numpy.pxd":830
 *             elif t == NPY_SHORT:       f[0] = 104 #"h"
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"             # <<<<<<<<<<<<<<
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_INT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 830; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 105;
        goto __pyx_L13;
      }

      /* "numpy.pxd":831
 *             elif t == NPY_USHORT:      f[0] =  72 #"H"
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_UINT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 831; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 73;
        goto __pyx_L13;
      }

      /* "numpy.pxd":832
 *             elif t == NPY_INT:         f[0] = 105 #"i"
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 832; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 108;
        goto __pyx_L13;
      }

      /* "numpy.pxd":833
 *             elif t == NPY_UINT:        f[0] =  73 #"I"
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_ULONG); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 833; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 76;
        goto __pyx_L13;
      }

      /* "numpy.pxd":834
 *             elif t == NPY_LONG:        f[0] = 108 #"l"
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONGLONG); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 834; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 113;
        goto __pyx_L13;
      }

      /* "numpy.pxd":835
 *             elif t == NPY_ULONG:       f[0] = 76  #"L"
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"             # <<<<<<<<<<<<<<
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 */
      __pyx_t_5 = PyInt_FromLong(NPY_ULONGLONG); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 835; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 81;
        goto __pyx_L13;
      }

      /* "numpy.pxd":836
 *             elif t == NPY_LONGLONG:    f[0] = 113 #"q"
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"             # <<<<<<<<<<<<<<
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_FLOAT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 836; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 102;
        goto __pyx_L13;
      }

      /* "numpy.pxd":837
 *             elif t == NPY_ULONGLONG:   f[0] = 81  #"Q"
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"             # <<<<<<<<<<<<<<
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 */
      __pyx_t_5 = PyInt_FromLong(NPY_DOUBLE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 837; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 100;
        goto __pyx_L13;
      }

      /* "numpy.pxd":838
 *             elif t == NPY_FLOAT:       f[0] = 102 #"f"
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"             # <<<<<<<<<<<<<<
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 */
      __pyx_t_3 = PyInt_FromLong(NPY_LONGDOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 838; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 103;
        goto __pyx_L13;
      }

      /* "numpy.pxd":839
 *             elif t == NPY_DOUBLE:      f[0] = 100 #"d"
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf             # <<<<<<<<<<<<<<
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 */
      __pyx_t_5 = PyInt_FromLong(NPY_CFLOAT); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 839; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 102;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L13;
      }

      /* "numpy.pxd":840
 *             elif t == NPY_LONGDOUBLE:  f[0] = 103 #"g"
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd             # <<<<<<<<<<<<<<
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 */
      __pyx_t_3 = PyInt_FromLong(NPY_CDOUBLE); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 840; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 100;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L13;
      }

      /* "numpy.pxd":841
 *             elif t == NPY_CFLOAT:      f[0] = 90; f[1] = 102; f += 1 # Zf
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg             # <<<<<<<<<<<<<<
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 */
      __pyx_t_5 = PyInt_FromLong(NPY_CLONGDOUBLE); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_5);
      __pyx_t_3 = PyObject_RichCompare(__pyx_v_t, __pyx_t_5, Py_EQ); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 841; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 90;
        (__pyx_v_f[1]) = 103;
        __pyx_v_f = (__pyx_v_f + 1);
        goto __pyx_L13;
      }

      /* "numpy.pxd":842
 *             elif t == NPY_CDOUBLE:     f[0] = 90; f[1] = 100; f += 1 # Zd
 *             elif t == NPY_CLONGDOUBLE: f[0] = 90; f[1] = 103; f += 1 # Zg
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"             # <<<<<<<<<<<<<<
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 */
      __pyx_t_3 = PyInt_FromLong(NPY_OBJECT); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_5 = PyObject_RichCompare(__pyx_v_t, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_5); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_7 = __Pyx_PyObject_IsTrue(__pyx_t_5); if (unlikely(__pyx_t_7 < 0)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 842; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
      if (__pyx_t_7) {
        (__pyx_v_f[0]) = 79;
        goto __pyx_L13;
      }
      /*else*/ {

        /* "numpy.pxd":844
 *             elif t == NPY_OBJECT:      f[0] = 79 #"O"
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)             # <<<<<<<<<<<<<<
 *             f += 1
 *         else:
 */
        __pyx_t_5 = PyNumber_Remainder(((PyObject *)__pyx_kp_u_32), __pyx_v_t); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(((PyObject *)__pyx_t_5));
        __pyx_t_3 = PyTuple_New(1); if (unlikely(!__pyx_t_3)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_3);
        PyTuple_SET_ITEM(__pyx_t_3, 0, ((PyObject *)__pyx_t_5));
        __Pyx_GIVEREF(((PyObject *)__pyx_t_5));
        __pyx_t_5 = 0;
        __pyx_t_5 = PyObject_Call(__pyx_builtin_ValueError, ((PyObject *)__pyx_t_3), NULL); if (unlikely(!__pyx_t_5)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
        __Pyx_GOTREF(__pyx_t_5);
        __Pyx_DECREF(((PyObject *)__pyx_t_3)); __pyx_t_3 = 0;
        __Pyx_Raise(__pyx_t_5, 0, 0, 0);
        __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
        {__pyx_filename = __pyx_f[1]; __pyx_lineno = 844; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      }
      __pyx_L13:;

      /* "numpy.pxd":845
 *             else:
 *                 raise ValueError(u"unknown dtype code in numpy.pxd (%d)" % t)
 *             f += 1             # <<<<<<<<<<<<<<
 *         else:
 *             # Cython ignores struct boundary information ("T{...}"),
 */
      __pyx_v_f = (__pyx_v_f + 1);
      goto __pyx_L11;
    }
    /*else*/ {

      /* "numpy.pxd":849
 *             # Cython ignores struct boundary information ("T{...}"),
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)             # <<<<<<<<<<<<<<
 *     return f
 * 
 */
      __pyx_t_12 = __pyx_f_5numpy__util_dtypestring(__pyx_v_child, __pyx_v_f, __pyx_v_end, __pyx_v_offset); if (unlikely(__pyx_t_12 == NULL)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
      __pyx_v_f = __pyx_t_12;
    }
    __pyx_L11:;
  }
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "numpy.pxd":850
 *             # so don't output it
 *             f = _util_dtypestring(child, f, end, offset)
 *     return f             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_r = __pyx_v_f;
  goto __pyx_L0;

  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("numpy._util_dtypestring", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XDECREF((PyObject *)__pyx_v_child);
  __Pyx_XDECREF(__pyx_v_fields);
  __Pyx_XDECREF(__pyx_v_childname);
  __Pyx_XDECREF(__pyx_v_new_offset);
  __Pyx_XDECREF(__pyx_v_t);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "numpy.pxd":965
 * 
 * 
 * cdef inline void set_array_base(ndarray arr, object base):             # <<<<<<<<<<<<<<
 *      cdef PyObject* baseptr
 *      if base is None:
 */

static CYTHON_INLINE void __pyx_f_5numpy_set_array_base(PyArrayObject *__pyx_v_arr, PyObject *__pyx_v_base) {
  PyObject *__pyx_v_baseptr;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("set_array_base", 0);

  /* "numpy.pxd":967
 * cdef inline void set_array_base(ndarray arr, object base):
 *      cdef PyObject* baseptr
 *      if base is None:             # <<<<<<<<<<<<<<
 *          baseptr = NULL
 *      else:
 */
  __pyx_t_1 = (__pyx_v_base == Py_None);
  if (__pyx_t_1) {

    /* "numpy.pxd":968
 *      cdef PyObject* baseptr
 *      if base is None:
 *          baseptr = NULL             # <<<<<<<<<<<<<<
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 */
    __pyx_v_baseptr = NULL;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "numpy.pxd":970
 *          baseptr = NULL
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!             # <<<<<<<<<<<<<<
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 */
    Py_INCREF(__pyx_v_base);

    /* "numpy.pxd":971
 *      else:
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base             # <<<<<<<<<<<<<<
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr
 */
    __pyx_v_baseptr = ((PyObject *)__pyx_v_base);
  }
  __pyx_L3:;

  /* "numpy.pxd":972
 *          Py_INCREF(base) # important to do this before decref below!
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)             # <<<<<<<<<<<<<<
 *      arr.base = baseptr
 * 
 */
  Py_XDECREF(__pyx_v_arr->base);

  /* "numpy.pxd":973
 *          baseptr = <PyObject*>base
 *      Py_XDECREF(arr.base)
 *      arr.base = baseptr             # <<<<<<<<<<<<<<
 * 
 * cdef inline object get_array_base(ndarray arr):
 */
  __pyx_v_arr->base = __pyx_v_baseptr;

  __Pyx_RefNannyFinishContext();
}

/* "numpy.pxd":975
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */

static CYTHON_INLINE PyObject *__pyx_f_5numpy_get_array_base(PyArrayObject *__pyx_v_arr) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  __Pyx_RefNannySetupContext("get_array_base", 0);

  /* "numpy.pxd":976
 * 
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:             # <<<<<<<<<<<<<<
 *         return None
 *     else:
 */
  __pyx_t_1 = (__pyx_v_arr->base == NULL);
  if (__pyx_t_1) {

    /* "numpy.pxd":977
 * cdef inline object get_array_base(ndarray arr):
 *     if arr.base is NULL:
 *         return None             # <<<<<<<<<<<<<<
 *     else:
 *         return <object>arr.base
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(Py_None);
    __pyx_r = Py_None;
    goto __pyx_L0;
    goto __pyx_L3;
  }
  /*else*/ {

    /* "numpy.pxd":979
 *         return None
 *     else:
 *         return <object>arr.base             # <<<<<<<<<<<<<<
 */
    __Pyx_XDECREF(__pyx_r);
    __Pyx_INCREF(((PyObject *)__pyx_v_arr->base));
    __pyx_r = ((PyObject *)__pyx_v_arr->base);
    goto __pyx_L0;
  }
  __pyx_L3:;

  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_heap __pyx_vtable_5pyart_3map_7ckdtree_heap;

static PyObject *__pyx_tp_new_5pyart_3map_7ckdtree_heap(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_3map_7ckdtree_heap *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_5pyart_3map_7ckdtree_heap *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_3map_7ckdtree_heap;
  return o;
}

static void __pyx_tp_dealloc_5pyart_3map_7ckdtree_heap(PyObject *o) {
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_3map_7ckdtree_4heap_3__dealloc__(o);
    if (PyErr_Occurred()) PyErr_WriteUnraisable(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  (*Py_TYPE(o)->tp_free)(o);
}

static PyMethodDef __pyx_methods_5pyart_3map_7ckdtree_heap[] = {
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_heap = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_heap = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_heap = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_heap = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_5pyart_3map_7ckdtree_heap = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("pyart.map.ckdtree.heap"), /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_3map_7ckdtree_heap), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_3map_7ckdtree_heap, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_heap, /*tp_as_number*/
  &__pyx_tp_as_sequence_heap, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_heap, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_heap, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE, /*tp_flags*/
  0, /*tp_doc*/
  0, /*tp_traverse*/
  0, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_3map_7ckdtree_heap, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_5pyart_3map_7ckdtree_4heap_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_3map_7ckdtree_heap, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_coo_entries __pyx_vtable_5pyart_3map_7ckdtree_coo_entries;

static PyObject *__pyx_tp_new_5pyart_3map_7ckdtree_coo_entries(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_3map_7ckdtree_coo_entries;
  p->i = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->j = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->v = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5pyart_3map_7ckdtree_coo_entries(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *p = (struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->i);
  Py_CLEAR(p->j);
  Py_CLEAR(p->v);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5pyart_3map_7ckdtree_coo_entries(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *p = (struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *)o;
  if (p->i) {
    e = (*v)(((PyObject*)p->i), a); if (e) return e;
  }
  if (p->j) {
    e = (*v)(((PyObject*)p->j), a); if (e) return e;
  }
  if (p->v) {
    e = (*v)(((PyObject*)p->v), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5pyart_3map_7ckdtree_coo_entries(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *p = (struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->i);
  p->i = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->j);
  p->j = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->v);
  p->v = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5pyart_3map_7ckdtree_coo_entries[] = {
  {__Pyx_NAMESTR("to_matrix"), (PyCFunction)__pyx_pw_5pyart_3map_7ckdtree_11coo_entries_3to_matrix, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(0)},
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_coo_entries = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_coo_entries = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_coo_entries = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_coo_entries = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_5pyart_3map_7ckdtree_coo_entries = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("pyart.map.ckdtree.coo_entries"), /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_3map_7ckdtree_coo_entries, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_coo_entries, /*tp_as_number*/
  &__pyx_tp_as_sequence_coo_entries, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_coo_entries, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_coo_entries, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5pyart_3map_7ckdtree_coo_entries, /*tp_traverse*/
  __pyx_tp_clear_5pyart_3map_7ckdtree_coo_entries, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_3map_7ckdtree_coo_entries, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_5pyart_3map_7ckdtree_11coo_entries_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_3map_7ckdtree_coo_entries, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyObject *__pyx_tp_new_5pyart_3map_7ckdtree_Rectangle(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)o);
  p->mins_arr = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->maxes_arr = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5pyart_3map_7ckdtree_Rectangle(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *p = (struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)o;
  PyObject_GC_UnTrack(o);
  Py_CLEAR(p->mins_arr);
  Py_CLEAR(p->maxes_arr);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5pyart_3map_7ckdtree_Rectangle(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *p = (struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)o;
  if (p->mins_arr) {
    e = (*v)(((PyObject*)p->mins_arr), a); if (e) return e;
  }
  if (p->maxes_arr) {
    e = (*v)(((PyObject*)p->maxes_arr), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5pyart_3map_7ckdtree_Rectangle(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *p = (struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->mins_arr);
  p->mins_arr = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->maxes_arr);
  p->maxes_arr = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5pyart_3map_7ckdtree_Rectangle[] = {
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_Rectangle = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_Rectangle = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_Rectangle = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_Rectangle = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_5pyart_3map_7ckdtree_Rectangle = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("pyart.map.ckdtree.Rectangle"), /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_3map_7ckdtree_Rectangle, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_Rectangle, /*tp_as_number*/
  &__pyx_tp_as_sequence_Rectangle, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_Rectangle, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_Rectangle, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5pyart_3map_7ckdtree_Rectangle, /*tp_traverse*/
  __pyx_tp_clear_5pyart_3map_7ckdtree_Rectangle, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_3map_7ckdtree_Rectangle, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_5pyart_3map_7ckdtree_9Rectangle_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_3map_7ckdtree_Rectangle, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_RectRectDistanceTracker __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker;

static PyObject *__pyx_tp_new_5pyart_3map_7ckdtree_RectRectDistanceTracker(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_3map_7ckdtree_RectRectDistanceTracker;
  p->rect1 = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)Py_None); Py_INCREF(Py_None);
  p->rect2 = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5pyart_3map_7ckdtree_RectRectDistanceTracker(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *p = (struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)o;
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_3map_7ckdtree_23RectRectDistanceTracker_3__dealloc__(o);
    if (PyErr_Occurred()) PyErr_WriteUnraisable(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->rect1);
  Py_CLEAR(p->rect2);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5pyart_3map_7ckdtree_RectRectDistanceTracker(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *p = (struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)o;
  if (p->rect1) {
    e = (*v)(((PyObject*)p->rect1), a); if (e) return e;
  }
  if (p->rect2) {
    e = (*v)(((PyObject*)p->rect2), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5pyart_3map_7ckdtree_RectRectDistanceTracker(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *p = (struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->rect1);
  p->rect1 = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->rect2);
  p->rect2 = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5pyart_3map_7ckdtree_RectRectDistanceTracker[] = {
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_RectRectDistanceTracker = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_RectRectDistanceTracker = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_RectRectDistanceTracker = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_RectRectDistanceTracker = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_5pyart_3map_7ckdtree_RectRectDistanceTracker = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("pyart.map.ckdtree.RectRectDistanceTracker"), /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_3map_7ckdtree_RectRectDistanceTracker, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_RectRectDistanceTracker, /*tp_as_number*/
  &__pyx_tp_as_sequence_RectRectDistanceTracker, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_RectRectDistanceTracker, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_RectRectDistanceTracker, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5pyart_3map_7ckdtree_RectRectDistanceTracker, /*tp_traverse*/
  __pyx_tp_clear_5pyart_3map_7ckdtree_RectRectDistanceTracker, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_3map_7ckdtree_RectRectDistanceTracker, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_5pyart_3map_7ckdtree_23RectRectDistanceTracker_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_3map_7ckdtree_RectRectDistanceTracker, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_PointRectDistanceTracker __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker;

static PyObject *__pyx_tp_new_5pyart_3map_7ckdtree_PointRectDistanceTracker(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_3map_7ckdtree_PointRectDistanceTracker;
  p->rect = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5pyart_3map_7ckdtree_PointRectDistanceTracker(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *p = (struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *)o;
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_3map_7ckdtree_24PointRectDistanceTracker_1__dealloc__(o);
    if (PyErr_Occurred()) PyErr_WriteUnraisable(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->rect);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5pyart_3map_7ckdtree_PointRectDistanceTracker(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *p = (struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *)o;
  if (p->rect) {
    e = (*v)(((PyObject*)p->rect), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5pyart_3map_7ckdtree_PointRectDistanceTracker(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *p = (struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->rect);
  p->rect = ((struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyMethodDef __pyx_methods_5pyart_3map_7ckdtree_PointRectDistanceTracker[] = {
  {0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_PointRectDistanceTracker = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_PointRectDistanceTracker = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_PointRectDistanceTracker = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_PointRectDistanceTracker = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_5pyart_3map_7ckdtree_PointRectDistanceTracker = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("pyart.map.ckdtree.PointRectDistanceTracker"), /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_3map_7ckdtree_PointRectDistanceTracker, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_PointRectDistanceTracker, /*tp_as_number*/
  &__pyx_tp_as_sequence_PointRectDistanceTracker, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_PointRectDistanceTracker, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_PointRectDistanceTracker, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  0, /*tp_doc*/
  __pyx_tp_traverse_5pyart_3map_7ckdtree_PointRectDistanceTracker, /*tp_traverse*/
  __pyx_tp_clear_5pyart_3map_7ckdtree_PointRectDistanceTracker, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_3map_7ckdtree_PointRectDistanceTracker, /*tp_methods*/
  0, /*tp_members*/
  0, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  0, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_3map_7ckdtree_PointRectDistanceTracker, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};
static struct __pyx_vtabstruct_5pyart_3map_7ckdtree_cKDTree __pyx_vtable_5pyart_3map_7ckdtree_cKDTree;

static PyObject *__pyx_tp_new_5pyart_3map_7ckdtree_cKDTree(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
  struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *p;
  PyObject *o = (*t->tp_alloc)(t, 0);
  if (!o) return 0;
  p = ((struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)o);
  p->__pyx_vtab = __pyx_vtabptr_5pyart_3map_7ckdtree_cKDTree;
  p->data = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->maxes = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->mins = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  p->indices = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  return o;
}

static void __pyx_tp_dealloc_5pyart_3map_7ckdtree_cKDTree(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *p = (struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)o;
  PyObject_GC_UnTrack(o);
  {
    PyObject *etype, *eval, *etb;
    PyErr_Fetch(&etype, &eval, &etb);
    ++Py_REFCNT(o);
    __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_3__dealloc__(o);
    if (PyErr_Occurred()) PyErr_WriteUnraisable(o);
    --Py_REFCNT(o);
    PyErr_Restore(etype, eval, etb);
  }
  Py_CLEAR(p->data);
  Py_CLEAR(p->maxes);
  Py_CLEAR(p->mins);
  Py_CLEAR(p->indices);
  PyObject_GC_Track(o);
  (*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_5pyart_3map_7ckdtree_cKDTree(PyObject *o, visitproc v, void *a) {
  int e;
  struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *p = (struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)o;
  if (p->data) {
    e = (*v)(((PyObject*)p->data), a); if (e) return e;
  }
  if (p->maxes) {
    e = (*v)(((PyObject*)p->maxes), a); if (e) return e;
  }
  if (p->mins) {
    e = (*v)(((PyObject*)p->mins), a); if (e) return e;
  }
  if (p->indices) {
    e = (*v)(((PyObject*)p->indices), a); if (e) return e;
  }
  return 0;
}

static int __pyx_tp_clear_5pyart_3map_7ckdtree_cKDTree(PyObject *o) {
  struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *p = (struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *)o;
  PyObject* tmp;
  tmp = ((PyObject*)p->data);
  p->data = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->maxes);
  p->maxes = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->mins);
  p->mins = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  tmp = ((PyObject*)p->indices);
  p->indices = ((PyArrayObject *)Py_None); Py_INCREF(Py_None);
  Py_XDECREF(tmp);
  return 0;
}

static PyObject *__pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_data(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_4data_1__get__(o);
}

static PyObject *__pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_n(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1n_1__get__(o);
}

static PyObject *__pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_m(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1m_1__get__(o);
}

static PyObject *__pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_leafsize(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_8leafsize_1__get__(o);
}

static PyObject *__pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_maxes(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_5maxes_1__get__(o);
}

static PyObject *__pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_mins(PyObject *o, CYTHON_UNUSED void *x) {
  return __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_4mins_1__get__(o);
}

static PyMethodDef __pyx_methods_5pyart_3map_7ckdtree_cKDTree[] = {
  {__Pyx_NAMESTR("query"), (PyCFunction)__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_5query, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_5pyart_3map_7ckdtree_7cKDTree_4query)},
  {__Pyx_NAMESTR("query_ball_point"), (PyCFunction)__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_7query_ball_point, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_5pyart_3map_7ckdtree_7cKDTree_6query_ball_point)},
  {__Pyx_NAMESTR("query_ball_tree"), (PyCFunction)__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_9query_ball_tree, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_5pyart_3map_7ckdtree_7cKDTree_8query_ball_tree)},
  {__Pyx_NAMESTR("query_pairs"), (PyCFunction)__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_11query_pairs, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_5pyart_3map_7ckdtree_7cKDTree_10query_pairs)},
  {__Pyx_NAMESTR("count_neighbors"), (PyCFunction)__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_13count_neighbors, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_5pyart_3map_7ckdtree_7cKDTree_12count_neighbors)},
  {__Pyx_NAMESTR("sparse_distance_matrix"), (PyCFunction)__pyx_pw_5pyart_3map_7ckdtree_7cKDTree_15sparse_distance_matrix, METH_VARARGS|METH_KEYWORDS, __Pyx_DOCSTR(__pyx_doc_5pyart_3map_7ckdtree_7cKDTree_14sparse_distance_matrix)},
  {0, 0, 0, 0}
};

static struct PyGetSetDef __pyx_getsets_5pyart_3map_7ckdtree_cKDTree[] = {
  {(char *)"data", __pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_data, 0, 0, 0},
  {(char *)"n", __pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_n, 0, 0, 0},
  {(char *)"m", __pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_m, 0, 0, 0},
  {(char *)"leafsize", __pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_leafsize, 0, 0, 0},
  {(char *)"maxes", __pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_maxes, 0, 0, 0},
  {(char *)"mins", __pyx_getprop_5pyart_3map_7ckdtree_7cKDTree_mins, 0, 0, 0},
  {0, 0, 0, 0, 0}
};

static PyNumberMethods __pyx_tp_as_number_cKDTree = {
  0, /*nb_add*/
  0, /*nb_subtract*/
  0, /*nb_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_divide*/
  #endif
  0, /*nb_remainder*/
  0, /*nb_divmod*/
  0, /*nb_power*/
  0, /*nb_negative*/
  0, /*nb_positive*/
  0, /*nb_absolute*/
  0, /*nb_nonzero*/
  0, /*nb_invert*/
  0, /*nb_lshift*/
  0, /*nb_rshift*/
  0, /*nb_and*/
  0, /*nb_xor*/
  0, /*nb_or*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_coerce*/
  #endif
  0, /*nb_int*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_long*/
  #else
  0, /*reserved*/
  #endif
  0, /*nb_float*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_oct*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*nb_hex*/
  #endif
  0, /*nb_inplace_add*/
  0, /*nb_inplace_subtract*/
  0, /*nb_inplace_multiply*/
  #if PY_MAJOR_VERSION < 3
  0, /*nb_inplace_divide*/
  #endif
  0, /*nb_inplace_remainder*/
  0, /*nb_inplace_power*/
  0, /*nb_inplace_lshift*/
  0, /*nb_inplace_rshift*/
  0, /*nb_inplace_and*/
  0, /*nb_inplace_xor*/
  0, /*nb_inplace_or*/
  0, /*nb_floor_divide*/
  0, /*nb_true_divide*/
  0, /*nb_inplace_floor_divide*/
  0, /*nb_inplace_true_divide*/
  #if PY_VERSION_HEX >= 0x02050000
  0, /*nb_index*/
  #endif
};

static PySequenceMethods __pyx_tp_as_sequence_cKDTree = {
  0, /*sq_length*/
  0, /*sq_concat*/
  0, /*sq_repeat*/
  0, /*sq_item*/
  0, /*sq_slice*/
  0, /*sq_ass_item*/
  0, /*sq_ass_slice*/
  0, /*sq_contains*/
  0, /*sq_inplace_concat*/
  0, /*sq_inplace_repeat*/
};

static PyMappingMethods __pyx_tp_as_mapping_cKDTree = {
  0, /*mp_length*/
  0, /*mp_subscript*/
  0, /*mp_ass_subscript*/
};

static PyBufferProcs __pyx_tp_as_buffer_cKDTree = {
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getreadbuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getwritebuffer*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getsegcount*/
  #endif
  #if PY_MAJOR_VERSION < 3
  0, /*bf_getcharbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_getbuffer*/
  #endif
  #if PY_VERSION_HEX >= 0x02060000
  0, /*bf_releasebuffer*/
  #endif
};

static PyTypeObject __pyx_type_5pyart_3map_7ckdtree_cKDTree = {
  PyVarObject_HEAD_INIT(0, 0)
  __Pyx_NAMESTR("pyart.map.ckdtree.cKDTree"), /*tp_name*/
  sizeof(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree), /*tp_basicsize*/
  0, /*tp_itemsize*/
  __pyx_tp_dealloc_5pyart_3map_7ckdtree_cKDTree, /*tp_dealloc*/
  0, /*tp_print*/
  0, /*tp_getattr*/
  0, /*tp_setattr*/
  #if PY_MAJOR_VERSION < 3
  0, /*tp_compare*/
  #else
  0, /*reserved*/
  #endif
  0, /*tp_repr*/
  &__pyx_tp_as_number_cKDTree, /*tp_as_number*/
  &__pyx_tp_as_sequence_cKDTree, /*tp_as_sequence*/
  &__pyx_tp_as_mapping_cKDTree, /*tp_as_mapping*/
  0, /*tp_hash*/
  0, /*tp_call*/
  0, /*tp_str*/
  0, /*tp_getattro*/
  0, /*tp_setattro*/
  &__pyx_tp_as_buffer_cKDTree, /*tp_as_buffer*/
  Py_TPFLAGS_DEFAULT|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
  __Pyx_DOCSTR("\n    cKDTree(data, int leafsize=10)\n\n    kd-tree for quick nearest-neighbor lookup\n\n    This class provides an index into a set of k-dimensional points\n    which can be used to rapidly look up the nearest neighbors of any\n    point. \n\n    The algorithm used is described in Maneewongvatana and Mount 1999. \n    The general idea is that the kd-tree is a binary trie, each of whose\n    nodes represents an axis-aligned hyperrectangle. Each node specifies\n    an axis and splits the set of points based on whether their coordinate\n    along that axis is greater than or less than a particular value. \n\n    During construction, the axis and splitting point are chosen by the \n    \"sliding midpoint\" rule, which ensures that the cells do not all\n    become long and thin. \n\n    The tree can be queried for the r closest neighbors of any given point \n    (optionally returning only those within some maximum distance of the \n    point). It can also be queried, with a substantial gain in efficiency, \n    for the r approximate closest neighbors.\n\n    For large dimensions (20 is already large) do not expect this to run \n    significantly faster than brute force. High-dimensional nearest-neighbor\n    queries are a substantial open problem in computer science.\n\n    Parameters\n    ----------\n    data : array-like, shape (n,m)\n        The n data points of dimension mto be indexed. This array is \n        not copied unless this is necessary to produce a contiguous \n        array of doubles, and so modifying this data will result in \n        bogus results.\n    leafsize : positive integer\n        The number of points at which the algorithm switches over to\n        brute-force.\n\n    "), /*tp_doc*/
  __pyx_tp_traverse_5pyart_3map_7ckdtree_cKDTree, /*tp_traverse*/
  __pyx_tp_clear_5pyart_3map_7ckdtree_cKDTree, /*tp_clear*/
  0, /*tp_richcompare*/
  0, /*tp_weaklistoffset*/
  0, /*tp_iter*/
  0, /*tp_iternext*/
  __pyx_methods_5pyart_3map_7ckdtree_cKDTree, /*tp_methods*/
  0, /*tp_members*/
  __pyx_getsets_5pyart_3map_7ckdtree_cKDTree, /*tp_getset*/
  0, /*tp_base*/
  0, /*tp_dict*/
  0, /*tp_descr_get*/
  0, /*tp_descr_set*/
  0, /*tp_dictoffset*/
  __pyx_pw_5pyart_3map_7ckdtree_7cKDTree_1__init__, /*tp_init*/
  0, /*tp_alloc*/
  __pyx_tp_new_5pyart_3map_7ckdtree_cKDTree, /*tp_new*/
  0, /*tp_free*/
  0, /*tp_is_gc*/
  0, /*tp_bases*/
  0, /*tp_mro*/
  0, /*tp_cache*/
  0, /*tp_subclasses*/
  0, /*tp_weaklist*/
  0, /*tp_del*/
  #if PY_VERSION_HEX >= 0x02060000
  0, /*tp_version_tag*/
  #endif
};

static PyMethodDef __pyx_methods[] = {
  {0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
static struct PyModuleDef __pyx_moduledef = {
    PyModuleDef_HEAD_INIT,
    __Pyx_NAMESTR("ckdtree"),
    __Pyx_DOCSTR(__pyx_k_38), /* m_doc */
    -1, /* m_size */
    __pyx_methods /* m_methods */,
    NULL, /* m_reload */
    NULL, /* m_traverse */
    NULL, /* m_clear */
    NULL /* m_free */
};
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_s_1, __pyx_k_1, sizeof(__pyx_k_1), 0, 0, 1, 0},
  {&__pyx_kp_s_10, __pyx_k_10, sizeof(__pyx_k_10), 0, 0, 1, 0},
  {&__pyx_kp_s_19, __pyx_k_19, sizeof(__pyx_k_19), 0, 0, 1, 0},
  {&__pyx_kp_s_2, __pyx_k_2, sizeof(__pyx_k_2), 0, 0, 1, 0},
  {&__pyx_kp_s_20, __pyx_k_20, sizeof(__pyx_k_20), 0, 0, 1, 0},
  {&__pyx_kp_s_23, __pyx_k_23, sizeof(__pyx_k_23), 0, 0, 1, 0},
  {&__pyx_kp_u_26, __pyx_k_26, sizeof(__pyx_k_26), 0, 1, 0, 0},
  {&__pyx_kp_u_28, __pyx_k_28, sizeof(__pyx_k_28), 0, 1, 0, 0},
  {&__pyx_kp_u_30, __pyx_k_30, sizeof(__pyx_k_30), 0, 1, 0, 0},
  {&__pyx_kp_u_32, __pyx_k_32, sizeof(__pyx_k_32), 0, 1, 0, 0},
  {&__pyx_kp_u_33, __pyx_k_33, sizeof(__pyx_k_33), 0, 1, 0, 0},
  {&__pyx_kp_u_36, __pyx_k_36, sizeof(__pyx_k_36), 0, 1, 0, 0},
  {&__pyx_n_s_39, __pyx_k_39, sizeof(__pyx_k_39), 0, 0, 1, 1},
  {&__pyx_kp_s_4, __pyx_k_4, sizeof(__pyx_k_4), 0, 0, 1, 0},
  {&__pyx_kp_u_40, __pyx_k_40, sizeof(__pyx_k_40), 0, 1, 0, 0},
  {&__pyx_kp_u_41, __pyx_k_41, sizeof(__pyx_k_41), 0, 1, 0, 0},
  {&__pyx_n_s_7, __pyx_k_7, sizeof(__pyx_k_7), 0, 0, 1, 1},
  {&__pyx_kp_s_9, __pyx_k_9, sizeof(__pyx_k_9), 0, 0, 1, 0},
  {&__pyx_n_s__C, __pyx_k__C, sizeof(__pyx_k__C), 0, 0, 1, 1},
  {&__pyx_n_s__MemoryError, __pyx_k__MemoryError, sizeof(__pyx_k__MemoryError), 0, 0, 1, 1},
  {&__pyx_n_s__RuntimeError, __pyx_k__RuntimeError, sizeof(__pyx_k__RuntimeError), 0, 0, 1, 1},
  {&__pyx_n_s__ValueError, __pyx_k__ValueError, sizeof(__pyx_k__ValueError), 0, 0, 1, 1},
  {&__pyx_n_s____all__, __pyx_k____all__, sizeof(__pyx_k____all__), 0, 0, 1, 1},
  {&__pyx_n_s____main__, __pyx_k____main__, sizeof(__pyx_k____main__), 0, 0, 1, 1},
  {&__pyx_n_s____test__, __pyx_k____test__, sizeof(__pyx_k____test__), 0, 0, 1, 1},
  {&__pyx_n_s__amax, __pyx_k__amax, sizeof(__pyx_k__amax), 0, 0, 1, 1},
  {&__pyx_n_s__amin, __pyx_k__amin, sizeof(__pyx_k__amin), 0, 0, 1, 1},
  {&__pyx_n_s__arange, __pyx_k__arange, sizeof(__pyx_k__arange), 0, 0, 1, 1},
  {&__pyx_n_s__array, __pyx_k__array, sizeof(__pyx_k__array), 0, 0, 1, 1},
  {&__pyx_n_s__asarray, __pyx_k__asarray, sizeof(__pyx_k__asarray), 0, 0, 1, 1},
  {&__pyx_n_s__ascontiguousarray, __pyx_k__ascontiguousarray, sizeof(__pyx_k__ascontiguousarray), 0, 0, 1, 1},
  {&__pyx_n_s__astype, __pyx_k__astype, sizeof(__pyx_k__astype), 0, 0, 1, 1},
  {&__pyx_n_s__axis, __pyx_k__axis, sizeof(__pyx_k__axis), 0, 0, 1, 1},
  {&__pyx_n_s__cKDTree, __pyx_k__cKDTree, sizeof(__pyx_k__cKDTree), 0, 0, 1, 1},
  {&__pyx_n_s__coo_matrix, __pyx_k__coo_matrix, sizeof(__pyx_k__coo_matrix), 0, 0, 1, 1},
  {&__pyx_n_s__data, __pyx_k__data, sizeof(__pyx_k__data), 0, 0, 1, 1},
  {&__pyx_n_s__dtype, __pyx_k__dtype, sizeof(__pyx_k__dtype), 0, 0, 1, 1},
  {&__pyx_n_s__empty, __pyx_k__empty, sizeof(__pyx_k__empty), 0, 0, 1, 1},
  {&__pyx_n_s__eps, __pyx_k__eps, sizeof(__pyx_k__eps), 0, 0, 1, 1},
  {&__pyx_n_s__fill, __pyx_k__fill, sizeof(__pyx_k__fill), 0, 0, 1, 1},
  {&__pyx_n_s__float64, __pyx_k__float64, sizeof(__pyx_k__float64), 0, 0, 1, 1},
  {&__pyx_n_s__inf, __pyx_k__inf, sizeof(__pyx_k__inf), 0, 0, 1, 1},
  {&__pyx_n_s__initial_size, __pyx_k__initial_size, sizeof(__pyx_k__initial_size), 0, 0, 1, 1},
  {&__pyx_n_s__intp, __pyx_k__intp, sizeof(__pyx_k__intp), 0, 0, 1, 1},
  {&__pyx_n_s__k, __pyx_k__k, sizeof(__pyx_k__k), 0, 0, 1, 1},
  {&__pyx_n_s__leafsize, __pyx_k__leafsize, sizeof(__pyx_k__leafsize), 0, 0, 1, 1},
  {&__pyx_n_s__max_distance, __pyx_k__max_distance, sizeof(__pyx_k__max_distance), 0, 0, 1, 1},
  {&__pyx_n_s__maxes_arr, __pyx_k__maxes_arr, sizeof(__pyx_k__maxes_arr), 0, 0, 1, 1},
  {&__pyx_n_s__mins_arr, __pyx_k__mins_arr, sizeof(__pyx_k__mins_arr), 0, 0, 1, 1},
  {&__pyx_n_s__ndindex, __pyx_k__ndindex, sizeof(__pyx_k__ndindex), 0, 0, 1, 1},
  {&__pyx_n_s__newaxis, __pyx_k__newaxis, sizeof(__pyx_k__newaxis), 0, 0, 1, 1},
  {&__pyx_n_s__np, __pyx_k__np, sizeof(__pyx_k__np), 0, 0, 1, 1},
  {&__pyx_n_s__numpy, __pyx_k__numpy, sizeof(__pyx_k__numpy), 0, 0, 1, 1},
  {&__pyx_n_s__object, __pyx_k__object, sizeof(__pyx_k__object), 0, 0, 1, 1},
  {&__pyx_n_s__order, __pyx_k__order, sizeof(__pyx_k__order), 0, 0, 1, 1},
  {&__pyx_n_s__other, __pyx_k__other, sizeof(__pyx_k__other), 0, 0, 1, 1},
  {&__pyx_n_s__p, __pyx_k__p, sizeof(__pyx_k__p), 0, 0, 1, 1},
  {&__pyx_n_s__prod, __pyx_k__prod, sizeof(__pyx_k__prod), 0, 0, 1, 1},
  {&__pyx_n_s__r, __pyx_k__r, sizeof(__pyx_k__r), 0, 0, 1, 1},
  {&__pyx_n_s__range, __pyx_k__range, sizeof(__pyx_k__range), 0, 0, 1, 1},
  {&__pyx_n_s__rect1, __pyx_k__rect1, sizeof(__pyx_k__rect1), 0, 0, 1, 1},
  {&__pyx_n_s__rect2, __pyx_k__rect2, sizeof(__pyx_k__rect2), 0, 0, 1, 1},
  {&__pyx_n_s__reshape, __pyx_k__reshape, sizeof(__pyx_k__reshape), 0, 0, 1, 1},
  {&__pyx_n_s__resize, __pyx_k__resize, sizeof(__pyx_k__resize), 0, 0, 1, 1},
  {&__pyx_n_s__scipy, __pyx_k__scipy, sizeof(__pyx_k__scipy), 0, 0, 1, 1},
  {&__pyx_n_s__shape, __pyx_k__shape, sizeof(__pyx_k__shape), 0, 0, 1, 1},
  {&__pyx_n_s__sparse, __pyx_k__sparse, sizeof(__pyx_k__sparse), 0, 0, 1, 1},
  {&__pyx_n_s__to_matrix, __pyx_k__to_matrix, sizeof(__pyx_k__to_matrix), 0, 0, 1, 1},
  {&__pyx_n_s__todok, __pyx_k__todok, sizeof(__pyx_k__todok), 0, 0, 1, 1},
  {&__pyx_n_s__upper_bound, __pyx_k__upper_bound, sizeof(__pyx_k__upper_bound), 0, 0, 1, 1},
  {&__pyx_n_s__x, __pyx_k__x, sizeof(__pyx_k__x), 0, 0, 1, 1},
  {&__pyx_n_s__zeros, __pyx_k__zeros, sizeof(__pyx_k__zeros), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_MemoryError = __Pyx_GetName(__pyx_b, __pyx_n_s__MemoryError); if (!__pyx_builtin_MemoryError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 143; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_ValueError = __Pyx_GetName(__pyx_b, __pyx_n_s__ValueError); if (!__pyx_builtin_ValueError) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 154; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_range = __Pyx_GetName(__pyx_b, __pyx_n_s__range); if (!__pyx_builtin_range) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 299; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_builtin_RuntimeError = __Pyx_GetName(__pyx_b, __pyx_n_s__RuntimeError); if (!__pyx_builtin_RuntimeError) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  return 0;
  __pyx_L1_error:;
  return -1;
}

static int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "pyart/map/ckdtree.pyx":496
 * 
 *         if rect1.m != rect2.m:
 *             raise ValueError("rect1 and rect2 have different dimensions")             # <<<<<<<<<<<<<<
 * 
 *         self.rect1 = rect1
 */
  __pyx_k_tuple_3 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_3)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 496; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_3);
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_2));
  PyTuple_SET_ITEM(__pyx_k_tuple_3, 0, ((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_2));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_3));

  /* "pyart/map/ckdtree.pyx":849
 *         self.leafsize = leafsize
 *         if self.leafsize<1:
 *             raise ValueError("leafsize must be at least 1")             # <<<<<<<<<<<<<<
 *         self.maxes = np.ascontiguousarray(np.amax(self.data,axis=0), dtype=np.float64)
 *         self.mins = np.ascontiguousarray(np.amin(self.data,axis=0), dtype=np.float64)
 */
  __pyx_k_tuple_5 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_5)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 849; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_5);
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_4));
  PyTuple_SET_ITEM(__pyx_k_tuple_5, 0, ((PyObject *)__pyx_kp_s_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_4));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_5));

  /* "pyart/map/ckdtree.pyx":1027
 *         #  distances between the nearest side of the cell and the target
 *         #  the head node of the cell
 *         q = heap(12)             # <<<<<<<<<<<<<<
 * 
 *         # priority queue for the nearest neighbors
 */
  __pyx_k_tuple_6 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_6)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1027; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_6);
  __Pyx_INCREF(__pyx_int_12);
  PyTuple_SET_ITEM(__pyx_k_tuple_6, 0, __pyx_int_12);
  __Pyx_GIVEREF(__pyx_int_12);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_6));

  /* "pyart/map/ckdtree.pyx":1252
 *                              "shape %s" % (int(self.m), np.shape(x)))
 *         if p < 1:
 *             raise ValueError("Only p-norms with 1<=p<=infinity permitted")             # <<<<<<<<<<<<<<
 *         if len(x.shape)==1:
 *             single = True
 */
  __pyx_k_tuple_11 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_11)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1252; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_11);
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_10));
  PyTuple_SET_ITEM(__pyx_k_tuple_11, 0, ((PyObject *)__pyx_kp_s_10));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_10));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_11));

  /* "pyart/map/ckdtree.pyx":1255
 *         if len(x.shape)==1:
 *             single = True
 *             x = x[np.newaxis,:]             # <<<<<<<<<<<<<<
 *         else:
 *             single = False
 */
  __pyx_k_slice_12 = PySlice_New(Py_None, Py_None, Py_None); if (unlikely(!__pyx_k_slice_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1255; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_slice_12);
  __Pyx_GIVEREF(__pyx_k_slice_12);

  /* "pyart/map/ckdtree.pyx":1291
 *                             # C long overlow, return array of dtype=np.int_p
 *                             if k==1:
 *                                 return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)             # <<<<<<<<<<<<<<
 *                             else:
 *                                 return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,))
 */
  __pyx_k_tuple_13 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_13)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_13);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_13, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_13));
  __pyx_k_tuple_14 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_14)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1291; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_14);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_14, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_14));

  /* "pyart/map/ckdtree.pyx":1297
 *                 # no C long overlow, return array of dtype=int
 *                 if k==1:
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape).astype(int)             # <<<<<<<<<<<<<<
 *                 else:
 *                     return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,)).astype(int)
 */
  __pyx_k_tuple_15 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_15);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_15, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_15, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_15));
  __pyx_k_tuple_16 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_16)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1297; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_16);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_16, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_16));

  /* "pyart/map/ckdtree.pyx":1304
 *                 # ... most other platforms
 *                 if k==1:
 *                     return np.reshape(dd[...,0],retshape), np.reshape(ii[...,0],retshape)             # <<<<<<<<<<<<<<
 *                 else:
 *                     return np.reshape(dd,retshape+(k,)), np.reshape(ii,retshape+(k,))
 */
  __pyx_k_tuple_17 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_17)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_17);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_17, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_17));
  __pyx_k_tuple_18 = PyTuple_New(2); if (unlikely(!__pyx_k_tuple_18)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1304; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_18);
  __Pyx_INCREF(Py_Ellipsis);
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 0, Py_Ellipsis);
  __Pyx_GIVEREF(Py_Ellipsis);
  __Pyx_INCREF(__pyx_int_0);
  PyTuple_SET_ITEM(__pyx_k_tuple_18, 1, __pyx_int_0);
  __Pyx_GIVEREF(__pyx_int_0);
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_18));

  /* "pyart/map/ckdtree.pyx":1593
 *         # Make sure trees are compatible
 *         if self.m != other.m:
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")             # <<<<<<<<<<<<<<
 * 
 *         # Track node-to-node min/max distances
 */
  __pyx_k_tuple_21 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_21)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1593; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_21);
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_20));
  PyTuple_SET_ITEM(__pyx_k_tuple_21, 0, ((PyObject *)__pyx_kp_s_20));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_20));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_21));

  /* "pyart/map/ckdtree.pyx":1939
 *         # Make sure trees are compatible
 *         if self.m != other.m:
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")             # <<<<<<<<<<<<<<
 * 
 *         # Make a copy of r array to ensure it's contiguous and to modify it
 */
  __pyx_k_tuple_22 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_22)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1939; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_22);
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_20));
  PyTuple_SET_ITEM(__pyx_k_tuple_22, 0, ((PyObject *)__pyx_kp_s_20));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_20));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_22));

  /* "pyart/map/ckdtree.pyx":1950
 *             n_queries = r.shape[0]
 *         else:
 *             raise ValueError("r must be either a single value or a one-dimensional array of values")             # <<<<<<<<<<<<<<
 * 
 *         # Internally, we represent all distances as distance ** p
 */
  __pyx_k_tuple_24 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_24)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1950; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_24);
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_23));
  PyTuple_SET_ITEM(__pyx_k_tuple_24, 0, ((PyObject *)__pyx_kp_s_23));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_23));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_24));

  /* "pyart/map/ckdtree.pyx":2102
 *         # Make sure trees are compatible
 *         if self.m != other.m:
 *             raise ValueError("Trees passed to query_ball_trees have different dimensionality")             # <<<<<<<<<<<<<<
 * 
 *         # Calculate mins and maxes to outer box
 */
  __pyx_k_tuple_25 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_25)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 2102; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_25);
  __Pyx_INCREF(((PyObject *)__pyx_kp_s_20));
  PyTuple_SET_ITEM(__pyx_k_tuple_25, 0, ((PyObject *)__pyx_kp_s_20));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_s_20));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_25));

  /* "numpy.pxd":215
 *             if ((flags & pybuf.PyBUF_C_CONTIGUOUS == pybuf.PyBUF_C_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_C_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not C contiguous")             # <<<<<<<<<<<<<<
 * 
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 */
  __pyx_k_tuple_27 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_27)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 215; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_27);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_26));
  PyTuple_SET_ITEM(__pyx_k_tuple_27, 0, ((PyObject *)__pyx_kp_u_26));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_26));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_27));

  /* "numpy.pxd":219
 *             if ((flags & pybuf.PyBUF_F_CONTIGUOUS == pybuf.PyBUF_F_CONTIGUOUS)
 *                 and not PyArray_CHKFLAGS(self, NPY_F_CONTIGUOUS)):
 *                 raise ValueError(u"ndarray is not Fortran contiguous")             # <<<<<<<<<<<<<<
 * 
 *             info.buf = PyArray_DATA(self)
 */
  __pyx_k_tuple_29 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_29)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 219; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_29);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_28));
  PyTuple_SET_ITEM(__pyx_k_tuple_29, 0, ((PyObject *)__pyx_kp_u_28));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_28));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_29));

  /* "numpy.pxd":257
 *                 if ((descr.byteorder == c'>' and little_endian) or
 *                     (descr.byteorder == c'<' and not little_endian)):
 *                     raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *                 if   t == NPY_BYTE:        f = "b"
 *                 elif t == NPY_UBYTE:       f = "B"
 */
  __pyx_k_tuple_31 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_31)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 257; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_31);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_30));
  PyTuple_SET_ITEM(__pyx_k_tuple_31, 0, ((PyObject *)__pyx_kp_u_30));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_30));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_31));

  /* "numpy.pxd":799
 * 
 *         if (end - f) - (new_offset - offset[0]) < 15:
 *             raise RuntimeError(u"Format string allocated too short, see comment in numpy.pxd")             # <<<<<<<<<<<<<<
 * 
 *         if ((child.byteorder == c'>' and little_endian) or
 */
  __pyx_k_tuple_34 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_34)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 799; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_34);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_33));
  PyTuple_SET_ITEM(__pyx_k_tuple_34, 0, ((PyObject *)__pyx_kp_u_33));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_33));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_34));

  /* "numpy.pxd":803
 *         if ((child.byteorder == c'>' and little_endian) or
 *             (child.byteorder == c'<' and not little_endian)):
 *             raise ValueError(u"Non-native byte order not supported")             # <<<<<<<<<<<<<<
 *             # One could encode it in the format string and have Cython
 *             # complain instead, BUT: < and > in format strings also imply
 */
  __pyx_k_tuple_35 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_35)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 803; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_35);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_30));
  PyTuple_SET_ITEM(__pyx_k_tuple_35, 0, ((PyObject *)__pyx_kp_u_30));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_30));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_35));

  /* "numpy.pxd":823
 *             t = child.type_num
 *             if end - f < 5:
 *                 raise RuntimeError(u"Format string allocated too short.")             # <<<<<<<<<<<<<<
 * 
 *             # Until ticket #99 is fixed, use integers to avoid warnings
 */
  __pyx_k_tuple_37 = PyTuple_New(1); if (unlikely(!__pyx_k_tuple_37)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 823; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_k_tuple_37);
  __Pyx_INCREF(((PyObject *)__pyx_kp_u_36));
  PyTuple_SET_ITEM(__pyx_k_tuple_37, 0, ((PyObject *)__pyx_kp_u_36));
  __Pyx_GIVEREF(((PyObject *)__pyx_kp_u_36));
  __Pyx_GIVEREF(((PyObject *)__pyx_k_tuple_37));
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_0 = PyInt_FromLong(0); if (unlikely(!__pyx_int_0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_12 = PyInt_FromLong(12); if (unlikely(!__pyx_int_12)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  __pyx_int_15 = PyInt_FromLong(15); if (unlikely(!__pyx_int_15)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  return 0;
  __pyx_L1_error:;
  return -1;
}

#if PY_MAJOR_VERSION < 3
PyMODINIT_FUNC initckdtree(void); /*proto*/
PyMODINIT_FUNC initckdtree(void)
#else
PyMODINIT_FUNC PyInit_ckdtree(void); /*proto*/
PyMODINIT_FUNC PyInit_ckdtree(void)
#endif
{
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  __pyx_t_5numpy_float64_t __pyx_t_3;
  __Pyx_RefNannyDeclarations
  #if CYTHON_REFNANNY
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
  if (!__Pyx_RefNanny) {
      PyErr_Clear();
      __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
      if (!__Pyx_RefNanny)
          Py_FatalError("failed to import 'refnanny' module");
  }
  #endif
  __Pyx_RefNannySetupContext("PyMODINIT_FUNC PyInit_ckdtree(void)", 0);
  if ( __Pyx_check_binary_version() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #ifdef __Pyx_CyFunction_USED
  if (__Pyx_CyFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4(__Pyx_NAMESTR("ckdtree"), __pyx_methods, __Pyx_DOCSTR(__pyx_k_38), 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    if (!PyDict_GetItemString(modules, "pyart.map.ckdtree")) {
      if (unlikely(PyDict_SetItemString(modules, "pyart.map.ckdtree", __pyx_m) < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
    }
  }
  #endif
  __pyx_b = PyImport_AddModule(__Pyx_NAMESTR(__Pyx_BUILTIN_MODULE_NAME)); if (unlikely(!__pyx_b)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  #if CYTHON_COMPILING_IN_PYPY
  Py_INCREF(__pyx_b);
  #endif
  if (__Pyx_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  /*--- Initialize various global constants etc. ---*/
  if (unlikely(__Pyx_InitGlobals() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__pyx_module_is_main_pyart__map__ckdtree) {
    if (__Pyx_SetAttrString(__pyx_m, "__name__", __pyx_n_s____main__) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;};
  }
  /*--- Builtin init code ---*/
  if (unlikely(__Pyx_InitCachedBuiltins() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Constants init code ---*/
  if (unlikely(__Pyx_InitCachedConstants() < 0)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Global init code ---*/
  /*--- Variable export code ---*/
  /*--- Function export code ---*/
  /*--- Type init code ---*/
  __pyx_vtabptr_5pyart_3map_7ckdtree_heap = &__pyx_vtable_5pyart_3map_7ckdtree_heap;
  __pyx_vtable_5pyart_3map_7ckdtree_heap._resize = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, __pyx_t_5numpy_intp_t))__pyx_f_5pyart_3map_7ckdtree_4heap__resize;
  __pyx_vtable_5pyart_3map_7ckdtree_heap.push = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, struct __pyx_t_5pyart_3map_7ckdtree_heapitem))__pyx_f_5pyart_3map_7ckdtree_4heap_push;
  __pyx_vtable_5pyart_3map_7ckdtree_heap.peek = (struct __pyx_t_5pyart_3map_7ckdtree_heapitem (*)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *))__pyx_f_5pyart_3map_7ckdtree_4heap_peek;
  __pyx_vtable_5pyart_3map_7ckdtree_heap.remove = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *))__pyx_f_5pyart_3map_7ckdtree_4heap_remove;
  __pyx_vtable_5pyart_3map_7ckdtree_heap.pop = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_heap *, struct __pyx_t_5pyart_3map_7ckdtree_heapitem *))__pyx_f_5pyart_3map_7ckdtree_4heap_pop;
  if (PyType_Ready(&__pyx_type_5pyart_3map_7ckdtree_heap) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(__pyx_type_5pyart_3map_7ckdtree_heap.tp_dict, __pyx_vtabptr_5pyart_3map_7ckdtree_heap) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "heap", (PyObject *)&__pyx_type_5pyart_3map_7ckdtree_heap) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 132; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_3map_7ckdtree_heap = &__pyx_type_5pyart_3map_7ckdtree_heap;
  __pyx_vtabptr_5pyart_3map_7ckdtree_coo_entries = &__pyx_vtable_5pyart_3map_7ckdtree_coo_entries;
  __pyx_vtable_5pyart_3map_7ckdtree_coo_entries.add = (void (*)(struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t))__pyx_f_5pyart_3map_7ckdtree_11coo_entries_add;
  if (PyType_Ready(&__pyx_type_5pyart_3map_7ckdtree_coo_entries) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(__pyx_type_5pyart_3map_7ckdtree_coo_entries.tp_dict, __pyx_vtabptr_5pyart_3map_7ckdtree_coo_entries) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "coo_entries", (PyObject *)&__pyx_type_5pyart_3map_7ckdtree_coo_entries) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 237; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_3map_7ckdtree_coo_entries = &__pyx_type_5pyart_3map_7ckdtree_coo_entries;
  if (PyType_Ready(&__pyx_type_5pyart_3map_7ckdtree_Rectangle) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 325; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "Rectangle", (PyObject *)&__pyx_type_5pyart_3map_7ckdtree_Rectangle) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 325; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_3map_7ckdtree_Rectangle = &__pyx_type_5pyart_3map_7ckdtree_Rectangle;
  __pyx_vtabptr_5pyart_3map_7ckdtree_RectRectDistanceTracker = &__pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker;
  __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker._init_stack = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker__init_stack;
  __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker._resize_stack = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t))__pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker__resize_stack;
  __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker._free_stack = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker__free_stack;
  __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker.push = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t))__pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push;
  __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker.push_less_of = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_less_of;
  __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker.push_greater_of = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *, __pyx_t_5numpy_intp_t, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_push_greater_of;
  __pyx_vtable_5pyart_3map_7ckdtree_RectRectDistanceTracker.pop = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_23RectRectDistanceTracker_pop;
  if (PyType_Ready(&__pyx_type_5pyart_3map_7ckdtree_RectRectDistanceTracker) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 456; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(__pyx_type_5pyart_3map_7ckdtree_RectRectDistanceTracker.tp_dict, __pyx_vtabptr_5pyart_3map_7ckdtree_RectRectDistanceTracker) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 456; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "RectRectDistanceTracker", (PyObject *)&__pyx_type_5pyart_3map_7ckdtree_RectRectDistanceTracker) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 456; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_3map_7ckdtree_RectRectDistanceTracker = &__pyx_type_5pyart_3map_7ckdtree_RectRectDistanceTracker;
  __pyx_vtabptr_5pyart_3map_7ckdtree_PointRectDistanceTracker = &__pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker._init_stack = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker__init_stack;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker._resize_stack = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, __pyx_t_5numpy_intp_t))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker__resize_stack;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker._free_stack = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker__free_stack;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker.init = (PyObject *(*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, __pyx_t_5numpy_float64_t *, struct __pyx_obj_5pyart_3map_7ckdtree_Rectangle *, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_init;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker.push = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker.push_less_of = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_less_of;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker.push_greater_of = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_push_greater_of;
  __pyx_vtable_5pyart_3map_7ckdtree_PointRectDistanceTracker.pop = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_24PointRectDistanceTracker_pop;
  if (PyType_Ready(&__pyx_type_5pyart_3map_7ckdtree_PointRectDistanceTracker) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(__pyx_type_5pyart_3map_7ckdtree_PointRectDistanceTracker.tp_dict, __pyx_vtabptr_5pyart_3map_7ckdtree_PointRectDistanceTracker) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "PointRectDistanceTracker", (PyObject *)&__pyx_type_5pyart_3map_7ckdtree_PointRectDistanceTracker) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 635; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_3map_7ckdtree_PointRectDistanceTracker = &__pyx_type_5pyart_3map_7ckdtree_PointRectDistanceTracker;
  __pyx_vtabptr_5pyart_3map_7ckdtree_cKDTree = &__pyx_vtable_5pyart_3map_7ckdtree_cKDTree;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___build = (struct __pyx_t_5pyart_3map_7ckdtree_innernode *(*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___build;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___free_tree = (PyObject *(*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___free_tree;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_intp_t *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query_ball_point_traverse_no_checking = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_point_traverse_no_checking;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query_ball_point_traverse_checking = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_PointRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_point_traverse_checking;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query_ball_point = (PyObject *(*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t, __pyx_t_5numpy_float64_t))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_point;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query_ball_tree_traverse_no_checking = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_tree_traverse_no_checking;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query_ball_tree_traverse_checking = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_ball_tree_traverse_checking;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query_pairs_traverse_no_checking = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_pairs_traverse_no_checking;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___query_pairs_traverse_checking = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, PyObject *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___query_pairs_traverse_checking;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___count_neighbors_traverse = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, __pyx_t_5numpy_intp_t, __pyx_t_5numpy_float64_t *, __pyx_t_5numpy_intp_t *, __pyx_t_5numpy_intp_t *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___count_neighbors_traverse;
  __pyx_vtable_5pyart_3map_7ckdtree_cKDTree.__pyx___sparse_distance_matrix_traverse = (int (*)(struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_cKDTree *, struct __pyx_obj_5pyart_3map_7ckdtree_coo_entries *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_t_5pyart_3map_7ckdtree_innernode *, struct __pyx_obj_5pyart_3map_7ckdtree_RectRectDistanceTracker *))__pyx_f_5pyart_3map_7ckdtree_7cKDTree___sparse_distance_matrix_traverse;
  if (PyType_Ready(&__pyx_type_5pyart_3map_7ckdtree_cKDTree) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 790; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetVtable(__pyx_type_5pyart_3map_7ckdtree_cKDTree.tp_dict, __pyx_vtabptr_5pyart_3map_7ckdtree_cKDTree) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 790; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (__Pyx_SetAttrString(__pyx_m, "cKDTree", (PyObject *)&__pyx_type_5pyart_3map_7ckdtree_cKDTree) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 790; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5pyart_3map_7ckdtree_cKDTree = &__pyx_type_5pyart_3map_7ckdtree_cKDTree;
  /*--- Type import code ---*/
  __pyx_ptype_7cpython_4type_type = __Pyx_ImportType(__Pyx_BUILTIN_MODULE_NAME, "type", 
  #if CYTHON_COMPILING_IN_PYPY
  sizeof(PyTypeObject),
  #else
  sizeof(PyHeapTypeObject),
  #endif
  0); if (unlikely(!__pyx_ptype_7cpython_4type_type)) {__pyx_filename = __pyx_f[2]; __pyx_lineno = 9; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_dtype = __Pyx_ImportType("numpy", "dtype", sizeof(PyArray_Descr), 0); if (unlikely(!__pyx_ptype_5numpy_dtype)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 155; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_flatiter = __Pyx_ImportType("numpy", "flatiter", sizeof(PyArrayIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_flatiter)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 165; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_broadcast = __Pyx_ImportType("numpy", "broadcast", sizeof(PyArrayMultiIterObject), 0); if (unlikely(!__pyx_ptype_5numpy_broadcast)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 169; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ndarray = __Pyx_ImportType("numpy", "ndarray", sizeof(PyArrayObject), 0); if (unlikely(!__pyx_ptype_5numpy_ndarray)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 178; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __pyx_ptype_5numpy_ufunc = __Pyx_ImportType("numpy", "ufunc", sizeof(PyUFuncObject), 0); if (unlikely(!__pyx_ptype_5numpy_ufunc)) {__pyx_filename = __pyx_f[1]; __pyx_lineno = 861; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  /*--- Variable import code ---*/
  /*--- Function import code ---*/
  /*--- Execution code ---*/

  /* "pyart/map/ckdtree.pyx":40
 * # Additional contributions by Patrick Varilly and Sturla Molden
 * # Released under the scipy license
 * import numpy as np             # <<<<<<<<<<<<<<
 * import scipy.sparse
 * 
 */
  __pyx_t_1 = __Pyx_Import(((PyObject *)__pyx_n_s__numpy), 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__np, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 40; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":41
 * # Released under the scipy license
 * import numpy as np
 * import scipy.sparse             # <<<<<<<<<<<<<<
 * 
 * cimport numpy as np
 */
  __pyx_t_1 = __Pyx_Import(((PyObject *)__pyx_n_s_39), 0, -1); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s__scipy, __pyx_t_1) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 41; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "pyart/map/ckdtree.pyx":49
 * cdef extern from "limits.h":
 *     long LONG_MAX
 * cdef np.float64_t infinity = np.inf             # <<<<<<<<<<<<<<
 * 
 * __all__ = ['cKDTree']
 */
  __pyx_t_1 = __Pyx_GetName(__pyx_m, __pyx_n_s__np); if (unlikely(!__pyx_t_1)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_2 = PyObject_GetAttr(__pyx_t_1, __pyx_n_s__inf); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_3 = __pyx_PyFloat_AsDouble(__pyx_t_2); if (unlikely((__pyx_t_3 == (npy_float64)-1) && PyErr_Occurred())) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 49; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_v_5pyart_3map_7ckdtree_infinity = __pyx_t_3;

  /* "pyart/map/ckdtree.pyx":51
 * cdef np.float64_t infinity = np.inf
 * 
 * __all__ = ['cKDTree']             # <<<<<<<<<<<<<<
 * 
 * 
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(((PyObject *)__pyx_n_s__cKDTree));
  PyList_SET_ITEM(__pyx_t_2, 0, ((PyObject *)__pyx_n_s__cKDTree));
  __Pyx_GIVEREF(((PyObject *)__pyx_n_s__cKDTree));
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____all__, ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 51; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "pyart/map/ckdtree.pyx":453
 *     np.float64_t min_distance, max_distance
 * 
 * cdef np.intp_t LESS = 1             # <<<<<<<<<<<<<<
 * cdef np.intp_t GREATER = 2
 * 
 */
  __pyx_v_5pyart_3map_7ckdtree_LESS = 1;

  /* "pyart/map/ckdtree.pyx":454
 * 
 * cdef np.intp_t LESS = 1
 * cdef np.intp_t GREATER = 2             # <<<<<<<<<<<<<<
 * 
 * cdef class RectRectDistanceTracker(object):
 */
  __pyx_v_5pyart_3map_7ckdtree_GREATER = 2;

  /* "pyart/map/ckdtree.pyx":1205
 *     @cython.wraparound(False)
 *     def query(cKDTree self, object x, np.intp_t k=1, np.float64_t eps=0,
 *               np.float64_t p=2, np.float64_t distance_upper_bound=infinity):             # <<<<<<<<<<<<<<
 *         """query(self, x, k=1, eps=0, p=2, distance_upper_bound=np.inf)
 * 
 */
  __pyx_k_8 = __pyx_v_5pyart_3map_7ckdtree_infinity;

  /* "pyart/map/ckdtree.pyx":1
 * # ckdtree.pyx taken from file of same name from SciPy             # <<<<<<<<<<<<<<
 * # http://www.scipy.org
 * # SciPy license:
 */
  __pyx_t_2 = PyDict_New(); if (unlikely(!__pyx_t_2)) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_GOTREF(((PyObject *)__pyx_t_2));
  if (PyDict_SetItem(__pyx_t_2, ((PyObject *)__pyx_kp_u_40), ((PyObject *)__pyx_kp_u_41)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s____test__, ((PyObject *)__pyx_t_2)) < 0) {__pyx_filename = __pyx_f[0]; __pyx_lineno = 1; __pyx_clineno = __LINE__; goto __pyx_L1_error;}
  __Pyx_DECREF(((PyObject *)__pyx_t_2)); __pyx_t_2 = 0;

  /* "numpy.pxd":975
 *      arr.base = baseptr
 * 
 * cdef inline object get_array_base(ndarray arr):             # <<<<<<<<<<<<<<
 *     if arr.base is NULL:
 *         return None
 */
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  if (__pyx_m) {
    __Pyx_AddTraceback("init pyart.map.ckdtree", __pyx_clineno, __pyx_lineno, __pyx_filename);
    Py_DECREF(__pyx_m); __pyx_m = 0;
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init pyart.map.ckdtree");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if PY_MAJOR_VERSION < 3
  return;
  #else
  return __pyx_m;
  #endif
}

/* Runtime support code */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule((char *)modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, (char *)"RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif /* CYTHON_REFNANNY */

static PyObject *__Pyx_GetName(PyObject *dict, PyObject *name) {
    PyObject *result;
    result = PyObject_GetAttr(dict, name);
    if (!result) {
        if (dict != __pyx_b) {
            PyErr_Clear();
            result = PyObject_GetAttr(__pyx_b, name);
        }
        if (!result) {
            PyErr_SetObject(PyExc_NameError, name);
        }
    }
    return result;
}

static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_CheckExact(key)) || likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (PyUnicode_GET_SIZE(**name) != PyUnicode_GET_SIZE(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (PyUnicode_GET_SIZE(**argname) != PyUnicode_GET_SIZE(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%s() takes %s %" CYTHON_FORMAT_SSIZE_T "d positional argument%s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

static CYTHON_INLINE void __Pyx_ErrRestore(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_Restore(type, value, tb);
#endif
}
static CYTHON_INLINE void __Pyx_ErrFetch(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(type, value, tb);
#endif
}

#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    #if PY_VERSION_HEX < 0x02050000
    if (PyClass_Check(type)) {
    #else
    if (PyType_Check(type)) {
    #endif
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        #if PY_VERSION_HEX < 0x02050000
            if (PyInstance_Check(type)) {
                type = (PyObject*) ((PyInstanceObject*)type)->in_class;
                Py_INCREF(type);
            }
            else {
                type = 0;
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception must be an old-style class or instance");
                goto raise_error;
            }
        #else
            type = (PyObject*) Py_TYPE(type);
            Py_INCREF(type);
            if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
                PyErr_SetString(PyExc_TypeError,
                    "raise: exception class must be a subclass of BaseException");
                goto raise_error;
            }
        #endif
    }
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else /* Python 3+ */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *args;
        if (!value)
            args = PyTuple_New(0);
        else if (PyTuple_Check(value)) {
            Py_INCREF(value);
            args = value;
        }
        else
            args = PyTuple_Pack(1, value);
        if (!args)
            goto bad;
        owned_instance = PyEval_CallObject(type, args);
        Py_DECREF(args);
        if (!owned_instance)
            goto bad;
        value = owned_instance;
        if (!PyExceptionInstance_Check(value)) {
            PyErr_Format(PyExc_TypeError,
                         "calling %R should have returned an instance of "
                         "BaseException, not %R",
                         type, Py_TYPE(value));
            goto bad;
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause && cause != Py_None) {
        PyObject *fixed_cause;
        if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        }
        else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        }
        else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
        PyThreadState *tstate = PyThreadState_GET();
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

static CYTHON_INLINE int __Pyx_CheckKeywordStrings(
    PyObject *kwdict,
    const char* function_name,
    int kw_allowed)
{
    PyObject* key = 0;
    Py_ssize_t pos = 0;
#if CPYTHON_COMPILING_IN_PYPY
    if (!kw_allowed && PyDict_Next(kwdict, &pos, &key, 0))
        goto invalid_keyword;
    return 1;
#else
    while (PyDict_Next(kwdict, &pos, &key, 0)) {
        #if PY_MAJOR_VERSION < 3
        if (unlikely(!PyString_CheckExact(key)) && unlikely(!PyString_Check(key)))
        #endif
            if (unlikely(!PyUnicode_Check(key)))
                goto invalid_keyword_type;
    }
    if ((!kw_allowed) && unlikely(key))
        goto invalid_keyword;
    return 1;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%s() keywords must be strings", function_name);
    return 0;
#endif
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%s() got an unexpected keyword argument '%s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
    return 0;
}

static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(PyObject_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

static int __Pyx_ArgTypeTest(PyObject *obj, PyTypeObject *type, int none_allowed,
    const char *name, int exact)
{
    if (!type) {
        PyErr_Format(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (none_allowed && obj == Py_None) return 1;
    else if (exact) {
        if (Py_TYPE(obj) == type) return 1;
    }
    else {
        if (PyObject_TypeCheck(obj, type)) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%s' has incorrect type (expected %s, got %s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

static CYTHON_INLINE void __Pyx_RaiseTooManyValuesError(Py_ssize_t expected) {
    PyErr_Format(PyExc_ValueError,
                 "too many values to unpack (expected %" CYTHON_FORMAT_SSIZE_T "d)", expected);
}

static CYTHON_INLINE void __Pyx_RaiseNeedMoreValuesError(Py_ssize_t index) {
    PyErr_Format(PyExc_ValueError,
                 "need more than %" CYTHON_FORMAT_SSIZE_T "d value%s to unpack",
                 index, (index == 1) ? "" : "s");
}

static CYTHON_INLINE int __Pyx_IterFinish(void) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    PyObject* exc_type = tstate->curexc_type;
    if (unlikely(exc_type)) {
        if (likely(exc_type == PyExc_StopIteration) || PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration)) {
            PyObject *exc_value, *exc_tb;
            exc_value = tstate->curexc_value;
            exc_tb = tstate->curexc_traceback;
            tstate->curexc_type = 0;
            tstate->curexc_value = 0;
            tstate->curexc_traceback = 0;
            Py_DECREF(exc_type);
            Py_XDECREF(exc_value);
            Py_XDECREF(exc_tb);
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#else
    if (unlikely(PyErr_Occurred())) {
        if (likely(PyErr_ExceptionMatches(PyExc_StopIteration))) {
            PyErr_Clear();
            return 0;
        } else {
            return -1;
        }
    }
    return 0;
#endif
}

static int __Pyx_IternextUnpackEndCheck(PyObject *retval, Py_ssize_t expected) {
    if (unlikely(retval)) {
        Py_DECREF(retval);
        __Pyx_RaiseTooManyValuesError(expected);
        return -1;
    } else {
        return __Pyx_IterFinish();
    }
    return 0;
}

static int __Pyx_GetException(PyObject **type, PyObject **value, PyObject **tb) {
    PyObject *local_type, *local_value, *local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    local_type = tstate->curexc_type;
    local_value = tstate->curexc_value;
    local_tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
#else
    PyErr_Fetch(&local_type, &local_value, &local_tb);
#endif
    PyErr_NormalizeException(&local_type, &local_value, &local_tb);
#if CYTHON_COMPILING_IN_CPYTHON
    if (unlikely(tstate->curexc_type))
#else
    if (unlikely(PyErr_Occurred()))
#endif
        goto bad;
    #if PY_MAJOR_VERSION >= 3
    if (unlikely(PyException_SetTraceback(local_value, local_tb) < 0))
        goto bad;
    #endif
    Py_INCREF(local_type);
    Py_INCREF(local_value);
    Py_INCREF(local_tb);
    *type = local_type;
    *value = local_value;
    *tb = local_tb;
#if CYTHON_COMPILING_IN_CPYTHON
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = local_type;
    tstate->exc_value = local_value;
    tstate->exc_traceback = local_tb;
    /* Make sure tstate is in a consistent state when we XDECREF
       these objects (DECREF may run arbitrary code). */
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(local_type, local_value, local_tb);
#endif
    return 0;
bad:
    *type = 0;
    *value = 0;
    *tb = 0;
    Py_XDECREF(local_type);
    Py_XDECREF(local_value);
    Py_XDECREF(local_tb);
    return -1;
}

static CYTHON_INLINE int __Pyx_IsLittleEndian(void) {
  unsigned int n = 1;
  return *(unsigned char*)(&n) != 0;
}
static void __Pyx_BufFmt_Init(__Pyx_BufFmt_Context* ctx,
                              __Pyx_BufFmt_StackElem* stack,
                              __Pyx_TypeInfo* type) {
  stack[0].field = &ctx->root;
  stack[0].parent_offset = 0;
  ctx->root.type = type;
  ctx->root.name = "buffer dtype";
  ctx->root.offset = 0;
  ctx->head = stack;
  ctx->head->field = &ctx->root;
  ctx->fmt_offset = 0;
  ctx->head->parent_offset = 0;
  ctx->new_packmode = '@';
  ctx->enc_packmode = '@';
  ctx->new_count = 1;
  ctx->enc_count = 0;
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  ctx->is_valid_array = 0;
  ctx->struct_alignment = 0;
  while (type->typegroup == 'S') {
    ++ctx->head;
    ctx->head->field = type->fields;
    ctx->head->parent_offset = 0;
    type = type->fields->type;
  }
}
static int __Pyx_BufFmt_ParseNumber(const char** ts) {
    int count;
    const char* t = *ts;
    if (*t < '0' || *t > '9') {
      return -1;
    } else {
        count = *t++ - '0';
        while (*t >= '0' && *t < '9') {
            count *= 10;
            count += *t++ - '0';
        }
    }
    *ts = t;
    return count;
}
static int __Pyx_BufFmt_ExpectNumber(const char **ts) {
    int number = __Pyx_BufFmt_ParseNumber(ts);
    if (number == -1) /* First char was not a digit */
        PyErr_Format(PyExc_ValueError,\
                     "Does not understand character buffer dtype format string ('%c')", **ts);
    return number;
}
static void __Pyx_BufFmt_RaiseUnexpectedChar(char ch) {
  PyErr_Format(PyExc_ValueError,
               "Unexpected format string character: '%c'", ch);
}
static const char* __Pyx_BufFmt_DescribeTypeChar(char ch, int is_complex) {
  switch (ch) {
    case 'c': return "'char'";
    case 'b': return "'signed char'";
    case 'B': return "'unsigned char'";
    case 'h': return "'short'";
    case 'H': return "'unsigned short'";
    case 'i': return "'int'";
    case 'I': return "'unsigned int'";
    case 'l': return "'long'";
    case 'L': return "'unsigned long'";
    case 'q': return "'long long'";
    case 'Q': return "'unsigned long long'";
    case 'f': return (is_complex ? "'complex float'" : "'float'");
    case 'd': return (is_complex ? "'complex double'" : "'double'");
    case 'g': return (is_complex ? "'complex long double'" : "'long double'");
    case 'T': return "a struct";
    case 'O': return "Python object";
    case 'P': return "a pointer";
    case 's': case 'p': return "a string";
    case 0: return "end";
    default: return "unparseable format string";
  }
}
static size_t __Pyx_BufFmt_TypeCharToStandardSize(char ch, int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return 2;
    case 'i': case 'I': case 'l': case 'L': return 4;
    case 'q': case 'Q': return 8;
    case 'f': return (is_complex ? 8 : 4);
    case 'd': return (is_complex ? 16 : 8);
    case 'g': {
      PyErr_SetString(PyExc_ValueError, "Python does not define a standard format string size for long double ('g')..");
      return 0;
    }
    case 'O': case 'P': return sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static size_t __Pyx_BufFmt_TypeCharToNativeSize(char ch, int is_complex) {
  switch (ch) {
    case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(short);
    case 'i': case 'I': return sizeof(int);
    case 'l': case 'L': return sizeof(long);
    #ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(PY_LONG_LONG);
    #endif
    case 'f': return sizeof(float) * (is_complex ? 2 : 1);
    case 'd': return sizeof(double) * (is_complex ? 2 : 1);
    case 'g': return sizeof(long double) * (is_complex ? 2 : 1);
    case 'O': case 'P': return sizeof(void*);
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
typedef struct { char c; short x; } __Pyx_st_short;
typedef struct { char c; int x; } __Pyx_st_int;
typedef struct { char c; long x; } __Pyx_st_long;
typedef struct { char c; float x; } __Pyx_st_float;
typedef struct { char c; double x; } __Pyx_st_double;
typedef struct { char c; long double x; } __Pyx_st_longdouble;
typedef struct { char c; void *x; } __Pyx_st_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { char c; PY_LONG_LONG x; } __Pyx_st_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToAlignment(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_st_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_st_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_st_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_st_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_st_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_st_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_st_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_st_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
/* These are for computing the padding at the end of the struct to align
   on the first member of the struct. This will probably the same as above,
   but we don't have any guarantees.
 */
typedef struct { short x; char c; } __Pyx_pad_short;
typedef struct { int x; char c; } __Pyx_pad_int;
typedef struct { long x; char c; } __Pyx_pad_long;
typedef struct { float x; char c; } __Pyx_pad_float;
typedef struct { double x; char c; } __Pyx_pad_double;
typedef struct { long double x; char c; } __Pyx_pad_longdouble;
typedef struct { void *x; char c; } __Pyx_pad_void_p;
#ifdef HAVE_LONG_LONG
typedef struct { PY_LONG_LONG x; char c; } __Pyx_pad_longlong;
#endif
static size_t __Pyx_BufFmt_TypeCharToPadding(char ch, CYTHON_UNUSED int is_complex) {
  switch (ch) {
    case '?': case 'c': case 'b': case 'B': case 's': case 'p': return 1;
    case 'h': case 'H': return sizeof(__Pyx_pad_short) - sizeof(short);
    case 'i': case 'I': return sizeof(__Pyx_pad_int) - sizeof(int);
    case 'l': case 'L': return sizeof(__Pyx_pad_long) - sizeof(long);
#ifdef HAVE_LONG_LONG
    case 'q': case 'Q': return sizeof(__Pyx_pad_longlong) - sizeof(PY_LONG_LONG);
#endif
    case 'f': return sizeof(__Pyx_pad_float) - sizeof(float);
    case 'd': return sizeof(__Pyx_pad_double) - sizeof(double);
    case 'g': return sizeof(__Pyx_pad_longdouble) - sizeof(long double);
    case 'P': case 'O': return sizeof(__Pyx_pad_void_p) - sizeof(void*);
    default:
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
}
static char __Pyx_BufFmt_TypeCharToGroup(char ch, int is_complex) {
  switch (ch) {
    case 'c':
        return 'H';
    case 'b': case 'h': case 'i':
    case 'l': case 'q': case 's': case 'p':
        return 'I';
    case 'B': case 'H': case 'I': case 'L': case 'Q':
        return 'U';
    case 'f': case 'd': case 'g':
        return (is_complex ? 'C' : 'R');
    case 'O':
        return 'O';
    case 'P':
        return 'P';
    default: {
      __Pyx_BufFmt_RaiseUnexpectedChar(ch);
      return 0;
    }
  }
}
static void __Pyx_BufFmt_RaiseExpected(__Pyx_BufFmt_Context* ctx) {
  if (ctx->head == NULL || ctx->head->field == &ctx->root) {
    const char* expected;
    const char* quote;
    if (ctx->head == NULL) {
      expected = "end";
      quote = "";
    } else {
      expected = ctx->head->field->type->name;
      quote = "'";
    }
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected %s%s%s but got %s",
                 quote, expected, quote,
                 __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex));
  } else {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_StructField* parent = (ctx->head - 1)->field;
    PyErr_Format(PyExc_ValueError,
                 "Buffer dtype mismatch, expected '%s' but got %s in '%s.%s'",
                 field->type->name, __Pyx_BufFmt_DescribeTypeChar(ctx->enc_type, ctx->is_complex),
                 parent->type->name, field->name);
  }
}
static int __Pyx_BufFmt_ProcessTypeChunk(__Pyx_BufFmt_Context* ctx) {
  char group;
  size_t size, offset, arraysize = 1;
  if (ctx->enc_type == 0) return 0;
  if (ctx->head->field->type->arraysize[0]) {
    int i, ndim = 0;
    if (ctx->enc_type == 's' || ctx->enc_type == 'p') {
        ctx->is_valid_array = ctx->head->field->type->ndim == 1;
        ndim = 1;
        if (ctx->enc_count != ctx->head->field->type->arraysize[0]) {
            PyErr_Format(PyExc_ValueError,
                         "Expected a dimension of size %zu, got %zu",
                         ctx->head->field->type->arraysize[0], ctx->enc_count);
            return -1;
        }
    }
    if (!ctx->is_valid_array) {
      PyErr_Format(PyExc_ValueError, "Expected %d dimensions, got %d",
                   ctx->head->field->type->ndim, ndim);
      return -1;
    }
    for (i = 0; i < ctx->head->field->type->ndim; i++) {
      arraysize *= ctx->head->field->type->arraysize[i];
    }
    ctx->is_valid_array = 0;
    ctx->enc_count = 1;
  }
  group = __Pyx_BufFmt_TypeCharToGroup(ctx->enc_type, ctx->is_complex);
  do {
    __Pyx_StructField* field = ctx->head->field;
    __Pyx_TypeInfo* type = field->type;
    if (ctx->enc_packmode == '@' || ctx->enc_packmode == '^') {
      size = __Pyx_BufFmt_TypeCharToNativeSize(ctx->enc_type, ctx->is_complex);
    } else {
      size = __Pyx_BufFmt_TypeCharToStandardSize(ctx->enc_type, ctx->is_complex);
    }
    if (ctx->enc_packmode == '@') {
      size_t align_at = __Pyx_BufFmt_TypeCharToAlignment(ctx->enc_type, ctx->is_complex);
      size_t align_mod_offset;
      if (align_at == 0) return -1;
      align_mod_offset = ctx->fmt_offset % align_at;
      if (align_mod_offset > 0) ctx->fmt_offset += align_at - align_mod_offset;
      if (ctx->struct_alignment == 0)
          ctx->struct_alignment = __Pyx_BufFmt_TypeCharToPadding(ctx->enc_type,
                                                                 ctx->is_complex);
    }
    if (type->size != size || type->typegroup != group) {
      if (type->typegroup == 'C' && type->fields != NULL) {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        ++ctx->head;
        ctx->head->field = type->fields;
        ctx->head->parent_offset = parent_offset;
        continue;
      }
      if ((type->typegroup == 'H' || group == 'H') && type->size == size) {
      } else {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
      }
    }
    offset = ctx->head->parent_offset + field->offset;
    if (ctx->fmt_offset != offset) {
      PyErr_Format(PyExc_ValueError,
                   "Buffer dtype mismatch; next field is at offset %" CYTHON_FORMAT_SSIZE_T "d but %" CYTHON_FORMAT_SSIZE_T "d expected",
                   (Py_ssize_t)ctx->fmt_offset, (Py_ssize_t)offset);
      return -1;
    }
    ctx->fmt_offset += size;
    if (arraysize)
      ctx->fmt_offset += (arraysize - 1) * size;
    --ctx->enc_count; /* Consume from buffer string */
    while (1) {
      if (field == &ctx->root) {
        ctx->head = NULL;
        if (ctx->enc_count != 0) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return -1;
        }
        break; /* breaks both loops as ctx->enc_count == 0 */
      }
      ctx->head->field = ++field;
      if (field->type == NULL) {
        --ctx->head;
        field = ctx->head->field;
        continue;
      } else if (field->type->typegroup == 'S') {
        size_t parent_offset = ctx->head->parent_offset + field->offset;
        if (field->type->fields->type == NULL) continue; /* empty struct */
        field = field->type->fields;
        ++ctx->head;
        ctx->head->field = field;
        ctx->head->parent_offset = parent_offset;
        break;
      } else {
        break;
      }
    }
  } while (ctx->enc_count);
  ctx->enc_type = 0;
  ctx->is_complex = 0;
  return 0;
}
static CYTHON_INLINE PyObject *
__pyx_buffmt_parse_array(__Pyx_BufFmt_Context* ctx, const char** tsp)
{
    const char *ts = *tsp;
    int i = 0, number;
    int ndim = ctx->head->field->type->ndim;
;
    ++ts;
    if (ctx->new_count != 1) {
        PyErr_SetString(PyExc_ValueError,
                        "Cannot handle repeated arrays in format string");
        return NULL;
    }
    if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
    while (*ts && *ts != ')') {
        if (isspace(*ts))
            continue;
        number = __Pyx_BufFmt_ExpectNumber(&ts);
        if (number == -1) return NULL;
        if (i < ndim && (size_t) number != ctx->head->field->type->arraysize[i])
            return PyErr_Format(PyExc_ValueError,
                        "Expected a dimension of size %zu, got %d",
                        ctx->head->field->type->arraysize[i], number);
        if (*ts != ',' && *ts != ')')
            return PyErr_Format(PyExc_ValueError,
                                "Expected a comma in format string, got '%c'", *ts);
        if (*ts == ',') ts++;
        i++;
    }
    if (i != ndim)
        return PyErr_Format(PyExc_ValueError, "Expected %d dimension(s), got %d",
                            ctx->head->field->type->ndim, i);
    if (!*ts) {
        PyErr_SetString(PyExc_ValueError,
                        "Unexpected end of format string, expected ')'");
        return NULL;
    }
    ctx->is_valid_array = 1;
    ctx->new_count = 1;
    *tsp = ++ts;
    return Py_None;
}
static const char* __Pyx_BufFmt_CheckString(__Pyx_BufFmt_Context* ctx, const char* ts) {
  int got_Z = 0;
  while (1) {
    switch(*ts) {
      case 0:
        if (ctx->enc_type != 0 && ctx->head == NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        if (ctx->head != NULL) {
          __Pyx_BufFmt_RaiseExpected(ctx);
          return NULL;
        }
                return ts;
      case ' ':
      case 10:
      case 13:
        ++ts;
        break;
      case '<':
        if (!__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Little-endian buffer not supported on big-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '>':
      case '!':
        if (__Pyx_IsLittleEndian()) {
          PyErr_SetString(PyExc_ValueError, "Big-endian buffer not supported on little-endian compiler");
          return NULL;
        }
        ctx->new_packmode = '=';
        ++ts;
        break;
      case '=':
      case '@':
      case '^':
        ctx->new_packmode = *ts++;
        break;
      case 'T': /* substruct */
        {
          const char* ts_after_sub;
          size_t i, struct_count = ctx->new_count;
          size_t struct_alignment = ctx->struct_alignment;
          ctx->new_count = 1;
          ++ts;
          if (*ts != '{') {
            PyErr_SetString(PyExc_ValueError, "Buffer acquisition: Expected '{' after 'T'");
            return NULL;
          }
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0; /* Erase processed last struct element */
          ctx->enc_count = 0;
          ctx->struct_alignment = 0;
          ++ts;
          ts_after_sub = ts;
          for (i = 0; i != struct_count; ++i) {
            ts_after_sub = __Pyx_BufFmt_CheckString(ctx, ts);
            if (!ts_after_sub) return NULL;
          }
          ts = ts_after_sub;
          if (struct_alignment) ctx->struct_alignment = struct_alignment;
        }
        break;
      case '}': /* end of substruct; either repeat or move on */
        {
          size_t alignment = ctx->struct_alignment;
          ++ts;
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_type = 0; /* Erase processed last struct element */
          if (alignment && ctx->fmt_offset % alignment) {
            ctx->fmt_offset += alignment - (ctx->fmt_offset % alignment);
          }
        }
        return ts;
      case 'x':
        if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
        ctx->fmt_offset += ctx->new_count;
        ctx->new_count = 1;
        ctx->enc_count = 0;
        ctx->enc_type = 0;
        ctx->enc_packmode = ctx->new_packmode;
        ++ts;
        break;
      case 'Z':
        got_Z = 1;
        ++ts;
        if (*ts != 'f' && *ts != 'd' && *ts != 'g') {
          __Pyx_BufFmt_RaiseUnexpectedChar('Z');
          return NULL;
        }        /* fall through */
      case 'c': case 'b': case 'B': case 'h': case 'H': case 'i': case 'I':
      case 'l': case 'L': case 'q': case 'Q':
      case 'f': case 'd': case 'g':
      case 'O': case 's': case 'p':
        if (ctx->enc_type == *ts && got_Z == ctx->is_complex &&
            ctx->enc_packmode == ctx->new_packmode) {
          ctx->enc_count += ctx->new_count;
        } else {
          if (__Pyx_BufFmt_ProcessTypeChunk(ctx) == -1) return NULL;
          ctx->enc_count = ctx->new_count;
          ctx->enc_packmode = ctx->new_packmode;
          ctx->enc_type = *ts;
          ctx->is_complex = got_Z;
        }
        ++ts;
        ctx->new_count = 1;
        got_Z = 0;
        break;
      case ':':
        ++ts;
        while(*ts != ':') ++ts;
        ++ts;
        break;
      case '(':
        if (!__pyx_buffmt_parse_array(ctx, &ts)) return NULL;
        break;
      default:
        {
          int number = __Pyx_BufFmt_ExpectNumber(&ts);
          if (number == -1) return NULL;
          ctx->new_count = (size_t)number;
        }
    }
  }
}
static CYTHON_INLINE void __Pyx_ZeroBuffer(Py_buffer* buf) {
  buf->buf = NULL;
  buf->obj = NULL;
  buf->strides = __Pyx_zeros;
  buf->shape = __Pyx_zeros;
  buf->suboffsets = __Pyx_minusones;
}
static CYTHON_INLINE int __Pyx_GetBufferAndValidate(
        Py_buffer* buf, PyObject* obj,  __Pyx_TypeInfo* dtype, int flags,
        int nd, int cast, __Pyx_BufFmt_StackElem* stack)
{
  if (obj == Py_None || obj == NULL) {
    __Pyx_ZeroBuffer(buf);
    return 0;
  }
  buf->buf = NULL;
  if (__Pyx_GetBuffer(obj, buf, flags) == -1) goto fail;
  if (buf->ndim != nd) {
    PyErr_Format(PyExc_ValueError,
                 "Buffer has wrong number of dimensions (expected %d, got %d)",
                 nd, buf->ndim);
    goto fail;
  }
  if (!cast) {
    __Pyx_BufFmt_Context ctx;
    __Pyx_BufFmt_Init(&ctx, stack, dtype);
    if (!__Pyx_BufFmt_CheckString(&ctx, buf->format)) goto fail;
  }
  if ((unsigned)buf->itemsize != dtype->size) {
    PyErr_Format(PyExc_ValueError,
      "Item size of buffer (%" CYTHON_FORMAT_SSIZE_T "d byte%s) does not match size of '%s' (%" CYTHON_FORMAT_SSIZE_T "d byte%s)",
      buf->itemsize, (buf->itemsize > 1) ? "s" : "",
      dtype->name, (Py_ssize_t)dtype->size, (dtype->size > 1) ? "s" : "");
    goto fail;
  }
  if (buf->suboffsets == NULL) buf->suboffsets = __Pyx_minusones;
  return 0;
fail:;
  __Pyx_ZeroBuffer(buf);
  return -1;
}
static CYTHON_INLINE void __Pyx_SafeReleaseBuffer(Py_buffer* info) {
  if (info->buf == NULL) return;
  if (info->suboffsets == __Pyx_minusones) info->suboffsets = NULL;
  __Pyx_ReleaseBuffer(info);
}

static void __Pyx_RaiseBufferFallbackError(void) {
  PyErr_Format(PyExc_ValueError,
     "Buffer acquisition failed on assignment; and then reacquiring the old buffer failed too!");
}

static void __Pyx_RaiseBufferIndexError(int axis) {
  PyErr_Format(PyExc_IndexError,
     "Out of bounds on buffer access (axis %d)", axis);
}

static CYTHON_INLINE void __Pyx_RaiseNoneNotIterableError(void) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
}

static CYTHON_INLINE PyObject *__Pyx_PyInt_to_py_Py_intptr_t(Py_intptr_t val) {
    const Py_intptr_t neg_one = (Py_intptr_t)-1, const_zero = (Py_intptr_t)0;
    const int is_unsigned = const_zero < neg_one;
    if ((sizeof(Py_intptr_t) == sizeof(char))  ||
        (sizeof(Py_intptr_t) == sizeof(short))) {
        return PyInt_FromLong((long)val);
    } else if ((sizeof(Py_intptr_t) == sizeof(int)) ||
               (sizeof(Py_intptr_t) == sizeof(long))) {
        if (is_unsigned)
            return PyLong_FromUnsignedLong((unsigned long)val);
        else
            return PyInt_FromLong((long)val);
    } else if (sizeof(Py_intptr_t) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG)val);
        else
            return PyLong_FromLongLong((PY_LONG_LONG)val);
    } else {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&val;
        return _PyLong_FromByteArray(bytes, sizeof(Py_intptr_t),
                                     little, !is_unsigned);
    }
}

static CYTHON_INLINE void __Pyx_ExceptionSave(PyObject **type, PyObject **value, PyObject **tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyThreadState *tstate = PyThreadState_GET();
    *type = tstate->exc_type;
    *value = tstate->exc_value;
    *tb = tstate->exc_traceback;
    Py_XINCREF(*type);
    Py_XINCREF(*value);
    Py_XINCREF(*tb);
#else
    PyErr_GetExcInfo(type, value, tb);
#endif
}
static void __Pyx_ExceptionReset(PyObject *type, PyObject *value, PyObject *tb) {
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    PyThreadState *tstate = PyThreadState_GET();
    tmp_type = tstate->exc_type;
    tmp_value = tstate->exc_value;
    tmp_tb = tstate->exc_traceback;
    tstate->exc_type = type;
    tstate->exc_value = value;
    tstate->exc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
#else
    PyErr_SetExcInfo(type, value, tb);
#endif
}

#if PY_MAJOR_VERSION < 3
static int __Pyx_GetBuffer(PyObject *obj, Py_buffer *view, int flags) {
    CYTHON_UNUSED PyObject *getbuffer_cobj;
  #if PY_VERSION_HEX >= 0x02060000
    if (PyObject_CheckBuffer(obj)) return PyObject_GetBuffer(obj, view, flags);
  #endif
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) return __pyx_pw_5numpy_7ndarray_1__getbuffer__(obj, view, flags);
  #if PY_VERSION_HEX < 0x02060000
    if (obj->ob_type->tp_dict &&
        (getbuffer_cobj = PyMapping_GetItemString(obj->ob_type->tp_dict,
                                             "__pyx_getbuffer"))) {
        getbufferproc func;
      #if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION == 0)
        func = (getbufferproc) PyCapsule_GetPointer(getbuffer_cobj, "getbuffer(obj, view, flags)");
      #else
        func = (getbufferproc) PyCObject_AsVoidPtr(getbuffer_cobj);
      #endif
        Py_DECREF(getbuffer_cobj);
        if (!func)
            goto fail;
        return func(obj, view, flags);
    } else {
        PyErr_Clear();
    }
  #endif
    PyErr_Format(PyExc_TypeError, "'%100s' does not have the buffer interface", Py_TYPE(obj)->tp_name);
#if PY_VERSION_HEX < 0x02060000
fail:
#endif
    return -1;
}
static void __Pyx_ReleaseBuffer(Py_buffer *view) {
    PyObject *obj = view->obj;
    CYTHON_UNUSED PyObject *releasebuffer_cobj;
    if (!obj) return;
  #if PY_VERSION_HEX >= 0x02060000
    if (PyObject_CheckBuffer(obj)) {
        PyBuffer_Release(view);
        return;
    }
  #endif
        if (PyObject_TypeCheck(obj, __pyx_ptype_5numpy_ndarray)) { __pyx_pw_5numpy_7ndarray_3__releasebuffer__(obj, view); return; }
  #if PY_VERSION_HEX < 0x02060000
    if (obj->ob_type->tp_dict &&
        (releasebuffer_cobj = PyMapping_GetItemString(obj->ob_type->tp_dict,
                                                      "__pyx_releasebuffer"))) {
        releasebufferproc func;
      #if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION == 3 && PY_MINOR_VERSION == 0)
        func = (releasebufferproc) PyCapsule_GetPointer(releasebuffer_cobj, "releasebuffer(obj, view)");
      #else
        func = (releasebufferproc) PyCObject_AsVoidPtr(releasebuffer_cobj);
      #endif
        Py_DECREF(releasebuffer_cobj);
        if (!func)
            goto fail;
        func(obj, view);
        return;
    } else {
        PyErr_Clear();
    }
  #endif
    goto nofail;
#if PY_VERSION_HEX < 0x02060000
fail:
#endif
    PyErr_WriteUnraisable(obj);
nofail:
    Py_DECREF(obj);
    view->obj = NULL;
}
#endif /*  PY_MAJOR_VERSION < 3 */


    static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, long level) {
    PyObject *py_import = 0;
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    py_import = __Pyx_GetAttrString(__pyx_b, "__import__");
    if (!py_import)
        goto bad;
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    #if PY_VERSION_HEX >= 0x02050000
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if (strchr(__Pyx_MODULE_NAME, '.')) {
                /* try package relative import first */
                PyObject *py_level = PyInt_FromLong(1);
                if (!py_level)
                    goto bad;
                module = PyObject_CallFunctionObjArgs(py_import,
                    name, global_dict, empty_dict, list, py_level, NULL);
                Py_DECREF(py_level);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0; /* try absolute import on failure */
        }
        #endif
        if (!module) {
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, NULL);
            Py_DECREF(py_level);
        }
    }
    #else
    if (level>0) {
        PyErr_SetString(PyExc_RuntimeError, "Relative import is not supported for Python <=2.4.");
        goto bad;
    }
    module = PyObject_CallFunctionObjArgs(py_import,
        name, global_dict, empty_dict, list, NULL);
    #endif
bad:
    Py_XDECREF(empty_list);
    Py_XDECREF(py_import);
    Py_XDECREF(empty_dict);
    return module;
}

static CYTHON_INLINE Py_intptr_t __Pyx_PyInt_from_py_Py_intptr_t(PyObject* x) {
    const Py_intptr_t neg_one = (Py_intptr_t)-1, const_zero = (Py_intptr_t)0;
    const int is_unsigned = const_zero < neg_one;
    if (sizeof(Py_intptr_t) == sizeof(char)) {
        if (is_unsigned)
            return (Py_intptr_t)__Pyx_PyInt_AsUnsignedChar(x);
        else
            return (Py_intptr_t)__Pyx_PyInt_AsSignedChar(x);
    } else if (sizeof(Py_intptr_t) == sizeof(short)) {
        if (is_unsigned)
            return (Py_intptr_t)__Pyx_PyInt_AsUnsignedShort(x);
        else
            return (Py_intptr_t)__Pyx_PyInt_AsSignedShort(x);
    } else if (sizeof(Py_intptr_t) == sizeof(int)) {
        if (is_unsigned)
            return (Py_intptr_t)__Pyx_PyInt_AsUnsignedInt(x);
        else
            return (Py_intptr_t)__Pyx_PyInt_AsSignedInt(x);
    } else if (sizeof(Py_intptr_t) == sizeof(long)) {
        if (is_unsigned)
            return (Py_intptr_t)__Pyx_PyInt_AsUnsignedLong(x);
        else
            return (Py_intptr_t)__Pyx_PyInt_AsSignedLong(x);
    } else if (sizeof(Py_intptr_t) == sizeof(PY_LONG_LONG)) {
        if (is_unsigned)
            return (Py_intptr_t)__Pyx_PyInt_AsUnsignedLongLong(x);
        else
            return (Py_intptr_t)__Pyx_PyInt_AsSignedLongLong(x);
    }  else {
        #if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
        PyErr_SetString(PyExc_RuntimeError,
                        "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
        #else
        Py_intptr_t val;
        PyObject *v = __Pyx_PyNumber_Int(x);
        #if PY_VERSION_HEX < 0x03000000
        if (likely(v) && !PyLong_Check(v)) {
            PyObject *tmp = v;
            v = PyNumber_Long(tmp);
            Py_DECREF(tmp);
        }
        #endif
        if (likely(v)) {
            int one = 1; int is_little = (int)*(unsigned char *)&one;
            unsigned char *bytes = (unsigned char *)&val;
            int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                          bytes, sizeof(val),
                                          is_little, !is_unsigned);
            Py_DECREF(v);
            if (likely(!ret))
                return val;
        }
        #endif
        return (Py_intptr_t)-1;
    }
}

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return ::std::complex< float >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      return x + y*(__pyx_t_float_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_float_complex __pyx_t_float_complex_from_parts(float x, float y) {
      __pyx_t_float_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eqf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_sumf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_difff(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_prodf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_quotf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
        __pyx_t_float_complex z;
        float denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_negf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zerof(__pyx_t_float_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_conjf(__pyx_t_float_complex a) {
        __pyx_t_float_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE float __Pyx_c_absf(__pyx_t_float_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrtf(z.real*z.real + z.imag*z.imag);
          #else
            return hypotf(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_float_complex __Pyx_c_powf(__pyx_t_float_complex a, __pyx_t_float_complex b) {
            __pyx_t_float_complex z;
            float r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    float denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(a, a);
                    case 3:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, a);
                    case 4:
                        z = __Pyx_c_prodf(a, a);
                        return __Pyx_c_prodf(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_absf(a);
                theta = atan2f(a.imag, a.real);
            }
            lnr = logf(r);
            z_r = expf(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cosf(z_theta);
            z.imag = z_r * sinf(z_theta);
            return z;
        }
    #endif
#endif

#if CYTHON_CCOMPLEX
  #ifdef __cplusplus
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return ::std::complex< double >(x, y);
    }
  #else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      return x + y*(__pyx_t_double_complex)_Complex_I;
    }
  #endif
#else
    static CYTHON_INLINE __pyx_t_double_complex __pyx_t_double_complex_from_parts(double x, double y) {
      __pyx_t_double_complex z;
      z.real = x;
      z.imag = y;
      return z;
    }
#endif

#if CYTHON_CCOMPLEX
#else
    static CYTHON_INLINE int __Pyx_c_eq(__pyx_t_double_complex a, __pyx_t_double_complex b) {
       return (a.real == b.real) && (a.imag == b.imag);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_sum(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real + b.real;
        z.imag = a.imag + b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_diff(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real - b.real;
        z.imag = a.imag - b.imag;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_prod(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        z.real = a.real * b.real - a.imag * b.imag;
        z.imag = a.real * b.imag + a.imag * b.real;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_quot(__pyx_t_double_complex a, __pyx_t_double_complex b) {
        __pyx_t_double_complex z;
        double denom = b.real * b.real + b.imag * b.imag;
        z.real = (a.real * b.real + a.imag * b.imag) / denom;
        z.imag = (a.imag * b.real - a.real * b.imag) / denom;
        return z;
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_neg(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real = -a.real;
        z.imag = -a.imag;
        return z;
    }
    static CYTHON_INLINE int __Pyx_c_is_zero(__pyx_t_double_complex a) {
       return (a.real == 0) && (a.imag == 0);
    }
    static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_conj(__pyx_t_double_complex a) {
        __pyx_t_double_complex z;
        z.real =  a.real;
        z.imag = -a.imag;
        return z;
    }
    #if 1
        static CYTHON_INLINE double __Pyx_c_abs(__pyx_t_double_complex z) {
          #if !defined(HAVE_HYPOT) || defined(_MSC_VER)
            return sqrt(z.real*z.real + z.imag*z.imag);
          #else
            return hypot(z.real, z.imag);
          #endif
        }
        static CYTHON_INLINE __pyx_t_double_complex __Pyx_c_pow(__pyx_t_double_complex a, __pyx_t_double_complex b) {
            __pyx_t_double_complex z;
            double r, lnr, theta, z_r, z_theta;
            if (b.imag == 0 && b.real == (int)b.real) {
                if (b.real < 0) {
                    double denom = a.real * a.real + a.imag * a.imag;
                    a.real = a.real / denom;
                    a.imag = -a.imag / denom;
                    b.real = -b.real;
                }
                switch ((int)b.real) {
                    case 0:
                        z.real = 1;
                        z.imag = 0;
                        return z;
                    case 1:
                        return a;
                    case 2:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(a, a);
                    case 3:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, a);
                    case 4:
                        z = __Pyx_c_prod(a, a);
                        return __Pyx_c_prod(z, z);
                }
            }
            if (a.imag == 0) {
                if (a.real == 0) {
                    return a;
                }
                r = a.real;
                theta = 0;
            } else {
                r = __Pyx_c_abs(a);
                theta = atan2(a.imag, a.real);
            }
            lnr = log(r);
            z_r = exp(lnr * b.real - theta * b.imag);
            z_theta = theta * b.real + lnr * b.imag;
            z.real = z_r * cos(z_theta);
            z.imag = z_r * sin(z_theta);
            return z;
        }
    #endif
#endif

static CYTHON_INLINE unsigned char __Pyx_PyInt_AsUnsignedChar(PyObject* x) {
    const unsigned char neg_one = (unsigned char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned char" :
                    "value too large to convert to unsigned char");
            }
            return (unsigned char)-1;
        }
        return (unsigned char)val;
    }
    return (unsigned char)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned short __Pyx_PyInt_AsUnsignedShort(PyObject* x) {
    const unsigned short neg_one = (unsigned short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned short" :
                    "value too large to convert to unsigned short");
            }
            return (unsigned short)-1;
        }
        return (unsigned short)val;
    }
    return (unsigned short)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE unsigned int __Pyx_PyInt_AsUnsignedInt(PyObject* x) {
    const unsigned int neg_one = (unsigned int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(unsigned int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(unsigned int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to unsigned int" :
                    "value too large to convert to unsigned int");
            }
            return (unsigned int)-1;
        }
        return (unsigned int)val;
    }
    return (unsigned int)__Pyx_PyInt_AsUnsignedLong(x);
}

static CYTHON_INLINE char __Pyx_PyInt_AsChar(PyObject* x) {
    const char neg_one = (char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to char" :
                    "value too large to convert to char");
            }
            return (char)-1;
        }
        return (char)val;
    }
    return (char)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE short __Pyx_PyInt_AsShort(PyObject* x) {
    const short neg_one = (short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to short" :
                    "value too large to convert to short");
            }
            return (short)-1;
        }
        return (short)val;
    }
    return (short)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsInt(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE signed char __Pyx_PyInt_AsSignedChar(PyObject* x) {
    const signed char neg_one = (signed char)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed char) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed char)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed char" :
                    "value too large to convert to signed char");
            }
            return (signed char)-1;
        }
        return (signed char)val;
    }
    return (signed char)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed short __Pyx_PyInt_AsSignedShort(PyObject* x) {
    const signed short neg_one = (signed short)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed short) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed short)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed short" :
                    "value too large to convert to signed short");
            }
            return (signed short)-1;
        }
        return (signed short)val;
    }
    return (signed short)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE signed int __Pyx_PyInt_AsSignedInt(PyObject* x) {
    const signed int neg_one = (signed int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(signed int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(signed int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to signed int" :
                    "value too large to convert to signed int");
            }
            return (signed int)-1;
        }
        return (signed int)val;
    }
    return (signed int)__Pyx_PyInt_AsSignedLong(x);
}

static CYTHON_INLINE int __Pyx_PyInt_AsLongDouble(PyObject* x) {
    const int neg_one = (int)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
    if (sizeof(int) < sizeof(long)) {
        long val = __Pyx_PyInt_AsLong(x);
        if (unlikely(val != (long)(int)val)) {
            if (!unlikely(val == -1 && PyErr_Occurred())) {
                PyErr_SetString(PyExc_OverflowError,
                    (is_unsigned && unlikely(val < 0)) ?
                    "can't convert negative value to int" :
                    "value too large to convert to int");
            }
            return (int)-1;
        }
        return (int)val;
    }
    return (int)__Pyx_PyInt_AsLong(x);
}

static CYTHON_INLINE unsigned long __Pyx_PyInt_AsUnsignedLong(PyObject* x) {
    const unsigned long neg_one = (unsigned long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned long");
            return (unsigned long)-1;
        }
        return (unsigned long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned long");
                return (unsigned long)-1;
            }
            return (unsigned long)PyLong_AsUnsignedLong(x);
        } else {
            return (unsigned long)PyLong_AsLong(x);
        }
    } else {
        unsigned long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned long)-1;
        val = __Pyx_PyInt_AsUnsignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE unsigned PY_LONG_LONG __Pyx_PyInt_AsUnsignedLongLong(PyObject* x) {
    const unsigned PY_LONG_LONG neg_one = (unsigned PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to unsigned PY_LONG_LONG");
            return (unsigned PY_LONG_LONG)-1;
        }
        return (unsigned PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to unsigned PY_LONG_LONG");
                return (unsigned PY_LONG_LONG)-1;
            }
            return (unsigned PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (unsigned PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        unsigned PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (unsigned PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsUnsignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE long __Pyx_PyInt_AsLong(PyObject* x) {
    const long neg_one = (long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to long");
            return (long)-1;
        }
        return (long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to long");
                return (long)-1;
            }
            return (long)PyLong_AsUnsignedLong(x);
        } else {
            return (long)PyLong_AsLong(x);
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (long)-1;
        val = __Pyx_PyInt_AsLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE PY_LONG_LONG __Pyx_PyInt_AsLongLong(PyObject* x) {
    const PY_LONG_LONG neg_one = (PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to PY_LONG_LONG");
            return (PY_LONG_LONG)-1;
        }
        return (PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to PY_LONG_LONG");
                return (PY_LONG_LONG)-1;
            }
            return (PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed long __Pyx_PyInt_AsSignedLong(PyObject* x) {
    const signed long neg_one = (signed long)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed long");
            return (signed long)-1;
        }
        return (signed long)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed long");
                return (signed long)-1;
            }
            return (signed long)PyLong_AsUnsignedLong(x);
        } else {
            return (signed long)PyLong_AsLong(x);
        }
    } else {
        signed long val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed long)-1;
        val = __Pyx_PyInt_AsSignedLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static CYTHON_INLINE signed PY_LONG_LONG __Pyx_PyInt_AsSignedLongLong(PyObject* x) {
    const signed PY_LONG_LONG neg_one = (signed PY_LONG_LONG)-1, const_zero = 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_VERSION_HEX < 0x03000000
    if (likely(PyInt_Check(x))) {
        long val = PyInt_AS_LONG(x);
        if (is_unsigned && unlikely(val < 0)) {
            PyErr_SetString(PyExc_OverflowError,
                            "can't convert negative value to signed PY_LONG_LONG");
            return (signed PY_LONG_LONG)-1;
        }
        return (signed PY_LONG_LONG)val;
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
            if (unlikely(Py_SIZE(x) < 0)) {
                PyErr_SetString(PyExc_OverflowError,
                                "can't convert negative value to signed PY_LONG_LONG");
                return (signed PY_LONG_LONG)-1;
            }
            return (signed PY_LONG_LONG)PyLong_AsUnsignedLongLong(x);
        } else {
            return (signed PY_LONG_LONG)PyLong_AsLongLong(x);
        }
    } else {
        signed PY_LONG_LONG val;
        PyObject *tmp = __Pyx_PyNumber_Int(x);
        if (!tmp) return (signed PY_LONG_LONG)-1;
        val = __Pyx_PyInt_AsSignedLongLong(tmp);
        Py_DECREF(tmp);
        return val;
    }
}

static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
}

static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        #if PY_VERSION_HEX < 0x02050000
        return PyErr_Warn(NULL, message);
        #else
        return PyErr_WarnEx(NULL, message, 1);
        #endif
    }
    return 0;
}

static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000 && !(PY_MAJOR_VERSION==3&&PY_MINOR_VERSION==0)
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItemString(dict, "__pyx_vtable__", ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

#ifndef __PYX_HAVE_RT_ImportModule
#define __PYX_HAVE_RT_ImportModule
static PyObject *__Pyx_ImportModule(const char *name) {
    PyObject *py_name = 0;
    PyObject *py_module = 0;
    py_name = __Pyx_PyIdentifier_FromString(name);
    if (!py_name)
        goto bad;
    py_module = PyImport_Import(py_name);
    Py_DECREF(py_name);
    return py_module;
bad:
    Py_XDECREF(py_name);
    return 0;
}
#endif

#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(const char *module_name, const char *class_name,
    size_t size, int strict)
{
    PyObject *py_module = 0;
    PyObject *result = 0;
    PyObject *py_name = 0;
    char warning[200];
    py_module = __Pyx_ImportModule(module_name);
    if (!py_module)
        goto bad;
    py_name = __Pyx_PyIdentifier_FromString(class_name);
    if (!py_name)
        goto bad;
    result = PyObject_GetAttr(py_module, py_name);
    Py_DECREF(py_name);
    py_name = 0;
    Py_DECREF(py_module);
    py_module = 0;
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%s.%s is not a type object",
            module_name, class_name);
        goto bad;
    }
    if (!strict && (size_t)((PyTypeObject *)result)->tp_basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility",
            module_name, class_name);
        #if PY_VERSION_HEX < 0x02050000
        if (PyErr_Warn(NULL, warning) < 0) goto bad;
        #else
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
        #endif
    }
    else if ((size_t)((PyTypeObject *)result)->tp_basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%s.%s has the wrong size, try recompiling",
            module_name, class_name);
        goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(py_module);
    Py_XDECREF(result);
    return NULL;
}
#endif

static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = (start + end) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, new_max*sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,            /*int argcount,*/
        0,            /*int kwonlyargcount,*/
        0,            /*int nlocals,*/
        0,            /*int stacksize,*/
        0,            /*int flags,*/
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,      /*int firstlineno,*/
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_globals = 0;
    PyFrameObject *py_frame = 0;
    py_code = __pyx_find_code_object(c_line ? c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? c_line : py_line, py_code);
    }
    py_globals = PyModule_GetDict(__pyx_m);
    if (!py_globals) goto bad;
    py_frame = PyFrame_New(
        PyThreadState_GET(), /*PyThreadState *tstate,*/
        py_code,             /*PyCodeObject *code,*/
        py_globals,          /*PyObject *globals,*/
        0                    /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    py_frame->f_lineno = py_line;
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else  /* Python 3+ has unicode identifiers */
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        ++t;
    }
    return 0;
}


/* Type Conversion Functions */

static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}

static CYTHON_INLINE PyObject* __Pyx_PyNumber_Int(PyObject* x) {
  PyNumberMethods *m;
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_VERSION_HEX < 0x03000000
  if (PyInt_Check(x) || PyLong_Check(x))
#else
  if (PyLong_Check(x))
#endif
    return Py_INCREF(x), x;
  m = Py_TYPE(x)->tp_as_number;
#if PY_VERSION_HEX < 0x03000000
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = PyNumber_Long(x);
  }
#else
  if (m && m->nb_int) {
    name = "int";
    res = PyNumber_Long(x);
  }
#endif
  if (res) {
#if PY_VERSION_HEX < 0x03000000
    if (!PyInt_Check(res) && !PyLong_Check(res)) {
#else
    if (!PyLong_Check(res)) {
#endif
      PyErr_Format(PyExc_TypeError,
                   "__%s__ returned non-%s (type %.200s)",
                   name, name, Py_TYPE(res)->tp_name);
      Py_DECREF(res);
      return NULL;
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}

static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject* x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}

static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
#if PY_VERSION_HEX < 0x02050000
   if (ival <= LONG_MAX)
       return PyInt_FromLong((long)ival);
   else {
       unsigned char *bytes = (unsigned char *) &ival;
       int one = 1; int little = (int)*(unsigned char*)&one;
       return _PyLong_FromByteArray(bytes, sizeof(size_t), little, 0);
   }
#else
   return PyInt_FromSize_t(ival);
#endif
}

static CYTHON_INLINE size_t __Pyx_PyInt_AsSize_t(PyObject* x) {
   unsigned PY_LONG_LONG val = __Pyx_PyInt_AsUnsignedLongLong(x);
   if (unlikely(val == (unsigned PY_LONG_LONG)-1 && PyErr_Occurred())) {
       return (size_t)-1;
   } else if (unlikely(val != (unsigned PY_LONG_LONG)(size_t)val)) {
       PyErr_SetString(PyExc_OverflowError,
                       "value too large to convert to size_t");
       return (size_t)-1;
   }
   return (size_t)val;
}


#endif /* Py_PYTHON_H */
